/*===========================================================================================================
                                                                          
    ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
    AUTHOR: P. Barrett Wheeler                  
    JOURNAL OF ACCOUNTING RESEARCH 

 	The code below uses National Information Center (NIC) data to determine the top regulatory ID for each 
	bank (i.e., the RSSDID of it's ultimate parent) in current and future periods. This is necessary to 
	control for mergers and acquisition when establishing the time series of a bank's loan originations.
	For example, the loan originations of Wachovia Corporation are included in the time series of Wells
	Fargo's loan originations after the acquisition of Wachovia on December 31, 2008. Prior to the
	acquisition, Wachovia's top RSSDID was 1073551. After the acquisition, Wachovia's top RSSDID 
	became 1120754 (i.e., the RSSDID of Wells Fargo).

 ============================================================================================================*/

libname nic 'C:\Users\pwheeler1\Box Sync\Data Sets\NIC Data';

proc sql;
create table rssdid_linktable as select a.*, b.successor_name as successor1_name, b.id_rssd_successor as successor1_rssdid, b.dt_trans as acq1_date
from box.rssdid_crsp_linktable_2016q4 as a left join nic.transformations_names_20180331 as b
on a.entity=b.id_rssd_predecessor order by name;
quit;
proc sql;
create table rssdid_linktable2 as select a.*, b.successor_name as successor2_name, b.id_rssd_successor as successor2_rssdid, b.dt_trans as acq2_date
from rssdid_linktable as a left join nic.transformations_names_20180331 as b
on a.successor1_rssdid=b.id_rssd_predecessor order by name;
quit;

data bank_attributes_active (keep=dt_start dt_end nm_lgl prim_fed_reg id_fdic_cert id_occ id_thrift id_rssd);
set nic.attributes_active_20180331;
run;
data bank_attributes_inactive (keep=dt_start dt_end nm_lgl prim_fed_reg id_fdic_cert id_occ id_thrift id_rssd);
set nic.attributes_inactive_20180331;
run;
data bank_attributes_branch (keep=dt_start dt_end nm_lgl prim_fed_reg id_fdic_cert id_occ id_thrift id_rssd);
set nic.attributes_branch_20180331;
run;
data bank_attributes;
set bank_attributes_active bank_attributes_inactive bank_attributes_branch;
run;

data nic.bank_attributes_aggregate;
set bank_attributes;
if prim_fed_reg = 'FDIC' then hmda_resp_id=put(id_fdic_cert,z10.);
if prim_fed_reg = 'OCC' then hmda_resp_id=put(id_occ,z10.);
if prim_fed_reg = 'FRS' then hmda_resp_id=put(id_rssd,z10.);
if prim_fed_reg = 'OTS' then hmda_resp_id=put(id_thrift,z10.);
run;
proc sort data=nic.bank_attributes_aggregate;
by id_rssd;
run;
proc sql;
create table bank_attributes2 as select a.*, b.successor_name as successor1_name, b.id_rssd_successor as successor1_rssdid, b.dt_trans as acq1_date
from nic.bank_attributes_aggregate as a left join nic.transformations_names_20180331 as b
on a.id_rssd=b.id_rssd_predecessor order by nm_lgl;

create table bank_attributes3 as select a.*, b.successor_name as successor2_name, b.id_rssd_successor as successor2_rssdid, b.dt_trans as acq2_date
from bank_attributes2 as a left join nic.transformations_names_20180331 as b
on a.successor1_rssdid=b.id_rssd_predecessor and b.dt_trans>acq1_date order by nm_lgl;

create table bank_attributes4 as select a.*, b.successor_name as successor3_name, b.id_rssd_successor as successor3_rssdid, b.dt_trans as acq3_date
from bank_attributes3 as a left join nic.transformations_names_20180331 as b
on a.successor2_rssdid=b.id_rssd_predecessor and b.dt_trans>acq2_date order by nm_lgl;

create table bank_attributes5 as select a.*, b.successor_name as successor4_name, b.id_rssd_successor as successor4_rssdid, b.dt_trans as acq4_date
from bank_attributes4 as a left join nic.transformations_names_20180331 as b
on a.successor3_rssdid=b.id_rssd_predecessor and b.dt_trans>acq3_date order by nm_lgl;

create table bank_attributes6 as select a.*, b.successor_name as successor5_name, b.id_rssd_successor as successor5_rssdid, b.dt_trans as acq5_date
from bank_attributes5 as a left join nic.transformations_names_20180331 as b
on a.successor4_rssdid=b.id_rssd_predecessor and b.dt_trans>acq4_date order by nm_lgl;

create table bank_attributes7 as select a.*, b.successor_name as successor6_name, b.id_rssd_successor as successor6_rssdid, b.dt_trans as acq6_date
from bank_attributes6 as a left join nic.transformations_names_20180331 as b
on a.successor5_rssdid=b.id_rssd_predecessor and b.dt_trans>acq5_date order by nm_lgl;

create table bank_attributes8 as select a.*, b.successor_name as successor7_name, b.id_rssd_successor as successor7_rssdid, b.dt_trans as acq7_date
from bank_attributes7 as a left join nic.transformations_names_20180331 as b
on a.successor6_rssdid=b.id_rssd_predecessor and b.dt_trans>acq6_date order by nm_lgl;

create table bank_attributes9 as select a.*, b.successor_name as successor8_name, b.id_rssd_successor as successor8_rssdid, b.dt_trans as acq8_date
from bank_attributes8 as a left join nic.transformations_names_20180331 as b
on a.successor7_rssdid=b.id_rssd_predecessor and b.dt_trans>acq7_date order by nm_lgl;

create table bank_attributes10 as select a.*, b.successor_name as successor9_name, b.id_rssd_successor as successor9_rssdid, b.dt_trans as acq9_date
from bank_attributes9 as a left join nic.transformations_names_20180331 as b
on a.successor8_rssdid=b.id_rssd_predecessor and b.dt_trans>acq8_date order by nm_lgl;
quit;
*bank_attributes10;
data banksacq;
set bank_attributes10;
if successor7_rssdid = . then delete;
run;

data box.top_regid_byperiod_2017;
set bank_attributes10;
/*2017*/
if (acq9_date ne . and acq9_date < 20171231) then topid_20171231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20171231) then topid_20171231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20171231) then topid_20171231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20171231) then topid_20171231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20171231) then topid_20171231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20171231) then topid_20171231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20171231) then topid_20171231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20171231) then topid_20171231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20171231) then topid_20171231=successor1_rssdid;
*else if dt_start > 20171231 then topid_20171231=.;
else topid_20171231=id_rssd;
if (acq9_date ne . and acq9_date < 20170930) then topid_20170930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20170930) then topid_20170930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20170930) then topid_20170930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20170930) then topid_20170930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20170930) then topid_20170930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20170930) then topid_20170930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20170930) then topid_20170930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20170930) then topid_20170930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20170930) then topid_20170930=successor1_rssdid;
*else if dt_start >20170930 then topid_20170930=.;
else topid_20170930=id_rssd;
if (acq9_date ne . and acq9_date < 20170630) then topid_20170630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20170630) then topid_20170630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20170630) then topid_20170630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20170630) then topid_20170630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20170630) then topid_20170630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20170630) then topid_20170630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20170630) then topid_20170630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20170630) then topid_20170630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20170630) then topid_20170630=successor1_rssdid;
*else if dt_start >20170630 then topid_20170630=.;
else topid_20170630=id_rssd;
if (acq9_date ne . and acq9_date < 20170331) then topid_20170331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20170331) then topid_20170331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20170331) then topid_20170331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20170331) then topid_20170331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20170331) then topid_20170331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20170331) then topid_20170331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20170331) then topid_20170331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20170331) then topid_20170331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20170331) then topid_20170331=successor1_rssdid;
*else if dt_start >20170331 then topid_20170331=.;
else topid_20170331=id_rssd;

/*2016*/
if (acq9_date ne . and acq9_date < 20161231) then topid_20161231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20161231) then topid_20161231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20161231) then topid_20161231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20161231) then topid_20161231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20161231) then topid_20161231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20161231) then topid_20161231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20161231) then topid_20161231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20161231) then topid_20161231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20161231) then topid_20161231=successor1_rssdid;
*else if dt_start > 20161231 then topid_20161231=.;
else topid_20161231=id_rssd;
if (acq9_date ne . and acq9_date < 20160930) then topid_20160930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20160930) then topid_20160930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20160930) then topid_20160930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20160930) then topid_20160930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20160930) then topid_20160930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20160930) then topid_20160930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20160930) then topid_20160930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20160930) then topid_20160930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20160930) then topid_20160930=successor1_rssdid;
*else if dt_start >20160930 then topid_20160930=.;
else topid_20160930=id_rssd;
if (acq9_date ne . and acq9_date < 20160630) then topid_20160630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20160630) then topid_20160630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20160630) then topid_20160630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20160630) then topid_20160630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20160630) then topid_20160630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20160630) then topid_20160630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20160630) then topid_20160630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20160630) then topid_20160630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20160630) then topid_20160630=successor1_rssdid;
*else if dt_start >20160630 then topid_20160630=.;
else topid_20160630=id_rssd;
if (acq9_date ne . and acq9_date < 20160331) then topid_20160331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20160331) then topid_20160331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20160331) then topid_20160331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20160331) then topid_20160331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20160331) then topid_20160331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20160331) then topid_20160331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20160331) then topid_20160331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20160331) then topid_20160331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20160331) then topid_20160331=successor1_rssdid;
*else if dt_start >20160331 then topid_20160331=.;
else topid_20160331=id_rssd;

/*2015*/
if (acq9_date ne . and acq9_date < 20151231) then topid_20151231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20151231) then topid_20151231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20151231) then topid_20151231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20151231) then topid_20151231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20151231) then topid_20151231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20151231) then topid_20151231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20151231) then topid_20151231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20151231) then topid_20151231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20151231) then topid_20151231=successor1_rssdid;
*else if dt_start > 20151231 then topid_20151231=.;
else topid_20151231=id_rssd;
if (acq9_date ne . and acq9_date < 20150930) then topid_20150930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20150930) then topid_20150930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20150930) then topid_20150930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20150930) then topid_20150930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20150930) then topid_20150930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20150930) then topid_20150930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20150930) then topid_20150930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20150930) then topid_20150930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20150930) then topid_20150930=successor1_rssdid;
*else if dt_start >20150930 then topid_20150930=.;
else topid_20150930=id_rssd;
if (acq9_date ne . and acq9_date < 20150630) then topid_20150630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20150630) then topid_20150630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20150630) then topid_20150630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20150630) then topid_20150630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20150630) then topid_20150630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20150630) then topid_20150630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20150630) then topid_20150630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20150630) then topid_20150630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20150630) then topid_20150630=successor1_rssdid;
*else if dt_start >20150630 then topid_20150630=.;
else topid_20150630=id_rssd;
if (acq9_date ne . and acq9_date < 20150331) then topid_20150331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20150331) then topid_20150331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20150331) then topid_20150331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20150331) then topid_20150331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20150331) then topid_20150331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20150331) then topid_20150331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20150331) then topid_20150331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20150331) then topid_20150331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20150331) then topid_20150331=successor1_rssdid;
*else if dt_start >20150331 then topid_20150331=.;
else topid_20150331=id_rssd;


/*2014*/
if (acq9_date ne . and acq9_date < 20141231) then topid_20141231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20141231) then topid_20141231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20141231) then topid_20141231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20141231) then topid_20141231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20141231) then topid_20141231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20141231) then topid_20141231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20141231) then topid_20141231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20141231) then topid_20141231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20141231) then topid_20141231=successor1_rssdid;
*else if dt_start > 20141231 then topid_20141231=.;
else topid_20141231=id_rssd;
if (acq9_date ne . and acq9_date < 20140930) then topid_20140930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20140930) then topid_20140930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20140930) then topid_20140930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20140930) then topid_20140930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20140930) then topid_20140930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20140930) then topid_20140930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20140930) then topid_20140930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20140930) then topid_20140930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20140930) then topid_20140930=successor1_rssdid;
*else if dt_start >20140930 then topid_20140930=.;
else topid_20140930=id_rssd;
if (acq9_date ne . and acq9_date < 20140630) then topid_20140630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20140630) then topid_20140630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20140630) then topid_20140630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20140630) then topid_20140630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20140630) then topid_20140630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20140630) then topid_20140630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20140630) then topid_20140630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20140630) then topid_20140630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20140630) then topid_20140630=successor1_rssdid;
*else if dt_start >20140630 then topid_20140630=.;
else topid_20140630=id_rssd;
if (acq9_date ne . and acq9_date < 20140331) then topid_20140331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20140331) then topid_20140331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20140331) then topid_20140331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20140331) then topid_20140331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20140331) then topid_20140331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20140331) then topid_20140331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20140331) then topid_20140331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20140331) then topid_20140331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20140331) then topid_20140331=successor1_rssdid;
*else if dt_start >20140331 then topid_20140331=.;
else topid_20140331=id_rssd;
/*2013*/
if (acq9_date ne . and acq9_date < 20131231) then topid_20131231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20131231) then topid_20131231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20131231) then topid_20131231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20131231) then topid_20131231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20131231) then topid_20131231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20131231) then topid_20131231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20131231) then topid_20131231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20131231) then topid_20131231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20131231) then topid_20131231=successor1_rssdid;
*else if dt_start >20131231 then topid_20131231=.;
else topid_20131231=id_rssd;
if (acq9_date ne . and acq9_date < 20130930) then topid_20130930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20130930) then topid_20130930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20130930) then topid_20130930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20130930) then topid_20130930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20130930) then topid_20130930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20130930) then topid_20130930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20130930) then topid_20130930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20130930) then topid_20130930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20130930) then topid_20130930=successor1_rssdid;
*else if dt_start >20130930 then topid_20130930=.;
else topid_20130930=id_rssd;
if (acq9_date ne . and acq9_date < 20130630) then topid_20130630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20130630) then topid_20130630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20130630) then topid_20130630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20130630) then topid_20130630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20130630) then topid_20130630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20130630) then topid_20130630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20130630) then topid_20130630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20130630) then topid_20130630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20130630) then topid_20130630=successor1_rssdid;
*else if dt_start >20130630 then topid_20130630=.;
else topid_20130630=id_rssd;
if (acq9_date ne . and acq9_date < 20130331) then topid_20130331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20130331) then topid_20130331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20130331) then topid_20130331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20130331) then topid_20130331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20130331) then topid_20130331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20130331) then topid_20130331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20130331) then topid_20130331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20130331) then topid_20130331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20130331) then topid_20130331=successor1_rssdid;
*else if dt_start >20130331 then topid_20130331=.;
else topid_20130331=id_rssd;
/*2012*/
if (acq9_date ne . and acq9_date < 20121231) then topid_20121231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20121231) then topid_20121231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20121231) then topid_20121231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20121231) then topid_20121231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20121231) then topid_20121231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20121231) then topid_20121231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20121231) then topid_20121231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20121231) then topid_20121231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20121231) then topid_20121231=successor1_rssdid;
*else if dt_start >20121231 then topid_20121231=.;
else topid_20121231=id_rssd;
if (acq9_date ne . and acq9_date < 20120930) then topid_20120930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20120930) then topid_20120930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20120930) then topid_20120930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20120930) then topid_20120930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20120930) then topid_20120930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20120930) then topid_20120930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20120930) then topid_20120930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20120930) then topid_20120930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20120930) then topid_20120930=successor1_rssdid;
*else if dt_start >20120930 then topid_20120930=.;
else topid_20120930=id_rssd;
if (acq9_date ne . and acq9_date < 20120630) then topid_20120630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20120630) then topid_20120630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20120630) then topid_20120630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20120630) then topid_20120630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20120630) then topid_20120630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20120630) then topid_20120630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20120630) then topid_20120630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20120630) then topid_20120630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20120630) then topid_20120630=successor1_rssdid;
*else if dt_start >20120630 then topid_20120630=.;
else topid_20120630=id_rssd;
if (acq9_date ne . and acq9_date < 20120331) then topid_20120331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20120331) then topid_20120331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20120331) then topid_20120331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20120331) then topid_20120331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20120331) then topid_20120331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20120331) then topid_20120331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20120331) then topid_20120331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20120331) then topid_20120331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20120331) then topid_20120331=successor1_rssdid;
*else if dt_start >20120331 then topid_20120331=.;
else topid_20120331=id_rssd;
/*2011*/
if (acq9_date ne . and acq9_date < 20111231) then topid_20111231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20111231) then topid_20111231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20111231) then topid_20111231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20111231) then topid_20111231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20111231) then topid_20111231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20111231) then topid_20111231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20111231) then topid_20111231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20111231) then topid_20111231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20111231) then topid_20111231=successor1_rssdid;
*else if dt_start >20111231 then topid_20111231=.;
else topid_20111231=id_rssd;
if (acq9_date ne . and acq9_date < 20110930) then topid_20110930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20110930) then topid_20110930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20110930) then topid_20110930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20110930) then topid_20110930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20110930) then topid_20110930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20110930) then topid_20110930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20110930) then topid_20110930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20110930) then topid_20110930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20110930) then topid_20110930=successor1_rssdid;
*else if dt_start >20110930 then topid_20110930=.;
else topid_20110930=id_rssd;
if (acq9_date ne . and acq9_date < 20110630) then topid_20110630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20110630) then topid_20110630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20110630) then topid_20110630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20110630) then topid_20110630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20110630) then topid_20110630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20110630) then topid_20110630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20110630) then topid_20110630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20110630) then topid_20110630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20110630) then topid_20110630=successor1_rssdid;
*else if dt_start >20110630 then topid_20110630=.;
else topid_20110630=id_rssd;
if (acq9_date ne . and acq9_date < 20110331) then topid_20110331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20110331) then topid_20110331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20110331) then topid_20110331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20110331) then topid_20110331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20110331) then topid_20110331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20110331) then topid_20110331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20110331) then topid_20110331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20110331) then topid_20110331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20110331) then topid_20110331=successor1_rssdid;
*else if dt_start >20110331 then topid_20110331=.;
else topid_20110331=id_rssd;
/*2010*/
if (acq9_date ne . and acq9_date < 20101231) then topid_20101231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20101231) then topid_20101231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20101231) then topid_20101231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20101231) then topid_20101231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20101231) then topid_20101231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20101231) then topid_20101231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20101231) then topid_20101231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20101231) then topid_20101231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20101231) then topid_20101231=successor1_rssdid;
*else if dt_start >20101231 then topid_20101231=.;
else topid_20101231=id_rssd;
if (acq9_date ne . and acq9_date < 20100930) then topid_20100930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20100930) then topid_20100930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20100930) then topid_20100930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20100930) then topid_20100930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20100930) then topid_20100930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20100930) then topid_20100930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20100930) then topid_20100930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20100930) then topid_20100930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20100930) then topid_20100930=successor1_rssdid;
*else if dt_start >20100930 then topid_20100930=.;
else topid_20100930=id_rssd;
if (acq9_date ne . and acq9_date < 20100630) then topid_20100630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20100630) then topid_20100630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20100630) then topid_20100630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20100630) then topid_20100630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20100630) then topid_20100630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20100630) then topid_20100630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20100630) then topid_20100630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20100630) then topid_20100630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20100630) then topid_20100630=successor1_rssdid;
*else if dt_start >20100630 then topid_20100630=.;
else topid_20100630=id_rssd;
if (acq9_date ne . and acq9_date < 20100331) then topid_20100331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20100331) then topid_20100331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20100331) then topid_20100331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20100331) then topid_20100331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20100331) then topid_20100331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20100331) then topid_20100331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20100331) then topid_20100331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20100331) then topid_20100331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20100331) then topid_20100331=successor1_rssdid;
*else if dt_start >20100331 then topid_20100331=.;
else topid_20100331=id_rssd;
/*2009*/
if (acq9_date ne . and acq9_date < 20091231) then topid_20091231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20091231) then topid_20091231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20091231) then topid_20091231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20091231) then topid_20091231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20091231) then topid_20091231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20091231) then topid_20091231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20091231) then topid_20091231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20091231) then topid_20091231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20091231) then topid_20091231=successor1_rssdid;
*else if dt_start >20091231 then topid_20091231=.;
else topid_20091231=id_rssd;
if (acq9_date ne . and acq9_date < 20090930) then topid_20090930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20090930) then topid_20090930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20090930) then topid_20090930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20090930) then topid_20090930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20090930) then topid_20090930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20090930) then topid_20090930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20090930) then topid_20090930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20090930) then topid_20090930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20090930) then topid_20090930=successor1_rssdid;
*else if dt_start >20090930 then topid_20090930=.;
else topid_20090930=id_rssd;
if (acq9_date ne . and acq9_date < 20090630) then topid_20090630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20090630) then topid_20090630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20090630) then topid_20090630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20090630) then topid_20090630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20090630) then topid_20090630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20090630) then topid_20090630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20090630) then topid_20090630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20090630) then topid_20090630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20090630) then topid_20090630=successor1_rssdid;
*else if dt_start >20090630 then topid_20090630=.;
else topid_20090630=id_rssd;
if (acq9_date ne . and acq9_date < 20090331) then topid_20090331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20090331) then topid_20090331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20090331) then topid_20090331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20090331) then topid_20090331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20090331) then topid_20090331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20090331) then topid_20090331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20090331) then topid_20090331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20090331) then topid_20090331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20090331) then topid_20090331=successor1_rssdid;
*else if dt_start >20090331 then topid_20090331=.;
else topid_20090331=id_rssd;
/*2008*/
if (acq9_date ne . and acq9_date < 20081231) then topid_20081231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20081231) then topid_20081231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20081231) then topid_20081231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20081231) then topid_20081231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20081231) then topid_20081231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20081231) then topid_20081231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20081231) then topid_20081231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20081231) then topid_20081231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20081231) then topid_20081231=successor1_rssdid;
*else if dt_start >20081231 then topid_20081231=.;
else topid_20081231=id_rssd;
if (acq9_date ne . and acq9_date < 20080930) then topid_20080930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20080930) then topid_20080930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20080930) then topid_20080930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20080930) then topid_20080930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20080930) then topid_20080930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20080930) then topid_20080930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20080930) then topid_20080930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20080930) then topid_20080930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20080930) then topid_20080930=successor1_rssdid;
*else if dt_start >20080930 then topid_20080930=.;
else topid_20080930=id_rssd;
if (acq9_date ne . and acq9_date < 20080630) then topid_20080630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20080630) then topid_20080630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20080630) then topid_20080630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20080630) then topid_20080630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20080630) then topid_20080630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20080630) then topid_20080630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20080630) then topid_20080630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20080630) then topid_20080630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20080630) then topid_20080630=successor1_rssdid;
*else if dt_start >20080630 then topid_20080630=.;
else topid_20080630=id_rssd;
if (acq9_date ne . and acq9_date < 20080331) then topid_20080331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20080331) then topid_20080331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20080331) then topid_20080331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20080331) then topid_20080331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20080331) then topid_20080331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20080331) then topid_20080331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20080331) then topid_20080331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20080331) then topid_20080331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20080331) then topid_20080331=successor1_rssdid;
*else if dt_start >20080331 then topid_20080331=.;
else topid_20080331=id_rssd;
/*2007*/
if (acq9_date ne . and acq9_date < 20071231) then topid_20071231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20071231) then topid_20071231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20071231) then topid_20071231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20071231) then topid_20071231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20071231) then topid_20071231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20071231) then topid_20071231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20071231) then topid_20071231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20071231) then topid_20071231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20071231) then topid_20071231=successor1_rssdid;
*else if dt_start >20071231 then topid_20071231=.;
else topid_20071231=id_rssd;
if (acq9_date ne . and acq9_date < 20070930) then topid_20070930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20070930) then topid_20070930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20070930) then topid_20070930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20070930) then topid_20070930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20070930) then topid_20070930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20070930) then topid_20070930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20070930) then topid_20070930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20070930) then topid_20070930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20070930) then topid_20070930=successor1_rssdid;
*else if dt_start >20070930 then topid_20070930=.;
else topid_20070930=id_rssd;
if (acq9_date ne . and acq9_date < 20070630) then topid_20070630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20070630) then topid_20070630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20070630) then topid_20070630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20070630) then topid_20070630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20070630) then topid_20070630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20070630) then topid_20070630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20070630) then topid_20070630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20070630) then topid_20070630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20070630) then topid_20070630=successor1_rssdid;
*else if dt_start >20070630 then topid_20070630=.;
else topid_20070630=id_rssd;
if (acq9_date ne . and acq9_date < 20070331) then topid_20070331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20070331) then topid_20070331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20070331) then topid_20070331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20070331) then topid_20070331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20070331) then topid_20070331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20070331) then topid_20070331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20070331) then topid_20070331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20070331) then topid_20070331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20070331) then topid_20070331=successor1_rssdid;
*else if dt_start >20070331 then topid_20070331=.;
else topid_20070331=id_rssd;
/*2006*/
if (acq9_date ne . and acq9_date < 20061231) then topid_20061231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20061231) then topid_20061231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20061231) then topid_20061231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20061231) then topid_20061231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20061231) then topid_20061231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20061231) then topid_20061231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20061231) then topid_20061231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20061231) then topid_20061231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20061231) then topid_20061231=successor1_rssdid;
*else if dt_start >20061231 then topid_20061231=.;
else topid_20061231=id_rssd;
if (acq9_date ne . and acq9_date < 20060930) then topid_20060930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20060930) then topid_20060930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20060930) then topid_20060930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20060930) then topid_20060930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20060930) then topid_20060930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20060930) then topid_20060930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20060930) then topid_20060930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20060930) then topid_20060930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20060930) then topid_20060930=successor1_rssdid;
*else if dt_start >20060930 then topid_20060930=.;
else topid_20060930=id_rssd;
if (acq9_date ne . and acq9_date < 20060630) then topid_20060630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20060630) then topid_20060630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20060630) then topid_20060630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20060630) then topid_20060630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20060630) then topid_20060630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20060630) then topid_20060630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20060630) then topid_20060630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20060630) then topid_20060630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20060630) then topid_20060630=successor1_rssdid;
*else if dt_start >20060630 then topid_20060630=.;
else topid_20060630=id_rssd;
if (acq9_date ne . and acq9_date < 20060331) then topid_20060331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20060331) then topid_20060331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20060331) then topid_20060331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20060331) then topid_20060331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20060331) then topid_20060331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20060331) then topid_20060331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20060331) then topid_20060331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20060331) then topid_20060331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20060331) then topid_20060331=successor1_rssdid;
*else if dt_start >20060331 then topid_20060331=.;
else topid_20060331=id_rssd;
/*2005*/
if (acq9_date ne . and acq9_date < 20051231) then topid_20051231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20051231) then topid_20051231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20051231) then topid_20051231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20051231) then topid_20051231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20051231) then topid_20051231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20051231) then topid_20051231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20051231) then topid_20051231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20051231) then topid_20051231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20051231) then topid_20051231=successor1_rssdid;
*else if dt_start >20051231 then topid_20051231=.;
else topid_20051231=id_rssd;
if (acq9_date ne . and acq9_date < 20050930) then topid_20050930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20050930) then topid_20050930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20050930) then topid_20050930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20050930) then topid_20050930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20050930) then topid_20050930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20050930) then topid_20050930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20050930) then topid_20050930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20050930) then topid_20050930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20050930) then topid_20050930=successor1_rssdid;
*else if dt_start >20050930 then topid_20050930=.;
else topid_20050930=id_rssd;
if (acq9_date ne . and acq9_date < 20050630) then topid_20050630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20050630) then topid_20050630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20050630) then topid_20050630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20050630) then topid_20050630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20050630) then topid_20050630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20050630) then topid_20050630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20050630) then topid_20050630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20050630) then topid_20050630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20050630) then topid_20050630=successor1_rssdid;
*else if dt_start >20050630 then topid_20050630=.;
else topid_20050630=id_rssd;
if (acq9_date ne . and acq9_date < 20050331) then topid_20050331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20050331) then topid_20050331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20050331) then topid_20050331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20050331) then topid_20050331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20050331) then topid_20050331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20050331) then topid_20050331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20050331) then topid_20050331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20050331) then topid_20050331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20050331) then topid_20050331=successor1_rssdid;
*else if dt_start >20050331 then topid_20050331=.;
else topid_20050331=id_rssd;
/*2004*/
if (acq9_date ne . and acq9_date < 20041231) then topid_20041231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20041231) then topid_20041231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20041231) then topid_20041231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20041231) then topid_20041231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20041231) then topid_20041231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20041231) then topid_20041231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20041231) then topid_20041231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20041231) then topid_20041231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20041231) then topid_20041231=successor1_rssdid;
*else if dt_start >20041231 then topid_20041231=.;
else topid_20041231=id_rssd;
if (acq9_date ne . and acq9_date < 20040930) then topid_20040930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20040930) then topid_20040930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20040930) then topid_20040930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20040930) then topid_20040930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20040930) then topid_20040930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20040930) then topid_20040930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20040930) then topid_20040930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20040930) then topid_20040930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20040930) then topid_20040930=successor1_rssdid;
*else if dt_start >20040930 then topid_20040930=.;
else topid_20040930=id_rssd;
if (acq9_date ne . and acq9_date < 20040630) then topid_20040630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20040630) then topid_20040630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20040630) then topid_20040630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20040630) then topid_20040630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20040630) then topid_20040630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20040630) then topid_20040630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20040630) then topid_20040630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20040630) then topid_20040630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20040630) then topid_20040630=successor1_rssdid;
*else if dt_start >20040630 then topid_20040630=.;
else topid_20040630=id_rssd;
if (acq9_date ne . and acq9_date < 20040331) then topid_20040331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20040331) then topid_20040331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20040331) then topid_20040331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20040331) then topid_20040331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20040331) then topid_20040331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20040331) then topid_20040331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20040331) then topid_20040331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20040331) then topid_20040331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20040331) then topid_20040331=successor1_rssdid;
*else if dt_start >20040331 then topid_20040331=.;
else topid_20040331=id_rssd;
/*2003*/
if (acq9_date ne . and acq9_date < 20031231) then topid_20031231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20031231) then topid_20031231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20031231) then topid_20031231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20031231) then topid_20031231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20031231) then topid_20031231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20031231) then topid_20031231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20031231) then topid_20031231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20031231) then topid_20031231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20031231) then topid_20031231=successor1_rssdid;
*else if dt_start >20031231 then topid_20031231=.;
else topid_20031231=id_rssd;
if (acq9_date ne . and acq9_date < 20030930) then topid_20030930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20030930) then topid_20030930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20030930) then topid_20030930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20030930) then topid_20030930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20030930) then topid_20030930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20030930) then topid_20030930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20030930) then topid_20030930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20030930) then topid_20030930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20030930) then topid_20030930=successor1_rssdid;
*else if dt_start >20030930 then topid_20030930=.;
else topid_20030930=id_rssd;
if (acq9_date ne . and acq9_date < 20030630) then topid_20030630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20030630) then topid_20030630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20030630) then topid_20030630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20030630) then topid_20030630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20030630) then topid_20030630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20030630) then topid_20030630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20030630) then topid_20030630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20030630) then topid_20030630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20030630) then topid_20030630=successor1_rssdid;
*else if dt_start >20030630 then topid_20030630=.;
else topid_20030630=id_rssd;
if (acq9_date ne . and acq9_date < 20030331) then topid_20030331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20030331) then topid_20030331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20030331) then topid_20030331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20030331) then topid_20030331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20030331) then topid_20030331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20030331) then topid_20030331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20030331) then topid_20030331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20030331) then topid_20030331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20030331) then topid_20030331=successor1_rssdid;
*else if dt_start >20030331 then topid_20030331=.;
else topid_20030331=id_rssd;
/*2002*/
if (acq9_date ne . and acq9_date < 20021231) then topid_20021231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20021231) then topid_20021231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20021231) then topid_20021231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20021231) then topid_20021231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20021231) then topid_20021231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20021231) then topid_20021231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20021231) then topid_20021231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20021231) then topid_20021231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20021231) then topid_20021231=successor1_rssdid;
*else if dt_start >20021231 then topid_20021231=.;
else topid_20021231=id_rssd;
if (acq9_date ne . and acq9_date < 20020930) then topid_20020930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20020930) then topid_20020930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20020930) then topid_20020930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20020930) then topid_20020930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20020930) then topid_20020930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20020930) then topid_20020930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20020930) then topid_20020930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20020930) then topid_20020930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20020930) then topid_20020930=successor1_rssdid;
*else if dt_start >20020930 then topid_20020930=.;
else topid_20020930=id_rssd;
if (acq9_date ne . and acq9_date < 20020630) then topid_20020630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20020630) then topid_20020630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20020630) then topid_20020630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20020630) then topid_20020630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20020630) then topid_20020630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20020630) then topid_20020630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20020630) then topid_20020630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20020630) then topid_20020630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20020630) then topid_20020630=successor1_rssdid;
*else if dt_start >20020630 then topid_20020630=.;
else topid_20020630=id_rssd;
if (acq9_date ne . and acq9_date < 20020331) then topid_20020331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20020331) then topid_20020331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20020331) then topid_20020331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20020331) then topid_20020331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20020331) then topid_20020331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20020331) then topid_20020331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20020331) then topid_20020331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20020331) then topid_20020331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20020331) then topid_20020331=successor1_rssdid;
*else if dt_start >20020331 then topid_20020331=.;
else topid_20020331=id_rssd;
/*2001*/
if (acq9_date ne . and acq9_date < 20011231) then topid_20011231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20011231) then topid_20011231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20011231) then topid_20011231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20011231) then topid_20011231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20011231) then topid_20011231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20011231) then topid_20011231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20011231) then topid_20011231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20011231) then topid_20011231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20011231) then topid_20011231=successor1_rssdid;
*else if dt_start >20011231 then topid_20011231=.;
else topid_20011231=id_rssd;
if (acq9_date ne . and acq9_date < 20010930) then topid_20010930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20010930) then topid_20010930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20010930) then topid_20010930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20010930) then topid_20010930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20010930) then topid_20010930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20010930) then topid_20010930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20010930) then topid_20010930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20010930) then topid_20010930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20010930) then topid_20010930=successor1_rssdid;
*else if dt_start >20010930 then topid_20010930=.;
else topid_20010930=id_rssd;
if (acq9_date ne . and acq9_date < 20010630) then topid_20010630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20010630) then topid_20010630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20010630) then topid_20010630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20010630) then topid_20010630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20010630) then topid_20010630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20010630) then topid_20010630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20010630) then topid_20010630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20010630) then topid_20010630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20010630) then topid_20010630=successor1_rssdid;
*else if dt_start >20010630 then topid_20010630=.;
else topid_20010630=id_rssd;
if (acq9_date ne . and acq9_date < 20010331) then topid_20010331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20010331) then topid_20010331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20010331) then topid_20010331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20010331) then topid_20010331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20010331) then topid_20010331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20010331) then topid_20010331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20010331) then topid_20010331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20010331) then topid_20010331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20010331) then topid_20010331=successor1_rssdid;
*else if dt_start >20010331 then topid_20010331=.;
else topid_20010331=id_rssd;
/*2000*/
if (acq9_date ne . and acq9_date < 20001231) then topid_20001231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20001231) then topid_20001231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20001231) then topid_20001231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20001231) then topid_20001231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20001231) then topid_20001231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20001231) then topid_20001231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20001231) then topid_20001231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20001231) then topid_20001231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20001231) then topid_20001231=successor1_rssdid;
*else if dt_start >20001231 then topid_20001231=.;
else topid_20001231=id_rssd;
if (acq9_date ne . and acq9_date < 20000930) then topid_20000930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20000930) then topid_20000930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20000930) then topid_20000930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20000930) then topid_20000930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20000930) then topid_20000930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20000930) then topid_20000930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20000930) then topid_20000930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20000930) then topid_20000930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20000930) then topid_20000930=successor1_rssdid;
*else if dt_start >20000930 then topid_20000930=.;
else topid_20000930=id_rssd;
if (acq9_date ne . and acq9_date < 20000630) then topid_20000630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20000630) then topid_20000630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20000630) then topid_20000630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20000630) then topid_20000630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20000630) then topid_20000630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20000630) then topid_20000630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20000630) then topid_20000630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20000630) then topid_20000630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20000630) then topid_20000630=successor1_rssdid;
*else if dt_start >20000630 then topid_20000630=.;
else topid_20000630=id_rssd;
if (acq9_date ne . and acq9_date < 20000331) then topid_20000331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 20000331) then topid_20000331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 20000331) then topid_20000331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 20000331) then topid_20000331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 20000331) then topid_20000331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 20000331) then topid_20000331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 20000331) then topid_20000331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 20000331) then topid_20000331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 20000331) then topid_20000331=successor1_rssdid;
*else if dt_start >20000331 then topid_20000331=.;
else topid_20000331=id_rssd;
/*1999*/
if (acq9_date ne . and acq9_date < 19991231) then topid_19991231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19991231) then topid_19991231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19991231) then topid_19991231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19991231) then topid_19991231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19991231) then topid_19991231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19991231) then topid_19991231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19991231) then topid_19991231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19991231) then topid_19991231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19991231) then topid_19991231=successor1_rssdid;
*else if dt_start >19991231 then topid_19991231=.;
else topid_19991231=id_rssd;
if (acq9_date ne . and acq9_date < 19990930) then topid_19990930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19990930) then topid_19990930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19990930) then topid_19990930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19990930) then topid_19990930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19990930) then topid_19990930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19990930) then topid_19990930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19990930) then topid_19990930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19990930) then topid_19990930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19990930) then topid_19990930=successor1_rssdid;
*else if dt_start >19990930 then topid_19990930=.;
else topid_19990930=id_rssd;
if (acq9_date ne . and acq9_date < 19990630) then topid_19990630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19990630) then topid_19990630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19990630) then topid_19990630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19990630) then topid_19990630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19990630) then topid_19990630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19990630) then topid_19990630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19990630) then topid_19990630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19990630) then topid_19990630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19990630) then topid_19990630=successor1_rssdid;
*else if dt_start >19990630 then topid_19990630=.;
else topid_19990630=id_rssd;
if (acq9_date ne . and acq9_date < 19990331) then topid_19990331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19990331) then topid_19990331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19990331) then topid_19990331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19990331) then topid_19990331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19990331) then topid_19990331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19990331) then topid_19990331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19990331) then topid_19990331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19990331) then topid_19990331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19990331) then topid_19990331=successor1_rssdid;
*else if dt_start >19990331 then topid_19990331=.;
else topid_19990331=id_rssd;
/*1998*/
if (acq9_date ne . and acq9_date < 19981231) then topid_19981231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19981231) then topid_19981231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19981231) then topid_19981231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19981231) then topid_19981231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19981231) then topid_19981231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19981231) then topid_19981231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19981231) then topid_19981231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19981231) then topid_19981231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19981231) then topid_19981231=successor1_rssdid;
*else if dt_start >19981231 then topid_19981231=.;
else topid_19981231=id_rssd;
if (acq9_date ne . and acq9_date < 19980930) then topid_19980930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19980930) then topid_19980930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19980930) then topid_19980930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19980930) then topid_19980930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19980930) then topid_19980930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19980930) then topid_19980930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19980930) then topid_19980930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19980930) then topid_19980930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19980930) then topid_19980930=successor1_rssdid;
*else if dt_start >19980930 then topid_19980930=.;
else topid_19980930=id_rssd;
if (acq9_date ne . and acq9_date < 19980630) then topid_19980630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19980630) then topid_19980630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19980630) then topid_19980630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19980630) then topid_19980630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19980630) then topid_19980630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19980630) then topid_19980630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19980630) then topid_19980630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19980630) then topid_19980630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19980630) then topid_19980630=successor1_rssdid;
*else if dt_start >19980630 then topid_19980630=.;
else topid_19980630=id_rssd;
if (acq9_date ne . and acq9_date < 19980331) then topid_19980331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19980331) then topid_19980331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19980331) then topid_19980331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19980331) then topid_19980331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19980331) then topid_19980331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19980331) then topid_19980331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19980331) then topid_19980331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19980331) then topid_19980331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19980331) then topid_19980331=successor1_rssdid;
*else if dt_start >19980331 then topid_19980331=.;
else topid_19980331=id_rssd;
/*1997*/
if (acq9_date ne . and acq9_date < 19971231) then topid_19971231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19971231) then topid_19971231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19971231) then topid_19971231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19971231) then topid_19971231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19971231) then topid_19971231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19971231) then topid_19971231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19971231) then topid_19971231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19971231) then topid_19971231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19971231) then topid_19971231=successor1_rssdid;
*else if dt_start >19971231 then topid_19971231=.;
else topid_19971231=id_rssd;
if (acq9_date ne . and acq9_date < 19970930) then topid_19970930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19970930) then topid_19970930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19970930) then topid_19970930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19970930) then topid_19970930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19970930) then topid_19970930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19970930) then topid_19970930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19970930) then topid_19970930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19970930) then topid_19970930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19970930) then topid_19970930=successor1_rssdid;
*else if dt_start >19970930 then topid_19970930=.;
else topid_19970930=id_rssd;
if (acq9_date ne . and acq9_date < 19970630) then topid_19970630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19970630) then topid_19970630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19970630) then topid_19970630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19970630) then topid_19970630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19970630) then topid_19970630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19970630) then topid_19970630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19970630) then topid_19970630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19970630) then topid_19970630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19970630) then topid_19970630=successor1_rssdid;
*else if dt_start >19970630 then topid_19970630=.;
else topid_19970630=id_rssd;
if (acq9_date ne . and acq9_date < 19970331) then topid_19970331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19970331) then topid_19970331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19970331) then topid_19970331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19970331) then topid_19970331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19970331) then topid_19970331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19970331) then topid_19970331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19970331) then topid_19970331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19970331) then topid_19970331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19970331) then topid_19970331=successor1_rssdid;
*else if dt_start >19970331 then topid_19970331=.;
else topid_19970331=id_rssd;
/*1996*/
if (acq9_date ne . and acq9_date < 19961231) then topid_19961231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19961231) then topid_19961231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19961231) then topid_19961231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19961231) then topid_19961231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19961231) then topid_19961231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19961231) then topid_19961231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19961231) then topid_19961231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19961231) then topid_19961231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19961231) then topid_19961231=successor1_rssdid;
*else if dt_start >19961231 then topid_19961231=.;
else topid_19961231=id_rssd;
if (acq9_date ne . and acq9_date < 19960930) then topid_19960930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19960930) then topid_19960930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19960930) then topid_19960930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19960930) then topid_19960930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19960930) then topid_19960930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19960930) then topid_19960930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19960930) then topid_19960930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19960930) then topid_19960930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19960930) then topid_19960930=successor1_rssdid;
*else if dt_start >19960930 then topid_19960930=.;
else topid_19960930=id_rssd;
if (acq9_date ne . and acq9_date < 19960630) then topid_19960630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19960630) then topid_19960630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19960630) then topid_19960630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19960630) then topid_19960630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19960630) then topid_19960630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19960630) then topid_19960630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19960630) then topid_19960630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19960630) then topid_19960630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19960630) then topid_19960630=successor1_rssdid;
*else if dt_start >19960630 then topid_19960630=.;
else topid_19960630=id_rssd;
if (acq9_date ne . and acq9_date < 19960331) then topid_19960331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19960331) then topid_19960331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19960331) then topid_19960331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19960331) then topid_19960331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19960331) then topid_19960331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19960331) then topid_19960331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19960331) then topid_19960331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19960331) then topid_19960331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19960331) then topid_19960331=successor1_rssdid;
*else if dt_start >19960331 then topid_19960331=.;
else topid_19960331=id_rssd;
/*1995*/
if (acq9_date ne . and acq9_date < 19951231) then topid_19951231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19951231) then topid_19951231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19951231) then topid_19951231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19951231) then topid_19951231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19951231) then topid_19951231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19951231) then topid_19951231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19951231) then topid_19951231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19951231) then topid_19951231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19951231) then topid_19951231=successor1_rssdid;
*else if dt_start >19951231 then topid_19951231=.;
else topid_19951231=id_rssd;
if (acq9_date ne . and acq9_date < 19950930) then topid_19950930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19950930) then topid_19950930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19950930) then topid_19950930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19950930) then topid_19950930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19950930) then topid_19950930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19950930) then topid_19950930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19950930) then topid_19950930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19950930) then topid_19950930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19950930) then topid_19950930=successor1_rssdid;
*else if dt_start >19950930 then topid_19950930=.;
else topid_19950930=id_rssd;
if (acq9_date ne . and acq9_date < 19950630) then topid_19950630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19950630) then topid_19950630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19950630) then topid_19950630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19950630) then topid_19950630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19950630) then topid_19950630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19950630) then topid_19950630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19950630) then topid_19950630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19950630) then topid_19950630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19950630) then topid_19950630=successor1_rssdid;
*else if dt_start >19950630 then topid_19950630=.;
else topid_19950630=id_rssd;
if (acq9_date ne . and acq9_date < 19950331) then topid_19950331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19950331) then topid_19950331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19950331) then topid_19950331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19950331) then topid_19950331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19950331) then topid_19950331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19950331) then topid_19950331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19950331) then topid_19950331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19950331) then topid_19950331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19950331) then topid_19950331=successor1_rssdid;
*else if dt_start >19950331 then topid_19950331=.;
else topid_19950331=id_rssd;
/*1994*/
if (acq9_date ne . and acq9_date < 19941231) then topid_19941231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19941231) then topid_19941231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19941231) then topid_19941231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19941231) then topid_19941231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19941231) then topid_19941231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19941231) then topid_19941231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19941231) then topid_19941231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19941231) then topid_19941231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19941231) then topid_19941231=successor1_rssdid;
*else if dt_start >19941231 then topid_19941231=.;
else topid_19941231=id_rssd;
if (acq9_date ne . and acq9_date < 19940930) then topid_19940930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19940930) then topid_19940930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19940930) then topid_19940930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19940930) then topid_19940930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19940930) then topid_19940930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19940930) then topid_19940930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19940930) then topid_19940930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19940930) then topid_19940930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19940930) then topid_19940930=successor1_rssdid;
*else if dt_start >19940930 then topid_19940930=.;
else topid_19940930=id_rssd;
if (acq9_date ne . and acq9_date < 19940630) then topid_19940630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19940630) then topid_19940630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19940630) then topid_19940630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19940630) then topid_19940630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19940630) then topid_19940630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19940630) then topid_19940630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19940630) then topid_19940630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19940630) then topid_19940630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19940630) then topid_19940630=successor1_rssdid;
*else if dt_start >19940630 then topid_19940630=.;
else topid_19940630=id_rssd;
if (acq9_date ne . and acq9_date < 19940331) then topid_19940331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19940331) then topid_19940331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19940331) then topid_19940331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19940331) then topid_19940331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19940331) then topid_19940331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19940331) then topid_19940331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19940331) then topid_19940331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19940331) then topid_19940331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19940331) then topid_19940331=successor1_rssdid;
*else if dt_start >19940331 then topid_19940331=.;
else topid_19940331=id_rssd;
/*1993*/
if (acq9_date ne . and acq9_date < 19931231) then topid_19931231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19931231) then topid_19931231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19931231) then topid_19931231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19931231) then topid_19931231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19931231) then topid_19931231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19931231) then topid_19931231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19931231) then topid_19931231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19931231) then topid_19931231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19931231) then topid_19931231=successor1_rssdid;
*else if dt_start >19931231 then topid_19931231=.;
else topid_19931231=id_rssd;
if (acq9_date ne . and acq9_date < 19930930) then topid_19930930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19930930) then topid_19930930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19930930) then topid_19930930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19930930) then topid_19930930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19930930) then topid_19930930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19930930) then topid_19930930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19930930) then topid_19930930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19930930) then topid_19930930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19930930) then topid_19930930=successor1_rssdid;
*else if dt_start >19930930 then topid_19930930=.;
else topid_19930930=id_rssd;
if (acq9_date ne . and acq9_date < 19930630) then topid_19930630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19930630) then topid_19930630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19930630) then topid_19930630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19930630) then topid_19930630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19930630) then topid_19930630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19930630) then topid_19930630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19930630) then topid_19930630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19930630) then topid_19930630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19930630) then topid_19930630=successor1_rssdid;
*else if dt_start >19930630 then topid_19930630=.;
else topid_19930630=id_rssd;
if (acq9_date ne . and acq9_date < 19930331) then topid_19930331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19930331) then topid_19930331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19930331) then topid_19930331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19930331) then topid_19930331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19930331) then topid_19930331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19930331) then topid_19930331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19930331) then topid_19930331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19930331) then topid_19930331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19930331) then topid_19930331=successor1_rssdid;
*else if dt_start >19930331 then topid_19930331=.;
else topid_19930331=id_rssd;
/*1992*/
if (acq9_date ne . and acq9_date < 19921231) then topid_19921231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19921231) then topid_19921231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19921231) then topid_19921231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19921231) then topid_19921231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19921231) then topid_19921231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19921231) then topid_19921231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19921231) then topid_19921231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19921231) then topid_19921231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19921231) then topid_19921231=successor1_rssdid;
*else if dt_start >19921231 then topid_19921231=.;
else topid_19921231=id_rssd;
if (acq9_date ne . and acq9_date < 19920930) then topid_19920930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19920930) then topid_19920930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19920930) then topid_19920930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19920930) then topid_19920930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19920930) then topid_19920930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19920930) then topid_19920930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19920930) then topid_19920930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19920930) then topid_19920930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19920930) then topid_19920930=successor1_rssdid;
*else if dt_start >19920930 then topid_19920930=.;
else topid_19920930=id_rssd;
if (acq9_date ne . and acq9_date < 19920630) then topid_19920630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19920630) then topid_19920630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19920630) then topid_19920630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19920630) then topid_19920630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19920630) then topid_19920630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19920630) then topid_19920630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19920630) then topid_19920630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19920630) then topid_19920630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19920630) then topid_19920630=successor1_rssdid;
*else if dt_start >19920630 then topid_19920630=.;
else topid_19920630=id_rssd;
if (acq9_date ne . and acq9_date < 19920331) then topid_19920331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19920331) then topid_19920331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19920331) then topid_19920331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19920331) then topid_19920331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19920331) then topid_19920331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19920331) then topid_19920331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19920331) then topid_19920331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19920331) then topid_19920331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19920331) then topid_19920331=successor1_rssdid;
*else if dt_start >19920331 then topid_19920331=.;
else topid_19920331=id_rssd;
/*1991*/
if (acq9_date ne . and acq9_date < 19911231) then topid_19911231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19911231) then topid_19911231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19911231) then topid_19911231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19911231) then topid_19911231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19911231) then topid_19911231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19911231) then topid_19911231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19911231) then topid_19911231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19911231) then topid_19911231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19911231) then topid_19911231=successor1_rssdid;
*else if dt_start >19911231 then topid_19911231=.;
else topid_19911231=id_rssd;
if (acq9_date ne . and acq9_date < 19910930) then topid_19910930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19910930) then topid_19910930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19910930) then topid_19910930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19910930) then topid_19910930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19910930) then topid_19910930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19910930) then topid_19910930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19910930) then topid_19910930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19910930) then topid_19910930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19910930) then topid_19910930=successor1_rssdid;
*else if dt_start >19910930 then topid_19910930=.;
else topid_19910930=id_rssd;
if (acq9_date ne . and acq9_date < 19910630) then topid_19910630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19910630) then topid_19910630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19910630) then topid_19910630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19910630) then topid_19910630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19910630) then topid_19910630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19910630) then topid_19910630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19910630) then topid_19910630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19910630) then topid_19910630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19910630) then topid_19910630=successor1_rssdid;
*else if dt_start >19910630 then topid_19910630=.;
else topid_19910630=id_rssd;
if (acq9_date ne . and acq9_date < 19910331) then topid_19910331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19910331) then topid_19910331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19910331) then topid_19910331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19910331) then topid_19910331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19910331) then topid_19910331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19910331) then topid_19910331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19910331) then topid_19910331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19910331) then topid_19910331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19910331) then topid_19910331=successor1_rssdid;
*else if dt_start >19910331 then topid_19910331=.;
else topid_19910331=id_rssd;
/*1990*/
if (acq9_date ne . and acq9_date < 19901231) then topid_19901231=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19901231) then topid_19901231=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19901231) then topid_19901231=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19901231) then topid_19901231=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19901231) then topid_19901231=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19901231) then topid_19901231=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19901231) then topid_19901231=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19901231) then topid_19901231=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19901231) then topid_19901231=successor1_rssdid;
*else if dt_start >19901231 then topid_19901231=.;
else topid_19901231=id_rssd;
if (acq9_date ne . and acq9_date < 19900930) then topid_19900930=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19900930) then topid_19900930=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19900930) then topid_19900930=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19900930) then topid_19900930=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19900930) then topid_19900930=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19900930) then topid_19900930=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19900930) then topid_19900930=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19900930) then topid_19900930=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19900930) then topid_19900930=successor1_rssdid;
*else if dt_start >19900930 then topid_19900930=.;
else topid_19900930=id_rssd;
if (acq9_date ne . and acq9_date < 19900630) then topid_19900630=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19900630) then topid_19900630=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19900630) then topid_19900630=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19900630) then topid_19900630=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19900630) then topid_19900630=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19900630) then topid_19900630=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19900630) then topid_19900630=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19900630) then topid_19900630=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19900630) then topid_19900630=successor1_rssdid;
*else if dt_start >19900630 then topid_19900630=.;
else topid_19900630=id_rssd;
if (acq9_date ne . and acq9_date < 19900331) then topid_19900331=successor9_rssdid;
else if (acq8_date ne . and acq8_date < 19900331) then topid_19900331=successor8_rssdid;
else if (acq7_date ne . and acq7_date < 19900331) then topid_19900331=successor7_rssdid;
else if (acq6_date ne . and acq6_date < 19900331) then topid_19900331=successor6_rssdid;
else if (acq5_date ne . and acq5_date < 19900331) then topid_19900331=successor5_rssdid;
else if (acq4_date ne . and acq4_date < 19900331) then topid_19900331=successor4_rssdid;
else if (acq3_date ne . and acq3_date < 19900331) then topid_19900331=successor3_rssdid;
else if (acq2_date ne . and acq2_date < 19900331) then topid_19900331=successor2_rssdid;
else if (acq1_date ne . and acq1_date < 19900331) then topid_19900331=successor1_rssdid;
*else if dt_start >19900331 then topid_19900331=.;
else topid_19900331=id_rssd;
run;
