/*===========================================================================================================
                                                                          
    ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
    AUTHOR: P. Barrett Wheeler                  
    JOURNAL OF ACCOUNTING RESEARCH 

 	The code below gathers data on single-family and multi-family mortgage loan originations by bank from
	1990-2016 filed pursuant to the Home Mortgage Disclosure Act (HMDA). Mortgage origination data is 
	aggregated in Loan Application Register (LAR) files, which are made available annually and maintained 
	on the FFIEC website. Different procedures are followed for the periods 1990-2003, 2004-2009, and 
	2010-2016 due to changes in the LAR over time. HMDA provides a dataset linking each bank's respondent ID
	to its Federal Reserve RSSID for years after 2003. For years prior to 2003, I manually gathered RSSDID 
	data from the National Information Center (NIC) website based on bank name and city. Data from the NIC
	is also used to determine the top regulatory ID for each bank (i.e., the RSSDID if its ultimate parent).

 ============================================================================================================*/

libname hmda 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA';


/*Infile LAR (HMDA's Loan/Application Register) 1990-2003*/
data hmda.lar_1990;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 1990.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_1991;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 1991.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_1992;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 1992.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_1993;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 1993.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_1994;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 1994.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_1995;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 1995.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_1996;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 1996.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_1997;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 1997.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_1998;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 1998.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_1999;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 1999.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_2000;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 2000.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_2001;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 2001.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_2002;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 2002.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;

data hmda.lar_2003;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 2003.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-28 state 29-30 county 31-33
census_tract 34-40 app_race 41 coapp_race 42 app_sex 43 coapp_sex 44 app_income 45-48 purchaser_type 49
denial1 50 denial2 51 denial3 52 edit_status 53 sequence_no 54-60;
run;


/*SUMMARIZE LOAN ORIGINATIONS BY LOAN TYPE AND INSTITUTION 1990-2003*/
/*1990*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_1990_singlefam;
set lar_1990;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_1990_multifam;
set lar_1990;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_1990_raw as select *, sum(amount) as lo_singlefam
from lar_1990_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_1990_raw as select *, sum(amount) as lo_multifam
from lar_1990_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_1990 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_1990_raw;
run;
proc sort data=hmda_singlefam_1990 nodupkey;
by resp_id;
run;
data hmda_multifam_1990 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_1990_raw;
run;
proc sort data=hmda_multifam_1990 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_1990;
set hmda_singlefam_1990;
run;
data hmda.hmda_multifam_1990;
set hmda_multifam_1990;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_1990_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_1990 as a left join hmda.panel_1990_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_1990_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231, b.topid_19951231, b.topid_19941231, b.topid_19931231, b.topid_19921231, b.topid_19911231
from hmda_singlefam_1990_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_1990_2 nodupkey out=hmda_singlefam_1990_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_1990;
set hmda_singlefam_1990_3;
run;

proc sql;
create table hmda_multifam_1990_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_1990 as a left join hmda.panel_1990_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_1990_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231, b.topid_19951231, b.topid_19941231, b.topid_19931231, b.topid_19921231, b.topid_19911231
from hmda_multifam_1990_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_1990_2 nodupkey out=hmda_multifam_1990_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_1990;
set hmda_multifam_1990_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_1990_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_1990 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_1990;
set hmda_singlefam_1990_4;
run;

proc sql;
create table hmda_multifam_1990_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_1990 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_1990;
set hmda_multifam_1990_4;
run;
proc sort data=hmda.hmda_singlefam_1990 nodupkey;
by rssdid resp_id;
run;
proc sort data=hmda.hmda_multifam_1990 nodupkey;
by rssdid resp_id;
run;

/*1991*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_1991_singlefam;
set lar_1991;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_1991_multifam;
set lar_1991;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_1991_raw as select *, sum(amount) as lo_singlefam
from lar_1991_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_1991_raw as select *, sum(amount) as lo_multifam
from lar_1991_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_1991 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_1991_raw;
run;
proc sort data=hmda_singlefam_1991 nodupkey;
by resp_id;
run;
data hmda_multifam_1991 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_1991_raw;
run;
proc sort data=hmda_multifam_1991 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_1991;
set hmda_singlefam_1991;
run;
data hmda.hmda_multifam_1991;
set hmda_multifam_1991;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_1991_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_1991 as a left join hmda.panel_1991_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_1991_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231, b.topid_19951231, b.topid_19941231, b.topid_19931231, b.topid_19921231
from hmda_singlefam_1991_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_1991_2 nodupkey out=hmda_singlefam_1991_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_1991;
set hmda_singlefam_1991_3;
run;

proc sql;
create table hmda_multifam_1991_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_1991 as a left join hmda.panel_1991_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_1991_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231, b.topid_19951231, b.topid_19941231, b.topid_19931231, b.topid_19921231
from hmda_multifam_1991_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_1991_2 nodupkey out=hmda_multifam_1991_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_1991;
set hmda_multifam_1991_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_1991_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_1991 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_1991;
set hmda_singlefam_1991_4;
run;

proc sql;
create table hmda_multifam_1991_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_1991 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_1991;
set hmda_multifam_1991_4;
run;
proc sort data=hmda.hmda_singlefam_1991 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_1991 nodupkey;
by resp_id agency_code;
run;

/*1992*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_1992_singlefam;
set lar_1992;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_1992_multifam;
set lar_1992;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_1992_raw as select *, sum(amount) as lo_singlefam
from lar_1992_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_1992_raw as select *, sum(amount) as lo_multifam
from lar_1992_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_1992 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_1992_raw;
run;
proc sort data=hmda_singlefam_1992 nodupkey;
by resp_id;
run;
data hmda_multifam_1992 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_1992_raw;
run;
proc sort data=hmda_multifam_1992 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_1992;
set hmda_singlefam_1992;
run;
data hmda.hmda_multifam_1992;
set hmda_multifam_1992;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_1992_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_1992 as a left join hmda.panel_1992_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_1992_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231, b.topid_19951231, b.topid_19941231, b.topid_19931231
from hmda_singlefam_1992_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_1992_2 nodupkey out=hmda_singlefam_1992_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_1992;
set hmda_singlefam_1992_3;
run;

proc sql;
create table hmda_multifam_1992_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_1992 as a left join hmda.panel_1992_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_1992_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231, b.topid_19951231, b.topid_19941231, b.topid_19931231
from hmda_multifam_1992_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_1992_2 nodupkey out=hmda_multifam_1992_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_1992;
set hmda_multifam_1992_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_1992_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_1992 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_1992;
set hmda_singlefam_1992_4;
run;

proc sql;
create table hmda_multifam_1992_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_1992 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_1992;
set hmda_multifam_1992_4;
run;
proc sort data=hmda.hmda_singlefam_1992 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_1992 nodupkey;
by resp_id agency_code;
run;

/*1993*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_1993_singlefam;
set lar_1993;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_1993_multifam;
set lar_1993;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_1993_raw as select *, sum(amount) as lo_singlefam
from lar_1993_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_1993_raw as select *, sum(amount) as lo_multifam
from lar_1993_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_1993 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_1993_raw;
run;
proc sort data=hmda_singlefam_1993 nodupkey;
by resp_id;
run;
data hmda_multifam_1993 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_1993_raw;
run;
proc sort data=hmda_multifam_1993 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_1993;
set hmda_singlefam_1993;
run;
data hmda.hmda_multifam_1993;
set hmda_multifam_1993;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_1993_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_1993 as a left join hmda.panel_1993_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_1993_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231, b.topid_19951231, b.topid_19941231
from hmda_singlefam_1993_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_1993_2 nodupkey out=hmda_singlefam_1993_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_1993;
set hmda_singlefam_1993_3;
run;

proc sql;
create table hmda_multifam_1993_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_1993 as a left join hmda.panel_1993_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_1993_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231, b.topid_19951231, b.topid_19941231
from hmda_multifam_1993_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_1993_2 nodupkey out=hmda_multifam_1993_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_1993;
set hmda_multifam_1993_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_1993_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_1993 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_1993;
set hmda_singlefam_1993_4;
run;

proc sql;
create table hmda_multifam_1993_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_1993 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_1993;
set hmda_multifam_1993_4;
run;
proc sort data=hmda.hmda_singlefam_1993 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_1993 nodupkey;
by resp_id agency_code;
run;

/*1994*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_1994_singlefam;
set lar_1994;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_1994_multifam;
set lar_1994;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_1994_raw as select *, sum(amount) as lo_singlefam
from lar_1994_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_1994_raw as select *, sum(amount) as lo_multifam
from lar_1994_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_1994 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_1994_raw;
run;
proc sort data=hmda_singlefam_1994 nodupkey;
by resp_id;
run;
data hmda_multifam_1994 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_1994_raw;
run;
proc sort data=hmda_multifam_1994 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_1994;
set hmda_singlefam_1994;
run;
data hmda.hmda_multifam_1994;
set hmda_multifam_1994;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_1994_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_1994 as a left join hmda.panel_1994_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_1994_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231, b.topid_19951231
from hmda_singlefam_1994_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_1994_2 nodupkey out=hmda_singlefam_1994_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_1994;
set hmda_singlefam_1994_3;
run;

proc sql;
create table hmda_multifam_1994_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_1994 as a left join hmda.panel_1994_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_1994_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231, b.topid_19951231
from hmda_multifam_1994_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_1994_2 nodupkey out=hmda_multifam_1994_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_1994;
set hmda_multifam_1994_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_1994_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_1994 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_1994;
set hmda_singlefam_1994_4;
run;

proc sql;
create table hmda_multifam_1994_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_1994 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_1994;
set hmda_multifam_1994_4;
run;
proc sort data=hmda.hmda_singlefam_1994 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_1994 nodupkey;
by resp_id agency_code;
run;


/*1995*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_1995_singlefam;
set lar_1995;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_1995_multifam;
set lar_1995;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_1995_raw as select *, sum(amount) as lo_singlefam
from lar_1995_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_1995_raw as select *, sum(amount) as lo_multifam
from lar_1995_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_1995 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_1995_raw;
run;
proc sort data=hmda_singlefam_1995 nodupkey;
by resp_id;
run;
data hmda_multifam_1995 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_1995_raw;
run;
proc sort data=hmda_multifam_1995 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_1995;
set hmda_singlefam_1995;
run;
data hmda.hmda_multifam_1995;
set hmda_multifam_1995;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_1995_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_1995 as a left join hmda.panel_1995_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_1995_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231
from hmda_singlefam_1995_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_1995_2 nodupkey out=hmda_singlefam_1995_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_1995;
set hmda_singlefam_1995_3;
run;

proc sql;
create table hmda_multifam_1995_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_1995 as a left join hmda.panel_1995_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_1995_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231,
b.topid_19961231
from hmda_multifam_1995_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_1995_2 nodupkey out=hmda_multifam_1995_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_1995;
set hmda_multifam_1995_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_1995_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_1995 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_1995;
set hmda_singlefam_1995_4;
run;

proc sql;
create table hmda_multifam_1995_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_1995 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_1995;
set hmda_multifam_1995_4;
run;
proc sort data=hmda.hmda_singlefam_1995 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_1995 nodupkey;
by resp_id agency_code;
run;


/*1996*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_1996_singlefam;
set lar_1996;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_1996_multifam;
set lar_1996;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_1996_raw as select *, sum(amount) as lo_singlefam
from lar_1996_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_1996_raw as select *, sum(amount) as lo_multifam
from lar_1996_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_1996 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_1996_raw;
run;
proc sort data=hmda_singlefam_1996 nodupkey;
by resp_id;
run;
data hmda_multifam_1996 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_1996_raw;
run;
proc sort data=hmda_multifam_1996 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_1996;
set hmda_singlefam_1996;
run;
data hmda.hmda_multifam_1996;
set hmda_multifam_1996;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_1996_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_1996 as a left join hmda.panel_1996_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_1996_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231
from hmda_singlefam_1996_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_1996_2 nodupkey out=hmda_singlefam_1996_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_1996;
set hmda_singlefam_1996_3;
run;

proc sql;
create table hmda_multifam_1996_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_1996 as a left join hmda.panel_1996_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_1996_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231, b.topid_19971231
from hmda_multifam_1996_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_1996_2 nodupkey out=hmda_multifam_1996_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_1996;
set hmda_multifam_1996_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_1996_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_1996 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_1996;
set hmda_singlefam_1996_4;
run;

proc sql;
create table hmda_multifam_1996_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_1996 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_1996;
set hmda_multifam_1996_4;
run;
proc sort data=hmda.hmda_singlefam_1996 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_1996 nodupkey;
by resp_id agency_code;
run;

/*1997*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_1997_singlefam;
set lar_1997;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_1997_multifam;
set lar_1997;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_1997_raw as select *, sum(amount) as lo_singlefam
from lar_1997_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_1997_raw as select *, sum(amount) as lo_multifam
from lar_1997_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_1997 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_1997_raw;
run;
proc sort data=hmda_singlefam_1997 nodupkey;
by resp_id;
run;
data hmda_multifam_1997 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_1997_raw;
run;
proc sort data=hmda_multifam_1997 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_1997;
set hmda_singlefam_1997;
run;
data hmda.hmda_multifam_1997;
set hmda_multifam_1997;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_1997_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_1997 as a left join hmda.panel_1997_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_1997_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231
from hmda_singlefam_1997_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_1997_2 nodupkey out=hmda_singlefam_1997_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_1997;
set hmda_singlefam_1997_3;
run;

proc sql;
create table hmda_multifam_1997_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_1997 as a left join hmda.panel_1997_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_1997_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231, b.topid_19981231
from hmda_multifam_1997_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_1997_2 nodupkey out=hmda_multifam_1997_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_1997;
set hmda_multifam_1997_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_1997_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_1997 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_1997;
set hmda_singlefam_1997_4;
run;

proc sql;
create table hmda_multifam_1997_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_1997 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_1997;
set hmda_multifam_1997_4;
run;
proc sort data=hmda.hmda_singlefam_1997 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_1997 nodupkey;
by resp_id agency_code;
run;


/*1998*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_1998_singlefam;
set lar_1998;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_1998_multifam;
set lar_1998;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_1998_raw as select *, sum(amount) as lo_singlefam
from lar_1998_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_1998_raw as select *, sum(amount) as lo_multifam
from lar_1998_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_1998 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_1998_raw;
run;
proc sort data=hmda_singlefam_1998 nodupkey;
by resp_id;
run;
data hmda_multifam_1998 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_1998_raw;
run;
proc sort data=hmda_multifam_1998 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_1998;
set hmda_singlefam_1998;
run;
data hmda.hmda_multifam_1998;
set hmda_multifam_1998;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_1998_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_1998 as a left join hmda.panel_1998_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_1998_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231
from hmda_singlefam_1998_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_1998_2 nodupkey out=hmda_singlefam_1998_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_1998;
set hmda_singlefam_1998_3;
run;

proc sql;
create table hmda_multifam_1998_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_1998 as a left join hmda.panel_1998_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_1998_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231, b.topid_19991231
from hmda_multifam_1998_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_1998_2 nodupkey out=hmda_multifam_1998_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_1998;
set hmda_multifam_1998_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_1998_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_1998 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_1998;
set hmda_singlefam_1998_4;
run;

proc sql;
create table hmda_multifam_1998_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_1998 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_1998;
set hmda_multifam_1998_4;
run;
proc sort data=hmda.hmda_singlefam_1998 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_1998 nodupkey;
by resp_id agency_code;
run;


/*1999*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_1999_singlefam;
set lar_1999;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_1999_multifam;
set lar_1999;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_1999_raw as select *, sum(amount) as lo_singlefam
from lar_1999_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_1999_raw as select *, sum(amount) as lo_multifam
from lar_1999_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_1999 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_1999_raw;
run;
proc sort data=hmda_singlefam_1999 nodupkey;
by resp_id;
run;
data hmda_multifam_1999 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_1999_raw;
run;
proc sort data=hmda_multifam_1999 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_1999;
set hmda_singlefam_1999;
run;
data hmda.hmda_multifam_1999;
set hmda_multifam_1999;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_1999_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_1999 as a left join hmda.panel_1999_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_1999_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231
from hmda_singlefam_1999_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_1999_2 nodupkey out=hmda_singlefam_1999_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_1999;
set hmda_singlefam_1999_3;
run; 

proc sql;
create table hmda_multifam_1999_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_1999 as a left join hmda.panel_1999_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_1999_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231, b.topid_20001231
from hmda_multifam_1999_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_1999_2 nodupkey out=hmda_multifam_1999_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_1999;
set hmda_multifam_1999_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_1999_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_1999 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_1999;
set hmda_singlefam_1999_4;
run;

proc sql;
create table hmda_multifam_1999_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_1999 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_1999;
set hmda_multifam_1999_4;
run;
proc sort data=hmda.hmda_singlefam_1999 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_1999 nodupkey;
by resp_id agency_code;
run;


/*2000*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_2000_singlefam;
set lar_2000;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_2000_multifam;
set lar_2000;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2000_raw as select *, sum(amount) as lo_singlefam
from lar_2000_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_2000_raw as select *, sum(amount) as lo_multifam
from lar_2000_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_2000 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2000_raw;
run;
proc sort data=hmda_singlefam_2000 nodupkey;
by resp_id;
run;
data hmda_multifam_2000 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2000_raw;
run;
proc sort data=hmda_multifam_2000 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_2000;
set hmda_singlefam_2000;
run;
data hmda.hmda_multifam_2000;
set hmda_multifam_2000;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2000_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_2000 as a left join hmda.panel_2000_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_2000_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231
from hmda_singlefam_2000_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2000_2 nodupkey out=hmda_singlefam_2000_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2000;
set hmda_singlefam_2000_3;
run; 

proc sql;
create table hmda_multifam_2000_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_2000 as a left join hmda.panel_2000_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2000_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231, b.topid_20011231
from hmda_multifam_2000_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2000_2 nodupkey out=hmda_multifam_2000_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2000;
set hmda_multifam_2000_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_2000_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2000 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2000;
set hmda_singlefam_2000_4;
run;

proc sql;
create table hmda_multifam_2000_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2000 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2000;
set hmda_multifam_2000_4;
run;
proc sort data=hmda.hmda_singlefam_2000 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_2000 nodupkey;
by resp_id agency_code;
run;


/*2001*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_2001_singlefam;
set lar_2001;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_2001_multifam;
set lar_2001;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2001_raw as select *, sum(amount) as lo_singlefam
from lar_2001_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_2001_raw as select *, sum(amount) as lo_multifam
from lar_2001_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_2001 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2001_raw;
run;
proc sort data=hmda_singlefam_2001 nodupkey;
by resp_id;
run;
data hmda_multifam_2001 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2001_raw;
run;
proc sort data=hmda_multifam_2001 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_2001;
set hmda_singlefam_2001;
run;
data hmda.hmda_multifam_2001;
set hmda_multifam_2001;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2001_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_2001 as a left join hmda.panel_2001_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_2001_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231
from hmda_singlefam_2001_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2001_2 nodupkey out=hmda_singlefam_2001_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2001;
set hmda_singlefam_2001_3;
run; 

proc sql;
create table hmda_multifam_2001_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_2001 as a left join hmda.panel_2001_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2001_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231, b.topid_20021231
from hmda_multifam_2001_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2001_2 nodupkey out=hmda_multifam_2001_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2001;
set hmda_multifam_2001_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_2001_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2001 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2001;
set hmda_singlefam_2001_4;
run;

proc sql;
create table hmda_multifam_2001_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2001 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2001;
set hmda_multifam_2001_4;
run;
proc sort data=hmda.hmda_singlefam_2001 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_2001 nodupkey;
by resp_id agency_code;
run;


/*2002*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_2002_singlefam;
set lar_2002;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_2002_multifam;
set lar_2002;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2002_raw as select *, sum(amount) as lo_singlefam
from lar_2002_singlefam
group by resp_id
order by resp_id;
quit;
proc sql;
create table hmda_multifam_2002_raw as select *, sum(amount) as lo_multifam
from lar_2002_multifam
group by resp_id
order by resp_id;
quit;

data hmda_singlefam_2002 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2002_raw;
run;
proc sort data=hmda_singlefam_2002 nodupkey;
by resp_id;
run;
data hmda_multifam_2002 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2002_raw;
run;
proc sort data=hmda_multifam_2002 nodupkey;
by resp_id;
run;

data hmda.hmda_singlefam_2002;
set hmda_singlefam_2002;
run;
data hmda.hmda_multifam_2002;
set hmda_multifam_2002;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2002_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_2002 as a left join hmda.panel_2002_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_2002_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231
from hmda_singlefam_2002_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2002_2 nodupkey out=hmda_singlefam_2002_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2002;
set hmda_singlefam_2002_3;
run; 

proc sql;
create table hmda_multifam_2002_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_2002 as a left join hmda.panel_2002_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2002_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231,
b.topid_20031231
from hmda_multifam_2002_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2002_2 nodupkey out=hmda_multifam_2002_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2002;
set hmda_multifam_2002_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_2002_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2002 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2002;
set hmda_singlefam_2002_4;
run;

proc sql;
create table hmda_multifam_2002_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2002 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2002;
set hmda_multifam_2002_4;
run;
proc sort data=hmda.hmda_singlefam_2002 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_2002 nodupkey;
by resp_id agency_code;
run;


/*2003*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_2003_singlefam;
set hmda.lar_2003;
if action not in (1,6) then delete;
if loan_purp = 4 then delete; /*loan_purp 1-3 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_2003_multifam;
set hmda.lar_2003;
if action not in (1,6) then delete;
if loan_purp ne 4 then delete; /*loan_purp = 4 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2003_raw as select *, sum(amount) as lo_singlefam
from lar_2003_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2003_raw as select *, sum(amount) as lo_multifam
from lar_2003_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2003 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2003_raw;
run;
proc sort data=hmda_singlefam_2003 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2003 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2003_raw;
run;
proc sort data=hmda_multifam_2003 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2003;
set hmda_singlefam_2003;
run;
data hmda.hmda_multifam_2003;
set hmda_multifam_2003;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2003_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_singlefam_2003 as a left join hmda.panel_2003_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_2003_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231
from hmda_singlefam_2003_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2003_2 nodupkey out=hmda_singlefam_2003_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2003;
set hmda_singlefam_2003_3;
run; 

proc sql;
create table hmda_multifam_2003_1 as select a.*, b.id_rssd as rssdid
from hmda.hmda_multifam_2003 as a left join hmda.panel_2003_withrssd as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2003_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231, b.topid_20041231
from hmda_multifam_2003_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2003_2 nodupkey out=hmda_multifam_2003_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2003;
set hmda_multifam_2003_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_2003_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2003 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2003;
set hmda_singlefam_2003_4;
run;

proc sql;
create table hmda_multifam_2003_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2003 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2003;
set hmda_multifam_2003_4;
run;
proc sort data=hmda.hmda_singlefam_2003 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_2003 nodupkey;
by resp_id agency_code;
run;


/*Infile LAR (HMDA's Loan/Application Register) 2004-2009*/
data hmda.lar_2004;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 2004.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-29 state 30-31 county 32-34
census_tract 35-41 app_sex 42 coapp_sex 43 app_income 44-47 purchaser_type 48 denial1 49 denial2 50 denial3 51 edit_status 52
prop_type 53 preapproval 54 app_ethnicity 55 coapp_ethnicity 56 app_race1 57 app_race2 58 app_race3 59 app_race4 60 app_race5 61
coapp_race1 62 coapp_race2 63 coapp_race3 64 coapp_race4 65 coapp_race5 66 rate_spread 67-71 hoepa_status 72 lien_status 73 sequence_no 74-80;
run;

data hmda.lar_2005;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 2005.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-29 state 30-31 county 32-34
census_tract 35-41 app_sex 42 coapp_sex 43 app_income 44-47 purchaser_type 48 denial1 49 denial2 50 denial3 51 edit_status 52
prop_type 53 preapproval 54 app_ethnicity 55 coapp_ethnicity 56 app_race1 57 app_race2 58 app_race3 59 app_race4 60 app_race5 61
coapp_race1 62 coapp_race2 63 coapp_race3 64 coapp_race4 65 coapp_race5 66 rate_spread 67-71 hoepa_status 72 lien_status 73 sequence_no 74-80;
run;

data hmda.lar_2006;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 2006.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-29 state 30-31 county 32-34
census_tract 35-41 app_sex 42 coapp_sex 43 app_income 44-47 purchaser_type 48 denial1 49 denial2 50 denial3 51 edit_status 52
prop_type 53 preapproval 54 app_ethnicity 55 coapp_ethnicity 56 app_race1 57 app_race2 58 app_race3 59 app_race4 60 app_race5 61
coapp_race1 62 coapp_race2 63 coapp_race3 64 coapp_race4 65 coapp_race5 66 rate_spread 67-71 hoepa_status 72 lien_status 73 sequence_no 74-80;
run;

data hmda.lar_2007;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 2007.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-29 state 30-31 county 32-34
census_tract 35-41 app_sex 42 coapp_sex 43 app_income 44-47 purchaser_type 48 denial1 49 denial2 50 denial3 51 edit_status 52
prop_type 53 preapproval 54 app_ethnicity 55 coapp_ethnicity 56 app_race1 57 app_race2 58 app_race3 59 app_race4 60 app_race5 61
coapp_race1 62 coapp_race2 63 coapp_race3 64 coapp_race4 65 coapp_race5 66 rate_spread 67-71 hoepa_status 72 lien_status 73 sequence_no 74-80;
run;

data hmda.lar_2008;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 2008.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-29 state 30-31 county 32-34
census_tract 35-41 app_sex 42 coapp_sex 43 app_income 44-47 purchaser_type 48 denial1 49 denial2 50 denial3 51 edit_status 52
prop_type 53 preapproval 54 app_ethnicity 55 coapp_ethnicity 56 app_race1 57 app_race2 58 app_race3 59 app_race4 60 app_race5 61
coapp_race1 62 coapp_race2 63 coapp_race3 64 coapp_race4 65 coapp_race5 66 rate_spread 67-71 hoepa_status 72 lien_status 73 sequence_no 74-80;
run;

data hmda.lar_2009;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\HMDA 2009.txt';
input year 1-4 resp_id $ 5-14 agency_code 15 loan_type 16 loan_purp 17 occupancy 18 amount 19-23 action 24 msa 25-29 state 30-31 county 32-34
census_tract 35-41 app_sex 42 coapp_sex 43 app_income 44-47 purchaser_type 48 denial1 49 denial2 50 denial3 51 edit_status 52
prop_type 53 preapproval 54 app_ethnicity 55 coapp_ethnicity 56 app_race1 57 app_race2 58 app_race3 59 app_race4 60 app_race5 61
coapp_race1 62 coapp_race2 63 coapp_race3 64 coapp_race4 65 coapp_race5 66 rate_spread 67-71 hoepa_status 72 lien_status 73 sequence_no 74-80;
run;

/*SUMMARIZE LOAN ORIGINATIONS BY LOAN TYPE AND INSTITUTION 2004-2009*/
/*2004*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_2004_singlefam;
set hmda.lar_2004;
if action not in (1,6) then delete;
if prop_type = 3 then delete; /*prop_type 1-2 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_2004_multifam;
set hmda.lar_2004;
if action not in (1,6) then delete;
if loan_purp ne 3 then delete; /*prop_type 3 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2004_raw as select *, sum(amount) as lo_singlefam
from lar_2004_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2004_raw as select *, sum(amount) as lo_multifam
from lar_2004_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2004 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2004_raw;
run;
proc sort data=hmda_singlefam_2004 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2004 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2004_raw;
run;
proc sort data=hmda_multifam_2004 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2004;
set hmda_singlefam_2004;
run;
data hmda.hmda_multifam_2004;
set hmda_multifam_2004;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2004_1 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231
from hmda.hmda_singlefam_2004 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2004_1 nodupkey out=hmda_singlefam_2004_2 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2004;
set hmda_singlefam_2004_2;
run; 

proc sql;
create table hmda_multifam_2004_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2004 as a left join hmda.panel_2004_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2004_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231, b.topid_20051231
from hmda_multifam_2004_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2004_2 nodupkey out=hmda_multifam_2004_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2004;
set hmda_multifam_2004_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_2004_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2004 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2004;
set hmda_singlefam_2004_4;
run;

proc sql;
create table hmda_multifam_2004_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2004 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2004;
set hmda_multifam_2004_4;
run;
proc sort data=hmda.hmda_singlefam_2004 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_2004 nodupkey;
by resp_id agency_code;
run;



/*2005*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_2005_singlefam;
set hmda.lar_2005;
if action not in (1,6) then delete;
if prop_type = 3 then delete; /*prop_type 1-2 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_2005_multifam;
set hmda.lar_2005;
if action not in (1,6) then delete;
if loan_purp ne 3 then delete; /*prop_type 3 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2005_raw as select *, sum(amount) as lo_singlefam
from lar_2005_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2005_raw as select *, sum(amount) as lo_multifam
from lar_2005_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2005 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2005_raw;
run;
proc sort data=hmda_singlefam_2005 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2005 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2005_raw;
run;
proc sort data=hmda_multifam_2005 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2005;
set hmda_singlefam_2005;
run;
data hmda.hmda_multifam_2005;
set hmda_multifam_2005;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2005_1 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231
from hmda.hmda_singlefam_2005 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2005_1 nodupkey out=hmda_singlefam_2005_2 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2005;
set hmda_singlefam_2005_2;
run; 

proc sql;
create table hmda_multifam_2005_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2005 as a left join hmda.panel_2005_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2005_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231, b.topid_20061231
from hmda_multifam_2005_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2005_2 nodupkey out=hmda_multifam_2005_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2005;
set hmda_multifam_2005_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_2005_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2005 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2005;
set hmda_singlefam_2005_4;
run;

proc sql;
create table hmda_multifam_2005_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2005 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2005;
set hmda_multifam_2005_4;
run;
proc sort data=hmda.hmda_singlefam_2005 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_2005 nodupkey;
by resp_id agency_code;
run;


/*2006*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_2006_singlefam;
set hmda.lar_2006;
if action not in (1,6) then delete;
if prop_type = 3 then delete; /*prop_type 1-2 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_2006_multifam;
set hmda.lar_2006;
if action not in (1,6) then delete;
if loan_purp ne 3 then delete; /*prop_type 3 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2006_raw as select *, sum(amount) as lo_singlefam
from lar_2006_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2006_raw as select *, sum(amount) as lo_multifam
from lar_2006_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2006 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2006_raw;
run;
proc sort data=hmda_singlefam_2006 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2006 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2006_raw;
run;
proc sort data=hmda_multifam_2006 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2006;
set hmda_singlefam_2006;
run;
data hmda.hmda_multifam_2006;
set hmda_multifam_2006;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2006_1 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231
from hmda.hmda_singlefam_2006 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2006_1 nodupkey out=hmda_singlefam_2006_2 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2006;
set hmda_singlefam_2006_2;
run; 

proc sql;
create table hmda_multifam_2006_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2006 as a left join hmda.panel_2006_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2006_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231, b.topid_20071231
from hmda_multifam_2006_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2006_2 nodupkey out=hmda_multifam_2006_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2006;
set hmda_multifam_2006_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_2006_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2006 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2006;
set hmda_singlefam_2006_4;
run;

proc sql;
create table hmda_multifam_2006_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2006 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2006;
set hmda_multifam_2006_4;
run;
proc sort data=hmda.hmda_singlefam_2006 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_2006 nodupkey;
by resp_id agency_code;
run;


/*2007*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_2007_singlefam;
set hmda.lar_2007;
if action not in (1,6) then delete;
if prop_type = 3 then delete; /*prop_type 1-2 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_2007_multifam;
set hmda.lar_2007;
if action not in (1,6) then delete;
if loan_purp ne 3 then delete; /*prop_type 3 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2007_raw as select *, sum(amount) as lo_singlefam
from lar_2007_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2007_raw as select *, sum(amount) as lo_multifam
from lar_2007_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2007 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2007_raw;
run;
proc sort data=hmda_singlefam_2007 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2007 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2007_raw;
run;
proc sort data=hmda_multifam_2007 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2007;
set hmda_singlefam_2007;
run;
data hmda.hmda_multifam_2007;
set hmda_multifam_2007;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2007_1 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231
from hmda.hmda_singlefam_2007 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2007_1 nodupkey out=hmda_singlefam_2007_2 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2007;
set hmda_singlefam_2007_2;
run; 

proc sql;
create table hmda_multifam_2007_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2007 as a left join hmda.panel_2007_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2007_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231, b.topid_20081231
from hmda_multifam_2007_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2007_2 nodupkey out=hmda_multifam_2007_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2007;
set hmda_multifam_2007_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_2007_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2007 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2007;
set hmda_singlefam_2007_4;
run;

proc sql;
create table hmda_multifam_2007_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2007 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2007;
set hmda_multifam_2007_4;
run;
proc sort data=hmda.hmda_singlefam_2007 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_2007 nodupkey;
by resp_id agency_code;
run;

/*2008*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_2008_singlefam;
set hmda.lar_2008;
if action not in (1,6) then delete;
if prop_type = 3 then delete; /*prop_type 1-2 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_2008_multifam;
set hmda.lar_2008;
if action not in (1,6) then delete;
if loan_purp ne 3 then delete; /*prop_type 3 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2008_raw as select *, sum(amount) as lo_singlefam
from lar_2008_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2008_raw as select *, sum(amount) as lo_multifam
from lar_2008_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2008 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2008_raw;
run;
proc sort data=hmda_singlefam_2008 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2008 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2008_raw;
run;
proc sort data=hmda_multifam_2008 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2008;
set hmda_singlefam_2008;
run;
data hmda.hmda_multifam_2008;
set hmda_multifam_2008;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2008_1 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231
from hmda.hmda_singlefam_2008 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2008_1 nodupkey out=hmda_singlefam_2008_2 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2008;
set hmda_singlefam_2008_2;
run; 

proc sql;
create table hmda_multifam_2008_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2008 as a left join hmda.panel_2008_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2008_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231, b.topid_20091231
from hmda_multifam_2008_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2008_2 nodupkey out=hmda_multifam_2008_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2008;
set hmda_multifam_2008_3;
run;

*Update through 2016;
proc sql;
create table hmda_singlefam_2008_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2008 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2008;
set hmda_singlefam_2008_4;
run;

proc sql;
create table hmda_multifam_2008_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2008 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2008;
set hmda_multifam_2008_4;
run;
proc sort data=hmda.hmda_singlefam_2008 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_2008 nodupkey;
by resp_id agency_code;
run;


/*2009*/
*Remove loans that were not originated (action code=1) or purchased (action code=6).  
Also remove loans originated and sold in the same calendar year;
data lar_2009_singlefam;
set hmda.lar_2009;
if action not in (1,6) then delete;
if prop_type = 3 then delete; /*prop_type 1-2 are for single-family dwellings*/
if purchaser_type ne 0 then delete;
run;
data lar_2009_multifam;
set hmda.lar_2009;
if action not in (1,6) then delete;
if loan_purp ne 3 then delete; /*prop_type 3 is for multifamily dwellings*/
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2009_raw as select *, sum(amount) as lo_singlefam
from lar_2009_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2009_raw as select *, sum(amount) as lo_multifam
from lar_2009_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2009 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2009_raw;
run;
proc sort data=hmda_singlefam_2009 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2009 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2009_raw;
run;
proc sort data=hmda_multifam_2009 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2009;
set hmda_singlefam_2009;
run;
data hmda.hmda_multifam_2009;
set hmda_multifam_2009;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2009_1 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231
from hmda.hmda_singlefam_2009 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2009_1 nodupkey out=hmda_singlefam_2009_2 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2009;
set hmda_singlefam_2009_2;
run;

proc sql;
create table hmda_multifam_2009_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2009 as a left join hmda.panel_2009_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2009_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231,
b.topid_20101231
from hmda_multifam_2009_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2009_2 nodupkey out=hmda_multifam_2009_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2009;
set hmda_multifam_2009_3;
run;

*Update top ID through 2016;
proc sql;
create table hmda_singlefam_2009_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2009 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2009;
set hmda_singlefam_2009_4;
run;

proc sql;
create table hmda_multifam_2009_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2009 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2009;
set hmda_multifam_2009_4;
run;
proc sort data=hmda.hmda_singlefam_2009 nodupkey;
by resp_id agency_code;
run;
proc sort data=hmda.hmda_multifam_2009 nodupkey;
by resp_id agency_code;
run;

/*2016*/
data hmda.lar_2016;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2016HMDALAR - National.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

*Remove loans that were not originated (action code=1) or purchased by the institution (action code=6)
Also remove loans that were sold during the same calendar year (purchaser_type not 0);
data lar_2016_singlefam;
set hmda.lar_2016;
if action not in (1,6) then delete;
if prop_type not in (1,2) then delete;
if purchaser_type ne 0 then delete;
run;
data lar_2016_multifam;
set hmda.lar_2016;
if action not in (1,6) then delete;
if prop_type ne 3 then delete;
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2016_raw as select *, sum(amount) as lo_singlefam
from lar_2016_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2016_raw as select *, sum(amount) as lo_multifam
from lar_2016_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2016 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2016_raw;
run;
proc sort data=hmda_singlefam_2016 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2016 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2016_raw;
run;
proc sort data=hmda_multifam_2016 nodupkey;
by agency_code resp_id;
run;

*Add rssdid;
proc sql;
create table hmda_singlefam_2016_1 as select a.*, b.rssdid
from hmda.hmda_singlefam_2016 as a left join hmda.panel_2016_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sort data=hmda_singlefam_2016_1 nodupkey dupout=hmda_dups;
by agency_code resp_id;
run;
proc sql;
create table hmda_multifam_2016_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2016 as a left join hmda.panel_2016_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sort data=hmda_multifam_2016_1 nodupkey dupout=hmda_dups;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2016;
set hmda_singlefam_2016_1;
run;
data hmda.hmda_multifam_2016;
set hmda_multifam_2016_1;
run;

/*2015*/
data hmda.lar_2015;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2015HMDALAR - National.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

*Remove loans that were not originated (action code=1) or purchased by the institution (action code=6)
Also remove loans that were sold during the same calendar year (purchaser_type not 0);
data lar_2015_singlefam;
set hmda.lar_2015;
if action not in (1,6) then delete;
if prop_type not in (1,2) then delete;
if purchaser_type ne 0 then delete;
run;
data lar_2015_multifam;
set hmda.lar_2015;
if action not in (1,6) then delete;
if prop_type ne 3 then delete;
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2015_raw as select *, sum(amount) as lo_singlefam
from lar_2015_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2015_raw as select *, sum(amount) as lo_multifam
from lar_2015_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2015 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2015_raw;
run;
proc sort data=hmda_singlefam_2015 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2015 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2015_raw;
run;
proc sort data=hmda_multifam_2015 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2015;
set hmda_singlefam_2015;
run;
data hmda.hmda_multifam_2015;
set hmda_multifam_2015;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2015_1 as select a.*, b.rssdid
from hmda.hmda_singlefam_2015 as a left join hmda.panel_2015_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_2015_2 as select a.*, b.topid_20161231
from hmda_singlefam_2015_1 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by a.resp_id;
quit;
proc sort data=hmda_singlefam_2015_2 nodupkey out=hmda_singlefam_2015_3;
by rssdid resp_id;
run;
data hmda.hmda_singlefam_2015;
set hmda_singlefam_2015_3;
run;

proc sql;
create table hmda_multifam_2015_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2015 as a left join hmda.panel_2015_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2015_2 as select a.*, b.topid_20161231
from hmda_multifam_2015_1 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by a.resp_id;
quit;
proc sort data=hmda_multifam_2015_2 nodupkey out=hmda_multifam_2015_3;
by rssdid resp_id;
run;
data hmda.hmda_multifam_2015;
set hmda_multifam_2015_3;
run;


/*2014*/
data lar_2014_1;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2014 LAR 1.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data lar_2014_2;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2014 LAR 2.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data lar_2014_3;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2014 LAR 3.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data hmda.lar_2014;
set lar_2014_1 lar_2014_2 lar_2014_3;
run;
*Remove loans that were not originated (action code=1) or purchased by the institution (action code=6)
Also remove loans that were sold during the same calendar year (purchaser_type not 0);
data lar_2014_singlefam;
set hmda.lar_2014;
if action not in (1,6) then delete;
if prop_type not in (1,2) then delete;
if purchaser_type ne 0 then delete;
run;
data lar_2014_multifam;
set hmda.lar_2014;
if action not in (1,6) then delete;
if prop_type ne 3 then delete;
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2014_raw as select *, sum(amount) as lo_singlefam
from lar_2014_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2014_raw as select *, sum(amount) as lo_multifam
from lar_2014_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2014 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2014_raw;
run;
proc sort data=hmda_singlefam_2014 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2014 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2014_raw;
run;
proc sort data=hmda_multifam_2014 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2014;
set hmda_singlefam_2014;
run;
data hmda.hmda_multifam_2014;
set hmda_multifam_2014;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2014_1 as select a.*, b.rssdid
from hmda.hmda_singlefam_2014 as a left join hmda.panel_2014_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_2014_2 as select a.*, b.topid_20151231, b.topid_20161231
from hmda_singlefam_2014_1 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by a.resp_id;
quit;
proc sort data=hmda_singlefam_2014_2 nodupkey out=hmda_singlefam_2014_3;
by rssdid resp_id;
run;
data hmda.hmda_singlefam_2014;
set hmda_singlefam_2014_3;
run;

proc sql;
create table hmda_multifam_2014_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2014 as a left join hmda.panel_2014_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2014_2 as select a.*, b.topid_20151231, b.topid_20161231
from hmda_multifam_2014_1 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by a.resp_id;
quit;
proc sort data=hmda_multifam_2014_2 nodupkey out=hmda_multifam_2014_3;
by rssdid resp_id;
run;
data hmda.hmda_multifam_2014;
set hmda_multifam_2014_3;
run;


/*2013*/
data lar_2013_1;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2013 LAR 1.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data lar_2013_2;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2013 LAR 2.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data lar_2013_3;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2013 LAR 3.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data hmda.lar_2013;
set lar_2013_1 lar_2013_2 lar_2013_3;
run;
proc sort data=hmda.lar_2013;
by resp_id;
run;
*Remove loans that were not originated (action code=1) or purchased (action code=6);
data lar_2013_singlefam;
set hmda.lar_2013;
if action not in (1,6) then delete;
if prop_type not in (1,2) then delete;
if purchaser_type ne 0 then delete;
run;
data lar_2013_multifam;
set hmda.lar_2013;
if action not in (1,6) then delete;
if prop_type ne 3 then delete;
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2013_raw as select *, sum(amount) as lo_singlefam
from lar_2013_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2013_raw as select *, sum(amount) as lo_multifam
from lar_2013_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2013 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2013_raw;
run;
proc sort data=hmda_singlefam_2013 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2013 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2013_raw;
run;
proc sort data=hmda_multifam_2013 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2013;
set hmda_singlefam_2013;
run;
data hmda.hmda_multifam_2013;
set hmda_multifam_2013;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2013_1 as select a.*, b.rssdid
from hmda.hmda_singlefam_2013 as a left join hmda.panel_2013_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_singlefam_2013_2 as select a.*, b.topid_20141231
from hmda_singlefam_2013_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.resp_id;
quit;
proc sort data=hmda_singlefam_2013_2 nodupkey out=hmda_singlefam_2013_3;
by rssdid resp_id;
run;
data hmda.hmda_singlefam_2013;
set hmda_singlefam_2013_3;
run;


proc sql;
create table hmda_multifam_2013_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2013 as a left join hmda.panel_2013_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2013_2 as select a.*, b.topid_20141231
from hmda_multifam_2013_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.resp_id;
quit;
proc sort data=hmda_multifam_2013_2 nodupkey out=hmda_multifam_2013_3;
by rssdid resp_id;
run;
data hmda.hmda_multifam_2013;
set hmda_multifam_2013_3;
run;

*Update top ID through 2016;
proc sql;
create table hmda_singlefam_2013_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2013 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2013;
set hmda_singlefam_2013_4;
run;
proc sort data=hmda.hmda_singlefam_2013 nodupkey;
by rssdid resp_id;
run;

proc sql;
create table hmda_multifam_2013_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2013 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2013;
set hmda_multifam_2013_4;
run;
proc sort data=hmda.hmda_multifam_2013 nodupkey;
by rssdid resp_id;
run;

/*2012*/
data lar_2012_1;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2012 LAR 1.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data lar_2012_2;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2012 LAR 2.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data lar_2012_3;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2012 LAR 3.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data hmda.lar_2012;
set lar_2012_1 lar_2012_2 lar_2012_3;
run;
*Remove loans that were not originated (action code=1) or purchased (action code=6);
data lar_2012_singlefam;
set hmda.lar_2012;
if action not in (1,6) then delete;
if prop_type not in (1,2) then delete;
if purchaser_type ne 0 then delete;
run;
data lar_2012_multifam;
set hmda.lar_2012;
if action not in (1,6) then delete;
if prop_type ne 3 then delete;
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2012_raw as select *, sum(amount) as lo_singlefam
from lar_2012_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2012_raw as select *, sum(amount) as lo_multifam
from lar_2012_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2012 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2012_raw;
run;
proc sort data=hmda_singlefam_2012 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2012 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2012_raw;
run;
proc sort data=hmda_multifam_2012 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2012;
set hmda_singlefam_2012;
run;
data hmda.hmda_multifam_2012;
set hmda_multifam_2012;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2012_1 as select a.*, b.topid_20141231, b.topid_20131231
from hmda.hmda_singlefam_2012 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2012_1 nodupkey out=hmda_singlefam_2012_2 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2012;
set hmda_singlefam_2012_2;
run;

proc sql;
create table hmda_multifam_2012_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2012 as a left join hmda.panel_2012_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2012_2 as select a.*, b.topid_20141231, b.topid_20131231
from hmda_multifam_2012_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2012_2 nodupkey out=hmda_multifam_2012_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2012;
set hmda_multifam_2012_3;
run;

*Update top ID through 2016;
proc sql;
create table hmda_singlefam_2012_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2012 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2012;
set hmda_singlefam_2012_4;
run;

proc sql;
create table hmda_multifam_2012_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2012 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2012;
set hmda_multifam_2012_4;
run;
proc sort data=hmda.hmda_singlefam_2012 nodupkey;
by rssdid resp_id;
run;
proc sort data=hmda.hmda_multifam_2012 nodupkey;
by rssdid resp_id;
run;

/*2011*/
data lar_2011_1;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2011 LAR 1.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data lar_2011_2;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2011 LAR 2.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data lar_2011_3;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2011 LAR 3.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data hmda.lar_2011;
set lar_2011_1 lar_2011_2 lar_2011_3;
run;
*Remove loans that were not originated (action code=1) or purchased (action code=6);
data lar_2011_singlefam;
set hmda.lar_2011;
if action not in (1,6) then delete;
if prop_type not in (1,2) then delete;
if purchaser_type ne 0 then delete;
run;
data lar_2011_multifam;
set hmda.lar_2011;
if action not in (1,6) then delete;
if prop_type ne 3 then delete;
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2011_raw as select *, sum(amount) as lo_singlefam
from lar_2011_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2011_raw as select *, sum(amount) as lo_multifam
from lar_2011_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2011 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2011_raw;
run;
proc sort data=hmda_singlefam_2011 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2011 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2011_raw;
run;
proc sort data=hmda_multifam_2011 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2011;
set hmda_singlefam_2011;
run;
data hmda.hmda_multifam_2011;
set hmda_multifam_2011;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2011_1 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231
from hmda.hmda_singlefam_2011 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2011_1 nodupkey out=hmda_singlefam_2011_2 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2011;
set hmda_singlefam_2011_2;
run;

proc sql;
create table hmda_multifam_2011_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2011 as a left join hmda.panel_2011_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2011_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231
from hmda_multifam_2011_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2011_2 nodupkey out=hmda_multifam_2011_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2011;
set hmda_multifam_2011_3;
run;

*Update top ID through 2016;
proc sql;
create table hmda_singlefam_2011_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2011 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2011;
set hmda_singlefam_2011_4;
run;

proc sql;
create table hmda_multifam_2011_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2011 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2011;
set hmda_multifam_2011_4;
run;
proc sort data=hmda.hmda_singlefam_2011 nodupkey;
by rssdid resp_id;
run;
proc sort data=hmda.hmda_multifam_2011 nodupkey;
by rssdid resp_id;
run;

/*2010*/
data lar_2010_1;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2010 LAR 1.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data lar_2010_2;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2010 LAR 2.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;

data lar_2010_3;
infile 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA\2010 LAR 3.csv' dlm= ',' dsd missover;
input year resp_id :$10. agency_code loan_type prop_type loan_purp occupancy amount preapproval action msa state county
census_tract app_ethnicity coapp_ethnicity app_race1 app_race2 app_race3 app_race4 app_race5 
coapp_race1 coapp_race2 coapp_race3 coapp_race4 coapp_race5 app_sex coapp_sex app_income purchaser_type
denial1 denial2 denial3 rate_spread hoepa_status lien_status edit_status sequence_no population minority_pop
ffiec_median_family_income tract_to_msa_income owner_occupied_units singlefam_units application_date_indicator;
run;


data hmda.lar_2010;
set lar_2010;
run;
data lar_2010;
set lar_2010_1 lar_2010_2 lar_2010_3;
run;
*Remove loans that were not originated (action code=1) or purchased (action code=6);
data lar_2010_singlefam;
set hmda.lar_2010;
if action not in (1,6) then delete;
if prop_type not in (1,2) then delete;
if purchaser_type ne 0 then delete;
run;
data lar_2010_multifam;
set lar_2010;
if action not in (1,6) then delete;
if prop_type ne 3 then delete;
if purchaser_type ne 0 then delete;
run;

proc sql;
create table hmda_singlefam_2010_raw as select *, sum(amount) as lo_singlefam
from lar_2010_singlefam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;
proc sql;
create table hmda_multifam_2010_raw as select *, sum(amount) as lo_multifam
from lar_2010_multifam
group by agency_code, resp_id
order by agency_code, resp_id;
quit;

data hmda_singlefam_2010 (keep = year resp_id agency_code lo_singlefam);
set hmda_singlefam_2010_raw;
run;
proc sort data=hmda_singlefam_2010 nodupkey;
by agency_code resp_id;
run;
data hmda_multifam_2010 (keep = year resp_id agency_code lo_multifam);
set hmda_multifam_2010_raw;
run;
proc sort data=hmda_multifam_2010 nodupkey;
by agency_code resp_id;
run;

data hmda.hmda_singlefam_2010;
set hmda_singlefam_2010;
run;
data hmda.hmda_multifam_2010;
set hmda_multifam_2010;
run;

*Add top regulatory ID's at future period ends;
proc sql;
create table hmda_singlefam_2010_1 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231
from hmda.hmda_singlefam_2010 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd order by a.rssdid;
quit;
proc sort data=hmda_singlefam_2010_1 nodupkey out=hmda_singlefam_2010_2 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_singlefam_2010;
set hmda_singlefam_2010_2;
run; 

proc sql;
create table hmda_multifam_2010_1 as select a.*, b.rssdid
from hmda.hmda_multifam_2010 as a left join hmda.panel_2010_nodupid as b
on a.resp_id=b.resp_id and a.agency_code=b.agency_code order by a.resp_id;
quit;
proc sql;
create table hmda_multifam_2010_2 as select a.*, b.topid_20141231, b.topid_20131231, b.topid_20121231, b.topid_20111231
from hmda_multifam_2010_1 as a left join box.top_regid_byperiod as b
on a.rssdid=b.id_rssd;
quit;
proc sort data=hmda_multifam_2010_2 nodupkey out=hmda_multifam_2010_3 dupout=hmda_dups;
by resp_id agency_code;
run;
data hmda.hmda_multifam_2010;
set hmda_multifam_2010_3;
run;

*Update top ID through 2016;
proc sql;
create table hmda_singlefam_2010_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_singlefam_2010 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_singlefam_2010;
set hmda_singlefam_2010_4;
run;

proc sql;
create table hmda_multifam_2010_4 as select a.*, b.topid_20161231, b.topid_20151231
from hmda.hmda_multifam_2010 as a left join box.top_regid_byperiod_2017 as b
on a.rssdid=b.id_rssd order by resp_id;
quit;
data hmda.hmda_multifam_2010;
set hmda_multifam_2010_4;
run;
proc sort data=hmda.hmda_singlefam_2010 nodupkey;
by rssdid resp_id;
run;
proc sort data=hmda.hmda_multifam_2010 nodupkey;
by rssdid resp_id;
run;

/*Aggregate all loan origination files from 1990-2016 into single file by loan type*/
data hmda.hmda_multifam_1990_2016;
set hmda.hmda_multifam_1990 hmda.hmda_multifam_1991 hmda.hmda_multifam_1992 hmda.hmda_multifam_1993 hmda.hmda_multifam_1994 hmda.hmda_multifam_1995 hmda.hmda_multifam_1996 
hmda.hmda_multifam_1997 hmda.hmda_multifam_1998 hmda.hmda_multifam_1999 hmda.hmda_multifam_2000 hmda.hmda_multifam_2001 hmda.hmda_multifam_2002 hmda.hmda_multifam_2003 
hmda.hmda_multifam_2004 hmda.hmda_multifam_2005 hmda.hmda_multifam_2006 hmda.hmda_multifam_2007 hmda.hmda_multifam_2008 hmda.hmda_multifam_2009 hmda.hmda_multifam_2010 
hmda.hmda_multifam_2011 hmda.hmda_multifam_2012 hmda.hmda_multifam_2013 hmda.hmda_multifam_2014 hmda.hmda_multifam_2015 hmda.hmda_multifam_2016;
run;

data hmda.hmda_singlefam_1990_2016;
set hmda.hmda_singlefam_1990 hmda.hmda_singlefam_1991 hmda.hmda_singlefam_1992 hmda.hmda_singlefam_1993 hmda.hmda_singlefam_1994 hmda.hmda_singlefam_1995 hmda.hmda_singlefam_1996 
hmda.hmda_singlefam_1997 hmda.hmda_singlefam_1998 hmda.hmda_singlefam_1999 hmda.hmda_singlefam_2000 hmda.hmda_singlefam_2001 hmda.hmda_singlefam_2002 hmda.hmda_singlefam_2003 
hmda.hmda_singlefam_2004 hmda.hmda_singlefam_2005 hmda.hmda_singlefam_2006 hmda.hmda_singlefam_2007 hmda.hmda_singlefam_2008 hmda.hmda_singlefam_2009 hmda.hmda_singlefam_2010 
hmda.hmda_singlefam_2011 hmda.hmda_singlefam_2012 hmda.hmda_singlefam_2013 hmda.hmda_singlefam_2014 hmda.hmda_singlefam_2015 hmda.hmda_singlefam_2016;
run;

























