/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below aggregates HMDA data on single-family loan originations at the consolidated level.

 =========================================================================================================*/

libname box 'C:\Users\pbwheele\Box Sync\Data Sets\CECL';

data ta;
set box.all_ta_1990_2017;
run;

/*HMDA Loan Originations Plus Lags*/
data sf_lo_1990_1 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 4 then delete;
run;
proc sql;
create table sf_lo_1990_2 as select a.*, b.ta
from sf_lo_1990_1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.name;
quit;
data sf_lo_1990_3;
set sf_lo_1990_2;
if ta=. then delete;
run;
/*Identify all subsidiaries in the corporate structure*/
proc sql;
create table sf_lo_1990_4a as select a.*, b.id_rssd_offspring as sub1_rssd 'sub1_rssd'
from sf_lo_1990_3 as a left join nic.relationships_names_20180331 as b
on a.rssd_id=b.id_rssd_parent and b.start<=11322<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_1990_4b as select a.*, b.id_rssd_offspring as sub2_rssd 'sub2_rssd'
from sf_lo_1990_4a as a left join nic.relationships_names_20180331 as b
on a.sub1_rssd=b.id_rssd_parent and b.start<=11322<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_1990_4c as select a.*, b.id_rssd_offspring as sub3_rssd 'sub3_rssd'
from sf_lo_1990_4b as a left join nic.relationships_names_20180331 as b
on a.sub2_rssd=b.id_rssd_parent and b.start<=11322<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_1990_4d as select a.*, b.id_rssd_offspring as sub4_rssd 'sub4_rssd'
from sf_lo_1990_4c as a left join nic.relationships_names_20180331 as b
on a.sub3_rssd=b.id_rssd_parent and b.start<=11322<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_1990_4e as select a.*, b.id_rssd_offspring as sub5_rssd 'sub5_rssd'
from sf_lo_1990_4d as a left join nic.relationships_names_20180331 as b
on a.sub4_rssd=b.id_rssd_parent and b.start<=11322<=b.end and (b.pct_equity>50 or b.other_basis_ind=1)
order by name, sub1_rssd, sub2_rssd, sub3_rssd, sub4_rssd;
quit;
/*Add single-family loan originations for 5th-level subsidiaries*/
data hmda_singlefam_1990;
set hmda.hmda_singlefam_1990;
if rssdid=. then delete;
run;
proc sql;
create table sf_lo_1990_5a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_1990_4e as a left join hmda_singlefam_1990 as b
on a.sub5_rssd=b.rssdid order by a.name;

create table sf_lo_1990_5b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_t
from sf_lo_1990_5a group by rssd_id order by name;
quit;
proc sort data=sf_lo_1990_5b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_1990_5c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_1990_5b as a left join hmda_singlefam_1990 as b
on a.sub4_rssd=b.rssdid order by a.name;

create table sf_lo_1990_5d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_t
from sf_lo_1990_5c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_1990_5d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_1990_5e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_1990_5d as a left join hmda_singlefam_1990 as b
on a.sub3_rssd=b.rssdid order by a.name;

create table sf_lo_1990_5f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_t
from sf_lo_1990_5e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_1990_5f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_1990_5g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_1990_5f as a left join hmda_singlefam_1990 as b
on a.sub2_rssd=b.rssdid order by a.name;

create table sf_lo_1990_5h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_t
from sf_lo_1990_5g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_1990_5h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_1990_5i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_1990_5h as a left join hmda_singlefam_1990 as b
on a.sub1_rssd=b.rssdid order by a.name;

create table sf_lo_1990_5j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_t
from sf_lo_1990_5i group by rssd_id order by name;
quit;
proc sort data=sf_lo_1990_5j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_1990_5k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_1990_5j as a left join hmda_singlefam_1990 as b
on a.rssd_id=b.rssdid order by a.name;

create table sf_lo_1990_5l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_t
from sf_lo_1990_5k group by rssd_id order by name;
quit;
proc sort data=sf_lo_1990_5l nodupkey;
by rssd_id;
run;
data sf_lo_1990_6 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_t lo_singlefam_sub1_t lo_singlefam_sub2_t lo_singlefam_sub3_t lo_singlefam_sub4_t lo_singlefam_sub5_t); 
set sf_lo_1990_5l;
if lo_singlefam_parent_t=. then lo_singlefam_parent_t=0;
if lo_singlefam_sub1_t=. then lo_singlefam_sub1_t=0;
if lo_singlefam_sub2_t=. then lo_singlefam_sub2_t=0;
if lo_singlefam_sub3_t=. then lo_singlefam_sub3_t=0;
if lo_singlefam_sub4_t=. then lo_singlefam_sub4_t=0;
if lo_singlefam_sub5_t=. then lo_singlefam_sub5_t=0;
lo_singlefam_t = lo_singlefam_parent_t + lo_singlefam_sub1_t + lo_singlefam_sub2_t + lo_singlefam_sub3_t + lo_singlefam_sub4_t + lo_singlefam_sub5_t;
run;

data box.hmda_sf_lo_1990;
set sf_lo_1990_6;
run;
proc sort data=box.hmda_sf_lo_1990;
by name;
run;
