/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below aggregates HMDA data on single-family loan originations at the consolidated level.

 =========================================================================================================*/

libname box 'C:\Users\pbwheele\Box Sync\Data Sets';

data ta;
set box.all_ta_1990_2017;
run;

/*HMDA Loan Originations Plus Lags*/
data sf_lo_1992_1 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 12 then delete;
run;
proc sql;
create table sf_lo_1992_2 as select a.*, b.ta
from sf_lo_1992_1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.name;
quit;
data sf_lo_1992_3;
set sf_lo_1992_2;
if ta=. then delete;
run;
/*Identify all subsidiaries in the corporate structure*/
proc sql;
create table sf_lo_1992_4a as select a.*, b.id_rssd_offspring as sub1_rssd 'sub1_rssd'
from sf_lo_1992_3 as a left join nic.relationships_20151231 as b
on a.rssd_id=b.id_rssd_parent and b.start<=12053<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_1992_4b as select a.*, b.id_rssd_offspring as sub2_rssd 'sub2_rssd'
from sf_lo_1992_4a as a left join nic.relationships_20151231 as b
on a.sub1_rssd=b.id_rssd_parent and b.start<=12053<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_1992_4c as select a.*, b.id_rssd_offspring as sub3_rssd 'sub3_rssd'
from sf_lo_1992_4b as a left join nic.relationships_20151231 as b
on a.sub2_rssd=b.id_rssd_parent and b.start<=12053<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_1992_4d as select a.*, b.id_rssd_offspring as sub4_rssd 'sub4_rssd'
from sf_lo_1992_4c as a left join nic.relationships_20151231 as b
on a.sub3_rssd=b.id_rssd_parent and b.start<=12053<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_1992_4e as select a.*, b.id_rssd_offspring as sub5_rssd 'sub5_rssd'
from sf_lo_1992_4d as a left join nic.relationships_20151231 as b
on a.sub4_rssd=b.id_rssd_parent and b.start<=12053<=b.end and (b.pct_equity>50 or b.other_basis_ind=1)
order by name, sub1_rssd, sub2_rssd, sub3_rssd, sub4_rssd;
quit;
/*Add 2012 single-family loan originations for 5th-level subsidiaries*/
data hmda_singlefam_1992;
set hmda.hmda_singlefam_1992;
if rssdid=. then delete;
run;
proc sql;
create table sf_lo_1992_5a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_1992_4e as a left join hmda_singlefam_1992 as b
on a.sub5_rssd=b.rssdid order by a.name;

create table sf_lo_1992_5b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_t
from sf_lo_1992_5a group by rssd_id order by name;
quit;
proc sort data=sf_lo_1992_5b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_1992_5c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_1992_5b as a left join hmda_singlefam_1992 as b
on a.sub4_rssd=b.rssdid order by a.name;

create table sf_lo_1992_5d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_t
from sf_lo_1992_5c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_1992_5d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_1992_5e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_1992_5d as a left join hmda_singlefam_1992 as b
on a.sub3_rssd=b.rssdid order by a.name;

create table sf_lo_1992_5f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_t
from sf_lo_1992_5e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_1992_5f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_1992_5g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_1992_5f as a left join hmda_singlefam_1992 as b
on a.sub2_rssd=b.rssdid order by a.name;

create table sf_lo_1992_5h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_t
from sf_lo_1992_5g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_1992_5h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_1992_5i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_1992_5h as a left join hmda_singlefam_1992 as b
on a.sub1_rssd=b.rssdid order by a.name;

create table sf_lo_1992_5j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_t
from sf_lo_1992_5i group by rssd_id order by name;
quit;
proc sort data=sf_lo_1992_5j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_1992_5k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_1992_5j as a left join hmda_singlefam_1992 as b
on a.rssd_id=b.rssdid order by a.name;

create table sf_lo_1992_5l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_t
from sf_lo_1992_5k group by rssd_id order by name;
quit;
proc sort data=sf_lo_1992_5l nodupkey;
by rssd_id;
run;
data sf_lo_1992_6 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_t lo_singlefam_sub1_t lo_singlefam_sub2_t lo_singlefam_sub3_t lo_singlefam_sub4_t lo_singlefam_sub5_t); 
set sf_lo_1992_5l;
if lo_singlefam_parent_t=. then lo_singlefam_parent_t=0;
if lo_singlefam_sub1_t=. then lo_singlefam_sub1_t=0;
if lo_singlefam_sub2_t=. then lo_singlefam_sub2_t=0;
if lo_singlefam_sub3_t=. then lo_singlefam_sub3_t=0;
if lo_singlefam_sub4_t=. then lo_singlefam_sub4_t=0;
if lo_singlefam_sub5_t=. then lo_singlefam_sub5_t=0;
lo_singlefam_t = lo_singlefam_parent_t + lo_singlefam_sub1_t + lo_singlefam_sub2_t + lo_singlefam_sub3_t + lo_singlefam_sub4_t + lo_singlefam_sub5_t;
run;

/*CREATE LAGGED ORIGINATIONS*/
/*LAG1*/
/*5th-level subsidiaries*/
data hmda_singlefam_1991;
set hmda.hmda_singlefam_1991;
if topid_19921231=. then delete;
run;
proc sql;
create table sf_lo_1992_7a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_1992_4e as a left join hmda_singlefam_1991 as b
on a.sub5_rssd=b.topid_19921231 order by a.name;

create table sf_lo_1992_7b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag1
from sf_lo_1992_7a group by rssd_id order by name;
quit;
proc sort data=sf_lo_1992_7b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_1992_7c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_1992_7b as a left join hmda_singlefam_1991 as b
on a.sub4_rssd=b.topid_19921231 order by a.name;

create table sf_lo_1992_7d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag1
from sf_lo_1992_7c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_1992_7d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_1992_7e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_1992_7d as a left join hmda_singlefam_1991 as b
on a.sub3_rssd=b.topid_19921231 order by a.name;

create table sf_lo_1992_7f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag1
from sf_lo_1992_7e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_1992_7f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_1992_7g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_1992_7f as a left join hmda_singlefam_1991 as b
on a.sub2_rssd=b.topid_19921231 order by a.name;

create table sf_lo_1992_7h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag1
from sf_lo_1992_7g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_1992_7h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_1992_7i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_1992_7h as a left join hmda_singlefam_1991 as b
on a.sub1_rssd=b.topid_19921231 order by a.name;

create table sf_lo_1992_7j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag1
from sf_lo_1992_7i group by rssd_id order by name;
quit;
proc sort data=sf_lo_1992_7j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_1992_7k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_1992_7j as a left join hmda_singlefam_1991 as b
on a.rssd_id=b.topid_19921231 order by a.name;

create table sf_lo_1992_7l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag1
from sf_lo_1992_7k group by rssd_id order by name;
quit;
proc sort data=sf_lo_1992_7l nodupkey;
by rssd_id;
run;
data sf_lo_1992_8 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag1 lo_singlefam_sub1_lag1 lo_singlefam_sub2_lag1 lo_singlefam_sub3_lag1 lo_singlefam_sub4_lag1 lo_singlefam_sub5_lag1); 
set sf_lo_1992_7l;
if lo_singlefam_parent_lag1=. then lo_singlefam_parent_lag1=0;
if lo_singlefam_sub1_lag1=. then lo_singlefam_sub1_lag1=0;
if lo_singlefam_sub2_lag1=. then lo_singlefam_sub2_lag1=0;
if lo_singlefam_sub3_lag1=. then lo_singlefam_sub3_lag1=0;
if lo_singlefam_sub4_lag1=. then lo_singlefam_sub4_lag1=0;
if lo_singlefam_sub5_lag1=. then lo_singlefam_sub5_lag1=0;
lo_singlefam_lag1 = lo_singlefam_parent_lag1 + lo_singlefam_sub1_lag1 + lo_singlefam_sub2_lag1 + lo_singlefam_sub3_lag1 + lo_singlefam_sub4_lag1 + lo_singlefam_sub5_lag1;
run;

/*LAG2*/
/*5th-level subsidiaries*/
data hmda_singlefam_1990;
set hmda.hmda_singlefam_1990;
if topid_19921231=. then delete;
run;
proc sql;
create table sf_lo_1992_9a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_1992_4e as a left join hmda_singlefam_1990 as b
on a.sub5_rssd=b.topid_19921231 order by a.name;

create table sf_lo_1992_9b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag2
from sf_lo_1992_9a group by rssd_id order by name;
quit;
proc sort data=sf_lo_1992_9b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_1992_9c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_1992_9b as a left join hmda_singlefam_1990 as b
on a.sub4_rssd=b.topid_19921231 order by a.name;

create table sf_lo_1992_9d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag2
from sf_lo_1992_9c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_1992_9d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_1992_9e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_1992_9d as a left join hmda_singlefam_1990 as b
on a.sub3_rssd=b.topid_19921231 order by a.name;

create table sf_lo_1992_9f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag2
from sf_lo_1992_9e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_1992_9f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_1992_9g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_1992_9f as a left join hmda_singlefam_1990 as b
on a.sub2_rssd=b.topid_19921231 order by a.name;

create table sf_lo_1992_9h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag2
from sf_lo_1992_9g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_1992_9h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_1992_9i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_1992_9h as a left join hmda_singlefam_1990 as b
on a.sub1_rssd=b.topid_19921231 order by a.name;

create table sf_lo_1992_9j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag2
from sf_lo_1992_9i group by rssd_id order by name;
quit;
proc sort data=sf_lo_1992_9j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_1992_9k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_1992_9j as a left join hmda_singlefam_1990 as b
on a.rssd_id=b.topid_19921231 order by a.name;

create table sf_lo_1992_9l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag2
from sf_lo_1992_9k group by rssd_id order by name;
quit;
proc sort data=sf_lo_1992_9l nodupkey;
by rssd_id;
run;
data sf_lo_1992_10 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag2 lo_singlefam_sub1_lag2 lo_singlefam_sub2_lag2 lo_singlefam_sub3_lag2 lo_singlefam_sub4_lag2 lo_singlefam_sub5_lag2); 
set sf_lo_1992_9l;
if lo_singlefam_parent_lag2=. then lo_singlefam_parent_lag2=0;
if lo_singlefam_sub1_lag2=. then lo_singlefam_sub1_lag2=0;
if lo_singlefam_sub2_lag2=. then lo_singlefam_sub2_lag2=0;
if lo_singlefam_sub3_lag2=. then lo_singlefam_sub3_lag2=0;
if lo_singlefam_sub4_lag2=. then lo_singlefam_sub4_lag2=0;
if lo_singlefam_sub5_lag2=. then lo_singlefam_sub5_lag2=0;
lo_singlefam_lag2 = lo_singlefam_parent_lag2 + lo_singlefam_sub1_lag2 + lo_singlefam_sub2_lag2 + lo_singlefam_sub3_lag2 + lo_singlefam_sub4_lag2 + lo_singlefam_sub5_lag2;
run;


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~;
*Aggregate all loan origination lag observations;
proc sql;
create table sf_lo_1992 as select a.*, b.lo_singlefam_lag1
from sf_lo_1992_6 as a left join sf_lo_1992_8 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_1992 as select a.*, b.lo_singlefam_lag2
from sf_lo_1992 as a left join sf_lo_1992_10 as b
on a.rssd_id=b.rssd_id order by a.name;
quit;

data box.hmda_sf_lo_1992;
set sf_lo_1992;
run;
