/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below aggregates HMDA data on single-family loan originations at the consolidated level.

 =========================================================================================================*/

libname box 'C:\Users\pbwheele\Box Sync\Data Sets';

data ta;
set box.all_ta_1990_2017;
run;

/*HMDA Loan Originations Plus Lags*/
data sf_lo_2006_1 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 68 then delete;
run;
proc sql;
create table sf_lo_2006_2 as select a.*, b.ta
from sf_lo_2006_1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.name;
quit;
data sf_lo_2006_3;
set sf_lo_2006_2;
if ta=. then delete;
run;
/*Identify all subsidiaries in the corporate structure*/
proc sql;
create table sf_lo_2006_4a as select a.*, b.id_rssd_offspring as sub1_rssd 'sub1_rssd'
from sf_lo_2006_3 as a left join nic.relationships_20151231 as b
on a.rssd_id=b.id_rssd_parent and b.start<=17166<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_2006_4b as select a.*, b.id_rssd_offspring as sub2_rssd 'sub2_rssd'
from sf_lo_2006_4a as a left join nic.relationships_20151231 as b
on a.sub1_rssd=b.id_rssd_parent and b.start<=17166<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_2006_4c as select a.*, b.id_rssd_offspring as sub3_rssd 'sub3_rssd'
from sf_lo_2006_4b as a left join nic.relationships_20151231 as b
on a.sub2_rssd=b.id_rssd_parent and b.start<=17166<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_2006_4d as select a.*, b.id_rssd_offspring as sub4_rssd 'sub4_rssd'
from sf_lo_2006_4c as a left join nic.relationships_20151231 as b
on a.sub3_rssd=b.id_rssd_parent and b.start<=17166<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_2006_4e as select a.*, b.id_rssd_offspring as sub5_rssd 'sub5_rssd'
from sf_lo_2006_4d as a left join nic.relationships_20151231 as b
on a.sub4_rssd=b.id_rssd_parent and b.start<=17166<=b.end and (b.pct_equity>50 or b.other_basis_ind=1)
order by name, sub1_rssd, sub2_rssd, sub3_rssd, sub4_rssd;
quit;
/*Add 2012 single-family loan originations for 5th-level subsidiaries*/
data hmda_singlefam_2006;
set hmda.hmda_singlefam_2006;
if rssdid=. then delete;
run;
proc sql;
create table sf_lo_2006_5a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_2006 as b
on a.sub5_rssd=b.rssdid order by a.name;

create table sf_lo_2006_5b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_t
from sf_lo_2006_5a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_5b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_5c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_5b as a left join hmda_singlefam_2006 as b
on a.sub4_rssd=b.rssdid order by a.name;

create table sf_lo_2006_5d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_t
from sf_lo_2006_5c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_5d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_5e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_5d as a left join hmda_singlefam_2006 as b
on a.sub3_rssd=b.rssdid order by a.name;

create table sf_lo_2006_5f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_t
from sf_lo_2006_5e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_5f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_5g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_5f as a left join hmda_singlefam_2006 as b
on a.sub2_rssd=b.rssdid order by a.name;

create table sf_lo_2006_5h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_t
from sf_lo_2006_5g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_5h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_5i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_5h as a left join hmda_singlefam_2006 as b
on a.sub1_rssd=b.rssdid order by a.name;

create table sf_lo_2006_5j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_t
from sf_lo_2006_5i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_5j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_5k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_5j as a left join hmda_singlefam_2006 as b
on a.rssd_id=b.rssdid order by a.name;

create table sf_lo_2006_5l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_t
from sf_lo_2006_5k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_5l nodupkey;
by rssd_id;
run;
data sf_lo_2006_6 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_t lo_singlefam_sub1_t lo_singlefam_sub2_t lo_singlefam_sub3_t lo_singlefam_sub4_t lo_singlefam_sub5_t); 
set sf_lo_2006_5l;
if lo_singlefam_parent_t=. then lo_singlefam_parent_t=0;
if lo_singlefam_sub1_t=. then lo_singlefam_sub1_t=0;
if lo_singlefam_sub2_t=. then lo_singlefam_sub2_t=0;
if lo_singlefam_sub3_t=. then lo_singlefam_sub3_t=0;
if lo_singlefam_sub4_t=. then lo_singlefam_sub4_t=0;
if lo_singlefam_sub5_t=. then lo_singlefam_sub5_t=0;
lo_singlefam_t = lo_singlefam_parent_t + lo_singlefam_sub1_t + lo_singlefam_sub2_t + lo_singlefam_sub3_t + lo_singlefam_sub4_t + lo_singlefam_sub5_t;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2013*/
/*LAG1*/
/*5th-level subsidiaries*/
data hmda_singlefam_2005;
set hmda.hmda_singlefam_2005;
if topid_20061231=. then delete;
run;
proc sql;
create table sf_lo_2006_7a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_2005 as b
on a.sub5_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_7b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag1
from sf_lo_2006_7a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_7b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_7c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_7b as a left join hmda_singlefam_2005 as b
on a.sub4_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_7d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag1
from sf_lo_2006_7c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_7d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_7e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_7d as a left join hmda_singlefam_2005 as b
on a.sub3_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_7f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag1
from sf_lo_2006_7e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_7f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_7g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_7f as a left join hmda_singlefam_2005 as b
on a.sub2_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_7h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag1
from sf_lo_2006_7g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_7h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_7i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_7h as a left join hmda_singlefam_2005 as b
on a.sub1_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_7j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag1
from sf_lo_2006_7i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_7j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_7k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_7j as a left join hmda_singlefam_2005 as b
on a.rssd_id=b.topid_20061231 order by a.name;

create table sf_lo_2006_7l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag1
from sf_lo_2006_7k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_7l nodupkey;
by rssd_id;
run;
data sf_lo_2006_8 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag1 lo_singlefam_sub1_lag1 lo_singlefam_sub2_lag1 lo_singlefam_sub3_lag1 lo_singlefam_sub4_lag1 lo_singlefam_sub5_lag1); 
set sf_lo_2006_7l;
if lo_singlefam_parent_lag1=. then lo_singlefam_parent_lag1=0;
if lo_singlefam_sub1_lag1=. then lo_singlefam_sub1_lag1=0;
if lo_singlefam_sub2_lag1=. then lo_singlefam_sub2_lag1=0;
if lo_singlefam_sub3_lag1=. then lo_singlefam_sub3_lag1=0;
if lo_singlefam_sub4_lag1=. then lo_singlefam_sub4_lag1=0;
if lo_singlefam_sub5_lag1=. then lo_singlefam_sub5_lag1=0;
lo_singlefam_lag1 = lo_singlefam_parent_lag1 + lo_singlefam_sub1_lag1 + lo_singlefam_sub2_lag1 + lo_singlefam_sub3_lag1 + lo_singlefam_sub4_lag1 + lo_singlefam_sub5_lag1;
run;

/*LAG2*/
/*5th-level subsidiaries*/
data hmda_singlefam_2004;
set hmda.hmda_singlefam_2004;
if topid_20061231=. then delete;
run;
proc sql;
create table sf_lo_2006_9a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_2004 as b
on a.sub5_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_9b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag2
from sf_lo_2006_9a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_9b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_9c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_9b as a left join hmda_singlefam_2004 as b
on a.sub4_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_9d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag2
from sf_lo_2006_9c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_9d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_9e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_9d as a left join hmda_singlefam_2004 as b
on a.sub3_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_9f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag2
from sf_lo_2006_9e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_9f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_9g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_9f as a left join hmda_singlefam_2004 as b
on a.sub2_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_9h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag2
from sf_lo_2006_9g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_9h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_9i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_9h as a left join hmda_singlefam_2004 as b
on a.sub1_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_9j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag2
from sf_lo_2006_9i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_9j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_9k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_9j as a left join hmda_singlefam_2004 as b
on a.rssd_id=b.topid_20061231 order by a.name;

create table sf_lo_2006_9l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag2
from sf_lo_2006_9k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_9l nodupkey;
by rssd_id;
run;
data sf_lo_2006_10 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag2 lo_singlefam_sub1_lag2 lo_singlefam_sub2_lag2 lo_singlefam_sub3_lag2 lo_singlefam_sub4_lag2 lo_singlefam_sub5_lag2); 
set sf_lo_2006_9l;
if lo_singlefam_parent_lag2=. then lo_singlefam_parent_lag2=0;
if lo_singlefam_sub1_lag2=. then lo_singlefam_sub1_lag2=0;
if lo_singlefam_sub2_lag2=. then lo_singlefam_sub2_lag2=0;
if lo_singlefam_sub3_lag2=. then lo_singlefam_sub3_lag2=0;
if lo_singlefam_sub4_lag2=. then lo_singlefam_sub4_lag2=0;
if lo_singlefam_sub5_lag2=. then lo_singlefam_sub5_lag2=0;
lo_singlefam_lag2 = lo_singlefam_parent_lag2 + lo_singlefam_sub1_lag2 + lo_singlefam_sub2_lag2 + lo_singlefam_sub3_lag2 + lo_singlefam_sub4_lag2 + lo_singlefam_sub5_lag2;
run;


/*LAG3*/
/*5th-level subsidiaries*/
data hmda_singlefam_2003;
set hmda.hmda_singlefam_2003;
if topid_20061231=. then delete;
run;
proc sql;
create table sf_lo_2006_11a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_2003 as b
on a.sub5_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_11b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag3
from sf_lo_2006_11a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_11b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_11c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_11b as a left join hmda_singlefam_2003 as b
on a.sub4_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_11d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag3
from sf_lo_2006_11c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_11d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_11e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_11d as a left join hmda_singlefam_2003 as b
on a.sub3_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_11f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag3
from sf_lo_2006_11e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_11f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_11g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_11f as a left join hmda_singlefam_2003 as b
on a.sub2_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_11h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag3
from sf_lo_2006_11g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_11h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_11i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_11h as a left join hmda_singlefam_2003 as b
on a.sub1_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_11j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag3
from sf_lo_2006_11i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_11j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_11k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_11j as a left join hmda_singlefam_2003 as b
on a.rssd_id=b.topid_20061231 order by a.name;

create table sf_lo_2006_11l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag3
from sf_lo_2006_11k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_11l nodupkey;
by rssd_id;
run;
data sf_lo_2006_12 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag3 lo_singlefam_sub1_lag3 lo_singlefam_sub2_lag3 lo_singlefam_sub3_lag3 lo_singlefam_sub4_lag3 lo_singlefam_sub5_lag3); 
set sf_lo_2006_11l;
if lo_singlefam_parent_lag3=. then lo_singlefam_parent_lag3=0;
if lo_singlefam_sub1_lag3=. then lo_singlefam_sub1_lag3=0;
if lo_singlefam_sub2_lag3=. then lo_singlefam_sub2_lag3=0;
if lo_singlefam_sub3_lag3=. then lo_singlefam_sub3_lag3=0;
if lo_singlefam_sub4_lag3=. then lo_singlefam_sub4_lag3=0;
if lo_singlefam_sub5_lag3=. then lo_singlefam_sub5_lag3=0;
lo_singlefam_lag3 = lo_singlefam_parent_lag3 + lo_singlefam_sub1_lag3 + lo_singlefam_sub2_lag3 + lo_singlefam_sub3_lag3 + lo_singlefam_sub4_lag3 + lo_singlefam_sub5_lag3;
run;


/*LAG4*/
/*5th-level subsidiaries*/
data hmda_singlefam_2002;
set hmda.hmda_singlefam_2002;
if topid_20061231=. then delete;
run;
proc sql;
create table sf_lo_2006_13a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_2002 as b
on a.sub5_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_13b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag4
from sf_lo_2006_13a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_13b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_13c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_13b as a left join hmda_singlefam_2002 as b
on a.sub4_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_13d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag4
from sf_lo_2006_13c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_13d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_13e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_13d as a left join hmda_singlefam_2002 as b
on a.sub3_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_13f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag4
from sf_lo_2006_13e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_13f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_13g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_13f as a left join hmda_singlefam_2002 as b
on a.sub2_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_13h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag4
from sf_lo_2006_13g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_13h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_13i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_13h as a left join hmda_singlefam_2002 as b
on a.sub1_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_13j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag4
from sf_lo_2006_13i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_13j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_13k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_13j as a left join hmda_singlefam_2002 as b
on a.rssd_id=b.topid_20061231 order by a.name;

create table sf_lo_2006_13l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag4
from sf_lo_2006_13k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_13l nodupkey;
by rssd_id;
run;
data sf_lo_2006_14 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag4 lo_singlefam_sub1_lag4 lo_singlefam_sub2_lag4 lo_singlefam_sub3_lag4 lo_singlefam_sub4_lag4 lo_singlefam_sub5_lag4); 
set sf_lo_2006_13l;
if lo_singlefam_parent_lag4=. then lo_singlefam_parent_lag4=0;
if lo_singlefam_sub1_lag4=. then lo_singlefam_sub1_lag4=0;
if lo_singlefam_sub2_lag4=. then lo_singlefam_sub2_lag4=0;
if lo_singlefam_sub3_lag4=. then lo_singlefam_sub3_lag4=0;
if lo_singlefam_sub4_lag4=. then lo_singlefam_sub4_lag4=0;
if lo_singlefam_sub5_lag4=. then lo_singlefam_sub5_lag4=0;
lo_singlefam_lag4 = lo_singlefam_parent_lag4 + lo_singlefam_sub1_lag4 + lo_singlefam_sub2_lag4 + lo_singlefam_sub3_lag4 + lo_singlefam_sub4_lag4 + lo_singlefam_sub5_lag4;
run;


/*LAG5*/
/*5th-level subsidiaries*/
data hmda_singlefam_2001;
set hmda.hmda_singlefam_2001;
if topid_20061231=. then delete;
run;
proc sql;
create table sf_lo_2006_15a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_2001 as b
on a.sub5_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_15b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag5
from sf_lo_2006_15a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_15b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_15c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_15b as a left join hmda_singlefam_2001 as b
on a.sub4_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_15d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag5
from sf_lo_2006_15c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_15d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_15e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_15d as a left join hmda_singlefam_2001 as b
on a.sub3_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_15f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag5
from sf_lo_2006_15e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_15f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_15g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_15f as a left join hmda_singlefam_2001 as b
on a.sub2_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_15h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag5
from sf_lo_2006_15g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_15h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_15i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_15h as a left join hmda_singlefam_2001 as b
on a.sub1_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_15j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag5
from sf_lo_2006_15i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_15j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_15k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_15j as a left join hmda_singlefam_2001 as b
on a.rssd_id=b.topid_20061231 order by a.name;

create table sf_lo_2006_15l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag5
from sf_lo_2006_15k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_15l nodupkey;
by rssd_id;
run;
data sf_lo_2006_16 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag5 lo_singlefam_sub1_lag5 lo_singlefam_sub2_lag5 lo_singlefam_sub3_lag5 lo_singlefam_sub4_lag5 lo_singlefam_sub5_lag5); 
set sf_lo_2006_15l;
if lo_singlefam_parent_lag5=. then lo_singlefam_parent_lag5=0;
if lo_singlefam_sub1_lag5=. then lo_singlefam_sub1_lag5=0;
if lo_singlefam_sub2_lag5=. then lo_singlefam_sub2_lag5=0;
if lo_singlefam_sub3_lag5=. then lo_singlefam_sub3_lag5=0;
if lo_singlefam_sub4_lag5=. then lo_singlefam_sub4_lag5=0;
if lo_singlefam_sub5_lag5=. then lo_singlefam_sub5_lag5=0;
lo_singlefam_lag5 = lo_singlefam_parent_lag5 + lo_singlefam_sub1_lag5 + lo_singlefam_sub2_lag5 + lo_singlefam_sub3_lag5 + lo_singlefam_sub4_lag5 + lo_singlefam_sub5_lag5;
run;


/*LAG6*/
/*5th-level subsidiaries*/
data hmda_singlefam_2000;
set hmda.hmda_singlefam_2000;
if topid_20061231=. then delete;
run;
proc sql;
create table sf_lo_2006_17a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_2000 as b
on a.sub5_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_17b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag6
from sf_lo_2006_17a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_17b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_17c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_17b as a left join hmda_singlefam_2000 as b
on a.sub4_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_17d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag6
from sf_lo_2006_17c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_17d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_17e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_17d as a left join hmda_singlefam_2000 as b
on a.sub3_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_17f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag6
from sf_lo_2006_17e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_17f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_17g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_17f as a left join hmda_singlefam_2000 as b
on a.sub2_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_17h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag6
from sf_lo_2006_17g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_17h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_17i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_17h as a left join hmda_singlefam_2000 as b
on a.sub1_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_17j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag6
from sf_lo_2006_17i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_17j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_17k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_17j as a left join hmda_singlefam_2000 as b
on a.rssd_id=b.topid_20061231 order by a.name;

create table sf_lo_2006_17l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag6
from sf_lo_2006_17k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_17l nodupkey;
by rssd_id;
run;
data sf_lo_2006_18 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag6 lo_singlefam_sub1_lag6 lo_singlefam_sub2_lag6 lo_singlefam_sub3_lag6 lo_singlefam_sub4_lag6 lo_singlefam_sub5_lag6); 
set sf_lo_2006_17l;
if lo_singlefam_parent_lag6=. then lo_singlefam_parent_lag6=0;
if lo_singlefam_sub1_lag6=. then lo_singlefam_sub1_lag6=0;
if lo_singlefam_sub2_lag6=. then lo_singlefam_sub2_lag6=0;
if lo_singlefam_sub3_lag6=. then lo_singlefam_sub3_lag6=0;
if lo_singlefam_sub4_lag6=. then lo_singlefam_sub4_lag6=0;
if lo_singlefam_sub5_lag6=. then lo_singlefam_sub5_lag6=0;
lo_singlefam_lag6 = lo_singlefam_parent_lag6 + lo_singlefam_sub1_lag6 + lo_singlefam_sub2_lag6 + lo_singlefam_sub3_lag6 + lo_singlefam_sub4_lag6 + lo_singlefam_sub5_lag6;
run;


/*LAG7*/
/*5th-level subsidiaries*/
data hmda_singlefam_1999;
set hmda.hmda_singlefam_1999;
if topid_20061231=. then delete;
run;
proc sql;
create table sf_lo_2006_19a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_1999 as b
on a.sub5_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_19b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag7
from sf_lo_2006_19a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_19b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_19c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_19b as a left join hmda_singlefam_1999 as b
on a.sub4_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_19d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag7
from sf_lo_2006_19c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_19d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_19e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_19d as a left join hmda_singlefam_1999 as b
on a.sub3_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_19f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag7
from sf_lo_2006_19e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_19f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_19g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_19f as a left join hmda_singlefam_1999 as b
on a.sub2_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_19h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag7
from sf_lo_2006_19g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_19h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_19i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_19h as a left join hmda_singlefam_1999 as b
on a.sub1_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_19j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag7
from sf_lo_2006_19i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_19j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_19k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_19j as a left join hmda_singlefam_1999 as b
on a.rssd_id=b.topid_20061231 order by a.name;

create table sf_lo_2006_19l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag7
from sf_lo_2006_19k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_19l nodupkey;
by rssd_id;
run;
data sf_lo_2006_20 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag7 lo_singlefam_sub1_lag7 lo_singlefam_sub2_lag7 lo_singlefam_sub3_lag7 lo_singlefam_sub4_lag7 lo_singlefam_sub5_lag7); 
set sf_lo_2006_19l;
if lo_singlefam_parent_lag7=. then lo_singlefam_parent_lag7=0;
if lo_singlefam_sub1_lag7=. then lo_singlefam_sub1_lag7=0;
if lo_singlefam_sub2_lag7=. then lo_singlefam_sub2_lag7=0;
if lo_singlefam_sub3_lag7=. then lo_singlefam_sub3_lag7=0;
if lo_singlefam_sub4_lag7=. then lo_singlefam_sub4_lag7=0;
if lo_singlefam_sub5_lag7=. then lo_singlefam_sub5_lag7=0;
lo_singlefam_lag7 = lo_singlefam_parent_lag7 + lo_singlefam_sub1_lag7 + lo_singlefam_sub2_lag7 + lo_singlefam_sub3_lag7 + lo_singlefam_sub4_lag7 + lo_singlefam_sub5_lag7;
run;

/*LAG8*/
/*5th-level subsidiaries*/
data hmda_singlefam_1998;
set hmda.hmda_singlefam_1998;
if topid_20061231=. then delete;
run;
proc sql;
create table sf_lo_2006_21a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_1998 as b
on a.sub5_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_21b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag8
from sf_lo_2006_21a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_21b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_21c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_21b as a left join hmda_singlefam_1998 as b
on a.sub4_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_21d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag8
from sf_lo_2006_21c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_21d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_21e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_21d as a left join hmda_singlefam_1998 as b
on a.sub3_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_21f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag8
from sf_lo_2006_21e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_21f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_21g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_21f as a left join hmda_singlefam_1998 as b
on a.sub2_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_21h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag8
from sf_lo_2006_21g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_21h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_21i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_21h as a left join hmda_singlefam_1998 as b
on a.sub1_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_21j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag8
from sf_lo_2006_21i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_21j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_21k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_21j as a left join hmda_singlefam_1998 as b
on a.rssd_id=b.topid_20061231 order by a.name;

create table sf_lo_2006_21l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag8
from sf_lo_2006_21k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_21l nodupkey;
by rssd_id;
run;
data sf_lo_2006_22 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag8 lo_singlefam_sub1_lag8 lo_singlefam_sub2_lag8 lo_singlefam_sub3_lag8 lo_singlefam_sub4_lag8 lo_singlefam_sub5_lag8); 
set sf_lo_2006_21l;
if lo_singlefam_parent_lag8=. then lo_singlefam_parent_lag8=0;
if lo_singlefam_sub1_lag8=. then lo_singlefam_sub1_lag8=0;
if lo_singlefam_sub2_lag8=. then lo_singlefam_sub2_lag8=0;
if lo_singlefam_sub3_lag8=. then lo_singlefam_sub3_lag8=0;
if lo_singlefam_sub4_lag8=. then lo_singlefam_sub4_lag8=0;
if lo_singlefam_sub5_lag8=. then lo_singlefam_sub5_lag8=0;
lo_singlefam_lag8 = lo_singlefam_parent_lag8 + lo_singlefam_sub1_lag8 + lo_singlefam_sub2_lag8 + lo_singlefam_sub3_lag8 + lo_singlefam_sub4_lag8 + lo_singlefam_sub5_lag8;
run;


/*LAG9*/
/*5th-level subsidiaries*/
data hmda_singlefam_1997;
set hmda.hmda_singlefam_1997;
if topid_20061231=. then delete;
run;
proc sql;
create table sf_lo_2006_23a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_1997 as b
on a.sub5_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_23b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag9
from sf_lo_2006_23a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_23b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_23c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_23b as a left join hmda_singlefam_1997 as b
on a.sub4_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_23d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag9
from sf_lo_2006_23c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_23d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_23e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_23d as a left join hmda_singlefam_1997 as b
on a.sub3_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_23f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag9
from sf_lo_2006_23e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_23f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_23g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_23f as a left join hmda_singlefam_1997 as b
on a.sub2_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_23h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag9
from sf_lo_2006_23g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_23h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_23i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_23h as a left join hmda_singlefam_1997 as b
on a.sub1_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_23j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag9
from sf_lo_2006_23i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_23j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_23k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_23j as a left join hmda_singlefam_1997 as b
on a.rssd_id=b.topid_20061231 order by a.name;

create table sf_lo_2006_23l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag9
from sf_lo_2006_23k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_23l nodupkey;
by rssd_id;
run;
data sf_lo_2006_24 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag9 lo_singlefam_sub1_lag9 lo_singlefam_sub2_lag9 lo_singlefam_sub3_lag9 lo_singlefam_sub4_lag9 lo_singlefam_sub5_lag9); 
set sf_lo_2006_23l;
if lo_singlefam_parent_lag9=. then lo_singlefam_parent_lag9=0;
if lo_singlefam_sub1_lag9=. then lo_singlefam_sub1_lag9=0;
if lo_singlefam_sub2_lag9=. then lo_singlefam_sub2_lag9=0;
if lo_singlefam_sub3_lag9=. then lo_singlefam_sub3_lag9=0;
if lo_singlefam_sub4_lag9=. then lo_singlefam_sub4_lag9=0;
if lo_singlefam_sub5_lag9=. then lo_singlefam_sub5_lag9=0;
lo_singlefam_lag9 = lo_singlefam_parent_lag9 + lo_singlefam_sub1_lag9 + lo_singlefam_sub2_lag9 + lo_singlefam_sub3_lag9 + lo_singlefam_sub4_lag9 + lo_singlefam_sub5_lag9;
run;


/*LAG10*/
/*5th-level subsidiaries*/
data hmda_singlefam_1996;
set hmda.hmda_singlefam_1996;
if topid_20061231=. then delete;
run;
proc sql;
create table sf_lo_2006_25a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2006_4e as a left join hmda_singlefam_1996 as b
on a.sub5_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_25b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag10
from sf_lo_2006_25a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_25b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2006_25c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2006_25b as a left join hmda_singlefam_1996 as b
on a.sub4_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_25d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag10
from sf_lo_2006_25c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2006_25d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2006_25e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2006_25d as a left join hmda_singlefam_1996 as b
on a.sub3_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_25f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag10
from sf_lo_2006_25e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2006_25f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2006_25g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2006_25f as a left join hmda_singlefam_1996 as b
on a.sub2_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_25h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag10
from sf_lo_2006_25g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2006_25h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2006_25i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2006_25h as a left join hmda_singlefam_1996 as b
on a.sub1_rssd=b.topid_20061231 order by a.name;

create table sf_lo_2006_25j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag10
from sf_lo_2006_25i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_25j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2006_25k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2006_25j as a left join hmda_singlefam_1996 as b
on a.rssd_id=b.topid_20061231 order by a.name;

create table sf_lo_2006_25l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag10
from sf_lo_2006_25k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2006_25l nodupkey;
by rssd_id;
run;
data sf_lo_2006_26 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag10 lo_singlefam_sub1_lag10 lo_singlefam_sub2_lag10 lo_singlefam_sub3_lag10 lo_singlefam_sub4_lag10 lo_singlefam_sub5_lag10); 
set sf_lo_2006_25l;
if lo_singlefam_parent_lag10=. then lo_singlefam_parent_lag10=0;
if lo_singlefam_sub1_lag10=. then lo_singlefam_sub1_lag10=0;
if lo_singlefam_sub2_lag10=. then lo_singlefam_sub2_lag10=0;
if lo_singlefam_sub3_lag10=. then lo_singlefam_sub3_lag10=0;
if lo_singlefam_sub4_lag10=. then lo_singlefam_sub4_lag10=0;
if lo_singlefam_sub5_lag10=. then lo_singlefam_sub5_lag10=0;
lo_singlefam_lag10 = lo_singlefam_parent_lag10 + lo_singlefam_sub1_lag10 + lo_singlefam_sub2_lag10 + lo_singlefam_sub3_lag10 + lo_singlefam_sub4_lag10 + lo_singlefam_sub5_lag10;
run;

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~;
*Aggregate all loan origination lag observations;
proc sql;
create table sf_lo_2006 as select a.*, b.lo_singlefam_lag1
from sf_lo_2006_6 as a left join sf_lo_2006_8 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2006 as select a.*, b.lo_singlefam_lag2
from sf_lo_2006 as a left join sf_lo_2006_10 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2006 as select a.*, b.lo_singlefam_lag3
from sf_lo_2006 as a left join sf_lo_2006_12 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2006 as select a.*, b.lo_singlefam_lag4
from sf_lo_2006 as a left join sf_lo_2006_14 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2006 as select a.*, b.lo_singlefam_lag5
from sf_lo_2006 as a left join sf_lo_2006_16 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2006 as select a.*, b.lo_singlefam_lag6
from sf_lo_2006 as a left join sf_lo_2006_18 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2006 as select a.*, b.lo_singlefam_lag7
from sf_lo_2006 as a left join sf_lo_2006_20 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2006 as select a.*, b.lo_singlefam_lag8
from sf_lo_2006 as a left join sf_lo_2006_22 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2006 as select a.*, b.lo_singlefam_lag9
from sf_lo_2006 as a left join sf_lo_2006_24 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2006 as select a.*, b.lo_singlefam_lag10
from sf_lo_2006 as a left join sf_lo_2006_26 as b
on a.rssd_id=b.rssd_id order by a.name;
quit;

data box.hmda_sf_lo_2006;
set sf_lo_2006;
run;
