/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below aggregates HMDA data on single-family loan originations at the consolidated level.

 =========================================================================================================*/

libname box 'C:\Users\pbwheele\Box Sync\Data Sets';

data ta;
set box.all_ta_1990_2017;
run;

/*HMDA Loan Originations Plus Lags*/
data sf_lo_2007_1 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 72 then delete;
run;
proc sql;
create table sf_lo_2007_2 as select a.*, b.ta
from sf_lo_2007_1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.name;
quit;
data sf_lo_2007_3;
set sf_lo_2007_2;
if ta=. then delete;
run;
/*Identify all subsidiaries in the corporate structure*/
proc sql;
create table sf_lo_2007_4a as select a.*, b.id_rssd_offspring as sub1_rssd 'sub1_rssd'
from sf_lo_2007_3 as a left join nic.relationships_20151231 as b
on a.rssd_id=b.id_rssd_parent and b.start<=17531<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_2007_4b as select a.*, b.id_rssd_offspring as sub2_rssd 'sub2_rssd'
from sf_lo_2007_4a as a left join nic.relationships_20151231 as b
on a.sub1_rssd=b.id_rssd_parent and b.start<=17531<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_2007_4c as select a.*, b.id_rssd_offspring as sub3_rssd 'sub3_rssd'
from sf_lo_2007_4b as a left join nic.relationships_20151231 as b
on a.sub2_rssd=b.id_rssd_parent and b.start<=17531<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_2007_4d as select a.*, b.id_rssd_offspring as sub4_rssd 'sub4_rssd'
from sf_lo_2007_4c as a left join nic.relationships_20151231 as b
on a.sub3_rssd=b.id_rssd_parent and b.start<=17531<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table sf_lo_2007_4e as select a.*, b.id_rssd_offspring as sub5_rssd 'sub5_rssd'
from sf_lo_2007_4d as a left join nic.relationships_20151231 as b
on a.sub4_rssd=b.id_rssd_parent and b.start<=17531<=b.end and (b.pct_equity>50 or b.other_basis_ind=1)
order by name, sub1_rssd, sub2_rssd, sub3_rssd, sub4_rssd;
quit;
/*Add 2012 single-family loan originations for 5th-level subsidiaries*/
data hmda_singlefam_2007;
set hmda.hmda_singlefam_2007;
if rssdid=. then delete;
run;
proc sql;
create table sf_lo_2007_5a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_2007 as b
on a.sub5_rssd=b.rssdid order by a.name;

create table sf_lo_2007_5b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_t
from sf_lo_2007_5a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_5b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_5c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_5b as a left join hmda_singlefam_2007 as b
on a.sub4_rssd=b.rssdid order by a.name;

create table sf_lo_2007_5d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_t
from sf_lo_2007_5c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_5d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_5e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_5d as a left join hmda_singlefam_2007 as b
on a.sub3_rssd=b.rssdid order by a.name;

create table sf_lo_2007_5f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_t
from sf_lo_2007_5e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_5f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_5g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_5f as a left join hmda_singlefam_2007 as b
on a.sub2_rssd=b.rssdid order by a.name;

create table sf_lo_2007_5h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_t
from sf_lo_2007_5g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_5h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_5i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_5h as a left join hmda_singlefam_2007 as b
on a.sub1_rssd=b.rssdid order by a.name;

create table sf_lo_2007_5j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_t
from sf_lo_2007_5i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_5j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_5k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_5j as a left join hmda_singlefam_2007 as b
on a.rssd_id=b.rssdid order by a.name;

create table sf_lo_2007_5l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_t
from sf_lo_2007_5k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_5l nodupkey;
by rssd_id;
run;
data sf_lo_2007_6 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_t lo_singlefam_sub1_t lo_singlefam_sub2_t lo_singlefam_sub3_t lo_singlefam_sub4_t lo_singlefam_sub5_t); 
set sf_lo_2007_5l;
if lo_singlefam_parent_t=. then lo_singlefam_parent_t=0;
if lo_singlefam_sub1_t=. then lo_singlefam_sub1_t=0;
if lo_singlefam_sub2_t=. then lo_singlefam_sub2_t=0;
if lo_singlefam_sub3_t=. then lo_singlefam_sub3_t=0;
if lo_singlefam_sub4_t=. then lo_singlefam_sub4_t=0;
if lo_singlefam_sub5_t=. then lo_singlefam_sub5_t=0;
lo_singlefam_t = lo_singlefam_parent_t + lo_singlefam_sub1_t + lo_singlefam_sub2_t + lo_singlefam_sub3_t + lo_singlefam_sub4_t + lo_singlefam_sub5_t;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2013*/
/*LAG1*/
/*5th-level subsidiaries*/
data hmda_singlefam_2006;
set hmda.hmda_singlefam_2006;
if topid_20071231=. then delete;
run;
proc sql;
create table sf_lo_2007_7a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_2006 as b
on a.sub5_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_7b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag1
from sf_lo_2007_7a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_7b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_7c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_7b as a left join hmda_singlefam_2006 as b
on a.sub4_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_7d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag1
from sf_lo_2007_7c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_7d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_7e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_7d as a left join hmda_singlefam_2006 as b
on a.sub3_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_7f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag1
from sf_lo_2007_7e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_7f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_7g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_7f as a left join hmda_singlefam_2006 as b
on a.sub2_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_7h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag1
from sf_lo_2007_7g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_7h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_7i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_7h as a left join hmda_singlefam_2006 as b
on a.sub1_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_7j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag1
from sf_lo_2007_7i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_7j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_7k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_7j as a left join hmda_singlefam_2006 as b
on a.rssd_id=b.topid_20071231 order by a.name;

create table sf_lo_2007_7l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag1
from sf_lo_2007_7k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_7l nodupkey;
by rssd_id;
run;
data sf_lo_2007_8 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag1 lo_singlefam_sub1_lag1 lo_singlefam_sub2_lag1 lo_singlefam_sub3_lag1 lo_singlefam_sub4_lag1 lo_singlefam_sub5_lag1); 
set sf_lo_2007_7l;
if lo_singlefam_parent_lag1=. then lo_singlefam_parent_lag1=0;
if lo_singlefam_sub1_lag1=. then lo_singlefam_sub1_lag1=0;
if lo_singlefam_sub2_lag1=. then lo_singlefam_sub2_lag1=0;
if lo_singlefam_sub3_lag1=. then lo_singlefam_sub3_lag1=0;
if lo_singlefam_sub4_lag1=. then lo_singlefam_sub4_lag1=0;
if lo_singlefam_sub5_lag1=. then lo_singlefam_sub5_lag1=0;
lo_singlefam_lag1 = lo_singlefam_parent_lag1 + lo_singlefam_sub1_lag1 + lo_singlefam_sub2_lag1 + lo_singlefam_sub3_lag1 + lo_singlefam_sub4_lag1 + lo_singlefam_sub5_lag1;
run;

/*LAG2*/
/*5th-level subsidiaries*/
data hmda_singlefam_2005;
set hmda.hmda_singlefam_2005;
if topid_20071231=. then delete;
run;
proc sql;
create table sf_lo_2007_9a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_2005 as b
on a.sub5_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_9b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag2
from sf_lo_2007_9a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_9b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_9c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_9b as a left join hmda_singlefam_2005 as b
on a.sub4_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_9d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag2
from sf_lo_2007_9c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_9d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_9e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_9d as a left join hmda_singlefam_2005 as b
on a.sub3_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_9f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag2
from sf_lo_2007_9e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_9f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_9g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_9f as a left join hmda_singlefam_2005 as b
on a.sub2_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_9h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag2
from sf_lo_2007_9g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_9h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_9i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_9h as a left join hmda_singlefam_2005 as b
on a.sub1_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_9j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag2
from sf_lo_2007_9i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_9j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_9k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_9j as a left join hmda_singlefam_2005 as b
on a.rssd_id=b.topid_20071231 order by a.name;

create table sf_lo_2007_9l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag2
from sf_lo_2007_9k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_9l nodupkey;
by rssd_id;
run;
data sf_lo_2007_10 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag2 lo_singlefam_sub1_lag2 lo_singlefam_sub2_lag2 lo_singlefam_sub3_lag2 lo_singlefam_sub4_lag2 lo_singlefam_sub5_lag2); 
set sf_lo_2007_9l;
if lo_singlefam_parent_lag2=. then lo_singlefam_parent_lag2=0;
if lo_singlefam_sub1_lag2=. then lo_singlefam_sub1_lag2=0;
if lo_singlefam_sub2_lag2=. then lo_singlefam_sub2_lag2=0;
if lo_singlefam_sub3_lag2=. then lo_singlefam_sub3_lag2=0;
if lo_singlefam_sub4_lag2=. then lo_singlefam_sub4_lag2=0;
if lo_singlefam_sub5_lag2=. then lo_singlefam_sub5_lag2=0;
lo_singlefam_lag2 = lo_singlefam_parent_lag2 + lo_singlefam_sub1_lag2 + lo_singlefam_sub2_lag2 + lo_singlefam_sub3_lag2 + lo_singlefam_sub4_lag2 + lo_singlefam_sub5_lag2;
run;


/*LAG3*/
/*5th-level subsidiaries*/
data hmda_singlefam_2004;
set hmda.hmda_singlefam_2004;
if topid_20071231=. then delete;
run;
proc sql;
create table sf_lo_2007_11a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_2004 as b
on a.sub5_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_11b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag3
from sf_lo_2007_11a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_11b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_11c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_11b as a left join hmda_singlefam_2004 as b
on a.sub4_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_11d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag3
from sf_lo_2007_11c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_11d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_11e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_11d as a left join hmda_singlefam_2004 as b
on a.sub3_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_11f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag3
from sf_lo_2007_11e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_11f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_11g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_11f as a left join hmda_singlefam_2004 as b
on a.sub2_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_11h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag3
from sf_lo_2007_11g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_11h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_11i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_11h as a left join hmda_singlefam_2004 as b
on a.sub1_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_11j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag3
from sf_lo_2007_11i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_11j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_11k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_11j as a left join hmda_singlefam_2004 as b
on a.rssd_id=b.topid_20071231 order by a.name;

create table sf_lo_2007_11l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag3
from sf_lo_2007_11k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_11l nodupkey;
by rssd_id;
run;
data sf_lo_2007_12 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag3 lo_singlefam_sub1_lag3 lo_singlefam_sub2_lag3 lo_singlefam_sub3_lag3 lo_singlefam_sub4_lag3 lo_singlefam_sub5_lag3); 
set sf_lo_2007_11l;
if lo_singlefam_parent_lag3=. then lo_singlefam_parent_lag3=0;
if lo_singlefam_sub1_lag3=. then lo_singlefam_sub1_lag3=0;
if lo_singlefam_sub2_lag3=. then lo_singlefam_sub2_lag3=0;
if lo_singlefam_sub3_lag3=. then lo_singlefam_sub3_lag3=0;
if lo_singlefam_sub4_lag3=. then lo_singlefam_sub4_lag3=0;
if lo_singlefam_sub5_lag3=. then lo_singlefam_sub5_lag3=0;
lo_singlefam_lag3 = lo_singlefam_parent_lag3 + lo_singlefam_sub1_lag3 + lo_singlefam_sub2_lag3 + lo_singlefam_sub3_lag3 + lo_singlefam_sub4_lag3 + lo_singlefam_sub5_lag3;
run;


/*LAG4*/
/*5th-level subsidiaries*/
data hmda_singlefam_2003;
set hmda.hmda_singlefam_2003;
if topid_20071231=. then delete;
run;
proc sql;
create table sf_lo_2007_13a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_2003 as b
on a.sub5_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_13b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag4
from sf_lo_2007_13a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_13b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_13c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_13b as a left join hmda_singlefam_2003 as b
on a.sub4_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_13d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag4
from sf_lo_2007_13c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_13d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_13e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_13d as a left join hmda_singlefam_2003 as b
on a.sub3_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_13f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag4
from sf_lo_2007_13e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_13f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_13g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_13f as a left join hmda_singlefam_2003 as b
on a.sub2_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_13h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag4
from sf_lo_2007_13g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_13h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_13i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_13h as a left join hmda_singlefam_2003 as b
on a.sub1_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_13j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag4
from sf_lo_2007_13i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_13j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_13k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_13j as a left join hmda_singlefam_2003 as b
on a.rssd_id=b.topid_20071231 order by a.name;

create table sf_lo_2007_13l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag4
from sf_lo_2007_13k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_13l nodupkey;
by rssd_id;
run;
data sf_lo_2007_14 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag4 lo_singlefam_sub1_lag4 lo_singlefam_sub2_lag4 lo_singlefam_sub3_lag4 lo_singlefam_sub4_lag4 lo_singlefam_sub5_lag4); 
set sf_lo_2007_13l;
if lo_singlefam_parent_lag4=. then lo_singlefam_parent_lag4=0;
if lo_singlefam_sub1_lag4=. then lo_singlefam_sub1_lag4=0;
if lo_singlefam_sub2_lag4=. then lo_singlefam_sub2_lag4=0;
if lo_singlefam_sub3_lag4=. then lo_singlefam_sub3_lag4=0;
if lo_singlefam_sub4_lag4=. then lo_singlefam_sub4_lag4=0;
if lo_singlefam_sub5_lag4=. then lo_singlefam_sub5_lag4=0;
lo_singlefam_lag4 = lo_singlefam_parent_lag4 + lo_singlefam_sub1_lag4 + lo_singlefam_sub2_lag4 + lo_singlefam_sub3_lag4 + lo_singlefam_sub4_lag4 + lo_singlefam_sub5_lag4;
run;


/*LAG5*/
/*5th-level subsidiaries*/
data hmda_singlefam_2002;
set hmda.hmda_singlefam_2002;
if topid_20071231=. then delete;
run;
proc sql;
create table sf_lo_2007_15a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_2002 as b
on a.sub5_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_15b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag5
from sf_lo_2007_15a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_15b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_15c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_15b as a left join hmda_singlefam_2002 as b
on a.sub4_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_15d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag5
from sf_lo_2007_15c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_15d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_15e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_15d as a left join hmda_singlefam_2002 as b
on a.sub3_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_15f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag5
from sf_lo_2007_15e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_15f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_15g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_15f as a left join hmda_singlefam_2002 as b
on a.sub2_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_15h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag5
from sf_lo_2007_15g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_15h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_15i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_15h as a left join hmda_singlefam_2002 as b
on a.sub1_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_15j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag5
from sf_lo_2007_15i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_15j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_15k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_15j as a left join hmda_singlefam_2002 as b
on a.rssd_id=b.topid_20071231 order by a.name;

create table sf_lo_2007_15l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag5
from sf_lo_2007_15k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_15l nodupkey;
by rssd_id;
run;
data sf_lo_2007_16 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag5 lo_singlefam_sub1_lag5 lo_singlefam_sub2_lag5 lo_singlefam_sub3_lag5 lo_singlefam_sub4_lag5 lo_singlefam_sub5_lag5); 
set sf_lo_2007_15l;
if lo_singlefam_parent_lag5=. then lo_singlefam_parent_lag5=0;
if lo_singlefam_sub1_lag5=. then lo_singlefam_sub1_lag5=0;
if lo_singlefam_sub2_lag5=. then lo_singlefam_sub2_lag5=0;
if lo_singlefam_sub3_lag5=. then lo_singlefam_sub3_lag5=0;
if lo_singlefam_sub4_lag5=. then lo_singlefam_sub4_lag5=0;
if lo_singlefam_sub5_lag5=. then lo_singlefam_sub5_lag5=0;
lo_singlefam_lag5 = lo_singlefam_parent_lag5 + lo_singlefam_sub1_lag5 + lo_singlefam_sub2_lag5 + lo_singlefam_sub3_lag5 + lo_singlefam_sub4_lag5 + lo_singlefam_sub5_lag5;
run;


/*LAG6*/
/*5th-level subsidiaries*/
data hmda_singlefam_2001;
set hmda.hmda_singlefam_2001;
if topid_20071231=. then delete;
run;
proc sql;
create table sf_lo_2007_17a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_2001 as b
on a.sub5_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_17b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag6
from sf_lo_2007_17a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_17b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_17c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_17b as a left join hmda_singlefam_2001 as b
on a.sub4_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_17d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag6
from sf_lo_2007_17c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_17d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_17e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_17d as a left join hmda_singlefam_2001 as b
on a.sub3_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_17f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag6
from sf_lo_2007_17e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_17f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_17g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_17f as a left join hmda_singlefam_2001 as b
on a.sub2_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_17h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag6
from sf_lo_2007_17g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_17h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_17i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_17h as a left join hmda_singlefam_2001 as b
on a.sub1_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_17j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag6
from sf_lo_2007_17i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_17j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_17k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_17j as a left join hmda_singlefam_2001 as b
on a.rssd_id=b.topid_20071231 order by a.name;

create table sf_lo_2007_17l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag6
from sf_lo_2007_17k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_17l nodupkey;
by rssd_id;
run;
data sf_lo_2007_18 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag6 lo_singlefam_sub1_lag6 lo_singlefam_sub2_lag6 lo_singlefam_sub3_lag6 lo_singlefam_sub4_lag6 lo_singlefam_sub5_lag6); 
set sf_lo_2007_17l;
if lo_singlefam_parent_lag6=. then lo_singlefam_parent_lag6=0;
if lo_singlefam_sub1_lag6=. then lo_singlefam_sub1_lag6=0;
if lo_singlefam_sub2_lag6=. then lo_singlefam_sub2_lag6=0;
if lo_singlefam_sub3_lag6=. then lo_singlefam_sub3_lag6=0;
if lo_singlefam_sub4_lag6=. then lo_singlefam_sub4_lag6=0;
if lo_singlefam_sub5_lag6=. then lo_singlefam_sub5_lag6=0;
lo_singlefam_lag6 = lo_singlefam_parent_lag6 + lo_singlefam_sub1_lag6 + lo_singlefam_sub2_lag6 + lo_singlefam_sub3_lag6 + lo_singlefam_sub4_lag6 + lo_singlefam_sub5_lag6;
run;


/*LAG7*/
/*5th-level subsidiaries*/
data hmda_singlefam_2000;
set hmda.hmda_singlefam_2000;
if topid_20071231=. then delete;
run;
proc sql;
create table sf_lo_2007_19a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_2000 as b
on a.sub5_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_19b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag7
from sf_lo_2007_19a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_19b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_19c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_19b as a left join hmda_singlefam_2000 as b
on a.sub4_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_19d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag7
from sf_lo_2007_19c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_19d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_19e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_19d as a left join hmda_singlefam_2000 as b
on a.sub3_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_19f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag7
from sf_lo_2007_19e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_19f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_19g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_19f as a left join hmda_singlefam_2000 as b
on a.sub2_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_19h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag7
from sf_lo_2007_19g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_19h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_19i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_19h as a left join hmda_singlefam_2000 as b
on a.sub1_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_19j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag7
from sf_lo_2007_19i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_19j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_19k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_19j as a left join hmda_singlefam_2000 as b
on a.rssd_id=b.topid_20071231 order by a.name;

create table sf_lo_2007_19l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag7
from sf_lo_2007_19k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_19l nodupkey;
by rssd_id;
run;
data sf_lo_2007_20 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag7 lo_singlefam_sub1_lag7 lo_singlefam_sub2_lag7 lo_singlefam_sub3_lag7 lo_singlefam_sub4_lag7 lo_singlefam_sub5_lag7); 
set sf_lo_2007_19l;
if lo_singlefam_parent_lag7=. then lo_singlefam_parent_lag7=0;
if lo_singlefam_sub1_lag7=. then lo_singlefam_sub1_lag7=0;
if lo_singlefam_sub2_lag7=. then lo_singlefam_sub2_lag7=0;
if lo_singlefam_sub3_lag7=. then lo_singlefam_sub3_lag7=0;
if lo_singlefam_sub4_lag7=. then lo_singlefam_sub4_lag7=0;
if lo_singlefam_sub5_lag7=. then lo_singlefam_sub5_lag7=0;
lo_singlefam_lag7 = lo_singlefam_parent_lag7 + lo_singlefam_sub1_lag7 + lo_singlefam_sub2_lag7 + lo_singlefam_sub3_lag7 + lo_singlefam_sub4_lag7 + lo_singlefam_sub5_lag7;
run;

/*LAG8*/
/*5th-level subsidiaries*/
data hmda_singlefam_1999;
set hmda.hmda_singlefam_1999;
if topid_20071231=. then delete;
run;
proc sql;
create table sf_lo_2007_21a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_1999 as b
on a.sub5_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_21b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag8
from sf_lo_2007_21a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_21b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_21c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_21b as a left join hmda_singlefam_1999 as b
on a.sub4_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_21d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag8
from sf_lo_2007_21c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_21d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_21e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_21d as a left join hmda_singlefam_1999 as b
on a.sub3_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_21f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag8
from sf_lo_2007_21e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_21f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_21g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_21f as a left join hmda_singlefam_1999 as b
on a.sub2_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_21h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag8
from sf_lo_2007_21g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_21h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_21i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_21h as a left join hmda_singlefam_1999 as b
on a.sub1_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_21j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag8
from sf_lo_2007_21i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_21j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_21k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_21j as a left join hmda_singlefam_1999 as b
on a.rssd_id=b.topid_20071231 order by a.name;

create table sf_lo_2007_21l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag8
from sf_lo_2007_21k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_21l nodupkey;
by rssd_id;
run;
data sf_lo_2007_22 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag8 lo_singlefam_sub1_lag8 lo_singlefam_sub2_lag8 lo_singlefam_sub3_lag8 lo_singlefam_sub4_lag8 lo_singlefam_sub5_lag8); 
set sf_lo_2007_21l;
if lo_singlefam_parent_lag8=. then lo_singlefam_parent_lag8=0;
if lo_singlefam_sub1_lag8=. then lo_singlefam_sub1_lag8=0;
if lo_singlefam_sub2_lag8=. then lo_singlefam_sub2_lag8=0;
if lo_singlefam_sub3_lag8=. then lo_singlefam_sub3_lag8=0;
if lo_singlefam_sub4_lag8=. then lo_singlefam_sub4_lag8=0;
if lo_singlefam_sub5_lag8=. then lo_singlefam_sub5_lag8=0;
lo_singlefam_lag8 = lo_singlefam_parent_lag8 + lo_singlefam_sub1_lag8 + lo_singlefam_sub2_lag8 + lo_singlefam_sub3_lag8 + lo_singlefam_sub4_lag8 + lo_singlefam_sub5_lag8;
run;


/*LAG9*/
/*5th-level subsidiaries*/
data hmda_singlefam_1998;
set hmda.hmda_singlefam_1998;
if topid_20071231=. then delete;
run;
proc sql;
create table sf_lo_2007_23a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_1998 as b
on a.sub5_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_23b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag9
from sf_lo_2007_23a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_23b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_23c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_23b as a left join hmda_singlefam_1998 as b
on a.sub4_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_23d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag9
from sf_lo_2007_23c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_23d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_23e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_23d as a left join hmda_singlefam_1998 as b
on a.sub3_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_23f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag9
from sf_lo_2007_23e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_23f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_23g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_23f as a left join hmda_singlefam_1998 as b
on a.sub2_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_23h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag9
from sf_lo_2007_23g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_23h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_23i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_23h as a left join hmda_singlefam_1998 as b
on a.sub1_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_23j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag9
from sf_lo_2007_23i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_23j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_23k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_23j as a left join hmda_singlefam_1998 as b
on a.rssd_id=b.topid_20071231 order by a.name;

create table sf_lo_2007_23l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag9
from sf_lo_2007_23k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_23l nodupkey;
by rssd_id;
run;
data sf_lo_2007_24 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag9 lo_singlefam_sub1_lag9 lo_singlefam_sub2_lag9 lo_singlefam_sub3_lag9 lo_singlefam_sub4_lag9 lo_singlefam_sub5_lag9); 
set sf_lo_2007_23l;
if lo_singlefam_parent_lag9=. then lo_singlefam_parent_lag9=0;
if lo_singlefam_sub1_lag9=. then lo_singlefam_sub1_lag9=0;
if lo_singlefam_sub2_lag9=. then lo_singlefam_sub2_lag9=0;
if lo_singlefam_sub3_lag9=. then lo_singlefam_sub3_lag9=0;
if lo_singlefam_sub4_lag9=. then lo_singlefam_sub4_lag9=0;
if lo_singlefam_sub5_lag9=. then lo_singlefam_sub5_lag9=0;
lo_singlefam_lag9 = lo_singlefam_parent_lag9 + lo_singlefam_sub1_lag9 + lo_singlefam_sub2_lag9 + lo_singlefam_sub3_lag9 + lo_singlefam_sub4_lag9 + lo_singlefam_sub5_lag9;
run;


/*LAG10*/
/*5th-level subsidiaries*/
data hmda_singlefam_1997;
set hmda.hmda_singlefam_1997;
if topid_20071231=. then delete;
run;
proc sql;
create table sf_lo_2007_25a as select a.*, b.lo_singlefam as lo_singlefam_sub5
from sf_lo_2007_4e as a left join hmda_singlefam_1997 as b
on a.sub5_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_25b as select *, sum(lo_singlefam_sub5) as lo_singlefam_sub5_lag10
from sf_lo_2007_25a group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_25b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table sf_lo_2007_25c as select a.*, b.lo_singlefam as lo_singlefam_sub4
from sf_lo_2007_25b as a left join hmda_singlefam_1997 as b
on a.sub4_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_25d as select *, sum(lo_singlefam_sub4) as lo_singlefam_sub4_lag10
from sf_lo_2007_25c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=sf_lo_2007_25d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table sf_lo_2007_25e as select a.*, b.lo_singlefam as lo_singlefam_sub3
from sf_lo_2007_25d as a left join hmda_singlefam_1997 as b
on a.sub3_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_25f as select *, sum(lo_singlefam_sub3) as lo_singlefam_sub3_lag10
from sf_lo_2007_25e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=sf_lo_2007_25f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table sf_lo_2007_25g as select a.*, b.lo_singlefam as lo_singlefam_sub2
from sf_lo_2007_25f as a left join hmda_singlefam_1997 as b
on a.sub2_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_25h as select *, sum(lo_singlefam_sub2) as lo_singlefam_sub2_lag10
from sf_lo_2007_25g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=sf_lo_2007_25h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table sf_lo_2007_25i as select a.*, b.lo_singlefam as lo_singlefam_sub1
from sf_lo_2007_25h as a left join hmda_singlefam_1997 as b
on a.sub1_rssd=b.topid_20071231 order by a.name;

create table sf_lo_2007_25j as select *, sum(lo_singlefam_sub1) as lo_singlefam_sub1_lag10
from sf_lo_2007_25i group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_25j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table sf_lo_2007_25k as select a.*, b.lo_singlefam as lo_singlefam_parent
from sf_lo_2007_25j as a left join hmda_singlefam_1997 as b
on a.rssd_id=b.topid_20071231 order by a.name;

create table sf_lo_2007_25l as select *, sum(lo_singlefam_parent) as lo_singlefam_parent_lag10
from sf_lo_2007_25k group by rssd_id order by name;
quit;
proc sort data=sf_lo_2007_25l nodupkey;
by rssd_id;
run;
data sf_lo_2007_26 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_singlefam_parent lo_singlefam_sub1 lo_singlefam_sub2 lo_singlefam_sub3 lo_singlefam_sub4 lo_singlefam_sub5 
lo_singlefam_parent_lag10 lo_singlefam_sub1_lag10 lo_singlefam_sub2_lag10 lo_singlefam_sub3_lag10 lo_singlefam_sub4_lag10 lo_singlefam_sub5_lag10); 
set sf_lo_2007_25l;
if lo_singlefam_parent_lag10=. then lo_singlefam_parent_lag10=0;
if lo_singlefam_sub1_lag10=. then lo_singlefam_sub1_lag10=0;
if lo_singlefam_sub2_lag10=. then lo_singlefam_sub2_lag10=0;
if lo_singlefam_sub3_lag10=. then lo_singlefam_sub3_lag10=0;
if lo_singlefam_sub4_lag10=. then lo_singlefam_sub4_lag10=0;
if lo_singlefam_sub5_lag10=. then lo_singlefam_sub5_lag10=0;
lo_singlefam_lag10 = lo_singlefam_parent_lag10 + lo_singlefam_sub1_lag10 + lo_singlefam_sub2_lag10 + lo_singlefam_sub3_lag10 + lo_singlefam_sub4_lag10 + lo_singlefam_sub5_lag10;
run;

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~;
*Aggregate all loan origination lag observations;
proc sql;
create table sf_lo_2007 as select a.*, b.lo_singlefam_lag1
from sf_lo_2007_6 as a left join sf_lo_2007_8 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2007 as select a.*, b.lo_singlefam_lag2
from sf_lo_2007 as a left join sf_lo_2007_10 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2007 as select a.*, b.lo_singlefam_lag3
from sf_lo_2007 as a left join sf_lo_2007_12 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2007 as select a.*, b.lo_singlefam_lag4
from sf_lo_2007 as a left join sf_lo_2007_14 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2007 as select a.*, b.lo_singlefam_lag5
from sf_lo_2007 as a left join sf_lo_2007_16 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2007 as select a.*, b.lo_singlefam_lag6
from sf_lo_2007 as a left join sf_lo_2007_18 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2007 as select a.*, b.lo_singlefam_lag7
from sf_lo_2007 as a left join sf_lo_2007_20 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2007 as select a.*, b.lo_singlefam_lag8
from sf_lo_2007 as a left join sf_lo_2007_22 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2007 as select a.*, b.lo_singlefam_lag9
from sf_lo_2007 as a left join sf_lo_2007_24 as b
on a.rssd_id=b.rssd_id order by a.name;

create table sf_lo_2007 as select a.*, b.lo_singlefam_lag10
from sf_lo_2007 as a left join sf_lo_2007_26 as b
on a.rssd_id=b.rssd_id order by a.name;
quit;

data box.hmda_sf_lo_2007;
set sf_lo_2007;
run;
