/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below estimates repayments on single-family and multi-family real estate loans based
		on HMDA origination data and beginning and ending loan balances for each bank. These repayment
		rates are used to estimate repayments on CRE and farm loans as discussed in Appendix B of the
		manuscript.

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';
libname hmda 'C:\Users\pwheeler1\Box Sync\Data Sets\HMDA';
libname nic 'C:\Users\pwheeler1\Box Sync\Data Sets\NIC Data';

data sf_payoffs1 (keep = snlkey name rssd_id rankdate ta lo_singlefam_t);
set lo.hmda_sf_lo_1990_2016;
run;
data all_sfloans_1990_2017;
set box.all_sfloans_1990_2017;
if reg_id=. then delete;
run;
proc sql;
create table sf_payoffs2a as select a.*, b.sfloans as end_sfloans
from sf_payoffs1 as a left join all_sfloans_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.rssd_id;

create table sf_payoffs2b as select a.*, b.sfloans as beg_sfloans
from sf_payoffs2a as a left join all_sfloans_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4 order by a.rssd_id;

create table sf_payoffs2c as select a.*, b.year
from sf_payoffs2b as a left join box.rankdates as b
on a.rankdate=b.rankdate;
quit;
proc sort data=sf_payoffs2c nodupkey out=sf_payoffs2d;
by rssd_id rankdate;
run;
*Add PY loans to PY loans of firms acquired during the year;
data nic;
set nic.transformations_20180331;
yearnum = put(dt_trans,$8.);
subst = substr(yearnum,1,4);
year = input(subst,4.);
run;
proc sql;
create table sf_payoffs3a as select a.*, b.id_rssd_predecessor as pyacquisition_rssd 'pyacquisition_rssd'
from sf_payoffs2d as a left join nic as b
on a.rssd_id=b.id_rssd_successor and b.year=a.year;
quit;
proc sql;
create table sf_payoffs3b as select a.*, b.lo_singlefam_t as lo_singlefam_pred 'lo_singlefam_pred'
from sf_payoffs3a as a left join lo.hmda_sf_lo_1990_2016 as b
on a.pyacquisition_rssd=b.rssd_id and a.rankdate=b.rankdate order by a.rssd_id, a.rankdate;

create table sf_payoffs3c as select a.*, b.sfloans as beg_sfloans_pred 'beg_sfloans_pred'
from sf_payoffs3b as a left join all_sfloans_1990_2017 as b
on a.pyacquisition_rssd=b.reg_id and a.rankdate=b.rankdate+4 order by a.rssd_id, a.rankdate;

create table sf_payoffs3d as select *, sum(lo_singlefam_pred) as lo_singlefam_preds, sum(beg_sfloans_pred) as beg_sfloans_preds
from sf_payoffs3c group by rssd_id, rankdate;
quit;
proc sort data=sf_payoffs3d nodupkey out=sf_payoffs3e;
by rssd_id rankdate;
run;
data sf_payoffs4 (drop= pyacquisition_rssd lo_singlefam_pred beg_sfloans_pred);
set sf_payoffs3e;
if beg_sfloans_preds=. then beg_sfloans_preds=0;
if lo_singlefam_preds=. then lo_singlefam_preds=0;
if lo_singlefam_t=. then delete;
sf_payoffs = beg_sfloans+beg_sfloans_preds+lo_singlefam_t+lo_singlefam_preds-end_sfloans;
run;

data mf_payoffs1 (keep = snlkey name rssd_id rankdate ta lo_multifam_t);
set lo.hmda_mf_lo_1990_2016;
run;
data all_mfloans_1990_2017;
set box.all_mfloans_1990_2017;
if reg_id=. then delete;
run;
proc sql;
create table mf_payoffs2a as select a.*, b.mfloans as end_mfloans
from mf_payoffs1 as a left join all_mfloans_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.rssd_id;

create table mf_payoffs2b as select a.*, b.mfloans as beg_mfloans
from mf_payoffs2a as a left join all_mfloans_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4 order by a.rssd_id;

create table mf_payoffs2c as select a.*, b.year
from mf_payoffs2b as a left join box.rankdates as b
on a.rankdate=b.rankdate;
quit;
proc sort data=mf_payoffs2c nodupkey out=mf_payoffs2d;
by rssd_id rankdate;
run;
*Add PY loans to PY loans of firms acquired during the year;
data nic;
set nic.transformations_20180331;
yearnum = put(dt_trans,$8.);
subst = substr(yearnum,1,4);
year = input(subst,4.);
run;
proc sql;
create table mf_payoffs3a as select a.*, b.id_rssd_predecessor as pyacquisition_rssd 'pyacquisition_rssd'
from mf_payoffs2d as a left join nic as b
on a.rssd_id=b.id_rssd_successor and b.year=a.year;
quit;
proc sql;
create table mf_payoffs3b as select a.*, b.lo_multifam_t as lo_multifam_pred 'lo_multifam_pred'
from mf_payoffs3a as a left join lo.hmda_mf_lo_1990_2016 as b
on a.pyacquisition_rssd=b.rssd_id and a.rankdate=b.rankdate order by a.rssd_id, a.rankdate;

create table mf_payoffs3c as select a.*, b.mfloans as beg_mfloans_pred 'beg_mfloans_pred'
from mf_payoffs3b as a left join all_mfloans_1990_2017 as b
on a.pyacquisition_rssd=b.reg_id and a.rankdate=b.rankdate+4 order by a.rssd_id, a.rankdate;

create table mf_payoffs3d as select *, sum(lo_multifam_pred) as lo_multifam_preds, sum(beg_mfloans_pred) as beg_mfloans_preds
from mf_payoffs3c group by rssd_id, rankdate;
quit;
proc sort data=mf_payoffs3d nodupkey out=mf_payoffs3e;
by rssd_id rankdate;
run;
data mf_payoffs4 (drop= pyacquisition_rssd lo_multifam_pred beg_mfloans_pred);
set mf_payoffs3e;
if beg_mfloans_preds=. then beg_mfloans_preds=0;
if lo_multifam_preds=. then lo_multifam_preds=0;
if lo_multifam_t=. then delete;
mf_payoffs = beg_mfloans+beg_mfloans_preds+lo_multifam_t+lo_multifam_preds-end_mfloans;
run;

proc sql;
create table sfmf_payoffs1 as select a.*, b.lo_multifam_t, b.end_mfloans, b.beg_mfloans, b.lo_multifam_preds, b.beg_mfloans_preds
from sf_payoffs4 as a left join mf_payoffs4 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;

data sfmf_payoffs2 (drop=sf_payoffs);
set sfmf_payoffs1;
lo_t=lo_singlefam_t+lo_multifam_t+lo_singlefam_preds+lo_multifam_preds;
endloans=end_sfloans+end_mfloans;
begloans=beg_sfloans+beg_mfloans+beg_sfloans_preds+beg_mfloans_preds;
run;

data sfmf_payoffs3 (drop=lo_singlefam_t end_sfloans beg_sfloans lo_singlefam_preds beg_sfloans_preds
lo_multifam_t end_mfloans beg_mfloans lo_multifam_preds beg_mfloans_preds);
set sfmf_payoffs2;
payoffs = begloans+lo_t-endloans;
run;

proc sql;
create table sfmf_payoffs4 as select avg(year) as year, sum(lo_t) as lo_t, sum(endloans) as endloans,
sum(begloans) as begloans, sum(payoffs) as payoffs
from sfmf_payoffs3 group by year order by year;
quit;

data sfmf_payoffs5;
set sfmf_payoffs4;
payoff_pct = payoffs/begloans;
run;

data lo.sfmf_payoffs;
set sfmf_payoffs5;
run;
