/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below aggregates HMDA data on multi-family real estate loan originations at the
		consolidated level.

 =========================================================================================================*/

libname box 'C:\Users\pbwheele\Box Sync\Data Sets';

data ta;
set box.all_ta_1990_2017;
run;

/*HMDA Loan Originations Plus Lags*/
data mf_lo_1991_1 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 8 then delete;
run;
proc sql;
create table mf_lo_1991_2 as select a.*, b.ta
from mf_lo_1991_1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.name;
quit;
data mf_lo_1991_3;
set mf_lo_1991_2;
if ta=. then delete;
run;
/*Identify all subsidiaries in the corporate structure*/
proc sql;
create table mf_lo_1991_4a as select a.*, b.id_rssd_offspring as sub1_rssd 'sub1_rssd'
from mf_lo_1991_3 as a left join nic.relationships_20151231 as b
on a.rssd_id=b.id_rssd_parent and b.start<=11687<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_1991_4b as select a.*, b.id_rssd_offspring as sub2_rssd 'sub2_rssd'
from mf_lo_1991_4a as a left join nic.relationships_20151231 as b
on a.sub1_rssd=b.id_rssd_parent and b.start<=11687<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_1991_4c as select a.*, b.id_rssd_offspring as sub3_rssd 'sub3_rssd'
from mf_lo_1991_4b as a left join nic.relationships_20151231 as b
on a.sub2_rssd=b.id_rssd_parent and b.start<=11687<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_1991_4d as select a.*, b.id_rssd_offspring as sub4_rssd 'sub4_rssd'
from mf_lo_1991_4c as a left join nic.relationships_20151231 as b
on a.sub3_rssd=b.id_rssd_parent and b.start<=11687<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_1991_4e as select a.*, b.id_rssd_offspring as sub5_rssd 'sub5_rssd'
from mf_lo_1991_4d as a left join nic.relationships_20151231 as b
on a.sub4_rssd=b.id_rssd_parent and b.start<=11687<=b.end and (b.pct_equity>50 or b.other_basis_ind=1)
order by name, sub1_rssd, sub2_rssd, sub3_rssd, sub4_rssd;
quit;
/*Add 2012 single-family loan originations for 5th-level subsidiaries*/
data hmda_multifam_1991;
set hmda.hmda_multifam_1991;
if rssdid=. then delete;
run;
proc sql;
create table mf_lo_1991_5a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_1991_4e as a left join hmda_multifam_1991 as b
on a.sub5_rssd=b.rssdid order by a.name;

create table mf_lo_1991_5b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_t
from mf_lo_1991_5a group by rssd_id order by name;
quit;
proc sort data=mf_lo_1991_5b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_1991_5c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_1991_5b as a left join hmda_multifam_1991 as b
on a.sub4_rssd=b.rssdid order by a.name;

create table mf_lo_1991_5d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_t
from mf_lo_1991_5c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_1991_5d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_1991_5e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_1991_5d as a left join hmda_multifam_1991 as b
on a.sub3_rssd=b.rssdid order by a.name;

create table mf_lo_1991_5f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_t
from mf_lo_1991_5e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_1991_5f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_1991_5g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_1991_5f as a left join hmda_multifam_1991 as b
on a.sub2_rssd=b.rssdid order by a.name;

create table mf_lo_1991_5h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_t
from mf_lo_1991_5g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_1991_5h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_1991_5i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_1991_5h as a left join hmda_multifam_1991 as b
on a.sub1_rssd=b.rssdid order by a.name;

create table mf_lo_1991_5j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_t
from mf_lo_1991_5i group by rssd_id order by name;
quit;
proc sort data=mf_lo_1991_5j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_1991_5k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_1991_5j as a left join hmda_multifam_1991 as b
on a.rssd_id=b.rssdid order by a.name;

create table mf_lo_1991_5l as select *, sum(lo_multifam_parent) as lo_multifam_parent_t
from mf_lo_1991_5k group by rssd_id order by name;
quit;
proc sort data=mf_lo_1991_5l nodupkey;
by rssd_id;
run;
data mf_lo_1991_6 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_t lo_multifam_sub1_t lo_multifam_sub2_t lo_multifam_sub3_t lo_multifam_sub4_t lo_multifam_sub5_t); 
set mf_lo_1991_5l;
if lo_multifam_parent_t=. then lo_multifam_parent_t=0;
if lo_multifam_sub1_t=. then lo_multifam_sub1_t=0;
if lo_multifam_sub2_t=. then lo_multifam_sub2_t=0;
if lo_multifam_sub3_t=. then lo_multifam_sub3_t=0;
if lo_multifam_sub4_t=. then lo_multifam_sub4_t=0;
if lo_multifam_sub5_t=. then lo_multifam_sub5_t=0;
lo_multifam_t = lo_multifam_parent_t + lo_multifam_sub1_t + lo_multifam_sub2_t + lo_multifam_sub3_t + lo_multifam_sub4_t + lo_multifam_sub5_t;
run;

/*CREATE LAGGED ORIGINATIONS*/
/*LAG1*/
/*5th-level subsidiaries*/
data hmda_multifam_1990;
set hmda.hmda_multifam_1990;
if topid_19911231=. then delete;
run;
proc sql;
create table mf_lo_1991_7a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_1991_4e as a left join hmda_multifam_1990 as b
on a.sub5_rssd=b.topid_19911231 order by a.name;

create table mf_lo_1991_7b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag1
from mf_lo_1991_7a group by rssd_id order by name;
quit;
proc sort data=mf_lo_1991_7b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_1991_7c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_1991_7b as a left join hmda_multifam_1990 as b
on a.sub4_rssd=b.topid_19911231 order by a.name;

create table mf_lo_1991_7d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag1
from mf_lo_1991_7c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_1991_7d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_1991_7e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_1991_7d as a left join hmda_multifam_1990 as b
on a.sub3_rssd=b.topid_19911231 order by a.name;

create table mf_lo_1991_7f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag1
from mf_lo_1991_7e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_1991_7f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_1991_7g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_1991_7f as a left join hmda_multifam_1990 as b
on a.sub2_rssd=b.topid_19911231 order by a.name;

create table mf_lo_1991_7h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag1
from mf_lo_1991_7g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_1991_7h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_1991_7i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_1991_7h as a left join hmda_multifam_1990 as b
on a.sub1_rssd=b.topid_19911231 order by a.name;

create table mf_lo_1991_7j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag1
from mf_lo_1991_7i group by rssd_id order by name;
quit;
proc sort data=mf_lo_1991_7j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_1991_7k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_1991_7j as a left join hmda_multifam_1990 as b
on a.rssd_id=b.topid_19911231 order by a.name;

create table mf_lo_1991_7l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag1
from mf_lo_1991_7k group by rssd_id order by name;
quit;
proc sort data=mf_lo_1991_7l nodupkey;
by rssd_id;
run;
data mf_lo_1991_8 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag1 lo_multifam_sub1_lag1 lo_multifam_sub2_lag1 lo_multifam_sub3_lag1 lo_multifam_sub4_lag1 lo_multifam_sub5_lag1); 
set mf_lo_1991_7l;
if lo_multifam_parent_lag1=. then lo_multifam_parent_lag1=0;
if lo_multifam_sub1_lag1=. then lo_multifam_sub1_lag1=0;
if lo_multifam_sub2_lag1=. then lo_multifam_sub2_lag1=0;
if lo_multifam_sub3_lag1=. then lo_multifam_sub3_lag1=0;
if lo_multifam_sub4_lag1=. then lo_multifam_sub4_lag1=0;
if lo_multifam_sub5_lag1=. then lo_multifam_sub5_lag1=0;
lo_multifam_lag1 = lo_multifam_parent_lag1 + lo_multifam_sub1_lag1 + lo_multifam_sub2_lag1 + lo_multifam_sub3_lag1 + lo_multifam_sub4_lag1 + lo_multifam_sub5_lag1;
run;


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~;
*Aggregate all loan origination lag observations;
proc sql;
create table mf_lo_1991 as select a.*, b.lo_multifam_lag1
from mf_lo_1991_6 as a left join mf_lo_1991_8 as b
on a.rssd_id=b.rssd_id order by a.name;
quit;

data box.hmda_mf_lo_1991;
set mf_lo_1991;
run;
