/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below aggregates HMDA data on multi-family real estate loan originations at the
		consolidated level.

 =========================================================================================================*/

libname box 'C:\Users\pbwheele\Box Sync\Data Sets';

data ta;
set box.all_ta_1990_2017;
run;

/*2002 HMDA Loan Originations Plus 10 Lags*/
data mf_lo_2001_1 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 48 then delete;
run;
proc sql;
create table mf_lo_2001_2 as select a.*, b.ta
from mf_lo_2001_1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.name;
quit;
data mf_lo_2001_3;
set mf_lo_2001_2;
if ta=. then delete;
run;
/*Identify all subsidiaries in the corporate structure*/
proc sql;
create table mf_lo_2001_4a as select a.*, b.id_rssd_offspring as sub1_rssd 'sub1_rssd'
from mf_lo_2001_3 as a left join nic.relationships_20151231 as b
on a.rssd_id=b.id_rssd_parent and b.start<=15340<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_2001_4b as select a.*, b.id_rssd_offspring as sub2_rssd 'sub2_rssd'
from mf_lo_2001_4a as a left join nic.relationships_20151231 as b
on a.sub1_rssd=b.id_rssd_parent and b.start<=15340<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_2001_4c as select a.*, b.id_rssd_offspring as sub3_rssd 'sub3_rssd'
from mf_lo_2001_4b as a left join nic.relationships_20151231 as b
on a.sub2_rssd=b.id_rssd_parent and b.start<=15340<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_2001_4d as select a.*, b.id_rssd_offspring as sub4_rssd 'sub4_rssd'
from mf_lo_2001_4c as a left join nic.relationships_20151231 as b
on a.sub3_rssd=b.id_rssd_parent and b.start<=15340<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_2001_4e as select a.*, b.id_rssd_offspring as sub5_rssd 'sub5_rssd'
from mf_lo_2001_4d as a left join nic.relationships_20151231 as b
on a.sub4_rssd=b.id_rssd_parent and b.start<=15340<=b.end and (b.pct_equity>50 or b.other_basis_ind=1)
order by name, sub1_rssd, sub2_rssd, sub3_rssd, sub4_rssd;
quit;
/*Add 2012 single-family loan originations for 5th-level subsidiaries*/
data hmda_multifam_2001;
set hmda.hmda_multifam_2001;
if rssdid=. then delete;
run;
proc sql;
create table mf_lo_2001_5a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_2001 as b
on a.sub5_rssd=b.rssdid order by a.name;

create table mf_lo_2001_5b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_t
from mf_lo_2001_5a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_5b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_5c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_5b as a left join hmda_multifam_2001 as b
on a.sub4_rssd=b.rssdid order by a.name;

create table mf_lo_2001_5d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_t
from mf_lo_2001_5c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_5d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_5e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_5d as a left join hmda_multifam_2001 as b
on a.sub3_rssd=b.rssdid order by a.name;

create table mf_lo_2001_5f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_t
from mf_lo_2001_5e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_5f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_5g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_5f as a left join hmda_multifam_2001 as b
on a.sub2_rssd=b.rssdid order by a.name;

create table mf_lo_2001_5h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_t
from mf_lo_2001_5g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_5h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_5i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_5h as a left join hmda_multifam_2001 as b
on a.sub1_rssd=b.rssdid order by a.name;

create table mf_lo_2001_5j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_t
from mf_lo_2001_5i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_5j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_5k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_5j as a left join hmda_multifam_2001 as b
on a.rssd_id=b.rssdid order by a.name;

create table mf_lo_2001_5l as select *, sum(lo_multifam_parent) as lo_multifam_parent_t
from mf_lo_2001_5k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_5l nodupkey;
by rssd_id;
run;
data mf_lo_2001_6 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_t lo_multifam_sub1_t lo_multifam_sub2_t lo_multifam_sub3_t lo_multifam_sub4_t lo_multifam_sub5_t); 
set mf_lo_2001_5l;
if lo_multifam_parent_t=. then lo_multifam_parent_t=0;
if lo_multifam_sub1_t=. then lo_multifam_sub1_t=0;
if lo_multifam_sub2_t=. then lo_multifam_sub2_t=0;
if lo_multifam_sub3_t=. then lo_multifam_sub3_t=0;
if lo_multifam_sub4_t=. then lo_multifam_sub4_t=0;
if lo_multifam_sub5_t=. then lo_multifam_sub5_t=0;
lo_multifam_t = lo_multifam_parent_t + lo_multifam_sub1_t + lo_multifam_sub2_t + lo_multifam_sub3_t + lo_multifam_sub4_t + lo_multifam_sub5_t;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2013*/
/*LAG1*/
/*5th-level subsidiaries*/
data hmda_multifam_2000;
set hmda.hmda_multifam_2000;
if topid_20011231=. then delete;
run;
proc sql;
create table mf_lo_2001_7a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_2000 as b
on a.sub5_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_7b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag1
from mf_lo_2001_7a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_7b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_7c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_7b as a left join hmda_multifam_2000 as b
on a.sub4_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_7d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag1
from mf_lo_2001_7c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_7d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_7e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_7d as a left join hmda_multifam_2000 as b
on a.sub3_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_7f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag1
from mf_lo_2001_7e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_7f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_7g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_7f as a left join hmda_multifam_2000 as b
on a.sub2_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_7h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag1
from mf_lo_2001_7g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_7h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_7i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_7h as a left join hmda_multifam_2000 as b
on a.sub1_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_7j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag1
from mf_lo_2001_7i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_7j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_7k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_7j as a left join hmda_multifam_2000 as b
on a.rssd_id=b.topid_20011231 order by a.name;

create table mf_lo_2001_7l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag1
from mf_lo_2001_7k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_7l nodupkey;
by rssd_id;
run;
data mf_lo_2001_8 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag1 lo_multifam_sub1_lag1 lo_multifam_sub2_lag1 lo_multifam_sub3_lag1 lo_multifam_sub4_lag1 lo_multifam_sub5_lag1); 
set mf_lo_2001_7l;
if lo_multifam_parent_lag1=. then lo_multifam_parent_lag1=0;
if lo_multifam_sub1_lag1=. then lo_multifam_sub1_lag1=0;
if lo_multifam_sub2_lag1=. then lo_multifam_sub2_lag1=0;
if lo_multifam_sub3_lag1=. then lo_multifam_sub3_lag1=0;
if lo_multifam_sub4_lag1=. then lo_multifam_sub4_lag1=0;
if lo_multifam_sub5_lag1=. then lo_multifam_sub5_lag1=0;
lo_multifam_lag1 = lo_multifam_parent_lag1 + lo_multifam_sub1_lag1 + lo_multifam_sub2_lag1 + lo_multifam_sub3_lag1 + lo_multifam_sub4_lag1 + lo_multifam_sub5_lag1;
run;

/*LAG2*/
/*5th-level subsidiaries*/
data hmda_multifam_1999;
set hmda.hmda_multifam_1999;
if topid_20011231=. then delete;
run;
proc sql;
create table mf_lo_2001_9a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_1999 as b
on a.sub5_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_9b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag2
from mf_lo_2001_9a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_9b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_9c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_9b as a left join hmda_multifam_1999 as b
on a.sub4_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_9d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag2
from mf_lo_2001_9c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_9d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_9e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_9d as a left join hmda_multifam_1999 as b
on a.sub3_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_9f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag2
from mf_lo_2001_9e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_9f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_9g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_9f as a left join hmda_multifam_1999 as b
on a.sub2_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_9h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag2
from mf_lo_2001_9g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_9h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_9i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_9h as a left join hmda_multifam_1999 as b
on a.sub1_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_9j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag2
from mf_lo_2001_9i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_9j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_9k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_9j as a left join hmda_multifam_1999 as b
on a.rssd_id=b.topid_20011231 order by a.name;

create table mf_lo_2001_9l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag2
from mf_lo_2001_9k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_9l nodupkey;
by rssd_id;
run;
data mf_lo_2001_10 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag2 lo_multifam_sub1_lag2 lo_multifam_sub2_lag2 lo_multifam_sub3_lag2 lo_multifam_sub4_lag2 lo_multifam_sub5_lag2); 
set mf_lo_2001_9l;
if lo_multifam_parent_lag2=. then lo_multifam_parent_lag2=0;
if lo_multifam_sub1_lag2=. then lo_multifam_sub1_lag2=0;
if lo_multifam_sub2_lag2=. then lo_multifam_sub2_lag2=0;
if lo_multifam_sub3_lag2=. then lo_multifam_sub3_lag2=0;
if lo_multifam_sub4_lag2=. then lo_multifam_sub4_lag2=0;
if lo_multifam_sub5_lag2=. then lo_multifam_sub5_lag2=0;
lo_multifam_lag2 = lo_multifam_parent_lag2 + lo_multifam_sub1_lag2 + lo_multifam_sub2_lag2 + lo_multifam_sub3_lag2 + lo_multifam_sub4_lag2 + lo_multifam_sub5_lag2;
run;


/*LAG3*/
/*5th-level subsidiaries*/
data hmda_multifam_1998;
set hmda.hmda_multifam_1998;
if topid_20011231=. then delete;
run;
proc sql;
create table mf_lo_2001_11a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_1998 as b
on a.sub5_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_11b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag3
from mf_lo_2001_11a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_11b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_11c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_11b as a left join hmda_multifam_1998 as b
on a.sub4_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_11d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag3
from mf_lo_2001_11c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_11d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_11e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_11d as a left join hmda_multifam_1998 as b
on a.sub3_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_11f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag3
from mf_lo_2001_11e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_11f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_11g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_11f as a left join hmda_multifam_1998 as b
on a.sub2_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_11h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag3
from mf_lo_2001_11g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_11h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_11i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_11h as a left join hmda_multifam_1998 as b
on a.sub1_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_11j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag3
from mf_lo_2001_11i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_11j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_11k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_11j as a left join hmda_multifam_1998 as b
on a.rssd_id=b.topid_20011231 order by a.name;

create table mf_lo_2001_11l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag3
from mf_lo_2001_11k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_11l nodupkey;
by rssd_id;
run;
data mf_lo_2001_12 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag3 lo_multifam_sub1_lag3 lo_multifam_sub2_lag3 lo_multifam_sub3_lag3 lo_multifam_sub4_lag3 lo_multifam_sub5_lag3); 
set mf_lo_2001_11l;
if lo_multifam_parent_lag3=. then lo_multifam_parent_lag3=0;
if lo_multifam_sub1_lag3=. then lo_multifam_sub1_lag3=0;
if lo_multifam_sub2_lag3=. then lo_multifam_sub2_lag3=0;
if lo_multifam_sub3_lag3=. then lo_multifam_sub3_lag3=0;
if lo_multifam_sub4_lag3=. then lo_multifam_sub4_lag3=0;
if lo_multifam_sub5_lag3=. then lo_multifam_sub5_lag3=0;
lo_multifam_lag3 = lo_multifam_parent_lag3 + lo_multifam_sub1_lag3 + lo_multifam_sub2_lag3 + lo_multifam_sub3_lag3 + lo_multifam_sub4_lag3 + lo_multifam_sub5_lag3;
run;


/*LAG4*/
/*5th-level subsidiaries*/
data hmda_multifam_1997;
set hmda.hmda_multifam_1997;
if topid_20011231=. then delete;
run;
proc sql;
create table mf_lo_2001_13a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_1997 as b
on a.sub5_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_13b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag4
from mf_lo_2001_13a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_13b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_13c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_13b as a left join hmda_multifam_1997 as b
on a.sub4_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_13d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag4
from mf_lo_2001_13c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_13d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_13e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_13d as a left join hmda_multifam_1997 as b
on a.sub3_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_13f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag4
from mf_lo_2001_13e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_13f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_13g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_13f as a left join hmda_multifam_1997 as b
on a.sub2_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_13h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag4
from mf_lo_2001_13g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_13h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_13i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_13h as a left join hmda_multifam_1997 as b
on a.sub1_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_13j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag4
from mf_lo_2001_13i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_13j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_13k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_13j as a left join hmda_multifam_1997 as b
on a.rssd_id=b.topid_20011231 order by a.name;

create table mf_lo_2001_13l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag4
from mf_lo_2001_13k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_13l nodupkey;
by rssd_id;
run;
data mf_lo_2001_14 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag4 lo_multifam_sub1_lag4 lo_multifam_sub2_lag4 lo_multifam_sub3_lag4 lo_multifam_sub4_lag4 lo_multifam_sub5_lag4); 
set mf_lo_2001_13l;
if lo_multifam_parent_lag4=. then lo_multifam_parent_lag4=0;
if lo_multifam_sub1_lag4=. then lo_multifam_sub1_lag4=0;
if lo_multifam_sub2_lag4=. then lo_multifam_sub2_lag4=0;
if lo_multifam_sub3_lag4=. then lo_multifam_sub3_lag4=0;
if lo_multifam_sub4_lag4=. then lo_multifam_sub4_lag4=0;
if lo_multifam_sub5_lag4=. then lo_multifam_sub5_lag4=0;
lo_multifam_lag4 = lo_multifam_parent_lag4 + lo_multifam_sub1_lag4 + lo_multifam_sub2_lag4 + lo_multifam_sub3_lag4 + lo_multifam_sub4_lag4 + lo_multifam_sub5_lag4;
run;


/*LAG5*/
/*5th-level subsidiaries*/
data hmda_multifam_1996;
set hmda.hmda_multifam_1996;
if topid_20011231=. then delete;
run;
proc sql;
create table mf_lo_2001_15a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_1996 as b
on a.sub5_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_15b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag5
from mf_lo_2001_15a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_15b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_15c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_15b as a left join hmda_multifam_1996 as b
on a.sub4_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_15d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag5
from mf_lo_2001_15c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_15d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_15e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_15d as a left join hmda_multifam_1996 as b
on a.sub3_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_15f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag5
from mf_lo_2001_15e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_15f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_15g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_15f as a left join hmda_multifam_1996 as b
on a.sub2_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_15h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag5
from mf_lo_2001_15g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_15h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_15i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_15h as a left join hmda_multifam_1996 as b
on a.sub1_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_15j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag5
from mf_lo_2001_15i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_15j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_15k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_15j as a left join hmda_multifam_1996 as b
on a.rssd_id=b.topid_20011231 order by a.name;

create table mf_lo_2001_15l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag5
from mf_lo_2001_15k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_15l nodupkey;
by rssd_id;
run;
data mf_lo_2001_16 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag5 lo_multifam_sub1_lag5 lo_multifam_sub2_lag5 lo_multifam_sub3_lag5 lo_multifam_sub4_lag5 lo_multifam_sub5_lag5); 
set mf_lo_2001_15l;
if lo_multifam_parent_lag5=. then lo_multifam_parent_lag5=0;
if lo_multifam_sub1_lag5=. then lo_multifam_sub1_lag5=0;
if lo_multifam_sub2_lag5=. then lo_multifam_sub2_lag5=0;
if lo_multifam_sub3_lag5=. then lo_multifam_sub3_lag5=0;
if lo_multifam_sub4_lag5=. then lo_multifam_sub4_lag5=0;
if lo_multifam_sub5_lag5=. then lo_multifam_sub5_lag5=0;
lo_multifam_lag5 = lo_multifam_parent_lag5 + lo_multifam_sub1_lag5 + lo_multifam_sub2_lag5 + lo_multifam_sub3_lag5 + lo_multifam_sub4_lag5 + lo_multifam_sub5_lag5;
run;


/*LAG6*/
/*5th-level subsidiaries*/
data hmda_multifam_1995;
set hmda.hmda_multifam_1995;
if topid_20011231=. then delete;
run;
proc sql;
create table mf_lo_2001_17a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_1995 as b
on a.sub5_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_17b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag6
from mf_lo_2001_17a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_17b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_17c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_17b as a left join hmda_multifam_1995 as b
on a.sub4_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_17d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag6
from mf_lo_2001_17c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_17d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_17e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_17d as a left join hmda_multifam_1995 as b
on a.sub3_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_17f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag6
from mf_lo_2001_17e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_17f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_17g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_17f as a left join hmda_multifam_1995 as b
on a.sub2_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_17h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag6
from mf_lo_2001_17g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_17h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_17i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_17h as a left join hmda_multifam_1995 as b
on a.sub1_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_17j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag6
from mf_lo_2001_17i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_17j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_17k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_17j as a left join hmda_multifam_1995 as b
on a.rssd_id=b.topid_20011231 order by a.name;

create table mf_lo_2001_17l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag6
from mf_lo_2001_17k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_17l nodupkey;
by rssd_id;
run;
data mf_lo_2001_18 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag6 lo_multifam_sub1_lag6 lo_multifam_sub2_lag6 lo_multifam_sub3_lag6 lo_multifam_sub4_lag6 lo_multifam_sub5_lag6); 
set mf_lo_2001_17l;
if lo_multifam_parent_lag6=. then lo_multifam_parent_lag6=0;
if lo_multifam_sub1_lag6=. then lo_multifam_sub1_lag6=0;
if lo_multifam_sub2_lag6=. then lo_multifam_sub2_lag6=0;
if lo_multifam_sub3_lag6=. then lo_multifam_sub3_lag6=0;
if lo_multifam_sub4_lag6=. then lo_multifam_sub4_lag6=0;
if lo_multifam_sub5_lag6=. then lo_multifam_sub5_lag6=0;
lo_multifam_lag6 = lo_multifam_parent_lag6 + lo_multifam_sub1_lag6 + lo_multifam_sub2_lag6 + lo_multifam_sub3_lag6 + lo_multifam_sub4_lag6 + lo_multifam_sub5_lag6;
run;


/*LAG7*/
/*5th-level subsidiaries*/
data hmda_multifam_1994;
set hmda.hmda_multifam_1994;
if topid_20011231=. then delete;
run;
proc sql;
create table mf_lo_2001_19a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_1994 as b
on a.sub5_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_19b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag7
from mf_lo_2001_19a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_19b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_19c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_19b as a left join hmda_multifam_1994 as b
on a.sub4_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_19d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag7
from mf_lo_2001_19c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_19d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_19e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_19d as a left join hmda_multifam_1994 as b
on a.sub3_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_19f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag7
from mf_lo_2001_19e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_19f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_19g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_19f as a left join hmda_multifam_1994 as b
on a.sub2_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_19h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag7
from mf_lo_2001_19g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_19h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_19i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_19h as a left join hmda_multifam_1994 as b
on a.sub1_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_19j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag7
from mf_lo_2001_19i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_19j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_19k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_19j as a left join hmda_multifam_1994 as b
on a.rssd_id=b.topid_20011231 order by a.name;

create table mf_lo_2001_19l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag7
from mf_lo_2001_19k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_19l nodupkey;
by rssd_id;
run;
data mf_lo_2001_20 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag7 lo_multifam_sub1_lag7 lo_multifam_sub2_lag7 lo_multifam_sub3_lag7 lo_multifam_sub4_lag7 lo_multifam_sub5_lag7); 
set mf_lo_2001_19l;
if lo_multifam_parent_lag7=. then lo_multifam_parent_lag7=0;
if lo_multifam_sub1_lag7=. then lo_multifam_sub1_lag7=0;
if lo_multifam_sub2_lag7=. then lo_multifam_sub2_lag7=0;
if lo_multifam_sub3_lag7=. then lo_multifam_sub3_lag7=0;
if lo_multifam_sub4_lag7=. then lo_multifam_sub4_lag7=0;
if lo_multifam_sub5_lag7=. then lo_multifam_sub5_lag7=0;
lo_multifam_lag7 = lo_multifam_parent_lag7 + lo_multifam_sub1_lag7 + lo_multifam_sub2_lag7 + lo_multifam_sub3_lag7 + lo_multifam_sub4_lag7 + lo_multifam_sub5_lag7;
run;

/*LAG8*/
/*5th-level subsidiaries*/
data hmda_multifam_1993;
set hmda.hmda_multifam_1993;
if topid_20011231=. then delete;
run;
proc sql;
create table mf_lo_2001_21a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_1993 as b
on a.sub5_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_21b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag8
from mf_lo_2001_21a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_21b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_21c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_21b as a left join hmda_multifam_1993 as b
on a.sub4_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_21d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag8
from mf_lo_2001_21c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_21d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_21e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_21d as a left join hmda_multifam_1993 as b
on a.sub3_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_21f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag8
from mf_lo_2001_21e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_21f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_21g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_21f as a left join hmda_multifam_1993 as b
on a.sub2_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_21h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag8
from mf_lo_2001_21g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_21h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_21i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_21h as a left join hmda_multifam_1993 as b
on a.sub1_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_21j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag8
from mf_lo_2001_21i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_21j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_21k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_21j as a left join hmda_multifam_1993 as b
on a.rssd_id=b.topid_20011231 order by a.name;

create table mf_lo_2001_21l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag8
from mf_lo_2001_21k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_21l nodupkey;
by rssd_id;
run;
data mf_lo_2001_22 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag8 lo_multifam_sub1_lag8 lo_multifam_sub2_lag8 lo_multifam_sub3_lag8 lo_multifam_sub4_lag8 lo_multifam_sub5_lag8); 
set mf_lo_2001_21l;
if lo_multifam_parent_lag8=. then lo_multifam_parent_lag8=0;
if lo_multifam_sub1_lag8=. then lo_multifam_sub1_lag8=0;
if lo_multifam_sub2_lag8=. then lo_multifam_sub2_lag8=0;
if lo_multifam_sub3_lag8=. then lo_multifam_sub3_lag8=0;
if lo_multifam_sub4_lag8=. then lo_multifam_sub4_lag8=0;
if lo_multifam_sub5_lag8=. then lo_multifam_sub5_lag8=0;
lo_multifam_lag8 = lo_multifam_parent_lag8 + lo_multifam_sub1_lag8 + lo_multifam_sub2_lag8 + lo_multifam_sub3_lag8 + lo_multifam_sub4_lag8 + lo_multifam_sub5_lag8;
run;


/*LAG9*/
/*5th-level subsidiaries*/
data hmda_multifam_1992;
set hmda.hmda_multifam_1992;
if topid_20011231=. then delete;
run;
proc sql;
create table mf_lo_2001_23a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_1992 as b
on a.sub5_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_23b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag9
from mf_lo_2001_23a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_23b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_23c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_23b as a left join hmda_multifam_1992 as b
on a.sub4_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_23d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag9
from mf_lo_2001_23c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_23d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_23e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_23d as a left join hmda_multifam_1992 as b
on a.sub3_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_23f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag9
from mf_lo_2001_23e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_23f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_23g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_23f as a left join hmda_multifam_1992 as b
on a.sub2_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_23h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag9
from mf_lo_2001_23g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_23h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_23i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_23h as a left join hmda_multifam_1992 as b
on a.sub1_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_23j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag9
from mf_lo_2001_23i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_23j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_23k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_23j as a left join hmda_multifam_1992 as b
on a.rssd_id=b.topid_20011231 order by a.name;

create table mf_lo_2001_23l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag9
from mf_lo_2001_23k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_23l nodupkey;
by rssd_id;
run;
data mf_lo_2001_24 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag9 lo_multifam_sub1_lag9 lo_multifam_sub2_lag9 lo_multifam_sub3_lag9 lo_multifam_sub4_lag9 lo_multifam_sub5_lag9); 
set mf_lo_2001_23l;
if lo_multifam_parent_lag9=. then lo_multifam_parent_lag9=0;
if lo_multifam_sub1_lag9=. then lo_multifam_sub1_lag9=0;
if lo_multifam_sub2_lag9=. then lo_multifam_sub2_lag9=0;
if lo_multifam_sub3_lag9=. then lo_multifam_sub3_lag9=0;
if lo_multifam_sub4_lag9=. then lo_multifam_sub4_lag9=0;
if lo_multifam_sub5_lag9=. then lo_multifam_sub5_lag9=0;
lo_multifam_lag9 = lo_multifam_parent_lag9 + lo_multifam_sub1_lag9 + lo_multifam_sub2_lag9 + lo_multifam_sub3_lag9 + lo_multifam_sub4_lag9 + lo_multifam_sub5_lag9;
run;


/*LAG10*/
/*5th-level subsidiaries*/
data hmda_multifam_1991;
set hmda.hmda_multifam_1991;
if topid_20011231=. then delete;
run;
proc sql;
create table mf_lo_2001_25a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2001_4e as a left join hmda_multifam_1991 as b
on a.sub5_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_25b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag10
from mf_lo_2001_25a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_25b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2001_25c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2001_25b as a left join hmda_multifam_1991 as b
on a.sub4_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_25d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag10
from mf_lo_2001_25c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2001_25d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2001_25e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2001_25d as a left join hmda_multifam_1991 as b
on a.sub3_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_25f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag10
from mf_lo_2001_25e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2001_25f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2001_25g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2001_25f as a left join hmda_multifam_1991 as b
on a.sub2_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_25h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag10
from mf_lo_2001_25g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2001_25h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2001_25i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2001_25h as a left join hmda_multifam_1991 as b
on a.sub1_rssd=b.topid_20011231 order by a.name;

create table mf_lo_2001_25j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag10
from mf_lo_2001_25i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_25j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2001_25k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2001_25j as a left join hmda_multifam_1991 as b
on a.rssd_id=b.topid_20011231 order by a.name;

create table mf_lo_2001_25l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag10
from mf_lo_2001_25k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2001_25l nodupkey;
by rssd_id;
run;
data mf_lo_2001_26 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag10 lo_multifam_sub1_lag10 lo_multifam_sub2_lag10 lo_multifam_sub3_lag10 lo_multifam_sub4_lag10 lo_multifam_sub5_lag10); 
set mf_lo_2001_25l;
if lo_multifam_parent_lag10=. then lo_multifam_parent_lag10=0;
if lo_multifam_sub1_lag10=. then lo_multifam_sub1_lag10=0;
if lo_multifam_sub2_lag10=. then lo_multifam_sub2_lag10=0;
if lo_multifam_sub3_lag10=. then lo_multifam_sub3_lag10=0;
if lo_multifam_sub4_lag10=. then lo_multifam_sub4_lag10=0;
if lo_multifam_sub5_lag10=. then lo_multifam_sub5_lag10=0;
lo_multifam_lag10 = lo_multifam_parent_lag10 + lo_multifam_sub1_lag10 + lo_multifam_sub2_lag10 + lo_multifam_sub3_lag10 + lo_multifam_sub4_lag10 + lo_multifam_sub5_lag10;
run;

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~;
*Aggregate all loan origination lag observations;
proc sql;
create table mf_lo_2001 as select a.*, b.lo_multifam_lag1
from mf_lo_2001_6 as a left join mf_lo_2001_8 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2001 as select a.*, b.lo_multifam_lag2
from mf_lo_2001 as a left join mf_lo_2001_10 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2001 as select a.*, b.lo_multifam_lag3
from mf_lo_2001 as a left join mf_lo_2001_12 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2001 as select a.*, b.lo_multifam_lag4
from mf_lo_2001 as a left join mf_lo_2001_14 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2001 as select a.*, b.lo_multifam_lag5
from mf_lo_2001 as a left join mf_lo_2001_16 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2001 as select a.*, b.lo_multifam_lag6
from mf_lo_2001 as a left join mf_lo_2001_18 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2001 as select a.*, b.lo_multifam_lag7
from mf_lo_2001 as a left join mf_lo_2001_20 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2001 as select a.*, b.lo_multifam_lag8
from mf_lo_2001 as a left join mf_lo_2001_22 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2001 as select a.*, b.lo_multifam_lag9
from mf_lo_2001 as a left join mf_lo_2001_24 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2001 as select a.*, b.lo_multifam_lag10
from mf_lo_2001 as a left join mf_lo_2001_26 as b
on a.rssd_id=b.rssd_id order by a.name;
quit;

data box.hmda_mf_lo_2001;
set mf_lo_2001;
run;
