/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below aggregates HMDA data on multi-family real estate loan originations at the
		consolidated level.

 =========================================================================================================*/

libname box 'C:\Users\pbwheele\Box Sync\Data Sets';

data ta;
set box.all_ta_1990_2017;
run;

/*2012 HMDA Loan Originations Plus 10 Lags*/
data mf_lo_2012_1 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 92 then delete;
run;
proc sql;
create table mf_lo_2012_2 as select a.*, b.ta
from mf_lo_2012_1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data mf_lo_2012_3;
set mf_lo_2012_2;
if ta=. then delete;
run;
/*Identify all subsidiaries in the corporate structure*/
proc sql;
create table mf_lo_2012_4a as select a.*, b.id_rssd_offspring as sub1_rssd 'sub1_rssd'
from mf_lo_2012_3 as a left join nic.relationships_20151231 as b
on a.rssd_id=b.id_rssd_parent and b.start<=19358<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_2012_4b as select a.*, b.id_rssd_offspring as sub2_rssd 'sub2_rssd'
from mf_lo_2012_4a as a left join nic.relationships_20151231 as b
on a.sub1_rssd=b.id_rssd_parent and b.start<=19358<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_2012_4c as select a.*, b.id_rssd_offspring as sub3_rssd 'sub3_rssd'
from mf_lo_2012_4b as a left join nic.relationships_20151231 as b
on a.sub2_rssd=b.id_rssd_parent and b.start<=19358<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_2012_4d as select a.*, b.id_rssd_offspring as sub4_rssd 'sub4_rssd'
from mf_lo_2012_4c as a left join nic.relationships_20151231 as b
on a.sub3_rssd=b.id_rssd_parent and b.start<=19358<=b.end and (b.pct_equity>50 or b.other_basis_ind=1);

create table mf_lo_2012_4e as select a.*, b.id_rssd_offspring as sub5_rssd 'sub5_rssd'
from mf_lo_2012_4d as a left join nic.relationships_20151231 as b
on a.sub4_rssd=b.id_rssd_parent and b.start<=19358<=b.end and (b.pct_equity>50 or b.other_basis_ind=1)
order by name, sub1_rssd, sub2_rssd, sub3_rssd, sub4_rssd;
quit;
/*Add 2012 single-family loan originations for 5th-level subsidiaries*/
data hmda_multifam_2012;
set hmda.hmda_multifam_2012;
if rssdid=. then delete;
run;
proc sql;
create table mf_lo_2012_5a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2012 as b
on a.sub5_rssd=b.rssdid order by a.name;

create table mf_lo_2012_5b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_t
from mf_lo_2012_5a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_5b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_5c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_5b as a left join hmda_multifam_2012 as b
on a.sub4_rssd=b.rssdid order by a.name;

create table mf_lo_2012_5d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_t
from mf_lo_2012_5c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_5d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_5e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_5d as a left join hmda_multifam_2012 as b
on a.sub3_rssd=b.rssdid order by a.name;

create table mf_lo_2012_5f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_t
from mf_lo_2012_5e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_5f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_5g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_5f as a left join hmda_multifam_2012 as b
on a.sub2_rssd=b.rssdid order by a.name;

create table mf_lo_2012_5h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_t
from mf_lo_2012_5g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_5h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_5i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_5h as a left join hmda_multifam_2012 as b
on a.sub1_rssd=b.rssdid order by a.name;

create table mf_lo_2012_5j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_t
from mf_lo_2012_5i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_5j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_5k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_5j as a left join hmda_multifam_2012 as b
on a.rssd_id=b.rssdid order by a.name;

create table mf_lo_2012_5l as select *, sum(lo_multifam_parent) as lo_multifam_parent_t
from mf_lo_2012_5k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_5l nodupkey;
by rssd_id;
run;
data mf_lo_2012_6 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_t lo_multifam_sub1_t lo_multifam_sub2_t lo_multifam_sub3_t lo_multifam_sub4_t lo_multifam_sub5_t); 
set mf_lo_2012_5l;
if lo_multifam_parent_t=. then lo_multifam_parent_t=0;
if lo_multifam_sub1_t=. then lo_multifam_sub1_t=0;
if lo_multifam_sub2_t=. then lo_multifam_sub2_t=0;
if lo_multifam_sub3_t=. then lo_multifam_sub3_t=0;
if lo_multifam_sub4_t=. then lo_multifam_sub4_t=0;
if lo_multifam_sub5_t=. then lo_multifam_sub5_t=0;
lo_multifam_t = lo_multifam_parent_t + lo_multifam_sub1_t + lo_multifam_sub2_t + lo_multifam_sub3_t + lo_multifam_sub4_t + lo_multifam_sub5_t;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2013*/
/*LAG1*/
/*5th-level subsidiaries*/
data hmda_multifam_2011;
set hmda.hmda_multifam_2011;
if topid_20121231=. then delete;
run;
proc sql;
create table mf_lo_2012_7a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2011 as b
on a.sub5_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_7b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag1
from mf_lo_2012_7a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_7b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_7c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_7b as a left join hmda_multifam_2011 as b
on a.sub4_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_7d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag1
from mf_lo_2012_7c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_7d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_7e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_7d as a left join hmda_multifam_2011 as b
on a.sub3_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_7f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag1
from mf_lo_2012_7e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_7f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_7g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_7f as a left join hmda_multifam_2011 as b
on a.sub2_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_7h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag1
from mf_lo_2012_7g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_7h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_7i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_7h as a left join hmda_multifam_2011 as b
on a.sub1_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_7j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag1
from mf_lo_2012_7i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_7j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_7k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_7j as a left join hmda_multifam_2011 as b
on a.rssd_id=b.topid_20121231 order by a.name;

create table mf_lo_2012_7l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag1
from mf_lo_2012_7k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_7l nodupkey;
by rssd_id;
run;
data mf_lo_2012_8 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag1 lo_multifam_sub1_lag1 lo_multifam_sub2_lag1 lo_multifam_sub3_lag1 lo_multifam_sub4_lag1 lo_multifam_sub5_lag1); 
set mf_lo_2012_7l;
if lo_multifam_parent_lag1=. then lo_multifam_parent_lag1=0;
if lo_multifam_sub1_lag1=. then lo_multifam_sub1_lag1=0;
if lo_multifam_sub2_lag1=. then lo_multifam_sub2_lag1=0;
if lo_multifam_sub3_lag1=. then lo_multifam_sub3_lag1=0;
if lo_multifam_sub4_lag1=. then lo_multifam_sub4_lag1=0;
if lo_multifam_sub5_lag1=. then lo_multifam_sub5_lag1=0;
lo_multifam_lag1 = lo_multifam_parent_lag1 + lo_multifam_sub1_lag1 + lo_multifam_sub2_lag1 + lo_multifam_sub3_lag1 + lo_multifam_sub4_lag1 + lo_multifam_sub5_lag1;
run;

/*LAG2*/
/*5th-level subsidiaries*/
data hmda_multifam_2010;
set hmda.hmda_multifam_2010;
if topid_20121231=. then delete;
run;
proc sql;
create table mf_lo_2012_9a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2010 as b
on a.sub5_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_9b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag2
from mf_lo_2012_9a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_9b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_9c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_9b as a left join hmda_multifam_2010 as b
on a.sub4_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_9d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag2
from mf_lo_2012_9c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_9d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_9e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_9d as a left join hmda_multifam_2010 as b
on a.sub3_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_9f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag2
from mf_lo_2012_9e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_9f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_9g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_9f as a left join hmda_multifam_2010 as b
on a.sub2_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_9h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag2
from mf_lo_2012_9g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_9h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_9i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_9h as a left join hmda_multifam_2010 as b
on a.sub1_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_9j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag2
from mf_lo_2012_9i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_9j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_9k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_9j as a left join hmda_multifam_2010 as b
on a.rssd_id=b.topid_20121231 order by a.name;

create table mf_lo_2012_9l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag2
from mf_lo_2012_9k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_9l nodupkey;
by rssd_id;
run;
data mf_lo_2012_10 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag2 lo_multifam_sub1_lag2 lo_multifam_sub2_lag2 lo_multifam_sub3_lag2 lo_multifam_sub4_lag2 lo_multifam_sub5_lag2); 
set mf_lo_2012_9l;
if lo_multifam_parent_lag2=. then lo_multifam_parent_lag2=0;
if lo_multifam_sub1_lag2=. then lo_multifam_sub1_lag2=0;
if lo_multifam_sub2_lag2=. then lo_multifam_sub2_lag2=0;
if lo_multifam_sub3_lag2=. then lo_multifam_sub3_lag2=0;
if lo_multifam_sub4_lag2=. then lo_multifam_sub4_lag2=0;
if lo_multifam_sub5_lag2=. then lo_multifam_sub5_lag2=0;
lo_multifam_lag2 = lo_multifam_parent_lag2 + lo_multifam_sub1_lag2 + lo_multifam_sub2_lag2 + lo_multifam_sub3_lag2 + lo_multifam_sub4_lag2 + lo_multifam_sub5_lag2;
run;


/*LAG3*/
/*5th-level subsidiaries*/
data hmda_multifam_2009;
set hmda.hmda_multifam_2009;
if topid_20121231=. then delete;
run;
proc sql;
create table mf_lo_2012_11a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2009 as b
on a.sub5_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_11b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag3
from mf_lo_2012_11a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_11b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_11c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_11b as a left join hmda_multifam_2009 as b
on a.sub4_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_11d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag3
from mf_lo_2012_11c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_11d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_11e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_11d as a left join hmda_multifam_2009 as b
on a.sub3_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_11f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag3
from mf_lo_2012_11e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_11f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_11g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_11f as a left join hmda_multifam_2009 as b
on a.sub2_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_11h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag3
from mf_lo_2012_11g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_11h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_11i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_11h as a left join hmda_multifam_2009 as b
on a.sub1_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_11j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag3
from mf_lo_2012_11i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_11j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_11k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_11j as a left join hmda_multifam_2009 as b
on a.rssd_id=b.topid_20121231 order by a.name;

create table mf_lo_2012_11l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag3
from mf_lo_2012_11k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_11l nodupkey;
by rssd_id;
run;
data mf_lo_2012_12 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag3 lo_multifam_sub1_lag3 lo_multifam_sub2_lag3 lo_multifam_sub3_lag3 lo_multifam_sub4_lag3 lo_multifam_sub5_lag3); 
set mf_lo_2012_11l;
if lo_multifam_parent_lag3=. then lo_multifam_parent_lag3=0;
if lo_multifam_sub1_lag3=. then lo_multifam_sub1_lag3=0;
if lo_multifam_sub2_lag3=. then lo_multifam_sub2_lag3=0;
if lo_multifam_sub3_lag3=. then lo_multifam_sub3_lag3=0;
if lo_multifam_sub4_lag3=. then lo_multifam_sub4_lag3=0;
if lo_multifam_sub5_lag3=. then lo_multifam_sub5_lag3=0;
lo_multifam_lag3 = lo_multifam_parent_lag3 + lo_multifam_sub1_lag3 + lo_multifam_sub2_lag3 + lo_multifam_sub3_lag3 + lo_multifam_sub4_lag3 + lo_multifam_sub5_lag3;
run;


/*LAG4*/
/*5th-level subsidiaries*/
data hmda_multifam_2008;
set hmda.hmda_multifam_2008;
if topid_20121231=. then delete;
run;
proc sql;
create table mf_lo_2012_13a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2008 as b
on a.sub5_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_13b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag4
from mf_lo_2012_13a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_13b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_13c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_13b as a left join hmda_multifam_2008 as b
on a.sub4_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_13d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag4
from mf_lo_2012_13c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_13d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_13e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_13d as a left join hmda_multifam_2008 as b
on a.sub3_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_13f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag4
from mf_lo_2012_13e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_13f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_13g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_13f as a left join hmda_multifam_2008 as b
on a.sub2_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_13h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag4
from mf_lo_2012_13g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_13h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_13i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_13h as a left join hmda_multifam_2008 as b
on a.sub1_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_13j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag4
from mf_lo_2012_13i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_13j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_13k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_13j as a left join hmda_multifam_2008 as b
on a.rssd_id=b.topid_20121231 order by a.name;

create table mf_lo_2012_13l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag4
from mf_lo_2012_13k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_13l nodupkey;
by rssd_id;
run;
data mf_lo_2012_14 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag4 lo_multifam_sub1_lag4 lo_multifam_sub2_lag4 lo_multifam_sub3_lag4 lo_multifam_sub4_lag4 lo_multifam_sub5_lag4); 
set mf_lo_2012_13l;
if lo_multifam_parent_lag4=. then lo_multifam_parent_lag4=0;
if lo_multifam_sub1_lag4=. then lo_multifam_sub1_lag4=0;
if lo_multifam_sub2_lag4=. then lo_multifam_sub2_lag4=0;
if lo_multifam_sub3_lag4=. then lo_multifam_sub3_lag4=0;
if lo_multifam_sub4_lag4=. then lo_multifam_sub4_lag4=0;
if lo_multifam_sub5_lag4=. then lo_multifam_sub5_lag4=0;
lo_multifam_lag4 = lo_multifam_parent_lag4 + lo_multifam_sub1_lag4 + lo_multifam_sub2_lag4 + lo_multifam_sub3_lag4 + lo_multifam_sub4_lag4 + lo_multifam_sub5_lag4;
run;


/*LAG5*/
/*5th-level subsidiaries*/
data hmda_multifam_2007;
set hmda.hmda_multifam_2007;
if topid_20121231=. then delete;
run;
proc sql;
create table mf_lo_2012_15a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2007 as b
on a.sub5_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_15b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag5
from mf_lo_2012_15a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_15b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_15c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_15b as a left join hmda_multifam_2007 as b
on a.sub4_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_15d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag5
from mf_lo_2012_15c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_15d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_15e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_15d as a left join hmda_multifam_2007 as b
on a.sub3_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_15f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag5
from mf_lo_2012_15e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_15f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_15g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_15f as a left join hmda_multifam_2007 as b
on a.sub2_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_15h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag5
from mf_lo_2012_15g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_15h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_15i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_15h as a left join hmda_multifam_2007 as b
on a.sub1_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_15j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag5
from mf_lo_2012_15i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_15j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_15k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_15j as a left join hmda_multifam_2007 as b
on a.rssd_id=b.topid_20121231 order by a.name;

create table mf_lo_2012_15l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag5
from mf_lo_2012_15k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_15l nodupkey;
by rssd_id;
run;
data mf_lo_2012_16 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag5 lo_multifam_sub1_lag5 lo_multifam_sub2_lag5 lo_multifam_sub3_lag5 lo_multifam_sub4_lag5 lo_multifam_sub5_lag5); 
set mf_lo_2012_15l;
if lo_multifam_parent_lag5=. then lo_multifam_parent_lag5=0;
if lo_multifam_sub1_lag5=. then lo_multifam_sub1_lag5=0;
if lo_multifam_sub2_lag5=. then lo_multifam_sub2_lag5=0;
if lo_multifam_sub3_lag5=. then lo_multifam_sub3_lag5=0;
if lo_multifam_sub4_lag5=. then lo_multifam_sub4_lag5=0;
if lo_multifam_sub5_lag5=. then lo_multifam_sub5_lag5=0;
lo_multifam_lag5 = lo_multifam_parent_lag5 + lo_multifam_sub1_lag5 + lo_multifam_sub2_lag5 + lo_multifam_sub3_lag5 + lo_multifam_sub4_lag5 + lo_multifam_sub5_lag5;
run;


/*LAG6*/
/*5th-level subsidiaries*/
data hmda_multifam_2006;
set hmda.hmda_multifam_2006;
if topid_20121231=. then delete;
run;
proc sql;
create table mf_lo_2012_17a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2006 as b
on a.sub5_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_17b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag6
from mf_lo_2012_17a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_17b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_17c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_17b as a left join hmda_multifam_2006 as b
on a.sub4_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_17d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag6
from mf_lo_2012_17c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_17d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_17e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_17d as a left join hmda_multifam_2006 as b
on a.sub3_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_17f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag6
from mf_lo_2012_17e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_17f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_17g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_17f as a left join hmda_multifam_2006 as b
on a.sub2_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_17h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag6
from mf_lo_2012_17g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_17h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_17i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_17h as a left join hmda_multifam_2006 as b
on a.sub1_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_17j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag6
from mf_lo_2012_17i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_17j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_17k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_17j as a left join hmda_multifam_2006 as b
on a.rssd_id=b.topid_20121231 order by a.name;

create table mf_lo_2012_17l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag6
from mf_lo_2012_17k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_17l nodupkey;
by rssd_id;
run;
data mf_lo_2012_18 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag6 lo_multifam_sub1_lag6 lo_multifam_sub2_lag6 lo_multifam_sub3_lag6 lo_multifam_sub4_lag6 lo_multifam_sub5_lag6); 
set mf_lo_2012_17l;
if lo_multifam_parent_lag6=. then lo_multifam_parent_lag6=0;
if lo_multifam_sub1_lag6=. then lo_multifam_sub1_lag6=0;
if lo_multifam_sub2_lag6=. then lo_multifam_sub2_lag6=0;
if lo_multifam_sub3_lag6=. then lo_multifam_sub3_lag6=0;
if lo_multifam_sub4_lag6=. then lo_multifam_sub4_lag6=0;
if lo_multifam_sub5_lag6=. then lo_multifam_sub5_lag6=0;
lo_multifam_lag6 = lo_multifam_parent_lag6 + lo_multifam_sub1_lag6 + lo_multifam_sub2_lag6 + lo_multifam_sub3_lag6 + lo_multifam_sub4_lag6 + lo_multifam_sub5_lag6;
run;


/*LAG7*/
/*5th-level subsidiaries*/
data hmda_multifam_2005;
set hmda.hmda_multifam_2005;
if topid_20121231=. then delete;
run;
proc sql;
create table mf_lo_2012_19a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2005 as b
on a.sub5_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_19b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag7
from mf_lo_2012_19a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_19b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_19c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_19b as a left join hmda_multifam_2005 as b
on a.sub4_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_19d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag7
from mf_lo_2012_19c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_19d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_19e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_19d as a left join hmda_multifam_2005 as b
on a.sub3_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_19f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag7
from mf_lo_2012_19e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_19f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_19g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_19f as a left join hmda_multifam_2005 as b
on a.sub2_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_19h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag7
from mf_lo_2012_19g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_19h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_19i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_19h as a left join hmda_multifam_2005 as b
on a.sub1_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_19j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag7
from mf_lo_2012_19i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_19j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_19k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_19j as a left join hmda_multifam_2005 as b
on a.rssd_id=b.topid_20121231 order by a.name;

create table mf_lo_2012_19l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag7
from mf_lo_2012_19k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_19l nodupkey;
by rssd_id;
run;
data mf_lo_2012_20 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag7 lo_multifam_sub1_lag7 lo_multifam_sub2_lag7 lo_multifam_sub3_lag7 lo_multifam_sub4_lag7 lo_multifam_sub5_lag7); 
set mf_lo_2012_19l;
if lo_multifam_parent_lag7=. then lo_multifam_parent_lag7=0;
if lo_multifam_sub1_lag7=. then lo_multifam_sub1_lag7=0;
if lo_multifam_sub2_lag7=. then lo_multifam_sub2_lag7=0;
if lo_multifam_sub3_lag7=. then lo_multifam_sub3_lag7=0;
if lo_multifam_sub4_lag7=. then lo_multifam_sub4_lag7=0;
if lo_multifam_sub5_lag7=. then lo_multifam_sub5_lag7=0;
lo_multifam_lag7 = lo_multifam_parent_lag7 + lo_multifam_sub1_lag7 + lo_multifam_sub2_lag7 + lo_multifam_sub3_lag7 + lo_multifam_sub4_lag7 + lo_multifam_sub5_lag7;
run;

/*LAG8*/
/*5th-level subsidiaries*/
data hmda_multifam_2004;
set hmda.hmda_multifam_2004;
if topid_20121231=. then delete;
run;
proc sql;
create table mf_lo_2012_21a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2004 as b
on a.sub5_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_21b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag8
from mf_lo_2012_21a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_21b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_21c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_21b as a left join hmda_multifam_2004 as b
on a.sub4_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_21d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag8
from mf_lo_2012_21c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_21d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_21e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_21d as a left join hmda_multifam_2004 as b
on a.sub3_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_21f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag8
from mf_lo_2012_21e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_21f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_21g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_21f as a left join hmda_multifam_2004 as b
on a.sub2_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_21h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag8
from mf_lo_2012_21g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_21h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_21i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_21h as a left join hmda_multifam_2004 as b
on a.sub1_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_21j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag8
from mf_lo_2012_21i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_21j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_21k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_21j as a left join hmda_multifam_2004 as b
on a.rssd_id=b.topid_20121231 order by a.name;

create table mf_lo_2012_21l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag8
from mf_lo_2012_21k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_21l nodupkey;
by rssd_id;
run;
data mf_lo_2012_22 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag8 lo_multifam_sub1_lag8 lo_multifam_sub2_lag8 lo_multifam_sub3_lag8 lo_multifam_sub4_lag8 lo_multifam_sub5_lag8); 
set mf_lo_2012_21l;
if lo_multifam_parent_lag8=. then lo_multifam_parent_lag8=0;
if lo_multifam_sub1_lag8=. then lo_multifam_sub1_lag8=0;
if lo_multifam_sub2_lag8=. then lo_multifam_sub2_lag8=0;
if lo_multifam_sub3_lag8=. then lo_multifam_sub3_lag8=0;
if lo_multifam_sub4_lag8=. then lo_multifam_sub4_lag8=0;
if lo_multifam_sub5_lag8=. then lo_multifam_sub5_lag8=0;
lo_multifam_lag8 = lo_multifam_parent_lag8 + lo_multifam_sub1_lag8 + lo_multifam_sub2_lag8 + lo_multifam_sub3_lag8 + lo_multifam_sub4_lag8 + lo_multifam_sub5_lag8;
run;


/*LAG9*/
/*5th-level subsidiaries*/
data hmda_multifam_2003;
set hmda.hmda_multifam_2003;
if topid_20121231=. then delete;
run;
proc sql;
create table mf_lo_2012_23a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2003 as b
on a.sub5_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_23b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag9
from mf_lo_2012_23a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_23b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_23c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_23b as a left join hmda_multifam_2003 as b
on a.sub4_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_23d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag9
from mf_lo_2012_23c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_23d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_23e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_23d as a left join hmda_multifam_2003 as b
on a.sub3_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_23f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag9
from mf_lo_2012_23e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_23f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_23g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_23f as a left join hmda_multifam_2003 as b
on a.sub2_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_23h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag9
from mf_lo_2012_23g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_23h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_23i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_23h as a left join hmda_multifam_2003 as b
on a.sub1_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_23j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag9
from mf_lo_2012_23i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_23j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_23k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_23j as a left join hmda_multifam_2003 as b
on a.rssd_id=b.topid_20121231 order by a.name;

create table mf_lo_2012_23l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag9
from mf_lo_2012_23k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_23l nodupkey;
by rssd_id;
run;
data mf_lo_2012_24 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag9 lo_multifam_sub1_lag9 lo_multifam_sub2_lag9 lo_multifam_sub3_lag9 lo_multifam_sub4_lag9 lo_multifam_sub5_lag9); 
set mf_lo_2012_23l;
if lo_multifam_parent_lag9=. then lo_multifam_parent_lag9=0;
if lo_multifam_sub1_lag9=. then lo_multifam_sub1_lag9=0;
if lo_multifam_sub2_lag9=. then lo_multifam_sub2_lag9=0;
if lo_multifam_sub3_lag9=. then lo_multifam_sub3_lag9=0;
if lo_multifam_sub4_lag9=. then lo_multifam_sub4_lag9=0;
if lo_multifam_sub5_lag9=. then lo_multifam_sub5_lag9=0;
lo_multifam_lag9 = lo_multifam_parent_lag9 + lo_multifam_sub1_lag9 + lo_multifam_sub2_lag9 + lo_multifam_sub3_lag9 + lo_multifam_sub4_lag9 + lo_multifam_sub5_lag9;
run;


/*LAG10*/
/*5th-level subsidiaries*/
data hmda_multifam_2002;
set hmda.hmda_multifam_2002;
if topid_20121231=. then delete;
run;
proc sql;
create table mf_lo_2012_25a as select a.*, b.lo_multifam as lo_multifam_sub5
from mf_lo_2012_4e as a left join hmda_multifam_2002 as b
on a.sub5_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_25b as select *, sum(lo_multifam_sub5) as lo_multifam_sub5_lag10
from mf_lo_2012_25a group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_25b nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd sub4_rssd;
run;
/*Add single-family loan originations for 4th-level subsidiaries*/
proc sql;
create table mf_lo_2012_25c as select a.*, b.lo_multifam as lo_multifam_sub4
from mf_lo_2012_25b as a left join hmda_multifam_2002 as b
on a.sub4_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_25d as select *, sum(lo_multifam_sub4) as lo_multifam_sub4_lag10
from mf_lo_2012_25c group by rssd_id order by name, sub1_rssd, sub2_rssd, sub3_rssd;
quit;
proc sort data=mf_lo_2012_25d nodupkey;
by rssd_id sub1_rssd sub2_rssd sub3_rssd;
run;
/*Add single-family loan originations for 3rd-level subsidiaries*/
proc sql;
create table mf_lo_2012_25e as select a.*, b.lo_multifam as lo_multifam_sub3
from mf_lo_2012_25d as a left join hmda_multifam_2002 as b
on a.sub3_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_25f as select *, sum(lo_multifam_sub3) as lo_multifam_sub3_lag10
from mf_lo_2012_25e group by rssd_id order by name, sub1_rssd, sub2_rssd;
quit;
proc sort data=mf_lo_2012_25f nodupkey;
by rssd_id sub1_rssd sub2_rssd;
run;
/*Add single-family loan originations for 2nd-level subsidiaries*/
proc sql;
create table mf_lo_2012_25g as select a.*, b.lo_multifam as lo_multifam_sub2
from mf_lo_2012_25f as a left join hmda_multifam_2002 as b
on a.sub2_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_25h as select *, sum(lo_multifam_sub2) as lo_multifam_sub2_lag10
from mf_lo_2012_25g group by rssd_id order by name, sub1_rssd;
quit;
proc sort data=mf_lo_2012_25h nodupkey;
by rssd_id sub1_rssd;
run;
/*Add single-family loan originations for 1st-level subsidiaries*/
proc sql;
create table mf_lo_2012_25i as select a.*, b.lo_multifam as lo_multifam_sub1
from mf_lo_2012_25h as a left join hmda_multifam_2002 as b
on a.sub1_rssd=b.topid_20121231 order by a.name;

create table mf_lo_2012_25j as select *, sum(lo_multifam_sub1) as lo_multifam_sub1_lag10
from mf_lo_2012_25i group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_25j nodupkey;
by rssd_id;
run;
/*Add single-family loan originations for parent (non-BHC)*/
proc sql;
create table mf_lo_2012_25k as select a.*, b.lo_multifam as lo_multifam_parent
from mf_lo_2012_25j as a left join hmda_multifam_2002 as b
on a.rssd_id=b.topid_20121231 order by a.name;

create table mf_lo_2012_25l as select *, sum(lo_multifam_parent) as lo_multifam_parent_lag10
from mf_lo_2012_25k group by rssd_id order by name;
quit;
proc sort data=mf_lo_2012_25l nodupkey;
by rssd_id;
run;
data mf_lo_2012_26 (drop = sub1_rssd sub2_rssd sub3_rssd sub4_rssd sub5_rssd
lo_multifam_parent lo_multifam_sub1 lo_multifam_sub2 lo_multifam_sub3 lo_multifam_sub4 lo_multifam_sub5 
lo_multifam_parent_lag10 lo_multifam_sub1_lag10 lo_multifam_sub2_lag10 lo_multifam_sub3_lag10 lo_multifam_sub4_lag10 lo_multifam_sub5_lag10); 
set mf_lo_2012_25l;
if lo_multifam_parent_lag10=. then lo_multifam_parent_lag10=0;
if lo_multifam_sub1_lag10=. then lo_multifam_sub1_lag10=0;
if lo_multifam_sub2_lag10=. then lo_multifam_sub2_lag10=0;
if lo_multifam_sub3_lag10=. then lo_multifam_sub3_lag10=0;
if lo_multifam_sub4_lag10=. then lo_multifam_sub4_lag10=0;
if lo_multifam_sub5_lag10=. then lo_multifam_sub5_lag10=0;
lo_multifam_lag10 = lo_multifam_parent_lag10 + lo_multifam_sub1_lag10 + lo_multifam_sub2_lag10 + lo_multifam_sub3_lag10 + lo_multifam_sub4_lag10 + lo_multifam_sub5_lag10;
run;

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~;
*Aggregate all loan origination lag observations;
proc sql;
create table mf_lo_2012 as select a.*, b.lo_multifam_lag1
from mf_lo_2012_6 as a left join mf_lo_2012_8 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2012 as select a.*, b.lo_multifam_lag2
from mf_lo_2012 as a left join mf_lo_2012_10 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2012 as select a.*, b.lo_multifam_lag3
from mf_lo_2012 as a left join mf_lo_2012_12 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2012 as select a.*, b.lo_multifam_lag4
from mf_lo_2012 as a left join mf_lo_2012_14 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2012 as select a.*, b.lo_multifam_lag5
from mf_lo_2012 as a left join mf_lo_2012_16 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2012 as select a.*, b.lo_multifam_lag6
from mf_lo_2012 as a left join mf_lo_2012_18 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2012 as select a.*, b.lo_multifam_lag7
from mf_lo_2012 as a left join mf_lo_2012_20 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2012 as select a.*, b.lo_multifam_lag8
from mf_lo_2012 as a left join mf_lo_2012_22 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2012 as select a.*, b.lo_multifam_lag9
from mf_lo_2012 as a left join mf_lo_2012_24 as b
on a.rssd_id=b.rssd_id order by a.name;

create table mf_lo_2012 as select a.*, b.lo_multifam_lag10
from mf_lo_2012 as a left join mf_lo_2012_26 as b
on a.rssd_id=b.rssd_id order by a.name;
quit;

data box.hmda_mf_lo_2012;
set mf_lo_2012;
run;
