/*========================================================================================================
                                                                          
    ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
    AUTHOR: P. Barrett Wheeler                  
    JOURNAL OF ACCOUNTING RESEARCH 

 	The code below estimates quarterly loan originations of commercial and industrial loans for
	the years 1991 to 2016 as discussed in Appendix B of the manuscript.

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';
libname nic 'C:\Users\pwheeler1\Box Sync\Data Sets\NIC Data';

data ta;
set box.all_ta_1990_2017;
run;

data cni1;
set box.all_cniloans_1990_2017;
if reg_id=. then delete;
run;
proc sql;
create table cni1a as select a.*, b.ta
from cni1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table cni1b as select *, median(ta) as med_ta
from cni1a group by rankdate order by rankdate;
quit;
data cni1c;
set cni1b;
if ta > med_ta then large=1;
else large=0;
run;

*Import estimated repayment rates;
PROC IMPORT OUT= WORK.repaymentrate_small
            DATAFILE= "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Average Maturity - C&I Loans - Small Domestic Banks - Through May 2017 - SAS.csv" 
            DBMS=CSV REPLACE; 
     GETNAMES=YES;
     DATAROW=2;
RUN;
PROC IMPORT OUT= WORK.repaymentrate_large
            DATAFILE= "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Average Maturity - C&I Loans - Large Domestic Banks - Through May 2017 - SAS.csv" 
            DBMS=CSV REPLACE; 
     GETNAMES=YES;
     DATAROW=2;
RUN;
proc sql;
create table repaymentrate_small as select a.*, b.rankdate
from repaymentrate_small as a left join box.rankdates as b
on a.year=b.year and a.qtr=b.qtr;
quit;
proc sql;
create table repaymentrate_large as select a.*, b.rankdate
from repaymentrate_large as a left join box.rankdates as b
on a.year=b.year and a.qtr=b.qtr;
quit;

*Create quarter end date to determine banks acquired during quarter;
Proc Sort data=cni1c;
By snlkey snlyear snlqtr;
Run;
Data cni2;
Set cni1c;
Format SNLYear 4.;
Run;
Data cni3 (Drop = QtrEnd_Old QtrDay SNLYearCharacter);
Set cni2;
SNLYearCharacter = PUT(SNLYear, $4.);
Format SNLQtr $2.;
snlperiod= SNLYearCharacter || SNLQtr;
If SNLQtr='Q4' then QtrDay='1231';
If SNLQtr='Q3' then QtrDay='0930';
If SNLQtr='Q2' then QtrDay='0630';
If SNLQtr='Q1' then QtrDay='0331';
QtrEnd_Old =SNLYearCharacter||QtrDay;
qtrend = Input(QtrEnd_Old,yymmdd8.);
Format QtrEnd date9.;
Run;

*Determine ID of any bank acquired during the quarter;
proc sql;
create table cni4 as select a.*, b.qtrend as lag_qtrend
from cni3 as a left join cni3 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;
quit;

data nic; set nic.transformations_20180331;
date_string = put(dt_trans,8.);
trans_dt = input(date_string, anydtdte8.);
format trans_dt yymmddn8.;
run;

proc sql;
create table cni5 as select a.*, b.id_rssd_predecessor
from cni4 as a left join nic as b
on a.reg_id=b.id_rssd_successor and a.lag_qtrend < b.trans_dt <= a.qtrend ;
quit;

proc sql;
create table cni6 as select a.*, b.cniloans as pq_cniloans
from cni5 as a left join cni5 as b
on a.snlkey=b.snlkey and a.lag_qtrend=b.qtrend;

create table cni7 as select a.*, b.cniloans as pred_pq_cniloans
from cni6 as a left join cni5 as b
on a.id_rssd_predecessor=b.reg_id and a.lag_qtrend=b.qtrend order by a.reg_id, a.rankdate;
quit;
proc sort data=cni7 nodupkey out=cni8;
by reg_id rankdate id_rssd_predecessor;
quit;
proc sql;
create table cni9 as select *, sum(pred_pq_cniloans) as sum_predloans
from cni8 group by reg_id, rankdate order by reg_id, rankdate;
quit;
data cni10;
set cni9;
if sum_predloans = . then sum_predloans = 0;
beg_cniloans = pq_cniloans + sum_predloans;
run;
proc sql;
create table cni11 as select a.*, b.annual_repayment_rate as repayment_large
from cni10 as a left join repaymentrate_large as b
on a.rankdate=b.rankdate;

create table cni12 as select a.*, b.annual_repayment_rate as repayment_small
from cni11 as a left join repaymentrate_small as b
on a.rankdate=b.rankdate;
quit;

data cni13;
set cni12;
if large=1 then repayment_rate=repayment_large;
if large=0 then repayment_rate=repayment_small;
est_repayments = beg_cniloans*(repayment_rate*.25);
format est_repayments 12.0;
run;

data cni14 (drop = pq_cniloans pred_pq_cniloans snlperiod id_rssd_predecessor sum_predloans);
set cni13;
est_lo=cniloans-beg_cniloans+est_repayments;
format est_lo 12.0;
run;

proc sql;
create table est_lo_cni as select a.*, 
b.topid_20161231, 
b.topid_20160930, 
b.topid_20160630,
b.topid_20160331,
b.topid_20151231,
b.topid_20150930,
b.topid_20150630,
b.topid_20150331,
b.topid_20141231, 
b.topid_20140930, 
b.topid_20140630,
b.topid_20140331,
b.topid_20131231,
b.topid_20130930,
b.topid_20130630,
b.topid_20130331,
b.topid_20121231,
b.topid_20120930,
b.topid_20120630,
b.topid_20120331,
b.topid_20111231,
b.topid_20110930,
b.topid_20110630,
b.topid_20110331,
b.topid_20101231,
b.topid_20100930,
b.topid_20100630,
b.topid_20100331,
b.topid_20091231,
b.topid_20090930,
b.topid_20090630,
b.topid_20090331,
b.topid_20081231,
b.topid_20080930,
b.topid_20080630,
b.topid_20080331,
b.topid_20071231,
b.topid_20070930,
b.topid_20070630,
b.topid_20070331,
b.topid_20061231,
b.topid_20060930,
b.topid_20060630,
b.topid_20060331,
b.topid_20051231,
b.topid_20050930,
b.topid_20050630,
b.topid_20050331,
b.topid_20041231,
b.topid_20040930,
b.topid_20040630,
b.topid_20040331,
b.topid_20031231,
b.topid_20030930,
b.topid_20030630,
b.topid_20030331,
b.topid_20021231,
b.topid_20020930,
b.topid_20020630,
b.topid_20020331,
b.topid_20011231,
b.topid_20010930,
b.topid_20010630,
b.topid_20010331,
b.topid_20001231,
b.topid_20000930,
b.topid_20000630,
b.topid_20000331,
b.topid_19991231,
b.topid_19990930,
b.topid_19990630,
b.topid_19990331,
b.topid_19981231,
b.topid_19980930,
b.topid_19980630,
b.topid_19980331,
b.topid_19971231,
b.topid_19970930,
b.topid_19970630,
b.topid_19970331,
b.topid_19961231,
b.topid_19960930,
b.topid_19960630,
b.topid_19960331,
b.topid_19951231,
b.topid_19950930,
b.topid_19950630,
b.topid_19950331,
b.topid_19941231,
b.topid_19940930,
b.topid_19940630,
b.topid_19940331,
b.topid_19931231,
b.topid_19930930,
b.topid_19930630,
b.topid_19930331,
b.topid_19921231,
b.topid_19920930,
b.topid_19920630,
b.topid_19920331,
b.topid_19911231,
b.topid_19910930,
b.topid_19910630,
b.topid_19910331,
b.topid_19901231,
b.topid_19900930,
b.topid_19900630,
b.topid_19900331
from cni14 as a left join box.top_regid_byperiod_2017 as b
on a.reg_id=b.id_rssd;
quit;

data lo.est_lo_cni_1990_2016;
set est_lo_cni;
run;


