/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below estimates quarterly loan originations of commercial real estate and farm loans for
		the years 1991 to 2016 as discussed in Appendix B of the manuscript.

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';
libname nic 'C:\Users\pwheeler1\Box Sync\Data Sets\NIC Data';

proc sql;
create table commandfarm1 as select a.*, b.farmloans, a.creloans+b.farmloans as commandfarmloans
from box.all_creloans_1990_2019 a left join box.all_farmloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
*Import estimated repayment rates of 1-4 and multifamily loans;
data repaymentrate; set lo.sfmf_payoffs; run;

*Create quarter end date to determine banks acquired during quarter;
Proc Sort data=commandfarm1;
By snlkey snlyear snlqtr;
Run;
Data commandfarm2;
Set commandfarm1;
Format SNLYear 4.;
if reg_id=. then delete;
Run;
Data commandfarm3 (Drop = QtrEnd_Old QtrDay SNLYearCharacter);
Set commandfarm2;
SNLYearCharacter = PUT(SNLYear, $4.);
Format SNLQtr $2.;
snlperiod= SNLYearCharacter || SNLQtr;
If SNLQtr='Q4' then QtrDay='1231';
If SNLQtr='Q3' then QtrDay='0930';
If SNLQtr='Q2' then QtrDay='0630';
If SNLQtr='Q1' then QtrDay='0331';
QtrEnd_Old =SNLYearCharacter||QtrDay;
qtrend = Input(QtrEnd_Old,yymmdd8.);
Format QtrEnd date9.;
Run;

*Determine ID of any bank acquired during the quarter;
proc sql;
create table commandfarm4 as select a.*, b.qtrend as lag_qtrend
from commandfarm3 as a left join commandfarm3 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;
quit;

data nic; set nic.transformations_20180331;
date_string = put(dt_trans,8.);
trans_dt = input(date_string, anydtdte8.);
format trans_dt yymmddn8.;
run;

proc sql;
create table commandfarm5 as select a.*, b.id_rssd_predecessor
from commandfarm4 as a left join nic as b
on a.reg_id=b.id_rssd_successor and a.lag_qtrend < b.trans_dt <= a.qtrend ;
quit;

proc sql;
create table commandfarm6 as select a.*, b.commandfarmloans as pq_commandfarmloans
from commandfarm5 as a left join commandfarm5 as b
on a.snlkey=b.snlkey and a.lag_qtrend=b.qtrend;

create table commandfarm7 as select a.*, b.commandfarmloans as pred_pq_commandfarmloans
from commandfarm6 as a left join commandfarm5 as b
on a.id_rssd_predecessor=b.reg_id and a.lag_qtrend=b.qtrend order by a.reg_id, a.rankdate;
quit;
proc sort data=commandfarm7 nodupkey out=commandfarm8;
by reg_id rankdate id_rssd_predecessor;
quit;
proc sql;
create table commandfarm9 as select *, sum(pred_pq_commandfarmloans) as sum_predloans
from commandfarm8 group by reg_id, rankdate order by reg_id, rankdate;
quit;
data commandfarm10;
set commandfarm9;
if sum_predloans = . then sum_predloans = 0;
beg_commandfarmloans = pq_commandfarmloans + sum_predloans;
run;
proc sql;
create table commandfarm11 as select a.*, (b.payoff_pct*beg_commandfarmloans)/4 as est_repayments format 12.0
from commandfarm10 as a left join repaymentrate as b
on a.snlyear=b.snlyear order by a.reg_id, a.rankdate;
quit;

data commandfarm12 (drop = pq_commandfarmloans pred_pq_commandfarmloans snlperiod id_rssd_predecessor sum_predloans);
set commandfarm11;
est_lo=commandfarmloans-beg_commandfarmloans+est_repayments;
format est_lo 12.0;
run;

proc sql;
create table commandfarm13 as select a.*, b.*
from commandfarm12 a left join box.top_regid_byperiod_2017 b
on a.reg_id=b.id_rssd;
quit;

proc sort data=commandfarm13 nodupkey;
by reg_id rankdate;
run;

data lo.est_lo_commandfarm_1990_2016;
set commandfarm13;
run;

