/*========================================================================================================
                                                                          
    ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
    AUTHOR: P. Barrett Wheeler                  
    JOURNAL OF ACCOUNTING RESEARCH 

 	The code below estimates quarterly loan originations of consumer loans for
	the years 1991 to 2016 as discussed in Appendix B of the manuscript.

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets';
libname nic 'C:\Users\pwheeler1\Box Sync\Data Sets\NIC Data';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';

data ta;
set box.all_ta_1990_2017;
run;

data cons1;
set box.all_consloans_1990_2017;
if reg_id=. then delete;
run;

*Interpolate consumer loans for ~1% of sample reporting only annually;
data cons1a;
set cons1;
lag_rankdate = lag(rankdate);
lag_snlkey = lag(snlkey);
if snlkey ne lag_snlkey then lag_rankdate=.;
run;
data cons_areport;
set cons1a;
if lag_rankdate = rankdate-1 then delete;
if lag_rankdate = . then delete;
run;
data cons_qreport;
set cons1a;
if lag_rankdate ne rankdate-1 then delete;
run;

proc sql;
create table cons_areport_1a as select a.*, b.snlqtr as snlqtr_new, b.rankdate as rankdate_new 
from cons_areport as a left join box.rankdates as b
on a.snlyear=b.snlyear order by a.reg_id, b.rankdate;
quit;

proc sql;
create table cons_areport_2 as select a.*, b.consloans as py_loans
from cons_areport_1a as a left join cons_areport_1a as b
on a.snlkey=b.snlkey and a.snlyear=b.snlyear+1 and b.snlqtr_new='Q4' order by a.reg_id, a.rankdate_new;
quit;

data cons_areport_3 (drop=rankdate lag_rankdate snlqtr lag_snlkey);
set cons_areport_2;
q_ch_loans = (consloans-py_loans)/4;
if snlqtr_new='Q1' then loans_new=py_loans+q_ch_loans;
if snlqtr_new='Q2' then loans_new=py_loans+(2*q_ch_loans);
if snlqtr_new='Q3' then loans_new=py_loans+(3*q_ch_loans);
if snlqtr_new='Q4' then loans_new=consloans;
rename rankdate_new = rankdate snlqtr_new = snlqtr;
run;

data cons_areport_4 (drop = consloans py_loans q_ch_loans);
set cons_areport_3;
rename loans_new = consloans;
run;
data cons1b (drop = lag_rankdate lag_snlkey);
set cons_qreport;
run;
data cons1c;
set cons1b cons_areport_4;
if consloans = . then delete;
run;

*Create quarter end date to determine banks acquired during quarter;
Proc Sort data=cons1c;
By snlkey snlyear snlqtr;
Run;
Data cons2;
Set cons1c;
Format SNLYear 4.;
Run;
Data cons3 (Drop = QtrEnd_Old QtrDay SNLYearCharacter);
Set cons2;
SNLYearCharacter = PUT(SNLYear, $4.);
Format SNLQtr $2.;
snlperiod= SNLYearCharacter || SNLQtr;
If SNLQtr='Q4' then QtrDay='1231';
If SNLQtr='Q3' then QtrDay='0930';
If SNLQtr='Q2' then QtrDay='0630';
If SNLQtr='Q1' then QtrDay='0331';
QtrEnd_Old =SNLYearCharacter||QtrDay;
qtrend = Input(QtrEnd_Old,yymmdd8.);
Format QtrEnd date9.;
Run;

*Determine ID of any bank acquired during the quarter;
proc sql;
create table cons4 as select a.*, b.qtrend as lag_qtrend
from cons3 as a left join cons3 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;
quit;

data nic; set nic.transformations_20180331;
date_string = put(dt_trans,8.);
trans_dt = input(date_string, anydtdte8.);
format trans_dt yymmddn8.;
run;

proc sql;
create table cons5 as select a.*, b.id_rssd_predecessor
from cons4 as a left join nic as b
on a.reg_id=b.id_rssd_successor and a.lag_qtrend < b.trans_dt <= a.qtrend ;
quit;

proc sql;
create table cons6 as select a.*, b.consloans as pq_consloans
from cons5 as a left join cons5 as b
on a.snlkey=b.snlkey and a.lag_qtrend=b.qtrend;

create table cons7 as select a.*, b.consloans as pred_pq_consloans
from cons6 as a left join cons5 as b
on a.id_rssd_predecessor=b.reg_id and a.lag_qtrend=b.qtrend order by a.reg_id, a.rankdate;
quit;
proc sort data=cons7 nodupkey out=cons8;
by reg_id rankdate id_rssd_predecessor;
quit;
proc sql;
create table cons9 as select *, sum(pred_pq_consloans) as sum_predloans
from cons8 group by reg_id, rankdate order by reg_id, rankdate;
quit;
data cons10;
set cons9;
if sum_predloans = . then sum_predloans = 0;
beg_consloans = pq_consloans + sum_predloans;
est_repayments = beg_consloans*.05; /*See Appendix B for discussion of 5% repayment assumption*/
format est_repayments 12.0;
run;

data cons11 (drop = pq_consloans pred_pq_consloans snlperiod id_rssd_predecessor sum_predloans);
set cons10;
est_lo=consloans-beg_consloans+est_repayments;
format est_lo 12.0;
run;
proc sort data=cons11 nodupkey out=cons12;
by reg_id rankdate;
quit;

proc sql;
create table est_lo_cons_1990_2016 as select a.*,
b.topid_20161231, 
b.topid_20160930, 
b.topid_20160630,
b.topid_20160331,
b.topid_20151231,
b.topid_20150930,
b.topid_20150630,
b.topid_20150331,
b.topid_20141231, 
b.topid_20140930, 
b.topid_20140630,
b.topid_20140331,
b.topid_20131231,
b.topid_20130930,
b.topid_20130630,
b.topid_20130331,
b.topid_20121231,
b.topid_20120930,
b.topid_20120630,
b.topid_20120331,
b.topid_20111231,
b.topid_20110930,
b.topid_20110630,
b.topid_20110331,
b.topid_20101231,
b.topid_20100930,
b.topid_20100630,
b.topid_20100331,
b.topid_20091231,
b.topid_20090930,
b.topid_20090630,
b.topid_20090331,
b.topid_20081231,
b.topid_20080930,
b.topid_20080630,
b.topid_20080331,
b.topid_20071231,
b.topid_20070930,
b.topid_20070630,
b.topid_20070331,
b.topid_20061231,
b.topid_20060930,
b.topid_20060630,
b.topid_20060331,
b.topid_20051231,
b.topid_20050930,
b.topid_20050630,
b.topid_20050331,
b.topid_20041231,
b.topid_20040930,
b.topid_20040630,
b.topid_20040331,
b.topid_20031231,
b.topid_20030930,
b.topid_20030630,
b.topid_20030331,
b.topid_20021231,
b.topid_20020930,
b.topid_20020630,
b.topid_20020331,
b.topid_20011231,
b.topid_20010930,
b.topid_20010630,
b.topid_20010331,
b.topid_20001231,
b.topid_20000930,
b.topid_20000630,
b.topid_20000331,
b.topid_19991231,
b.topid_19990930,
b.topid_19990630,
b.topid_19990331,
b.topid_19981231,
b.topid_19980930,
b.topid_19980630,
b.topid_19980331,
b.topid_19971231,
b.topid_19970930,
b.topid_19970630,
b.topid_19970331,
b.topid_19961231,
b.topid_19960930,
b.topid_19960630,
b.topid_19960331,
b.topid_19951231,
b.topid_19950930,
b.topid_19950630,
b.topid_19950331,
b.topid_19941231,
b.topid_19940930,
b.topid_19940630,
b.topid_19940331,
b.topid_19931231,
b.topid_19930930,
b.topid_19930630,
b.topid_19930331,
b.topid_19921231,
b.topid_19920930,
b.topid_19920630,
b.topid_19920331,
b.topid_19911231,
b.topid_19910930,
b.topid_19910630,
b.topid_19910331,
b.topid_19901231,
b.topid_19900930,
b.topid_19900630,
b.topid_19900331
from cons12 as a left join box.top_regid_byperiod_2017 as b
on a.reg_id=b.id_rssd;
quit;

data lo.est_lo_cons_1990_2016;
set est_lo_cons_1990_2016;
run;


