/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below estimates the non-linear model Eq. (5) for consumer loans with
		an initial parameter of 0.0025 provided for each beta coefficient. Eq. (5) is estimated with between
		one and twenty-four lags of estimated loan originations. The residuals from these models are then
		collected for use in estimation of Eq. (6).

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';
libname ecl 'C:\Users\pwheeler1\Box Sync\Data Sets\ECL Estimates';
signoff;
/*Connect to WRDS server*/
%let wrds=wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS compress=yes;
signon username=_prompt_;

/*Create temporary folder 4 as 'bw1' and create a remote directory in my explorer*/
libname bw1 remote '/scratch/tulane/' server=wrds;
rsubmit; libname bw1 '/scratch/tulane/'; endrsubmit;
libname bw2 remote '/home/tulane/pbwheele/' server=wrds;
rsubmit; libname bw2 '/home/tulane/pbwheele/'; endrsubmit;


*Create estimation data set;
proc sql;
create table lo8 as select snlkey, name, rssd_id, rankdate,
est_lo_t as lo_cons_t,
est_lo_lag1 as lo_cons_lag1,
est_lo_lag2 as lo_cons_lag2,
est_lo_lag3 as lo_cons_lag3,
est_lo_lag4 as lo_cons_lag4,
est_lo_lag5 as lo_cons_lag5,
est_lo_lag6 as lo_cons_lag6,
est_lo_lag7 as lo_cons_lag7,
est_lo_lag8 as lo_cons_lag8,
est_lo_lag9 as lo_cons_lag9,
est_lo_lag10 as lo_cons_lag10,
est_lo_lag11 as lo_cons_lag11,
est_lo_lag12 as lo_cons_lag12,
est_lo_lag13 as lo_cons_lag13,
est_lo_lag14 as lo_cons_lag14,
est_lo_lag15 as lo_cons_lag15,
est_lo_lag16 as lo_cons_lag16,
est_lo_lag17 as lo_cons_lag17,
est_lo_lag18 as lo_cons_lag18,
est_lo_lag19 as lo_cons_lag19,
est_lo_lag20 as lo_cons_lag20,
est_lo_lag21 as lo_cons_lag21,
est_lo_lag22 as lo_cons_lag22,
est_lo_lag23 as lo_cons_lag23,
est_lo_lag24 as lo_cons_lag24,
est_lo_lag25 as lo_cons_lag25,
est_lo_lag26 as lo_cons_lag26,
est_lo_lag27 as lo_cons_lag27,
est_lo_lag28 as lo_cons_lag28,
est_lo_lag29 as lo_cons_lag29,
est_lo_lag30 as lo_cons_lag30,
est_lo_lag31 as lo_cons_lag31,
est_lo_lag32 as lo_cons_lag32,
est_lo_lag33 as lo_cons_lag33,
est_lo_lag34 as lo_cons_lag34,
est_lo_lag35 as lo_cons_lag35,
est_lo_lag36 as lo_cons_lag36,
est_lo_lag37 as lo_cons_lag37,
est_lo_lag38 as lo_cons_lag38,
est_lo_lag39 as lo_cons_lag39
from lo.lo_cons_1990_2016
order by rssd_id, rankdate;
quit;

proc sql;
create table ecl_cons1 as select a.snlkey, a.snlyear, a.snlqtr, a.name, a.reg_id, a.rankdate, a.date, a.co_consloans as co_cons, b.*
from box.all_co_bytype_1990_2016 a left join lo8 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.snlkey, a.rankdate;
quit;

*Create dataset to estimate rolling regressions for ECL estimation;
data ecl_cons2;
set ecl_cons1;
if lo_cons_lag1=. then delete;
if lo_cons_lag2=. then delete;
if lo_cons_lag3=. then delete;
if lo_cons_lag4=. then delete;
if lo_cons_lag5=. then delete;
if lo_cons_lag6=. then delete;
if lo_cons_lag7=. then delete;
if lo_cons_lag8=. then delete;
if lo_cons_lag9=. then delete;
if lo_cons_lag10=. then delete;
if lo_cons_lag11=. then delete;
if lo_cons_lag12=. then delete;
if lo_cons_lag13=. then delete;
if lo_cons_lag14=. then delete;
if lo_cons_lag15=. then delete;
if lo_cons_lag16=. then delete;
if lo_cons_lag17=. then delete;
if lo_cons_lag18=. then delete;
if lo_cons_lag19=. then delete;
if lo_cons_lag20=. then delete;
if lo_cons_lag21=. then delete;
if lo_cons_lag22=. then delete;
if lo_cons_lag23=. then delete;
if lo_cons_lag24=. then delete;
run;

*TRANSFER TO LO FOLDER;
data lo.ecl_cons2; set ecl_cons2; run;
*Then.........;
*TRANSFER TO WRDS SERVER VIA FTP SITE;
*THEN.........;

rsubmit;
data ecl_cons2; set bw2.ecl_cons2; run;
endrsubmit;



rsubmit;
/*~~~~~~~~~~~~~~~~~~~~~~~~*/
/*ECL MACRO*/
/*~~~~~~~~~~~~~~~~~~~~~~~~*/

*Rolling regressions macro;
%macro ecl_cons_0025(first_rankdate, last_rankdate, inset=, roll1=,roll2=, roll3=, roll4=, roll5=, roll6=, roll7=, roll8=);

data &roll1;
set &inset;
if rankdate not in (&first_rankdate:&last_rankdate) then delete;
run;

proc sql;
create table &roll2 as select a.*, count(a.snlkey) as obs
from &roll1 as a
group by snlkey
order by snlkey, rankdate;
quit;

data &roll3;
set &roll2;
if obs < 40 then delete;
run;

ods graphics off;
ods exclude all;
/*1 lag*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025;
model co_cons = b1*lo_cons_lag1;
bounds b1 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_1 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_1 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 1 as model, 0.0025 as param
from roll4_1 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*2 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2;
bounds b1 >= 0, b2 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_2 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_2 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 2 as model, 0.0025 as param
from roll4_2 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*3 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3;
bounds b1 >= 0, b2 >= 0, b3 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_3 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_3 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 3 as model, 0.0025 as param
from roll4_3 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*4 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_4 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_4 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 4 as model, 0.0025 as param
from roll4_4 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*5 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_5 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_5 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 5 as model, 0.0025 as param
from roll4_5 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*6 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_6 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_6 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 6 as model, 0.0025 as param
from roll4_6 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*7 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_7 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_7 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 7 as model, 0.0025 as param
from roll4_7 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*8 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_8 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_8 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 8 as model, 0.0025 as param
from roll4_8 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*9 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_9 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_9 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 9 as model, 0.0025 as param
from roll4_9 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*10 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_10 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_10 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 10 as model, 0.0025 as param
from roll4_10 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*11 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_11 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_11 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 11 as model, 0.0025 as param
from roll4_11 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*12 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 ;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_12 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_12 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 12 as model, 0.0025 as param
from roll4_12 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*13 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_13 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_13 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 13 as model, 0.0025 as param
from roll4_13 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*14 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_14 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_14 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 14 as model, 0.0025 as param
from roll4_14 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*15 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_15 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_15 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 15 as model, 0.0025 as param
from roll4_15 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*16 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_16 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_16 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 16 as model, 0.0025 as param
from roll4_16 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*17 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_17 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_17 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 17 as model, 0.0025 as param
from roll4_17 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*18 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_18 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_18 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 18 as model, 0.0025 as param
from roll4_18 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*19 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_19 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_19 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 19 as model, 0.0025 as param
from roll4_19 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*20 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_20 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_20 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 20 as model, 0.0025 as param
from roll4_20 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*21 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_21 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_21 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 21 as model, 0.0025 as param
from roll4_21 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*22 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025 b22 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21 + b22*lo_cons_lag22;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_22 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_22 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 22 as model, 0.0025 as param
from roll4_22 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*23 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025 b22 = 0.0025 b23 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21 + b22*lo_cons_lag22 + b23*lo_cons_lag23;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_23 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_23 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 23 as model, 0.0025 as param
from roll4_23 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*24 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025 b22 = 0.0025 b23 = 0.0025 b24 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21 + b22*lo_cons_lag22 + b23*lo_cons_lag23 + b24*lo_cons_lag24;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_24 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_24 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 24 as model, 0.0025 as param
from roll4_24 a left join residual b
on a.snlkey=b.snlkey;
quit;

ods exclude none;

*Retain model with highest adjusted r-sq;
data &roll4;
set roll4_1 roll4_2 roll4_3 roll4_4 roll4_5 roll4_6 roll4_7 roll4_8
roll4_9 roll4_10 roll4_11 roll4_12 roll4_13 roll4_14 roll4_15 roll4_16
roll4_17 roll4_18 roll4_19 roll4_20 roll4_21 roll4_22 roll4_23 roll4_24;
run;

proc sql;
create table &roll5 as select *, max(pseudo_rsq) as max_pseudo_rsq
from &roll4
group by snlkey order by snlkey, rankdate;
quit;
data &roll6 (drop=max_pseudo_rsq);
set &roll5;
if pseudo_rsq ne max_pseudo_rsq then delete;
run;

proc sort data=&roll6; by snlkey rankdate model ; run;
proc sort data=&roll6 nodupkey; by snlkey rankdate; run;

dm 'clear log';
%mend;
endrsubmit;

*Run estimation macro;
/*ROLLING REGRESSIONS FOR ECL ESTIMATION: RUN AFTER RUNNING ECL MACRO*/
rsubmit; *Macro 2016Q4;
%ecl_cons_0025(69, 108, inset=ecl_cons2, roll1=Q42016_1 ,roll2=Q42016_2, roll3=Q42016_3, roll4=Q42016_4, roll5=Q42016_5, roll6=Q42016_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2016Q3;
%ecl_cons_0025(68, 107, inset=ecl_cons2, roll1=Q32016_1 ,roll2=Q32016_2, roll3=Q32016_3, roll4=Q32016_4, roll5=Q32016_5, roll6=Q32016_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2016Q2;
%ecl_cons_0025(67, 106, inset=ecl_cons2, roll1=Q22016_1 ,roll2=Q22016_2, roll3=Q22016_3, roll4=Q22016_4, roll5=Q22016_5, roll6=Q22016_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2016Q1;
%ecl_cons_0025(66, 105, inset=ecl_cons2, roll1=Q12016_1 ,roll2=Q12016_2, roll3=Q12016_3, roll4=Q12016_4, roll5=Q12016_5, roll6=Q12016_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q4;
%ecl_cons_0025(65, 104, inset=ecl_cons2, roll1=Q42015_1 ,roll2=Q42015_2, roll3=Q42015_3, roll4=Q42015_4, roll5=Q42015_5, roll6=Q42015_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q3;
%ecl_cons_0025(64, 103, inset=ecl_cons2, roll1=Q32015_1 ,roll2=Q32015_2, roll3=Q32015_3, roll4=Q32015_4, roll5=Q32015_5, roll6=Q32015_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q2;
%ecl_cons_0025(63, 102, inset=ecl_cons2, roll1=Q22015_1 ,roll2=Q22015_2, roll3=Q22015_3, roll4=Q22015_4, roll5=Q22015_5, roll6=Q22015_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q1;
%ecl_cons_0025(62, 101, inset=ecl_cons2, roll1=Q12015_1 ,roll2=Q12015_2, roll3=Q12015_3, roll4=Q12015_4, roll5=Q12015_5, roll6=Q12015_cons);
endrsubmit; dm 'clear log';

rsubmit; *Macro 2014Q4;
%ecl_cons_0025(61, 100, inset=ecl_cons2, roll1=Q42014_1 ,roll2=Q42014_2, roll3=Q42014_3, roll4=Q42014_4, roll5=Q42014_5, roll6=Q42014_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q3;
%ecl_cons_0025(60, 99, inset=ecl_cons2, roll1=Q32014_1 ,roll2=Q32014_2, roll3=Q32014_3, roll4=Q32014_4, roll5=Q32014_5, roll6=Q32014_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q2;
%ecl_cons_0025(59, 98, inset=ecl_cons2, roll1=Q22014_1 ,roll2=Q22014_2, roll3=Q22014_3, roll4=Q22014_4, roll5=Q22014_5, roll6=Q22014_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q1;
%ecl_cons_0025(58, 97, inset=ecl_cons2, roll1=Q12014_1 ,roll2=Q12014_2, roll3=Q12014_3, roll4=Q12014_4, roll5=Q12014_5, roll6=Q12014_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q4;
%ecl_cons_0025(57, 96, inset=ecl_cons2, roll1=Q42013_1 ,roll2=Q42013_2, roll3=Q42013_3, roll4=Q42013_4, roll5=Q42013_5, roll6=Q42013_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q3;
%ecl_cons_0025(56, 95, inset=ecl_cons2, roll1=Q32013_1 ,roll2=Q32013_2, roll3=Q32013_3, roll4=Q32013_4, roll5=Q32013_5, roll6=Q32013_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q2;
%ecl_cons_0025(55, 94, inset=ecl_cons2, roll1=Q22013_1 ,roll2=Q22013_2, roll3=Q22013_3, roll4=Q22013_4, roll5=Q22013_5, roll6=Q22013_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q1;
%ecl_cons_0025(54, 93, inset=ecl_cons2, roll1=Q12013_1 ,roll2=Q12013_2, roll3=Q12013_3, roll4=Q12013_4, roll5=Q12013_5, roll6=Q12013_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q4;
%ecl_cons_0025(53, 92, inset=ecl_cons2, roll1=Q42012_1 ,roll2=Q42012_2, roll3=Q42012_3, roll4=Q42012_4, roll5=Q42012_5, roll6=Q42012_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q3;
%ecl_cons_0025(52, 91, inset=ecl_cons2, roll1=Q32012_1 ,roll2=Q32012_2, roll3=Q32012_3, roll4=Q32012_4, roll5=Q32012_5, roll6=Q32012_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q2;
%ecl_cons_0025(51, 90, inset=ecl_cons2, roll1=Q22012_1 ,roll2=Q22012_2, roll3=Q22012_3, roll4=Q22012_4, roll5=Q22012_5, roll6=Q22012_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q1;
%ecl_cons_0025(50, 89, inset=ecl_cons2, roll1=Q12012_1 ,roll2=Q12012_2, roll3=Q12012_3, roll4=Q12012_4, roll5=Q12012_5, roll6=Q12012_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q4;
%ecl_cons_0025(49, 88, inset=ecl_cons2, roll1=Q42011_1 ,roll2=Q42011_2, roll3=Q42011_3, roll4=Q42011_4, roll5=Q42011_5, roll6=Q42011_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q3;
%ecl_cons_0025(48, 87, inset=ecl_cons2, roll1=Q32011_1 ,roll2=Q32011_2, roll3=Q32011_3, roll4=Q32011_4, roll5=Q32011_5, roll6=Q32011_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q2;
%ecl_cons_0025(47, 86, inset=ecl_cons2, roll1=Q22011_1 ,roll2=Q22011_2, roll3=Q22011_3, roll4=Q22011_4, roll5=Q22011_5, roll6=Q22011_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q1;
%ecl_cons_0025(46, 85, inset=ecl_cons2, roll1=Q12011_1 ,roll2=Q12011_2, roll3=Q12011_3, roll4=Q12011_4, roll5=Q12011_5, roll6=Q12011_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q2;
%ecl_cons_0025(47, 86, inset=ecl_cons2, roll1=Q22011_1 ,roll2=Q22011_2, roll3=Q22011_3, roll4=Q22011_4, roll5=Q22011_5, roll6=Q22011_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q4;
%ecl_cons_0025(45, 84, inset=ecl_cons2, roll1=Q42010_1 ,roll2=Q42010_2, roll3=Q42010_3, roll4=Q42010_4, roll5=Q42010_5, roll6=Q42010_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q3;
%ecl_cons_0025(44, 83, inset=ecl_cons2, roll1=Q32010_1 ,roll2=Q32010_2, roll3=Q32010_3, roll4=Q32010_4, roll5=Q32010_5, roll6=Q32010_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q2;
%ecl_cons_0025(43, 82, inset=ecl_cons2, roll1=Q22010_1 ,roll2=Q22010_2, roll3=Q22010_3, roll4=Q22010_4, roll5=Q22010_5, roll6=Q22010_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q1;
%ecl_cons_0025(42, 81, inset=ecl_cons2, roll1=Q12010_1 ,roll2=Q12010_2, roll3=Q12010_3, roll4=Q12010_4, roll5=Q12010_5, roll6=Q12010_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q4;
%ecl_cons_0025(41, 80, inset=ecl_cons2, roll1=Q42009_1 ,roll2=Q42009_2, roll3=Q42009_3, roll4=Q42009_4, roll5=Q42009_5, roll6=Q42009_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q3;
%ecl_cons_0025(40, 79, inset=ecl_cons2, roll1=Q32009_1 ,roll2=Q32009_2, roll3=Q32009_3, roll4=Q32009_4, roll5=Q32009_5, roll6=Q32009_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q2;
%ecl_cons_0025(39, 78, inset=ecl_cons2, roll1=Q22009_1 ,roll2=Q22009_2, roll3=Q22009_3, roll4=Q22009_4, roll5=Q22009_5, roll6=Q22009_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q1;
%ecl_cons_0025(38, 77, inset=ecl_cons2, roll1=Q12009_1 ,roll2=Q12009_2, roll3=Q12009_3, roll4=Q12009_4, roll5=Q12009_5, roll6=Q12009_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q4;
%ecl_cons_0025(37, 76, inset=ecl_cons2, roll1=Q42008_1 ,roll2=Q42008_2, roll3=Q42008_3, roll4=Q42008_4, roll5=Q42008_5, roll6=Q42008_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q3;
%ecl_cons_0025(36, 75, inset=ecl_cons2, roll1=Q32008_1 ,roll2=Q32008_2, roll3=Q32008_3, roll4=Q32008_4, roll5=Q32008_5, roll6=Q32008_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q2;
%ecl_cons_0025(35, 74, inset=ecl_cons2, roll1=Q22008_1 ,roll2=Q22008_2, roll3=Q22008_3, roll4=Q22008_4, roll5=Q22008_5, roll6=Q22008_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q1;
%ecl_cons_0025(34, 73, inset=ecl_cons2, roll1=Q12008_1 ,roll2=Q12008_2, roll3=Q12008_3, roll4=Q12008_4, roll5=Q12008_5, roll6=Q12008_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q4;
%ecl_cons_0025(33, 72, inset=ecl_cons2, roll1=Q42007_1 ,roll2=Q42007_2, roll3=Q42007_3, roll4=Q42007_4, roll5=Q42007_5, roll6=Q42007_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q3;
%ecl_cons_0025(32, 71, inset=ecl_cons2, roll1=Q32007_1 ,roll2=Q32007_2, roll3=Q32007_3, roll4=Q32007_4, roll5=Q32007_5, roll6=Q32007_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q2;
%ecl_cons_0025(31, 70, inset=ecl_cons2, roll1=Q22007_1 ,roll2=Q22007_2, roll3=Q22007_3, roll4=Q22007_4, roll5=Q22007_5, roll6=Q22007_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q1;
%ecl_cons_0025(30, 69, inset=ecl_cons2, roll1=Q12007_1 ,roll2=Q12007_2, roll3=Q12007_3, roll4=Q12007_4, roll5=Q12007_5, roll6=Q12007_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q4;
%ecl_cons_0025(29, 68, inset=ecl_cons2, roll1=Q42006_1 ,roll2=Q42006_2, roll3=Q42006_3, roll4=Q42006_4, roll5=Q42006_5, roll6=Q42006_cons);
endrsubmit; dm 'clear log';

rsubmit;
*Aggregate ECL estimates into one file;
data ecl_cons3;
set 
Q42006_cons
Q12007_cons
Q22007_cons
Q32007_cons
Q42007_cons
Q12008_cons
Q22008_cons
Q32008_cons
Q42008_cons
Q12009_cons
Q22009_cons
Q32009_cons
Q42009_cons
Q12010_cons
Q22010_cons
Q32010_cons
Q42010_cons
Q12011_cons
Q22011_cons
Q32011_cons
Q42011_cons
Q12012_cons
Q22012_cons
Q32012_cons
Q42012_cons
Q12013_cons
Q22013_cons
Q32013_cons
Q42013_cons
Q12014_cons
Q22014_cons
Q32014_cons
Q42014_cons
Q12015_cons
Q22015_cons
Q32015_cons
Q42015_cons
Q12016_cons
Q22016_cons
Q32016_cons
Q42016_cons;
Run;
proc sort data=ecl_cons3; by snlkey rollreg_rankdate rankdate; run;
data bw2.ecl_cons_residuals0025;
set ecl_cons3;
run;
endrsubmit;

