/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below estimates the non-linear model Eq. (5) for other non-real estate loans (including C&I)
		with 20 lags of loan originations and an initial parameter value of 0.0025 provided for each beta
		coefficient.

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';
libname ecl 'C:\Users\pwheeler1\Box Sync\Data Sets\ECL Estimates';

/*Connect to WRDS server*/
%let wrds=wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS compress=yes;
signon username=_prompt_;

/*Create temporary folder 4 as 'bw1' and create a remote directory in my explorer*/
libname bw1 remote '/scratch/tulane/' server=wrds;
rsubmit; libname bw1 '/scratch/tulane/'; endrsubmit;
libname bw2 remote '/home/tulane/pbwheele/' server=wrds;
rsubmit; libname bw2 '/home/tulane/pbwheele/'; endrsubmit;


*Create estimation data set;
proc sql;
create table lo7 as select snlkey, name, rssd_id, rankdate,
est_lo_t as cni_lo_t,
est_lo_lag1 as cni_lo_lag1,
est_lo_lag2 as cni_lo_lag2,
est_lo_lag3 as cni_lo_lag3,
est_lo_lag4 as cni_lo_lag4,
est_lo_lag5 as cni_lo_lag5,
est_lo_lag6 as cni_lo_lag6,
est_lo_lag7 as cni_lo_lag7,
est_lo_lag8 as cni_lo_lag8,
est_lo_lag9 as cni_lo_lag9,
est_lo_lag10 as cni_lo_lag10,
est_lo_lag11 as cni_lo_lag11,
est_lo_lag12 as cni_lo_lag12,
est_lo_lag13 as cni_lo_lag13,
est_lo_lag14 as cni_lo_lag14,
est_lo_lag15 as cni_lo_lag15,
est_lo_lag16 as cni_lo_lag16,
est_lo_lag17 as cni_lo_lag17,
est_lo_lag18 as cni_lo_lag18,
est_lo_lag19 as cni_lo_lag19,
est_lo_lag20 as cni_lo_lag20,
est_lo_lag21 as cni_lo_lag21,
est_lo_lag22 as cni_lo_lag22,
est_lo_lag23 as cni_lo_lag23,
est_lo_lag24 as cni_lo_lag24,
est_lo_lag25 as cni_lo_lag25,
est_lo_lag26 as cni_lo_lag26,
est_lo_lag27 as cni_lo_lag27,
est_lo_lag28 as cni_lo_lag28,
est_lo_lag29 as cni_lo_lag29,
est_lo_lag30 as cni_lo_lag30,
est_lo_lag31 as cni_lo_lag31,
est_lo_lag32 as cni_lo_lag32,
est_lo_lag33 as cni_lo_lag33,
est_lo_lag34 as cni_lo_lag34,
est_lo_lag35 as cni_lo_lag35,
est_lo_lag36 as cni_lo_lag36,
est_lo_lag37 as cni_lo_lag37,
est_lo_lag38 as cni_lo_lag38,
est_lo_lag39 as cni_lo_lag39
from lo.lo_cni_1990_2016
order by rssd_id, rankdate;
quit;

proc sql;
create table lo9 as select a.*,
b.est_lo_t as ag_lo_t,
b.est_lo_lag1 as ag_lo_lag1,
b.est_lo_lag2 as ag_lo_lag2,
b.est_lo_lag3 as ag_lo_lag3,
b.est_lo_lag4 as ag_lo_lag4,
b.est_lo_lag5 as ag_lo_lag5,
b.est_lo_lag6 as ag_lo_lag6,
b.est_lo_lag7 as ag_lo_lag7,
b.est_lo_lag8 as ag_lo_lag8,
b.est_lo_lag9 as ag_lo_lag9,
b.est_lo_lag10 as ag_lo_lag10,
b.est_lo_lag11 as ag_lo_lag11,
b.est_lo_lag12 as ag_lo_lag12,
b.est_lo_lag13 as ag_lo_lag13,
b.est_lo_lag14 as ag_lo_lag14,
b.est_lo_lag15 as ag_lo_lag15,
b.est_lo_lag16 as ag_lo_lag16,
b.est_lo_lag17 as ag_lo_lag17,
b.est_lo_lag18 as ag_lo_lag18,
b.est_lo_lag19 as ag_lo_lag19,
b.est_lo_lag20 as ag_lo_lag20,
b.est_lo_lag21 as ag_lo_lag21,
b.est_lo_lag22 as ag_lo_lag22,
b.est_lo_lag23 as ag_lo_lag23,
b.est_lo_lag24 as ag_lo_lag24,
b.est_lo_lag25 as ag_lo_lag25,
b.est_lo_lag26 as ag_lo_lag26,
b.est_lo_lag27 as ag_lo_lag27,
b.est_lo_lag28 as ag_lo_lag28,
b.est_lo_lag29 as ag_lo_lag29,
b.est_lo_lag30 as ag_lo_lag30,
b.est_lo_lag31 as ag_lo_lag31,
b.est_lo_lag32 as ag_lo_lag32,
b.est_lo_lag33 as ag_lo_lag33,
b.est_lo_lag34 as ag_lo_lag34,
b.est_lo_lag35 as ag_lo_lag35,
b.est_lo_lag36 as ag_lo_lag36,
b.est_lo_lag37 as ag_lo_lag37,
b.est_lo_lag38 as ag_lo_lag38,
b.est_lo_lag39 as ag_lo_lag39
from lo7 as a left join lo.lo_ag_1990_2016 as b
on a.rssd_id=b.rssd_id and a.rankdate=b.rankdate order by a.rssd_id, a.rankdate;
quit;

data lo10; set lo9;
lo_othnonre_t = cni_lo_t+ag_lo_t;
lo_othnonre_lag1 = cni_lo_lag1+ag_lo_lag1;
lo_othnonre_lag1=cni_lo_lag1+ag_lo_lag1;
lo_othnonre_lag2=cni_lo_lag2+ag_lo_lag2;
lo_othnonre_lag3=cni_lo_lag3+ag_lo_lag3;
lo_othnonre_lag4=cni_lo_lag4+ag_lo_lag4;
lo_othnonre_lag5=cni_lo_lag5+ag_lo_lag5;
lo_othnonre_lag6=cni_lo_lag6+ag_lo_lag6;
lo_othnonre_lag7=cni_lo_lag7+ag_lo_lag7;
lo_othnonre_lag8=cni_lo_lag8+ag_lo_lag8;
lo_othnonre_lag9=cni_lo_lag9+ag_lo_lag9;
lo_othnonre_lag10=cni_lo_lag10+ag_lo_lag10;
lo_othnonre_lag11=cni_lo_lag11+ag_lo_lag11;
lo_othnonre_lag12=cni_lo_lag12+ag_lo_lag12;
lo_othnonre_lag13=cni_lo_lag13+ag_lo_lag13;
lo_othnonre_lag14=cni_lo_lag14+ag_lo_lag14;
lo_othnonre_lag15=cni_lo_lag15+ag_lo_lag15;
lo_othnonre_lag16=cni_lo_lag16+ag_lo_lag16;
lo_othnonre_lag17=cni_lo_lag17+ag_lo_lag17;
lo_othnonre_lag18=cni_lo_lag18+ag_lo_lag18;
lo_othnonre_lag19=cni_lo_lag19+ag_lo_lag19;
lo_othnonre_lag20=cni_lo_lag20+ag_lo_lag20;
lo_othnonre_lag21=cni_lo_lag21+ag_lo_lag21;
lo_othnonre_lag22=cni_lo_lag22+ag_lo_lag22;
lo_othnonre_lag23=cni_lo_lag23+ag_lo_lag23;
lo_othnonre_lag24=cni_lo_lag24+ag_lo_lag24;
lo_othnonre_lag25=cni_lo_lag25+ag_lo_lag25;
lo_othnonre_lag26=cni_lo_lag26+ag_lo_lag26;
lo_othnonre_lag27=cni_lo_lag27+ag_lo_lag27;
lo_othnonre_lag28=cni_lo_lag28+ag_lo_lag28;
lo_othnonre_lag29=cni_lo_lag29+ag_lo_lag29;
lo_othnonre_lag30=cni_lo_lag30+ag_lo_lag30;
lo_othnonre_lag31=cni_lo_lag31+ag_lo_lag31;
lo_othnonre_lag32=cni_lo_lag32+ag_lo_lag32;
lo_othnonre_lag33=cni_lo_lag33+ag_lo_lag33;
lo_othnonre_lag34=cni_lo_lag34+ag_lo_lag34;
lo_othnonre_lag35=cni_lo_lag35+ag_lo_lag35;
lo_othnonre_lag36=cni_lo_lag36+ag_lo_lag36;
lo_othnonre_lag37=cni_lo_lag37+ag_lo_lag37;
lo_othnonre_lag38=cni_lo_lag38+ag_lo_lag38;
lo_othnonre_lag39=cni_lo_lag39+ag_lo_lag39;
run;

data lo11 (keep = snlkey name rssd_id snlyear snlqtr rankdate
lo_othnonre_t lo_othnonre_lag1 lo_othnonre_lag2 lo_othnonre_lag3 lo_othnonre_lag4 lo_othnonre_lag5 lo_othnonre_lag6
lo_othnonre_lag7 lo_othnonre_lag8 lo_othnonre_lag9 lo_othnonre_lag10 lo_othnonre_lag11 lo_othnonre_lag12 lo_othnonre_lag13
lo_othnonre_lag14 lo_othnonre_lag15 lo_othnonre_lag16 lo_othnonre_lag17 lo_othnonre_lag18 lo_othnonre_lag19
lo_othnonre_lag20 lo_othnonre_lag21 lo_othnonre_lag22 lo_othnonre_lag23 lo_othnonre_lag24 lo_othnonre_lag25 lo_othnonre_lag26
lo_othnonre_lag27 lo_othnonre_lag28 lo_othnonre_lag29 lo_othnonre_lag30 lo_othnonre_lag31 lo_othnonre_lag32 lo_othnonre_lag33
lo_othnonre_lag34 lo_othnonre_lag35 lo_othnonre_lag36 lo_othnonre_lag37 lo_othnonre_lag38 lo_othnonre_lag39);
set lo10; run;

proc sql;
create table ecl_othnonre1 as select a.snlkey, a.snlyear, a.snlqtr, a.name, a.reg_id, a.rankdate, a.date, a.co_cni+a.co_ag as co_othnonre, b.*
from box.all_co_bytype_1990_2018 a left join lo11 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.snlkey, a.rankdate;
quit;

*Create dataset to estimate rolling regressions for ECL estimation;
data ecl_othnonre2;
set ecl_othnonre1;
if lo_othnonre_lag1=. then delete;
if lo_othnonre_lag2=. then delete;
if lo_othnonre_lag3=. then delete;
if lo_othnonre_lag4=. then delete;
if lo_othnonre_lag5=. then delete;
if lo_othnonre_lag6=. then delete;
if lo_othnonre_lag7=. then delete;
if lo_othnonre_lag8=. then delete;
if lo_othnonre_lag9=. then delete;
if lo_othnonre_lag10=. then delete;
if lo_othnonre_lag11=. then delete;
if lo_othnonre_lag12=. then delete;
if lo_othnonre_lag13=. then delete;
if lo_othnonre_lag14=. then delete;
if lo_othnonre_lag15=. then delete;
if lo_othnonre_lag16=. then delete;
if lo_othnonre_lag17=. then delete;
if lo_othnonre_lag18=. then delete;
if lo_othnonre_lag19=. then delete;
if lo_othnonre_lag20=. then delete;
run;

*TRANSFER TO LO FOLDER;
data lo.ecl_othnonre2_20lags; set ecl_othnonre2; run;
*Then.........;
*TRANSFER TO WRDS SERVER VIA FTP SITE;
*THEN.........;

rsubmit;
data ecl_othnonre2; set bw2.ecl_othnonre2_20lags; run;
endrsubmit;

rsubmit;
/*~~~~~~~~~~~~~~~~~~~~~~~~*/
/*ECL MACRO*/
/*~~~~~~~~~~~~~~~~~~~~~~~~*/

*Rolling regressions macro;
%macro ecl_othnonre_0025(first_rankdate, last_rankdate, inset=, roll1=,roll2=, roll3=, roll4=, roll5=, roll6=, roll7=, roll8=);

data &roll1;
set &inset;
if rankdate not in (&first_rankdate:&last_rankdate) then delete;
run;

proc sql;
create table &roll2 as select a.*, count(a.snlkey) as obs
from &roll1 as a
group by snlkey
order by snlkey, rankdate;
quit;

data &roll3;
set &roll2;
if obs < 40 then delete;
run;

ods graphics off;
ods exclude all;
/*1 lag*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1;
bounds b1 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_1 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_1 as select a.*, b.res
from roll4_1 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*2 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2;
bounds b1 >= 0, b2 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_2 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_2 as select a.*, b.res
from roll4_2 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*3 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3;
bounds b1 >= 0, b2 >= 0, b3 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_3 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_3 as select a.*, b.res
from roll4_3 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*4 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_4 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_4 as select a.*, b.res
from roll4_4 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*5 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_5 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_5 as select a.*, b.res
from roll4_5 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*6 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_6 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_6 as select a.*, b.res
from roll4_6 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*7 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_7 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_7 as select a.*, b.res
from roll4_7 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*8 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_8 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_8 as select a.*, b.res
from roll4_8 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*9 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_9 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_9 as select a.*, b.res
from roll4_9 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*10 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_10 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_10 as select a.*, b.res
from roll4_10 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*11 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10 + b11*lo_othnonre_lag11;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_11 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_11 as select a.*, b.res
from roll4_11 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*12 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10 + b11*lo_othnonre_lag11 + b12*lo_othnonre_lag12 ;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_12 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_12 as select a.*, b.res
from roll4_12 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*13 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10 + b11*lo_othnonre_lag11 + b12*lo_othnonre_lag12 + b13*lo_othnonre_lag13;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_13 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_13 as select a.*, b.res
from roll4_13 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*14 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10 + b11*lo_othnonre_lag11 + b12*lo_othnonre_lag12 + b13*lo_othnonre_lag13 + b14*lo_othnonre_lag14;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_14 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_14 as select a.*, b.res
from roll4_14 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*15 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10 + b11*lo_othnonre_lag11 + b12*lo_othnonre_lag12 + b13*lo_othnonre_lag13 + b14*lo_othnonre_lag14 + b15*lo_othnonre_lag15;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_15 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_15 as select a.*, b.res
from roll4_15 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*16 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10 + b11*lo_othnonre_lag11 + b12*lo_othnonre_lag12 + b13*lo_othnonre_lag13 + b14*lo_othnonre_lag14 + b15*lo_othnonre_lag15 + b16*lo_othnonre_lag16;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_16 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_16 as select a.*, b.res
from roll4_16 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*17 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10 + b11*lo_othnonre_lag11 + b12*lo_othnonre_lag12 + b13*lo_othnonre_lag13 + b14*lo_othnonre_lag14 + b15*lo_othnonre_lag15 + b16*lo_othnonre_lag16 + b17*lo_othnonre_lag17;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_17 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_17 as select a.*, b.res
from roll4_17 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*18 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10 + b11*lo_othnonre_lag11 + b12*lo_othnonre_lag12 + b13*lo_othnonre_lag13 + b14*lo_othnonre_lag14 + b15*lo_othnonre_lag15 + b16*lo_othnonre_lag16 + b17*lo_othnonre_lag17 + b18*lo_othnonre_lag18;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_18 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_18 as select a.*, b.res
from roll4_18 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*19 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10 + b11*lo_othnonre_lag11 + b12*lo_othnonre_lag12 + b13*lo_othnonre_lag13 + b14*lo_othnonre_lag14 + b15*lo_othnonre_lag15 + b16*lo_othnonre_lag16 + b17*lo_othnonre_lag17 + b18*lo_othnonre_lag18 + b19*lo_othnonre_lag19;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_19 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_19 as select a.*, b.res
from roll4_19 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*20 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025;
model co_othnonre = b1*lo_othnonre_lag1 + b2*lo_othnonre_lag2 + b3*lo_othnonre_lag3 + b4*lo_othnonre_lag4 + b5*lo_othnonre_lag5 + b6*lo_othnonre_lag6 + b7*lo_othnonre_lag7 + b8*lo_othnonre_lag8 + b9*lo_othnonre_lag9 + b10*lo_othnonre_lag10 + b11*lo_othnonre_lag11 + b12*lo_othnonre_lag12 + b13*lo_othnonre_lag13 + b14*lo_othnonre_lag14 + b15*lo_othnonre_lag15 + b16*lo_othnonre_lag16 + b17*lo_othnonre_lag17 + b18*lo_othnonre_lag18 + b19*lo_othnonre_lag19 + b20*lo_othnonre_lag20;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_20 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_20 as select a.*, b.res
from roll4_20 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

*Merge coefficients with bank data;
data &roll4;
set roll4_1 roll4_2 roll4_3 roll4_4 roll4_5 roll4_6 roll4_7 roll4_8
roll4_9 roll4_10 roll4_11 roll4_12 roll4_13 roll4_14 roll4_15 roll4_16
roll4_17 roll4_18 roll4_19 roll4_20;
if b2=. and b3=. and b4=. and b5=. and b6=. and b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=1;
else if b3=. and b4=. and b5=. and b6=. and b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=2;
else if b4=. and b5=. and b6=. and b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=3;
else if b5=. and b6=. and b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=4;
else if b6=. and b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=5;
else if b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=6;
else if b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=7;
else if b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=8;
else if b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=9;
else if b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=10;
else if b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=11;
else if b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=12;
else if b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=13;
else if b15=. and b16=. and b17=. and b18=. and b19=. and b20=. then model=14;
else if b16=. and b17=. and b18=. and b19=. and b20=. then model=15;
else if b17=. and b18=. and b19=. and b20=. then model=16;
else if b18=. and b19=. and b20=. then model=17;
else if b19=. and b20=. then model=18;
else if b20=. then model=19;
else  model=20;
run;
proc sql;
create table &roll5 as select a.*,
CASE when b.b1 ne . then b.b1 else 0 END as b1 'Coefficient t-1',
CASE when b.b2 ne . then b.b2 else 0 END as b2 'Coefficient t-2',
CASE when b.b3 ne . then b.b3 else 0 END as b3 'Coefficient t-3',
CASE when b.b4 ne . then b.b4 else 0 END as b4 'Coefficient t-4',
CASE when b.b5 ne . then b.b5 else 0 END as b5 'Coefficient t-5',
CASE when b.b6 ne . then b.b6 else 0 END as b6 'Coefficient t-6',
CASE when b.b7 ne . then b.b7 else 0 END as b7 'Coefficient t-7',
CASE when b.b8 ne . then b.b8 else 0 END as b8 'Coefficient t-8',
CASE when b.b9 ne . then b.b9 else 0 END as b9 'Coefficient t-9',
CASE when b.b10 ne . then b.b10 else 0 END as b10 'Coefficient t-10',
CASE when b.b11 ne . then b.b11 else 0 END as b11 'Coefficient t-11',
CASE when b.b12 ne . then b.b12 else 0 END as b12 'Coefficient t-12',
CASE when b.b13 ne . then b.b13 else 0 END as b13 'Coefficient t-13',
CASE when b.b14 ne . then b.b14 else 0 END as b14 'Coefficient t-14',
CASE when b.b15 ne . then b.b15 else 0 END as b15 'Coefficient t-15',
CASE when b.b16 ne . then b.b16 else 0 END as b16 'Coefficient t-16',
CASE when b.b17 ne . then b.b17 else 0 END as b17 'Coefficient t-17',
CASE when b.b18 ne . then b.b18 else 0 END as b18 'Coefficient t-18',
CASE when b.b19 ne . then b.b19 else 0 END as b19 'Coefficient t-19',
CASE when b.b20 ne . then b.b20 else 0 END as b20 'Coefficient t-20',
b.model, b.pseudo_rsq, b._iter_, b._status_, b.res

from &roll3 as a left join &roll4 as b
on a.snlkey=b.snlkey and a.rankdate=&last_rankdate
order by a.snlkey, a.rankdate, b.model;
quit;

*Calculate expected charge-offs by year and then aggregate;
data &roll6;
set &roll5;
ecl_othnonre_t = lo_othnonre_t * (b1 + b2 + b3 + b4 + b5 + b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag1 = lo_othnonre_lag1 * (b2 + b3 + b4 + b5 + b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag2 = lo_othnonre_lag2 * (b3 + b4 + b5 + b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag3 = lo_othnonre_lag3 * (b4 + b5 + b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag4 = lo_othnonre_lag4 * (b5 + b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag5 = lo_othnonre_lag5 * (b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag6 = lo_othnonre_lag6 * (b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag7 = lo_othnonre_lag7 * (b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag8 = lo_othnonre_lag8 * (b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag9 = lo_othnonre_lag9 * (b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag10 = lo_othnonre_lag10 * (b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag11 = lo_othnonre_lag11 * (b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag12 = lo_othnonre_lag12 * (b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag13 = lo_othnonre_lag13 * (b14 + b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag14 = lo_othnonre_lag14 * (b15 + b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag15 = lo_othnonre_lag15 * (b16 + b17 + b18 + b19 + b20);
ecl_othnonre_lag16 = lo_othnonre_lag16 * (b17 + b18 + b19 + b20);
ecl_othnonre_lag17 = lo_othnonre_lag17 * (b18 + b19 + b20);
ecl_othnonre_lag18 = lo_othnonre_lag18 * (b19 + b20);
ecl_othnonre_lag19 = lo_othnonre_lag19 * (b20);

ecl_othnonre = ecl_othnonre_t + ecl_othnonre_lag1 + ecl_othnonre_lag2 + ecl_othnonre_lag3 + ecl_othnonre_lag4 + ecl_othnonre_lag5 + ecl_othnonre_lag6 + ecl_othnonre_lag7 + ecl_othnonre_lag8 + ecl_othnonre_lag9 + ecl_othnonre_lag10 + ecl_othnonre_lag11 + ecl_othnonre_lag12 + ecl_othnonre_lag13 + ecl_othnonre_lag14 + ecl_othnonre_lag15 + ecl_othnonre_lag16 + ecl_othnonre_lag17 + ecl_othnonre_lag18 + ecl_othnonre_lag19;
if model=. then delete;
run;
proc sort data=&roll6;
by snlkey rankdate model;
run;
*Retain model with highest adjusted r-sq;
proc sql;
create table &roll7 as select *, max(pseudo_rsq) as max_pseudo_rsq, mean(ecl_othnonre) as mean_ecl_othnonre, std(ecl_othnonre) as std_ecl_othnonre, (mean(ecl_othnonre)/std(ecl_othnonre)) as mean_std_ratio_othnonre
from &roll6
group by snlkey, rankdate
order by snlkey, rankdate;
quit;
data &roll8 (drop=max_pseudo_rsq);
set &roll7;
if pseudo_rsq ne max_pseudo_rsq then delete;
run;

proc sort data=&roll8 nodupkey; by snlkey rankdate; run;

dm 'clear log';
%mend;
endrsubmit;
rsubmit; data bw2.Q42016_othnonre; set Q42016_othnonre; run; endrsubmit;
*Run estimation macro;
/*ROLLING REGRESSIONS FOR ECL ESTIMATION: RUN AFTER RUNNING ECL MACRO*/
rsubmit;*Macro 2016Q4;
%ecl_othnonre_0025(69, 108, inset=ecl_othnonre2, roll1=Q42016_1 ,roll2=Q42016_2, roll3=Q42016_3, roll4=Q42016_4, roll5=Q42016_5, roll6=Q42016_6, roll7=Q42016_7, roll8=Q42016_othnonre);
endrsubmit; dm 'clear log';
rsubmit;*Macro 2016Q3;
%ecl_othnonre_0025(68, 107, inset=ecl_othnonre2, roll1=Q32016_1 ,roll2=Q32016_2, roll3=Q32016_3, roll4=Q32016_4, roll5=Q32016_5, roll6=Q32016_6, roll7=Q32016_7, roll8=Q32016_othnonre);
endrsubmit; dm 'clear log';
rsubmit;*Macro 2016Q2;
%ecl_othnonre_0025(67, 106, inset=ecl_othnonre2, roll1=Q22016_1 ,roll2=Q22016_2, roll3=Q22016_3, roll4=Q22016_4, roll5=Q22016_5, roll6=Q22016_6, roll7=Q22016_7, roll8=Q22016_othnonre);
endrsubmit; dm 'clear log';
rsubmit;*Macro 2016Q1;
%ecl_othnonre_0025(66, 105, inset=ecl_othnonre2, roll1=Q12016_1 ,roll2=Q12016_2, roll3=Q12016_3, roll4=Q12016_4, roll5=Q12016_5, roll6=Q12016_6, roll7=Q12016_7, roll8=Q12016_othnonre);
endrsubmit; dm 'clear log';
rsubmit;*Macro 2015Q4;
%ecl_othnonre_0025(65, 104, inset=ecl_othnonre2, roll1=Q42015_1 ,roll2=Q42015_2, roll3=Q42015_3, roll4=Q42015_4, roll5=Q42015_5, roll6=Q42015_6, roll7=Q42015_7, roll8=Q42015_othnonre);
endrsubmit; dm 'clear log';
rsubmit;*Macro 2015Q3;
%ecl_othnonre_0025(64, 103, inset=ecl_othnonre2, roll1=Q32015_1 ,roll2=Q32015_2, roll3=Q32015_3, roll4=Q32015_4, roll5=Q32015_5, roll6=Q32015_6, roll7=Q32015_7, roll8=Q32015_othnonre);
endrsubmit; dm 'clear log';
rsubmit;*Macro 2015Q2;
%ecl_othnonre_0025(63, 102, inset=ecl_othnonre2, roll1=Q22015_1 ,roll2=Q22015_2, roll3=Q22015_3, roll4=Q22015_4, roll5=Q22015_5, roll6=Q22015_6, roll7=Q22015_7, roll8=Q22015_othnonre);
endrsubmit; dm 'clear log';
rsubmit;*Macro 2015Q1;
%ecl_othnonre_0025(62, 101, inset=ecl_othnonre2, roll1=Q12015_1 ,roll2=Q12015_2, roll3=Q12015_3, roll4=Q12015_4, roll5=Q12015_5, roll6=Q12015_6, roll7=Q12015_7, roll8=Q12015_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q4;
%ecl_othnonre_0025(61, 100, inset=ecl_othnonre2, roll1=Q42014_1 ,roll2=Q42014_2, roll3=Q42014_3, roll4=Q42014_4, roll5=Q42014_5, roll6=Q42014_6, roll7=Q42014_7, roll8=Q42014_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q3;
%ecl_othnonre_0025(60, 99, inset=ecl_othnonre2, roll1=Q32014_1 ,roll2=Q32014_2, roll3=Q32014_3, roll4=Q32014_4, roll5=Q32014_5, roll6=Q32014_6, roll7=Q32014_7, roll8=Q32014_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q2;
%ecl_othnonre_0025(59, 98, inset=ecl_othnonre2, roll1=Q22014_1 ,roll2=Q22014_2, roll3=Q22014_3, roll4=Q22014_4, roll5=Q22014_5, roll6=Q22014_6, roll7=Q22014_7, roll8=Q22014_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q1;
%ecl_othnonre_0025(58, 97, inset=ecl_othnonre2, roll1=Q12014_1 ,roll2=Q12014_2, roll3=Q12014_3, roll4=Q12014_4, roll5=Q12014_5, roll6=Q12014_6, roll7=Q12014_7, roll8=Q12014_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q4;
%ecl_othnonre_0025(57, 96, inset=ecl_othnonre2, roll1=Q42013_1 ,roll2=Q42013_2, roll3=Q42013_3, roll4=Q42013_4, roll5=Q42013_5, roll6=Q42013_6, roll7=Q42013_7, roll8=Q42013_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q3;
%ecl_othnonre_0025(56, 95, inset=ecl_othnonre2, roll1=Q32013_1 ,roll2=Q32013_2, roll3=Q32013_3, roll4=Q32013_4, roll5=Q32013_5, roll6=Q32013_6, roll7=Q32013_7, roll8=Q32013_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q2;
%ecl_othnonre_0025(55, 94, inset=ecl_othnonre2, roll1=Q22013_1 ,roll2=Q22013_2, roll3=Q22013_3, roll4=Q22013_4, roll5=Q22013_5, roll6=Q22013_6, roll7=Q22013_7, roll8=Q22013_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q1;
%ecl_othnonre_0025(54, 93, inset=ecl_othnonre2, roll1=Q12013_1 ,roll2=Q12013_2, roll3=Q12013_3, roll4=Q12013_4, roll5=Q12013_5, roll6=Q12013_6, roll7=Q12013_7, roll8=Q12013_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q4;
%ecl_othnonre_0025(53, 92, inset=ecl_othnonre2, roll1=Q42012_1 ,roll2=Q42012_2, roll3=Q42012_3, roll4=Q42012_4, roll5=Q42012_5, roll6=Q42012_6, roll7=Q42012_7, roll8=Q42012_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q3;
%ecl_othnonre_0025(52, 91, inset=ecl_othnonre2, roll1=Q32012_1 ,roll2=Q32012_2, roll3=Q32012_3, roll4=Q32012_4, roll5=Q32012_5, roll6=Q32012_6, roll7=Q32012_7, roll8=Q32012_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q2;
%ecl_othnonre_0025(51, 90, inset=ecl_othnonre2, roll1=Q22012_1 ,roll2=Q22012_2, roll3=Q22012_3, roll4=Q22012_4, roll5=Q22012_5, roll6=Q22012_6, roll7=Q22012_7, roll8=Q22012_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q1;
%ecl_othnonre_0025(50, 89, inset=ecl_othnonre2, roll1=Q12012_1 ,roll2=Q12012_2, roll3=Q12012_3, roll4=Q12012_4, roll5=Q12012_5, roll6=Q12012_6, roll7=Q12012_7, roll8=Q12012_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q4;
%ecl_othnonre_0025(49, 88, inset=ecl_othnonre2, roll1=Q42011_1 ,roll2=Q42011_2, roll3=Q42011_3, roll4=Q42011_4, roll5=Q42011_5, roll6=Q42011_6, roll7=Q42011_7, roll8=Q42011_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q3;
%ecl_othnonre_0025(48, 87, inset=ecl_othnonre2, roll1=Q32011_1 ,roll2=Q32011_2, roll3=Q32011_3, roll4=Q32011_4, roll5=Q32011_5, roll6=Q32011_6, roll7=Q32011_7, roll8=Q32011_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q2;
%ecl_othnonre_0025(47, 86, inset=ecl_othnonre2, roll1=Q22011_1 ,roll2=Q22011_2, roll3=Q22011_3, roll4=Q22011_4, roll5=Q22011_5, roll6=Q22011_6, roll7=Q22011_7, roll8=Q22011_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q1;
%ecl_othnonre_0025(46, 85, inset=ecl_othnonre2, roll1=Q12011_1 ,roll2=Q12011_2, roll3=Q12011_3, roll4=Q12011_4, roll5=Q12011_5, roll6=Q12011_6, roll7=Q12011_7, roll8=Q12011_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q4;
%ecl_othnonre_0025(45, 84, inset=ecl_othnonre2, roll1=Q42010_1 ,roll2=Q42010_2, roll3=Q42010_3, roll4=Q42010_4, roll5=Q42010_5, roll6=Q42010_6, roll7=Q42010_7, roll8=Q42010_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q3;
%ecl_othnonre_0025(44, 83, inset=ecl_othnonre2, roll1=Q32010_1 ,roll2=Q32010_2, roll3=Q32010_3, roll4=Q32010_4, roll5=Q32010_5, roll6=Q32010_6, roll7=Q32010_7, roll8=Q32010_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q2;
%ecl_othnonre_0025(43, 82, inset=ecl_othnonre2, roll1=Q22010_1 ,roll2=Q22010_2, roll3=Q22010_3, roll4=Q22010_4, roll5=Q22010_5, roll6=Q22010_6, roll7=Q22010_7, roll8=Q22010_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q1;
%ecl_othnonre_0025(42, 81, inset=ecl_othnonre2, roll1=Q12010_1 ,roll2=Q12010_2, roll3=Q12010_3, roll4=Q12010_4, roll5=Q12010_5, roll6=Q12010_6, roll7=Q12010_7, roll8=Q12010_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q4;
%ecl_othnonre_0025(41, 80, inset=ecl_othnonre2, roll1=Q42009_1 ,roll2=Q42009_2, roll3=Q42009_3, roll4=Q42009_4, roll5=Q42009_5, roll6=Q42009_6, roll7=Q42009_7, roll8=Q42009_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q3;
%ecl_othnonre_0025(40, 79, inset=ecl_othnonre2, roll1=Q32009_1 ,roll2=Q32009_2, roll3=Q32009_3, roll4=Q32009_4, roll5=Q32009_5, roll6=Q32009_6, roll7=Q32009_7, roll8=Q32009_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q2;
%ecl_othnonre_0025(39, 78, inset=ecl_othnonre2, roll1=Q22009_1 ,roll2=Q22009_2, roll3=Q22009_3, roll4=Q22009_4, roll5=Q22009_5, roll6=Q22009_6, roll7=Q22009_7, roll8=Q22009_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q1;
%ecl_othnonre_0025(38, 77, inset=ecl_othnonre2, roll1=Q12009_1 ,roll2=Q12009_2, roll3=Q12009_3, roll4=Q12009_4, roll5=Q12009_5, roll6=Q12009_6, roll7=Q12009_7, roll8=Q12009_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q4;
%ecl_othnonre_0025(37, 76, inset=ecl_othnonre2, roll1=Q42008_1 ,roll2=Q42008_2, roll3=Q42008_3, roll4=Q42008_4, roll5=Q42008_5, roll6=Q42008_6, roll7=Q42008_7, roll8=Q42008_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q3;
%ecl_othnonre_0025(36, 75, inset=ecl_othnonre2, roll1=Q32008_1 ,roll2=Q32008_2, roll3=Q32008_3, roll4=Q32008_4, roll5=Q32008_5, roll6=Q32008_6, roll7=Q32008_7, roll8=Q32008_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q2;
%ecl_othnonre_0025(35, 74, inset=ecl_othnonre2, roll1=Q22008_1 ,roll2=Q22008_2, roll3=Q22008_3, roll4=Q22008_4, roll5=Q22008_5, roll6=Q22008_6, roll7=Q22008_7, roll8=Q22008_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q1;
%ecl_othnonre_0025(34, 73, inset=ecl_othnonre2, roll1=Q12008_1 ,roll2=Q12008_2, roll3=Q12008_3, roll4=Q12008_4, roll5=Q12008_5, roll6=Q12008_6, roll7=Q12008_7, roll8=Q12008_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q4;
%ecl_othnonre_0025(33, 72, inset=ecl_othnonre2, roll1=Q42007_1 ,roll2=Q42007_2, roll3=Q42007_3, roll4=Q42007_4, roll5=Q42007_5, roll6=Q42007_6, roll7=Q42007_7, roll8=Q42007_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q3;
%ecl_othnonre_0025(32, 71, inset=ecl_othnonre2, roll1=Q32007_1 ,roll2=Q32007_2, roll3=Q32007_3, roll4=Q32007_4, roll5=Q32007_5, roll6=Q32007_6, roll7=Q32007_7, roll8=Q32007_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q2;
%ecl_othnonre_0025(31, 70, inset=ecl_othnonre2, roll1=Q22007_1 ,roll2=Q22007_2, roll3=Q22007_3, roll4=Q22007_4, roll5=Q22007_5, roll6=Q22007_6, roll7=Q22007_7, roll8=Q22007_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q1;
%ecl_othnonre_0025(30, 69, inset=ecl_othnonre2, roll1=Q12007_1 ,roll2=Q12007_2, roll3=Q12007_3, roll4=Q12007_4, roll5=Q12007_5, roll6=Q12007_6, roll7=Q12007_7, roll8=Q12007_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q4;
%ecl_othnonre_0025(29, 68, inset=ecl_othnonre2, roll1=Q42006_1 ,roll2=Q42006_2, roll3=Q42006_3, roll4=Q42006_4, roll5=Q42006_5, roll6=Q42006_6, roll7=Q42006_7, roll8=Q42006_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q3;
%ecl_othnonre_0025(28, 67, inset=ecl_othnonre2, roll1=Q32006_1 ,roll2=Q32006_2, roll3=Q32006_3, roll4=Q32006_4, roll5=Q32006_5, roll6=Q32006_6, roll7=Q32006_7, roll8=Q32006_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q2;
%ecl_othnonre_0025(27, 66, inset=ecl_othnonre2, roll1=Q22006_1 ,roll2=Q22006_2, roll3=Q22006_3, roll4=Q22006_4, roll5=Q22006_5, roll6=Q22006_6, roll7=Q22006_7, roll8=Q22006_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q1;
%ecl_othnonre_0025(26, 65, inset=ecl_othnonre2, roll1=Q12006_1 ,roll2=Q12006_2, roll3=Q12006_3, roll4=Q12006_4, roll5=Q12006_5, roll6=Q12006_6, roll7=Q12006_7, roll8=Q12006_othnonre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2005Q4;
%ecl_othnonre_0025(25, 64, inset=ecl_othnonre2, roll1=Q42005_1 ,roll2=Q42005_2, roll3=Q42005_3, roll4=Q42005_4, roll5=Q42005_5, roll6=Q42005_6, roll7=Q42005_7, roll8=Q42005_othnonre);
endrsubmit; dm 'clear log';

rsubmit;
*Aggregate ECL estimates into one file;
data ecl_othnonre3;
set 
Q42005_othnonre
Q12006_othnonre
Q22006_othnonre
Q32006_othnonre
Q42006_othnonre
Q12007_othnonre
Q22007_othnonre
Q32007_othnonre
Q42007_othnonre
Q12008_othnonre
Q22008_othnonre
Q32008_othnonre
Q42008_othnonre
Q12009_othnonre
Q22009_othnonre
Q32009_othnonre
Q42009_othnonre
Q12010_othnonre
Q22010_othnonre
Q32010_othnonre
Q42010_othnonre
Q12011_othnonre
Q22011_othnonre
Q32011_othnonre
Q42011_othnonre
Q12012_othnonre
Q22012_othnonre
Q32012_othnonre
Q42012_othnonre
Q12013_othnonre
Q22013_othnonre
Q32013_othnonre
Q42013_othnonre
Q12014_othnonre
Q22014_othnonre
Q32014_othnonre
Q42014_othnonre
Q12015_othnonre
Q22015_othnonre
Q32015_othnonre
Q42015_othnonre
Q12016_othnonre
Q22016_othnonre
Q32016_othnonre
Q42016_othnonre;
Run;
proc sort data=ecl_othnonre3; by rankdate name; run;
data bw2.ecl_othnonre_par0025_20;
set ecl_othnonre3;
if ecl_othnonre=. then delete;
ID = _N_;
run;
endrsubmit;

