/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below estimates the non-linear model Eq. (5) for consumer loans with 28 lags of loan
		originations and an initial parameter value of 0.0025 provided for each beta coefficient.

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';
libname ecl 'C:\Users\pwheeler1\Box Sync\Data Sets\ECL Estimates';

/*Connect to WRDS server*/
%let wrds=wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS compress=yes;
signon username=_prompt_;

/*Create temporary folder 4 as 'bw1' and create a remote directory in my explorer*/
libname bw1 remote '/scratch/tulane/' server=wrds;
rsubmit; libname bw1 '/scratch/tulane/'; endrsubmit;
libname bw2 remote '/home/tulane/pbwheele/' server=wrds;
rsubmit; libname bw2 '/home/tulane/pbwheele/'; endrsubmit;


*Create estimation data set;
proc sql;
create table lo8 as select snlkey, name, rssd_id, rankdate,
est_lo_t as lo_cons_t,
est_lo_lag1 as lo_cons_lag1,
est_lo_lag2 as lo_cons_lag2,
est_lo_lag3 as lo_cons_lag3,
est_lo_lag4 as lo_cons_lag4,
est_lo_lag5 as lo_cons_lag5,
est_lo_lag6 as lo_cons_lag6,
est_lo_lag7 as lo_cons_lag7,
est_lo_lag8 as lo_cons_lag8,
est_lo_lag9 as lo_cons_lag9,
est_lo_lag10 as lo_cons_lag10,
est_lo_lag11 as lo_cons_lag11,
est_lo_lag12 as lo_cons_lag12,
est_lo_lag13 as lo_cons_lag13,
est_lo_lag14 as lo_cons_lag14,
est_lo_lag15 as lo_cons_lag15,
est_lo_lag16 as lo_cons_lag16,
est_lo_lag17 as lo_cons_lag17,
est_lo_lag18 as lo_cons_lag18,
est_lo_lag19 as lo_cons_lag19,
est_lo_lag20 as lo_cons_lag20,
est_lo_lag21 as lo_cons_lag21,
est_lo_lag22 as lo_cons_lag22,
est_lo_lag23 as lo_cons_lag23,
est_lo_lag24 as lo_cons_lag24,
est_lo_lag25 as lo_cons_lag25,
est_lo_lag26 as lo_cons_lag26,
est_lo_lag27 as lo_cons_lag27,
est_lo_lag28 as lo_cons_lag28,
est_lo_lag29 as lo_cons_lag29,
est_lo_lag30 as lo_cons_lag30,
est_lo_lag31 as lo_cons_lag31,
est_lo_lag32 as lo_cons_lag32,
est_lo_lag33 as lo_cons_lag33,
est_lo_lag34 as lo_cons_lag34,
est_lo_lag35 as lo_cons_lag35,
est_lo_lag36 as lo_cons_lag36,
est_lo_lag37 as lo_cons_lag37,
est_lo_lag38 as lo_cons_lag38,
est_lo_lag39 as lo_cons_lag39
from lo.lo_cons_1990_2016
order by rssd_id, rankdate;
quit;

proc sql;
create table ecl_cons1 as select a.snlkey, a.snlyear, a.snlqtr, a.name, a.reg_id, a.rankdate, a.date, a.co_consloans as co_cons, b.*
from box.all_co_bytype_1990_2018 a left join lo8 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.snlkey, a.rankdate;
quit;

*Create dataset to estimate rolling regressions for ECL estimation;
data ecl_cons2;
set ecl_cons1;
if lo_cons_lag1=. then delete;
if lo_cons_lag2=. then delete;
if lo_cons_lag3=. then delete;
if lo_cons_lag4=. then delete;
if lo_cons_lag5=. then delete;
if lo_cons_lag6=. then delete;
if lo_cons_lag7=. then delete;
if lo_cons_lag8=. then delete;
if lo_cons_lag9=. then delete;
if lo_cons_lag10=. then delete;
if lo_cons_lag11=. then delete;
if lo_cons_lag12=. then delete;
if lo_cons_lag13=. then delete;
if lo_cons_lag14=. then delete;
if lo_cons_lag15=. then delete;
if lo_cons_lag16=. then delete;
if lo_cons_lag17=. then delete;
if lo_cons_lag18=. then delete;
if lo_cons_lag19=. then delete;
if lo_cons_lag20=. then delete;
if lo_cons_lag21=. then delete;
if lo_cons_lag22=. then delete;
if lo_cons_lag23=. then delete;
if lo_cons_lag24=. then delete;
if lo_cons_lag25=. then delete;
if lo_cons_lag26=. then delete;
if lo_cons_lag27=. then delete;
if lo_cons_lag28=. then delete;
run;

*TRANSFER TO LO FOLDER;
data lo.ecl_cons2_28lags; set ecl_cons2; run;
*Then.........;
*TRANSFER TO WRDS SERVER VIA FTP SITE;
*THEN.........;

rsubmit;
data ecl_cons2; set bw2.ecl_cons2_28lags; run;
endrsubmit;

rsubmit;
/*~~~~~~~~~~~~~~~~~~~~~~~~*/
/*ECL MACRO*/
/*~~~~~~~~~~~~~~~~~~~~~~~~*/

*Rolling regressions macro;
%macro ecl_cons_0025(first_rankdate, last_rankdate, inset=, roll1=,roll2=, roll3=, roll4=, roll5=, roll6=, roll7=, roll8=);

data &roll1;
set &inset;
if rankdate not in (&first_rankdate:&last_rankdate) then delete;
run;

proc sql;
create table &roll2 as select a.*, count(a.snlkey) as obs
from &roll1 as a
group by snlkey
order by snlkey, rankdate;
quit;

data &roll3;
set &roll2;
if obs < 40 then delete;
run;

ods graphics off;
ods exclude all;
/*1 lag*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025;
model co_cons = b1*lo_cons_lag1;
bounds b1 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_1 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_1 as select a.*, b.res
from roll4_1 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*2 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2;
bounds b1 >= 0, b2 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_2 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_2 as select a.*, b.res
from roll4_2 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*3 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3;
bounds b1 >= 0, b2 >= 0, b3 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_3 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_3 as select a.*, b.res
from roll4_3 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*4 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_4 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_4 as select a.*, b.res
from roll4_4 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*5 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_5 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_5 as select a.*, b.res
from roll4_5 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*6 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_6 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_6 as select a.*, b.res
from roll4_6 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*7 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_7 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_7 as select a.*, b.res
from roll4_7 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*8 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_8 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_8 as select a.*, b.res
from roll4_8 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*9 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_9 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_9 as select a.*, b.res
from roll4_9 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*10 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_10 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_10 as select a.*, b.res
from roll4_10 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*11 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_11 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_11 as select a.*, b.res
from roll4_11 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*12 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 ;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_12 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_12 as select a.*, b.res
from roll4_12 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*13 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_13 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_13 as select a.*, b.res
from roll4_13 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*14 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_14 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_14 as select a.*, b.res
from roll4_14 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*15 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_15 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_15 as select a.*, b.res
from roll4_15 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*16 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_16 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_16 as select a.*, b.res
from roll4_16 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*17 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_17 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_17 as select a.*, b.res
from roll4_17 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*18 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_18 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_18 as select a.*, b.res
from roll4_18 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*19 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_19 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_19 as select a.*, b.res
from roll4_19 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*20 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_20 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_20 as select a.*, b.res
from roll4_20 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*21 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_21 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_21 as select a.*, b.res
from roll4_21 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*22 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025 b22 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21 + b22*lo_cons_lag22;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_22 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_22 as select a.*, b.res
from roll4_22 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*23 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025 b22 = 0.0025 b23 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21 + b22*lo_cons_lag22 + b23*lo_cons_lag23;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_23 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_23 as select a.*, b.res
from roll4_23 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*24 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025 b22 = 0.0025 b23 = 0.0025 b24 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21 + b22*lo_cons_lag22 + b23*lo_cons_lag23 + b24*lo_cons_lag24;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_24 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_24 as select a.*, b.res
from roll4_24 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*25 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025 b22 = 0.0025 b23 = 0.0025 b24 = 0.0025 b25 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21 + b22*lo_cons_lag22 + b23*lo_cons_lag23 + b24*lo_cons_lag24 + b25*lo_cons_lag25;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0, b25 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_25 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_25 as select a.*, b.res
from roll4_25 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*26 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025 b22 = 0.0025 b23 = 0.0025 b24 = 0.0025 b25 = 0.0025 b26 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21 + b22*lo_cons_lag22 + b23*lo_cons_lag23 + b24*lo_cons_lag24 + b25*lo_cons_lag25 + b26*lo_cons_lag26;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0, b25 >= 0, b26 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_26 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_26 as select a.*, b.res
from roll4_26 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*27 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025 b22 = 0.0025 b23 = 0.0025 b24 = 0.0025 b25 = 0.0025 b26 = 0.0025 b27 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21 + b22*lo_cons_lag22 + b23*lo_cons_lag23 + b24*lo_cons_lag24 + b25*lo_cons_lag25 + b26*lo_cons_lag26 + b27*lo_cons_lag27;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0, b25 >= 0, b26 >= 0, b27 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_27 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_27 as select a.*, b.res
from roll4_27 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

/*28 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0025 b2 = 0.0025 b3 = 0.0025 b4 = 0.0025 b5 = 0.0025 b6 = 0.0025 b7 = 0.0025 b8 = 0.0025 b9 = 0.0025 b10 = 0.0025 b11 = 0.0025 b12 = 0.0025 b13 = 0.0025 b14 = 0.0025 b15 = 0.0025 b16 = 0.0025 b17 = 0.0025 b18 = 0.0025 b19 = 0.0025 b20 = 0.0025 b21 = 0.0025 b22 = 0.0025 b23 = 0.0025 b24 = 0.0025 b25 = 0.0025 b26 = 0.0025 b27 = 0.0025 b28 = 0.0025;
model co_cons = b1*lo_cons_lag1 + b2*lo_cons_lag2 + b3*lo_cons_lag3 + b4*lo_cons_lag4 + b5*lo_cons_lag5 + b6*lo_cons_lag6 + b7*lo_cons_lag7 + b8*lo_cons_lag8 + b9*lo_cons_lag9 + b10*lo_cons_lag10 + b11*lo_cons_lag11 + b12*lo_cons_lag12 + b13*lo_cons_lag13 + b14*lo_cons_lag14 + b15*lo_cons_lag15 + b16*lo_cons_lag16 + b17*lo_cons_lag17 + b18*lo_cons_lag18 + b19*lo_cons_lag19 + b20*lo_cons_lag20 + b21*lo_cons_lag21 + b22*lo_cons_lag22 + b23*lo_cons_lag23 + b24*lo_cons_lag24 + b25*lo_cons_lag25 + b26*lo_cons_lag26 + b27*lo_cons_lag27 + b28*lo_cons_lag28;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0, b25 >= 0, b26 >= 0, b27 >= 0, b28 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_28 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_28 as select a.*, b.res
from roll4_27 a left join residual b
on a.snlkey=b.snlkey and b.rankdate=&last_rankdate;
quit;

*Merge coefficients with bank data;
data &roll4;
set roll4_1 roll4_2 roll4_3 roll4_4 roll4_5 roll4_6 roll4_7 roll4_8
roll4_9 roll4_10 roll4_11 roll4_12 roll4_13 roll4_14 roll4_15 roll4_16
roll4_17 roll4_18 roll4_19 roll4_20 roll4_21 roll4_22 roll4_23 roll4_24
roll4_25 roll4_26 roll4_27 roll4_28;
if b2=. and b3=. and b4=. and b5=. and b6=. and b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=1;
else if b3=. and b4=. and b5=. and b6=. and b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=2;
else if b4=. and b5=. and b6=. and b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=3;
else if b5=. and b6=. and b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=4;
else if b6=. and b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=5;
else if b7=. and b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=6;
else if b8=. and b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=7;
else if b9=. and b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=8;
else if b10=. and b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=9;
else if b11=. and b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=10;
else if b12=. and b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=11;
else if b13=. and b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=12;
else if b14=. and b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=13;
else if b15=. and b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=14;
else if b16=. and b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=15;
else if b17=. and b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=16;
else if b18=. and b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=17;
else if b19=. and b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=18;
else if b20=. and b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=19;
else if b21=. and b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=20;
else if b22=. and b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=21;
else if b23=. and b24=. and b25=. and b26=. and b27=. and b28=. then model=22;
else if b24=. and b25=. and b26=. and b27=. and b28=. then model=23;
else if b25=. and b26=. and b27=. and b28=. then model=24;
else if b26=. and b27=. and b28=. then model=25;
else if b27=. and b28=. then model=26;
else if b28=. then model=27;
else model=28;
run;
proc sql;
create table &roll5 as select a.*,
CASE when b.b1 ne . then b.b1 else 0 END as b1 'Coefficient t-1',
CASE when b.b2 ne . then b.b2 else 0 END as b2 'Coefficient t-2',
CASE when b.b3 ne . then b.b3 else 0 END as b3 'Coefficient t-3',
CASE when b.b4 ne . then b.b4 else 0 END as b4 'Coefficient t-4',
CASE when b.b5 ne . then b.b5 else 0 END as b5 'Coefficient t-5',
CASE when b.b6 ne . then b.b6 else 0 END as b6 'Coefficient t-6',
CASE when b.b7 ne . then b.b7 else 0 END as b7 'Coefficient t-7',
CASE when b.b8 ne . then b.b8 else 0 END as b8 'Coefficient t-8',
CASE when b.b9 ne . then b.b9 else 0 END as b9 'Coefficient t-9',
CASE when b.b10 ne . then b.b10 else 0 END as b10 'Coefficient t-10',
CASE when b.b11 ne . then b.b11 else 0 END as b11 'Coefficient t-11',
CASE when b.b12 ne . then b.b12 else 0 END as b12 'Coefficient t-12',
CASE when b.b13 ne . then b.b13 else 0 END as b13 'Coefficient t-13',
CASE when b.b14 ne . then b.b14 else 0 END as b14 'Coefficient t-14',
CASE when b.b15 ne . then b.b15 else 0 END as b15 'Coefficient t-15',
CASE when b.b16 ne . then b.b16 else 0 END as b16 'Coefficient t-16',
CASE when b.b17 ne . then b.b17 else 0 END as b17 'Coefficient t-17',
CASE when b.b18 ne . then b.b18 else 0 END as b18 'Coefficient t-18',
CASE when b.b19 ne . then b.b19 else 0 END as b19 'Coefficient t-19',
CASE when b.b20 ne . then b.b20 else 0 END as b20 'Coefficient t-20',
CASE when b.b21 ne . then b.b21 else 0 END as b21 'Coefficient t-21',
CASE when b.b22 ne . then b.b22 else 0 END as b22 'Coefficient t-22',
CASE when b.b23 ne . then b.b23 else 0 END as b23 'Coefficient t-23',
CASE when b.b24 ne . then b.b24 else 0 END as b24 'Coefficient t-24',
CASE when b.b21 ne . then b.b21 else 0 END as b25 'Coefficient t-25',
CASE when b.b22 ne . then b.b22 else 0 END as b26 'Coefficient t-26',
CASE when b.b23 ne . then b.b23 else 0 END as b27 'Coefficient t-27',
CASE when b.b24 ne . then b.b24 else 0 END as b28 'Coefficient t-28',
b.model, b.pseudo_rsq, b._iter_, b._status_, b.res

from &roll3 as a left join &roll4 as b
on a.snlkey=b.snlkey and a.rankdate=&last_rankdate
order by a.snlkey, a.rankdate, b.model;
quit;

*Calculate expected charge-offs by year and then aggregate;
data &roll6;
set &roll5;
ecl_cons_t = lo_cons_t * (b1 + b2 + b3 + b4 + b5 + b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag1 = lo_cons_lag1 * (b2 + b3 + b4 + b5 + b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag2 = lo_cons_lag2 * (b3 + b4 + b5 + b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag3 = lo_cons_lag3 * (b4 + b5 + b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag4 = lo_cons_lag4 * (b5 + b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag5 = lo_cons_lag5 * (b6 + b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag6 = lo_cons_lag6 * (b7 + b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag7 = lo_cons_lag7 * (b8 + b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag8 = lo_cons_lag8 * (b9 + b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag9 = lo_cons_lag9 * (b10 + b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag10 = lo_cons_lag10 * (b11 + b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag11 = lo_cons_lag11 * (b12 + b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag12 = lo_cons_lag12 * (b13 + b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag13 = lo_cons_lag13 * (b14 + b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag14 = lo_cons_lag14 * (b15 + b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag15 = lo_cons_lag15 * (b16 + b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag16 = lo_cons_lag16 * (b17 + b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag17 = lo_cons_lag17 * (b18 + b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag18 = lo_cons_lag18 * (b19 + b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag19 = lo_cons_lag19 * (b20 + b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag20 = lo_cons_lag20 * (b21 + b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag21 = lo_cons_lag21 * (b22 + b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag22 = lo_cons_lag22 * (b23 + b24 + b25 + b26 + b27 + b28);
ecl_cons_lag23 = lo_cons_lag23 * (b24 + b25 + b26 + b27 + b28);
ecl_cons_lag24 = lo_cons_lag24 * (b25 + b26 + b27 + b28);
ecl_cons_lag25 = lo_cons_lag25 * (b26 + b27 + b28);
ecl_cons_lag26 = lo_cons_lag26 * (b27 + b28);
ecl_cons_lag27 = lo_cons_lag27 * (b28);

ecl_cons = ecl_cons_t + ecl_cons_lag1 + ecl_cons_lag2 + ecl_cons_lag3 + ecl_cons_lag4 + ecl_cons_lag5 + ecl_cons_lag6 + ecl_cons_lag7 + ecl_cons_lag8 + ecl_cons_lag9 + ecl_cons_lag10 + ecl_cons_lag11 + ecl_cons_lag12 + ecl_cons_lag13 + ecl_cons_lag14 + ecl_cons_lag15 + ecl_cons_lag16 + ecl_cons_lag17 + ecl_cons_lag18 + ecl_cons_lag19
+ ecl_cons_lag20 + ecl_cons_lag21 + ecl_cons_lag22 + ecl_cons_lag23 + ecl_cons_lag24 + ecl_cons_lag25 + ecl_cons_lag26 + ecl_cons_lag27;
if model=. then delete;
run;
proc sort data=&roll6;
by snlkey rankdate model;
run;
*Retain model with highest adjusted r-sq;
proc sql;
create table &roll7 as select *, max(pseudo_rsq) as max_pseudo_rsq, mean(ecl_cons) as mean_ecl_cons, std(ecl_cons) as std_ecl_cons, (mean(ecl_cons)/std(ecl_cons)) as mean_std_ratio_cons
from &roll6
group by snlkey, rankdate
order by snlkey, rankdate;
quit;
data &roll8 (drop=max_pseudo_rsq);
set &roll7;
if pseudo_rsq ne max_pseudo_rsq then delete;
run;

proc sort data=&roll8 nodupkey; by snlkey rankdate; run;

dm 'clear log';
%mend;
endrsubmit;

*Run estimation macro;
/*ROLLING REGRESSIONS FOR ECL ESTIMATION: RUN AFTER RUNNING ECL MACRO*/
rsubmit; *Macro 2016Q4;
%ecl_cons_0025(69, 108, inset=ecl_cons2, roll1=Q42016_1 ,roll2=Q42016_2, roll3=Q42016_3, roll4=Q42016_4, roll5=Q42016_5, roll6=Q42016_6, roll7=Q42016_7, roll8=Q42016_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2016Q3;
%ecl_cons_0025(68, 107, inset=ecl_cons2, roll1=Q32016_1 ,roll2=Q32016_2, roll3=Q32016_3, roll4=Q32016_4, roll5=Q32016_5, roll6=Q32016_6, roll7=Q32016_7, roll8=Q32016_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2016Q2;
%ecl_cons_0025(67, 106, inset=ecl_cons2, roll1=Q22016_1 ,roll2=Q22016_2, roll3=Q22016_3, roll4=Q22016_4, roll5=Q22016_5, roll6=Q22016_6, roll7=Q22016_7, roll8=Q22016_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2016Q1;
%ecl_cons_0025(66, 105, inset=ecl_cons2, roll1=Q12016_1 ,roll2=Q12016_2, roll3=Q12016_3, roll4=Q12016_4, roll5=Q12016_5, roll6=Q12016_6, roll7=Q12016_7, roll8=Q12016_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q4;
%ecl_cons_0025(65, 104, inset=ecl_cons2, roll1=Q42015_1 ,roll2=Q42015_2, roll3=Q42015_3, roll4=Q42015_4, roll5=Q42015_5, roll6=Q42015_6, roll7=Q42015_7, roll8=Q42015_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q3;
%ecl_cons_0025(64, 103, inset=ecl_cons2, roll1=Q32015_1 ,roll2=Q32015_2, roll3=Q32015_3, roll4=Q32015_4, roll5=Q32015_5, roll6=Q32015_6, roll7=Q32015_7, roll8=Q32015_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q2;
%ecl_cons_0025(63, 102, inset=ecl_cons2, roll1=Q22015_1 ,roll2=Q22015_2, roll3=Q22015_3, roll4=Q22015_4, roll5=Q22015_5, roll6=Q22015_6, roll7=Q22015_7, roll8=Q22015_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q1;
%ecl_cons_0025(62, 101, inset=ecl_cons2, roll1=Q12015_1 ,roll2=Q12015_2, roll3=Q12015_3, roll4=Q12015_4, roll5=Q12015_5, roll6=Q12015_6, roll7=Q12015_7, roll8=Q12015_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q4;
%ecl_cons_0025(61, 100, inset=ecl_cons2, roll1=Q42014_1 ,roll2=Q42014_2, roll3=Q42014_3, roll4=Q42014_4, roll5=Q42014_5, roll6=Q42014_6, roll7=Q42014_7, roll8=Q42014_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q3;
%ecl_cons_0025(60, 99, inset=ecl_cons2, roll1=Q32014_1 ,roll2=Q32014_2, roll3=Q32014_3, roll4=Q32014_4, roll5=Q32014_5, roll6=Q32014_6, roll7=Q32014_7, roll8=Q32014_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q2;
%ecl_cons_0025(59, 98, inset=ecl_cons2, roll1=Q22014_1 ,roll2=Q22014_2, roll3=Q22014_3, roll4=Q22014_4, roll5=Q22014_5, roll6=Q22014_6, roll7=Q22014_7, roll8=Q22014_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q1;
%ecl_cons_0025(58, 97, inset=ecl_cons2, roll1=Q12014_1 ,roll2=Q12014_2, roll3=Q12014_3, roll4=Q12014_4, roll5=Q12014_5, roll6=Q12014_6, roll7=Q12014_7, roll8=Q12014_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q4;
%ecl_cons_0025(57, 96, inset=ecl_cons2, roll1=Q42013_1 ,roll2=Q42013_2, roll3=Q42013_3, roll4=Q42013_4, roll5=Q42013_5, roll6=Q42013_6, roll7=Q42013_7, roll8=Q42013_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q3;
%ecl_cons_0025(56, 95, inset=ecl_cons2, roll1=Q32013_1 ,roll2=Q32013_2, roll3=Q32013_3, roll4=Q32013_4, roll5=Q32013_5, roll6=Q32013_6, roll7=Q32013_7, roll8=Q32013_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q2;
%ecl_cons_0025(55, 94, inset=ecl_cons2, roll1=Q22013_1 ,roll2=Q22013_2, roll3=Q22013_3, roll4=Q22013_4, roll5=Q22013_5, roll6=Q22013_6, roll7=Q22013_7, roll8=Q22013_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q1;
%ecl_cons_0025(54, 93, inset=ecl_cons2, roll1=Q12013_1 ,roll2=Q12013_2, roll3=Q12013_3, roll4=Q12013_4, roll5=Q12013_5, roll6=Q12013_6, roll7=Q12013_7, roll8=Q12013_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q4;
%ecl_cons_0025(53, 92, inset=ecl_cons2, roll1=Q42012_1 ,roll2=Q42012_2, roll3=Q42012_3, roll4=Q42012_4, roll5=Q42012_5, roll6=Q42012_6, roll7=Q42012_7, roll8=Q42012_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q3;
%ecl_cons_0025(52, 91, inset=ecl_cons2, roll1=Q32012_1 ,roll2=Q32012_2, roll3=Q32012_3, roll4=Q32012_4, roll5=Q32012_5, roll6=Q32012_6, roll7=Q32012_7, roll8=Q32012_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q2;
%ecl_cons_0025(51, 90, inset=ecl_cons2, roll1=Q22012_1 ,roll2=Q22012_2, roll3=Q22012_3, roll4=Q22012_4, roll5=Q22012_5, roll6=Q22012_6, roll7=Q22012_7, roll8=Q22012_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q1;
%ecl_cons_0025(50, 89, inset=ecl_cons2, roll1=Q12012_1 ,roll2=Q12012_2, roll3=Q12012_3, roll4=Q12012_4, roll5=Q12012_5, roll6=Q12012_6, roll7=Q12012_7, roll8=Q12012_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q4;
%ecl_cons_0025(49, 88, inset=ecl_cons2, roll1=Q42011_1 ,roll2=Q42011_2, roll3=Q42011_3, roll4=Q42011_4, roll5=Q42011_5, roll6=Q42011_6, roll7=Q42011_7, roll8=Q42011_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q3;
%ecl_cons_0025(48, 87, inset=ecl_cons2, roll1=Q32011_1 ,roll2=Q32011_2, roll3=Q32011_3, roll4=Q32011_4, roll5=Q32011_5, roll6=Q32011_6, roll7=Q32011_7, roll8=Q32011_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q2;
%ecl_cons_0025(47, 86, inset=ecl_cons2, roll1=Q22011_1 ,roll2=Q22011_2, roll3=Q22011_3, roll4=Q22011_4, roll5=Q22011_5, roll6=Q22011_6, roll7=Q22011_7, roll8=Q22011_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q1;
%ecl_cons_0025(46, 85, inset=ecl_cons2, roll1=Q12011_1 ,roll2=Q12011_2, roll3=Q12011_3, roll4=Q12011_4, roll5=Q12011_5, roll6=Q12011_6, roll7=Q12011_7, roll8=Q12011_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q4;
%ecl_cons_0025(45, 84, inset=ecl_cons2, roll1=Q42010_1 ,roll2=Q42010_2, roll3=Q42010_3, roll4=Q42010_4, roll5=Q42010_5, roll6=Q42010_6, roll7=Q42010_7, roll8=Q42010_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q3;
%ecl_cons_0025(44, 83, inset=ecl_cons2, roll1=Q32010_1 ,roll2=Q32010_2, roll3=Q32010_3, roll4=Q32010_4, roll5=Q32010_5, roll6=Q32010_6, roll7=Q32010_7, roll8=Q32010_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q2;
%ecl_cons_0025(43, 82, inset=ecl_cons2, roll1=Q22010_1 ,roll2=Q22010_2, roll3=Q22010_3, roll4=Q22010_4, roll5=Q22010_5, roll6=Q22010_6, roll7=Q22010_7, roll8=Q22010_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q1;
%ecl_cons_0025(42, 81, inset=ecl_cons2, roll1=Q12010_1 ,roll2=Q12010_2, roll3=Q12010_3, roll4=Q12010_4, roll5=Q12010_5, roll6=Q12010_6, roll7=Q12010_7, roll8=Q12010_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q4;
%ecl_cons_0025(41, 80, inset=ecl_cons2, roll1=Q42009_1 ,roll2=Q42009_2, roll3=Q42009_3, roll4=Q42009_4, roll5=Q42009_5, roll6=Q42009_6, roll7=Q42009_7, roll8=Q42009_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q3;
%ecl_cons_0025(40, 79, inset=ecl_cons2, roll1=Q32009_1 ,roll2=Q32009_2, roll3=Q32009_3, roll4=Q32009_4, roll5=Q32009_5, roll6=Q32009_6, roll7=Q32009_7, roll8=Q32009_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q2;
%ecl_cons_0025(39, 78, inset=ecl_cons2, roll1=Q22009_1 ,roll2=Q22009_2, roll3=Q22009_3, roll4=Q22009_4, roll5=Q22009_5, roll6=Q22009_6, roll7=Q22009_7, roll8=Q22009_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q1;
%ecl_cons_0025(38, 77, inset=ecl_cons2, roll1=Q12009_1 ,roll2=Q12009_2, roll3=Q12009_3, roll4=Q12009_4, roll5=Q12009_5, roll6=Q12009_6, roll7=Q12009_7, roll8=Q12009_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q4;
%ecl_cons_0025(37, 76, inset=ecl_cons2, roll1=Q42008_1 ,roll2=Q42008_2, roll3=Q42008_3, roll4=Q42008_4, roll5=Q42008_5, roll6=Q42008_6, roll7=Q42008_7, roll8=Q42008_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q3;
%ecl_cons_0025(36, 75, inset=ecl_cons2, roll1=Q32008_1 ,roll2=Q32008_2, roll3=Q32008_3, roll4=Q32008_4, roll5=Q32008_5, roll6=Q32008_6, roll7=Q32008_7, roll8=Q32008_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q2;
%ecl_cons_0025(35, 74, inset=ecl_cons2, roll1=Q22008_1 ,roll2=Q22008_2, roll3=Q22008_3, roll4=Q22008_4, roll5=Q22008_5, roll6=Q22008_6, roll7=Q22008_7, roll8=Q22008_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q1;
%ecl_cons_0025(34, 73, inset=ecl_cons2, roll1=Q12008_1 ,roll2=Q12008_2, roll3=Q12008_3, roll4=Q12008_4, roll5=Q12008_5, roll6=Q12008_6, roll7=Q12008_7, roll8=Q12008_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q4;
%ecl_cons_0025(33, 72, inset=ecl_cons2, roll1=Q42007_1 ,roll2=Q42007_2, roll3=Q42007_3, roll4=Q42007_4, roll5=Q42007_5, roll6=Q42007_6, roll7=Q42007_7, roll8=Q42007_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q3;
%ecl_cons_0025(32, 71, inset=ecl_cons2, roll1=Q32007_1 ,roll2=Q32007_2, roll3=Q32007_3, roll4=Q32007_4, roll5=Q32007_5, roll6=Q32007_6, roll7=Q32007_7, roll8=Q32007_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q2;
%ecl_cons_0025(31, 70, inset=ecl_cons2, roll1=Q22007_1 ,roll2=Q22007_2, roll3=Q22007_3, roll4=Q22007_4, roll5=Q22007_5, roll6=Q22007_6, roll7=Q22007_7, roll8=Q22007_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q1;
%ecl_cons_0025(30, 69, inset=ecl_cons2, roll1=Q12007_1 ,roll2=Q12007_2, roll3=Q12007_3, roll4=Q12007_4, roll5=Q12007_5, roll6=Q12007_6, roll7=Q12007_7, roll8=Q12007_cons);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q4;
%ecl_cons_0025(29, 68, inset=ecl_cons2, roll1=Q42006_1 ,roll2=Q42006_2, roll3=Q42006_3, roll4=Q42006_4, roll5=Q42006_5, roll6=Q42006_6, roll7=Q42006_7, roll8=Q42006_cons);
endrsubmit; dm 'clear log';

rsubmit;
*Aggregate ECL estimates into one file;
data ecl_cons3;
set 
Q42006_cons
Q12007_cons
Q22007_cons
Q32007_cons
Q42007_cons
Q12008_cons
Q22008_cons
Q32008_cons
Q42008_cons
Q12009_cons
Q22009_cons
Q32009_cons
Q42009_cons
Q12010_cons
Q22010_cons
Q32010_cons
Q42010_cons
Q12011_cons
Q22011_cons
Q32011_cons
Q42011_cons
Q12012_cons
Q22012_cons
Q32012_cons
Q42012_cons
Q12013_cons
Q22013_cons
Q32013_cons
Q42013_cons
Q12014_cons
Q22014_cons
Q32014_cons
Q42014_cons
Q12015_cons
Q22015_cons
Q32015_cons
Q42015_cons
Q12016_cons
Q22016_cons
Q32016_cons
Q42016_cons;
Run;
proc sort data=ecl_cons3; by rankdate name; run;
data bw2.ecl_cons_param0025_28;
set ecl_cons3;
if ecl_cons=0 then delete;
ID = _N_;
run;
endrsubmit;
