/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below estimates the non-linear model Eq. (5) for non-single-family real estate loans with
		20 lags of loan originations an initial parameter value of 0.001 provided for each beta coefficient.
		The residuals from these models are then collected for use in estimation of Eq. (6).

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';
libname ecl 'C:\Users\pwheeler1\Box Sync\Data Sets\ECL Estimates';

/*Connect to WRDS server*/
%let wrds=wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS compress=yes;
signon username=_prompt_;

/*Create temporary folder 4 as 'bw1' and create a remote directory in my explorer*/
libname bw1 remote '/scratch/tulane/' server=wrds;
rsubmit; libname bw1 '/scratch/tulane/'; endrsubmit;
libname bw2 remote '/home/tulane/pbwheele/' server=wrds;
rsubmit; libname bw2 '/home/tulane/pbwheele/'; endrsubmit;

*Create estimation data set;
*NOTE: HMDA data is ANNUAL not quarterly;
*Interpolate to create quarterly loan originations;
proc sql;
create table lo3a as select a.snlkey, a.name, a.rssd_id, a.rankdate, b.year, b.qtr
from lo.hmda_mf_lo_1990_2016 as a left join box.rankdates as b
on a.rankdate=b.rankdate;

create table lo3b as select a.*, b.rankdate as rankdate_new, b.qtr as qtr_new
from lo3a as a left join box.rankdates as b
on a.year=b.year order by a.rssd_id, b.rankdate;
quit;
data lo3 (drop=rankdate qtr);
set lo3b;
rename rankdate_new = rankdate qtr_new = qtr;
run;

proc sql;
create table lo4a as select a.*,
b.lo_multifam_t/4 as lo_multifam_t, b.lo_multifam_t/4 as lo_multifam_lag1, b.lo_multifam_t/4 as lo_multifam_lag2, b.lo_multifam_t/4 as lo_multifam_lag3,  
b.lo_multifam_lag1/4 as lo_multifam_lag4, b.lo_multifam_lag1/4 as lo_multifam_lag5, b.lo_multifam_lag1/4 as lo_multifam_lag6, b.lo_multifam_lag1/4 as lo_multifam_lag7,
b.lo_multifam_lag2/4 as lo_multifam_lag8, b.lo_multifam_lag2/4 as lo_multifam_lag9, b.lo_multifam_lag2/4 as lo_multifam_lag10, b.lo_multifam_lag2/4 as lo_multifam_lag11,
b.lo_multifam_lag3/4 as lo_multifam_lag12, b.lo_multifam_lag3/4 as lo_multifam_lag13, b.lo_multifam_lag3/4 as lo_multifam_lag14, b.lo_multifam_lag3/4 as lo_multifam_lag15,
b.lo_multifam_lag4/4 as lo_multifam_lag16, b.lo_multifam_lag4/4 as lo_multifam_lag17, b.lo_multifam_lag4/4 as lo_multifam_lag18, b.lo_multifam_lag4/4 as lo_multifam_lag19,
b.lo_multifam_lag5/4 as lo_multifam_lag20, b.lo_multifam_lag5/4 as lo_multifam_lag21, b.lo_multifam_lag5/4 as lo_multifam_lag22, b.lo_multifam_lag5/4 as lo_multifam_lag23,
b.lo_multifam_lag6/4 as lo_multifam_lag24, b.lo_multifam_lag6/4 as lo_multifam_lag25, b.lo_multifam_lag6/4 as lo_multifam_lag26, b.lo_multifam_lag6/4 as lo_multifam_lag27,
b.lo_multifam_lag7/4 as lo_multifam_lag28, b.lo_multifam_lag7/4 as lo_multifam_lag29, b.lo_multifam_lag7/4 as lo_multifam_lag30, b.lo_multifam_lag7/4 as lo_multifam_lag31,
b.lo_multifam_lag8/4 as lo_multifam_lag32, b.lo_multifam_lag8/4 as lo_multifam_lag33, b.lo_multifam_lag8/4 as lo_multifam_lag34, b.lo_multifam_lag8/4 as lo_multifam_lag35,
b.lo_multifam_lag9/4 as lo_multifam_lag36, b.lo_multifam_lag9/4 as lo_multifam_lag37, b.lo_multifam_lag9/4 as lo_multifam_lag38, b.lo_multifam_lag9/4 as lo_multifam_lag39

from lo3 as a left join lo.hmda_mf_lo_1990_2016 as b
on a.rssd_id=b.rssd_id and a.rankdate=b.rankdate order by a.rssd_id, a.rankdate;

create table lo4b as select a.*,
b.lo_multifam_t/4 as lo_multifam_t, b.lo_multifam_t/4 as lo_multifam_lag1, b.lo_multifam_t/4 as lo_multifam_lag2, b.lo_multifam_lag1/4 as lo_multifam_lag3, 
b.lo_multifam_lag1/4 as lo_multifam_lag4, b.lo_multifam_lag1/4 as lo_multifam_lag5, b.lo_multifam_lag1/4 as lo_multifam_lag6, b.lo_multifam_lag2/4 as lo_multifam_lag7, 
b.lo_multifam_lag2/4 as lo_multifam_lag8, b.lo_multifam_lag2/4 as lo_multifam_lag9, b.lo_multifam_lag2/4 as lo_multifam_lag10, b.lo_multifam_lag3/4 as lo_multifam_lag11, 
b.lo_multifam_lag3/4 as lo_multifam_lag12, b.lo_multifam_lag3/4 as lo_multifam_lag13, b.lo_multifam_lag3/4 as lo_multifam_lag14, b.lo_multifam_lag4/4 as lo_multifam_lag15, 
b.lo_multifam_lag4/4 as lo_multifam_lag16, b.lo_multifam_lag4/4 as lo_multifam_lag17, b.lo_multifam_lag4/4 as lo_multifam_lag18, b.lo_multifam_lag5/4 as lo_multifam_lag19, 
b.lo_multifam_lag5/4 as lo_multifam_lag20, b.lo_multifam_lag5/4 as lo_multifam_lag21, b.lo_multifam_lag5/4 as lo_multifam_lag22, b.lo_multifam_lag6/4 as lo_multifam_lag23, 
b.lo_multifam_lag6/4 as lo_multifam_lag24, b.lo_multifam_lag6/4 as lo_multifam_lag25, b.lo_multifam_lag6/4 as lo_multifam_lag26, b.lo_multifam_lag7/4 as lo_multifam_lag27, 
b.lo_multifam_lag7/4 as lo_multifam_lag28, b.lo_multifam_lag7/4 as lo_multifam_lag29, b.lo_multifam_lag7/4 as lo_multifam_lag30, b.lo_multifam_lag8/4 as lo_multifam_lag31, 
b.lo_multifam_lag8/4 as lo_multifam_lag32, b.lo_multifam_lag8/4 as lo_multifam_lag33, b.lo_multifam_lag8/4 as lo_multifam_lag34, b.lo_multifam_lag9/4 as lo_multifam_lag35, 
b.lo_multifam_lag9/4 as lo_multifam_lag36, b.lo_multifam_lag9/4 as lo_multifam_lag37, b.lo_multifam_lag9/4 as lo_multifam_lag38, b.lo_multifam_lag10/4 as lo_multifam_lag39

from lo3 as a left join lo.hmda_mf_lo_1990_2016 as b
on a.rssd_id=b.rssd_id and a.rankdate+1=b.rankdate order by a.rssd_id, a.rankdate;

create table lo4c as select a.*,
b.lo_multifam_t/4 as lo_multifam_t, b.lo_multifam_t/4 as lo_multifam_lag1, b.lo_multifam_lag1/4 as lo_multifam_lag2, b.lo_multifam_lag1/4 as lo_multifam_lag3, 
b.lo_multifam_lag1/4 as lo_multifam_lag4, b.lo_multifam_lag1/4 as lo_multifam_lag5, b.lo_multifam_lag2/4 as lo_multifam_lag6, b.lo_multifam_lag2/4 as lo_multifam_lag7, 
b.lo_multifam_lag2/4 as lo_multifam_lag8, b.lo_multifam_lag2/4 as lo_multifam_lag9, b.lo_multifam_lag3/4 as lo_multifam_lag10, b.lo_multifam_lag3/4 as lo_multifam_lag11, 
b.lo_multifam_lag3/4 as lo_multifam_lag12, b.lo_multifam_lag3/4 as lo_multifam_lag13, b.lo_multifam_lag4/4 as lo_multifam_lag14, b.lo_multifam_lag4/4 as lo_multifam_lag15, 
b.lo_multifam_lag4/4 as lo_multifam_lag16, b.lo_multifam_lag4/4 as lo_multifam_lag17, b.lo_multifam_lag5/4 as lo_multifam_lag18, b.lo_multifam_lag5/4 as lo_multifam_lag19, 
b.lo_multifam_lag5/4 as lo_multifam_lag20, b.lo_multifam_lag5/4 as lo_multifam_lag21, b.lo_multifam_lag6/4 as lo_multifam_lag22, b.lo_multifam_lag6/4 as lo_multifam_lag23, 
b.lo_multifam_lag6/4 as lo_multifam_lag24, b.lo_multifam_lag6/4 as lo_multifam_lag25, b.lo_multifam_lag7/4 as lo_multifam_lag26, b.lo_multifam_lag7/4 as lo_multifam_lag27, 
b.lo_multifam_lag7/4 as lo_multifam_lag28, b.lo_multifam_lag7/4 as lo_multifam_lag29, b.lo_multifam_lag8/4 as lo_multifam_lag30, b.lo_multifam_lag8/4 as lo_multifam_lag31, 
b.lo_multifam_lag8/4 as lo_multifam_lag32, b.lo_multifam_lag8/4 as lo_multifam_lag33, b.lo_multifam_lag9/4 as lo_multifam_lag34, b.lo_multifam_lag9/4 as lo_multifam_lag35, 
b.lo_multifam_lag9/4 as lo_multifam_lag36, b.lo_multifam_lag9/4 as lo_multifam_lag37, b.lo_multifam_lag10/4 as lo_multifam_lag38, b.lo_multifam_lag10/4 as lo_multifam_lag39

from lo3 as a left join lo.hmda_mf_lo_1990_2016 as b
on a.rssd_id=b.rssd_id and a.rankdate+2=b.rankdate order by a.rssd_id, a.rankdate;

create table lo4d as select a.*,
b.lo_multifam_t/4 as lo_multifam_t, b.lo_multifam_lag1/4 as lo_multifam_lag1, b.lo_multifam_lag1/4 as lo_multifam_lag2, b.lo_multifam_lag1/4 as lo_multifam_lag3, 
b.lo_multifam_lag1/4 as lo_multifam_lag4, b.lo_multifam_lag2/4 as lo_multifam_lag5, b.lo_multifam_lag2/4 as lo_multifam_lag6, b.lo_multifam_lag2/4 as lo_multifam_lag7, 
b.lo_multifam_lag2/4 as lo_multifam_lag8, b.lo_multifam_lag3/4 as lo_multifam_lag9, b.lo_multifam_lag3/4 as lo_multifam_lag10, b.lo_multifam_lag3/4 as lo_multifam_lag11, 
b.lo_multifam_lag3/4 as lo_multifam_lag12, b.lo_multifam_lag4/4 as lo_multifam_lag13, b.lo_multifam_lag4/4 as lo_multifam_lag14, b.lo_multifam_lag4/4 as lo_multifam_lag15, 
b.lo_multifam_lag4/4 as lo_multifam_lag16, b.lo_multifam_lag5/4 as lo_multifam_lag17, b.lo_multifam_lag5/4 as lo_multifam_lag18, b.lo_multifam_lag5/4 as lo_multifam_lag19, 
b.lo_multifam_lag5/4 as lo_multifam_lag20, b.lo_multifam_lag6/4 as lo_multifam_lag21, b.lo_multifam_lag6/4 as lo_multifam_lag22, b.lo_multifam_lag6/4 as lo_multifam_lag23, 
b.lo_multifam_lag6/4 as lo_multifam_lag24, b.lo_multifam_lag7/4 as lo_multifam_lag25, b.lo_multifam_lag7/4 as lo_multifam_lag26, b.lo_multifam_lag7/4 as lo_multifam_lag27, 
b.lo_multifam_lag7/4 as lo_multifam_lag28, b.lo_multifam_lag8/4 as lo_multifam_lag29, b.lo_multifam_lag8/4 as lo_multifam_lag30, b.lo_multifam_lag8/4 as lo_multifam_lag31, 
b.lo_multifam_lag8/4 as lo_multifam_lag32, b.lo_multifam_lag9/4 as lo_multifam_lag33, b.lo_multifam_lag9/4 as lo_multifam_lag34, b.lo_multifam_lag9/4 as lo_multifam_lag35, 
b.lo_multifam_lag9/4 as lo_multifam_lag36, b.lo_multifam_lag10/4 as lo_multifam_lag37, b.lo_multifam_lag10/4 as lo_multifam_lag38, b.lo_multifam_lag10/4 as lo_multifam_lag39

from lo3 as a left join lo.hmda_mf_lo_1990_2016 as b
on a.rssd_id=b.rssd_id and a.rankdate+3=b.rankdate order by a.rssd_id, a.rankdate;
quit;

data lo4_q4;
set lo4a;
if lo_multifam_t=. then delete;
run;
data lo4_q3;
set lo4b;
if lo_multifam_t=. then delete;
run;
data lo4_q2;
set lo4c;
if lo_multifam_t=. then delete;
run;
data lo4_q1;
set lo4d;
if lo_multifam_t=. then delete;
run;

data lo4;
set lo4_q4 lo4_q3 lo4_q2 lo4_q1;
run;
proc sort data=lo4;
by rssd_id rankdate;
quit;

proc sql;
create table lo5 as select a.*,
b.est_lo_t as commandfarm_lo_t,
b.est_lo_lag1 as commandfarm_lo_lag1,
b.est_lo_lag2 as commandfarm_lo_lag2,
b.est_lo_lag3 as commandfarm_lo_lag3,
b.est_lo_lag4 as commandfarm_lo_lag4,
b.est_lo_lag5 as commandfarm_lo_lag5,
b.est_lo_lag6 as commandfarm_lo_lag6,
b.est_lo_lag7 as commandfarm_lo_lag7,
b.est_lo_lag8 as commandfarm_lo_lag8,
b.est_lo_lag9 as commandfarm_lo_lag9,
b.est_lo_lag10 as commandfarm_lo_lag10,
b.est_lo_lag11 as commandfarm_lo_lag11,
b.est_lo_lag12 as commandfarm_lo_lag12,
b.est_lo_lag13 as commandfarm_lo_lag13,
b.est_lo_lag14 as commandfarm_lo_lag14,
b.est_lo_lag15 as commandfarm_lo_lag15,
b.est_lo_lag16 as commandfarm_lo_lag16,
b.est_lo_lag17 as commandfarm_lo_lag17,
b.est_lo_lag18 as commandfarm_lo_lag18,
b.est_lo_lag19 as commandfarm_lo_lag19,
b.est_lo_lag20 as commandfarm_lo_lag20,
b.est_lo_lag21 as commandfarm_lo_lag21,
b.est_lo_lag22 as commandfarm_lo_lag22,
b.est_lo_lag23 as commandfarm_lo_lag23,
b.est_lo_lag24 as commandfarm_lo_lag24,
b.est_lo_lag25 as commandfarm_lo_lag25,
b.est_lo_lag26 as commandfarm_lo_lag26,
b.est_lo_lag27 as commandfarm_lo_lag27,
b.est_lo_lag28 as commandfarm_lo_lag28,
b.est_lo_lag29 as commandfarm_lo_lag29,
b.est_lo_lag30 as commandfarm_lo_lag30,
b.est_lo_lag31 as commandfarm_lo_lag31,
b.est_lo_lag32 as commandfarm_lo_lag32,
b.est_lo_lag33 as commandfarm_lo_lag33,
b.est_lo_lag34 as commandfarm_lo_lag34,
b.est_lo_lag35 as commandfarm_lo_lag35,
b.est_lo_lag36 as commandfarm_lo_lag36,
b.est_lo_lag37 as commandfarm_lo_lag37,
b.est_lo_lag38 as commandfarm_lo_lag38,
b.est_lo_lag39 as commandfarm_lo_lag39
from lo4 as a left join lo.lo_commandfarm_1990_2016 as b
on a.rssd_id=b.rssd_id and a.rankdate=b.rankdate order by a.rssd_id, a.rankdate;
quit;

data lo6; set lo5;
lo_nonsfre_t = lo_multifam_t+commandfarm_lo_t;
lo_nonsfre_lag1 = lo_multifam_lag1+commandfarm_lo_lag1;
lo_nonsfre_lag1=lo_multifam_lag1+commandfarm_lo_lag1;
lo_nonsfre_lag2=lo_multifam_lag2+commandfarm_lo_lag2;
lo_nonsfre_lag3=lo_multifam_lag3+commandfarm_lo_lag3;
lo_nonsfre_lag4=lo_multifam_lag4+commandfarm_lo_lag4;
lo_nonsfre_lag5=lo_multifam_lag5+commandfarm_lo_lag5;
lo_nonsfre_lag6=lo_multifam_lag6+commandfarm_lo_lag6;
lo_nonsfre_lag7=lo_multifam_lag7+commandfarm_lo_lag7;
lo_nonsfre_lag8=lo_multifam_lag8+commandfarm_lo_lag8;
lo_nonsfre_lag9=lo_multifam_lag9+commandfarm_lo_lag9;
lo_nonsfre_lag10=lo_multifam_lag10+commandfarm_lo_lag10;
lo_nonsfre_lag11=lo_multifam_lag11+commandfarm_lo_lag11;
lo_nonsfre_lag12=lo_multifam_lag12+commandfarm_lo_lag12;
lo_nonsfre_lag13=lo_multifam_lag13+commandfarm_lo_lag13;
lo_nonsfre_lag14=lo_multifam_lag14+commandfarm_lo_lag14;
lo_nonsfre_lag15=lo_multifam_lag15+commandfarm_lo_lag15;
lo_nonsfre_lag16=lo_multifam_lag16+commandfarm_lo_lag16;
lo_nonsfre_lag17=lo_multifam_lag17+commandfarm_lo_lag17;
lo_nonsfre_lag18=lo_multifam_lag18+commandfarm_lo_lag18;
lo_nonsfre_lag19=lo_multifam_lag19+commandfarm_lo_lag19;
lo_nonsfre_lag20=lo_multifam_lag20+commandfarm_lo_lag20;
lo_nonsfre_lag21=lo_multifam_lag21+commandfarm_lo_lag21;
lo_nonsfre_lag22=lo_multifam_lag22+commandfarm_lo_lag22;
lo_nonsfre_lag23=lo_multifam_lag23+commandfarm_lo_lag23;
lo_nonsfre_lag24=lo_multifam_lag24+commandfarm_lo_lag24;
lo_nonsfre_lag25=lo_multifam_lag25+commandfarm_lo_lag25;
lo_nonsfre_lag26=lo_multifam_lag26+commandfarm_lo_lag26;
lo_nonsfre_lag27=lo_multifam_lag27+commandfarm_lo_lag27;
lo_nonsfre_lag28=lo_multifam_lag28+commandfarm_lo_lag28;
lo_nonsfre_lag29=lo_multifam_lag29+commandfarm_lo_lag29;
lo_nonsfre_lag30=lo_multifam_lag30+commandfarm_lo_lag30;
lo_nonsfre_lag31=lo_multifam_lag31+commandfarm_lo_lag31;
lo_nonsfre_lag32=lo_multifam_lag32+commandfarm_lo_lag32;
lo_nonsfre_lag33=lo_multifam_lag33+commandfarm_lo_lag33;
lo_nonsfre_lag34=lo_multifam_lag34+commandfarm_lo_lag34;
lo_nonsfre_lag35=lo_multifam_lag35+commandfarm_lo_lag35;
lo_nonsfre_lag36=lo_multifam_lag36+commandfarm_lo_lag36;
lo_nonsfre_lag37=lo_multifam_lag37+commandfarm_lo_lag37;
lo_nonsfre_lag38=lo_multifam_lag38+commandfarm_lo_lag38;
lo_nonsfre_lag39=lo_multifam_lag39+commandfarm_lo_lag39;
run;

data lo7 (keep = snlkey name rssd_id snlyear snlqtr rankdate
lo_nonsfre_t lo_nonsfre_lag1 lo_nonsfre_lag2 lo_nonsfre_lag3 lo_nonsfre_lag4 lo_nonsfre_lag5 lo_nonsfre_lag6
lo_nonsfre_lag7 lo_nonsfre_lag8 lo_nonsfre_lag9 lo_nonsfre_lag10 lo_nonsfre_lag11 lo_nonsfre_lag12 lo_nonsfre_lag13
lo_nonsfre_lag14 lo_nonsfre_lag15 lo_nonsfre_lag16 lo_nonsfre_lag17 lo_nonsfre_lag18 lo_nonsfre_lag19
lo_nonsfre_lag20 lo_nonsfre_lag21 lo_nonsfre_lag22 lo_nonsfre_lag23 lo_nonsfre_lag24 lo_nonsfre_lag25 lo_nonsfre_lag26
lo_nonsfre_lag27 lo_nonsfre_lag28 lo_nonsfre_lag29 lo_nonsfre_lag30 lo_nonsfre_lag31 lo_nonsfre_lag32 lo_nonsfre_lag33
lo_nonsfre_lag34 lo_nonsfre_lag35 lo_nonsfre_lag36 lo_nonsfre_lag37 lo_nonsfre_lag38 lo_nonsfre_lag39);
set lo6; run;

proc sql;
create table ecl_nonsfre1 as select a.snlkey, a.snlyear, a.snlqtr, a.name, a.reg_id, a.rankdate, a.date, a.co_mf+a.co_cre+a.co_farm as co_nonsfre, b.*
from box.all_co_bytype_1990_2018 a left join lo7 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.snlkey, a.rankdate;
quit;

*Create dataset to estimate rolling regressions for ECL estimation;
data ecl_nonsfre2;
set ecl_nonsfre1;
if lo_nonsfre_lag1=. then delete;
if lo_nonsfre_lag2=. then delete;
if lo_nonsfre_lag3=. then delete;
if lo_nonsfre_lag4=. then delete;
if lo_nonsfre_lag5=. then delete;
if lo_nonsfre_lag6=. then delete;
if lo_nonsfre_lag7=. then delete;
if lo_nonsfre_lag8=. then delete;
if lo_nonsfre_lag9=. then delete;
if lo_nonsfre_lag10=. then delete;
if lo_nonsfre_lag11=. then delete;
if lo_nonsfre_lag12=. then delete;
if lo_nonsfre_lag13=. then delete;
if lo_nonsfre_lag14=. then delete;
if lo_nonsfre_lag15=. then delete;
if lo_nonsfre_lag16=. then delete;
if lo_nonsfre_lag17=. then delete;
if lo_nonsfre_lag18=. then delete;
if lo_nonsfre_lag19=. then delete;
if lo_nonsfre_lag20=. then delete;
run;

*TRANSFER TO LO FOLDER;
data lo.ecl_nonsfre2_20lags; set ecl_nonsfre2; run;
*Then.........;
*TRANSFER TO WRDS SERVER VIA FTP SITE;
*THEN.........;

rsubmit;
data ecl_nonsfre2; set bw2.ecl_nonsfre2_20lags; run;
endrsubmit;


rsubmit;
/*~~~~~~~~~~~~~~~~~~~~~~~~*/
/*ECL MACRO*/
/*~~~~~~~~~~~~~~~~~~~~~~~~*/

*Rolling regressions macro;
%macro ecl_nonsfre_001(first_rankdate, last_rankdate, inset=, roll1=,roll2=, roll3=, roll4=, roll5=, roll6=, roll7=, roll8=);

data &roll1;
set &inset;
if rankdate not in (&first_rankdate:&last_rankdate) then delete;
run;

proc sql;
create table &roll2 as select a.*, count(a.snlkey) as obs
from &roll1 as a
group by snlkey
order by snlkey, rankdate;
quit;

data &roll3;
set &roll2;
if obs < 40 then delete;
run;

ods graphics off;
ods exclude all;
/*1 lag*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1;
bounds b1 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_1 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_1 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 1 as model, 0.001 as param
from roll4_1 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*2 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2;
bounds b1 >= 0, b2 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_2 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_2 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 2 as model, 0.001 as param
from roll4_2 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*3 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3;
bounds b1 >= 0, b2 >= 0, b3 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_3 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_3 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 3 as model, 0.001 as param
from roll4_3 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*4 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_4 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_4 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 4 as model, 0.001 as param
from roll4_4 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*5 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_5 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_5 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 5 as model, 0.001 as param
from roll4_5 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*6 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_6 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_6 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 6 as model, 0.001 as param
from roll4_6 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*7 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_7 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_7 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 7 as model, 0.001 as param
from roll4_7 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*8 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_8 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_8 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 8 as model, 0.001 as param
from roll4_8 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*9 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_9 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_9 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 9 as model, 0.001 as param
from roll4_9 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*10 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_10 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_10 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 10 as model, 0.001 as param
from roll4_10 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*11 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001 b11 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10 + b11*lo_nonsfre_lag11;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_11 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_11 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 11 as model, 0.001 as param
from roll4_11 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*12 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001 b11 = 0.001 b12 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10 + b11*lo_nonsfre_lag11 + b12*lo_nonsfre_lag12 ;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_12 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_12 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 12 as model, 0.001 as param
from roll4_12 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*13 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001 b11 = 0.001 b12 = 0.001 b13 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10 + b11*lo_nonsfre_lag11 + b12*lo_nonsfre_lag12 + b13*lo_nonsfre_lag13;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_13 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_13 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 13 as model, 0.001 as param
from roll4_13 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*14 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001 b11 = 0.001 b12 = 0.001 b13 = 0.001 b14 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10 + b11*lo_nonsfre_lag11 + b12*lo_nonsfre_lag12 + b13*lo_nonsfre_lag13 + b14*lo_nonsfre_lag14;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_14 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_14 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 14 as model, 0.001 as param
from roll4_14 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*15 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001 b11 = 0.001 b12 = 0.001 b13 = 0.001 b14 = 0.001 b15 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10 + b11*lo_nonsfre_lag11 + b12*lo_nonsfre_lag12 + b13*lo_nonsfre_lag13 + b14*lo_nonsfre_lag14 + b15*lo_nonsfre_lag15;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_15 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_15 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 15 as model, 0.001 as param
from roll4_15 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*16 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001 b11 = 0.001 b12 = 0.001 b13 = 0.001 b14 = 0.001 b15 = 0.001 b16 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10 + b11*lo_nonsfre_lag11 + b12*lo_nonsfre_lag12 + b13*lo_nonsfre_lag13 + b14*lo_nonsfre_lag14 + b15*lo_nonsfre_lag15 + b16*lo_nonsfre_lag16;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_16 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_16 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 16 as model, 0.001 as param
from roll4_16 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*17 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001 b11 = 0.001 b12 = 0.001 b13 = 0.001 b14 = 0.001 b15 = 0.001 b16 = 0.001 b17 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10 + b11*lo_nonsfre_lag11 + b12*lo_nonsfre_lag12 + b13*lo_nonsfre_lag13 + b14*lo_nonsfre_lag14 + b15*lo_nonsfre_lag15 + b16*lo_nonsfre_lag16 + b17*lo_nonsfre_lag17;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_17 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_17 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 17 as model, 0.001 as param
from roll4_17 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*18 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001 b11 = 0.001 b12 = 0.001 b13 = 0.001 b14 = 0.001 b15 = 0.001 b16 = 0.001 b17 = 0.001 b18 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10 + b11*lo_nonsfre_lag11 + b12*lo_nonsfre_lag12 + b13*lo_nonsfre_lag13 + b14*lo_nonsfre_lag14 + b15*lo_nonsfre_lag15 + b16*lo_nonsfre_lag16 + b17*lo_nonsfre_lag17 + b18*lo_nonsfre_lag18;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_18 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_18 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 18 as model, 0.001 as param
from roll4_18 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*19 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001 b11 = 0.001 b12 = 0.001 b13 = 0.001 b14 = 0.001 b15 = 0.001 b16 = 0.001 b17 = 0.001 b18 = 0.001 b19 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10 + b11*lo_nonsfre_lag11 + b12*lo_nonsfre_lag12 + b13*lo_nonsfre_lag13 + b14*lo_nonsfre_lag14 + b15*lo_nonsfre_lag15 + b16*lo_nonsfre_lag16 + b17*lo_nonsfre_lag17 + b18*lo_nonsfre_lag18 + b19*lo_nonsfre_lag19;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_19 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_19 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 19 as model, 0.001 as param
from roll4_19 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*20 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.001 b2 = 0.001 b3 = 0.001 b4 = 0.001 b5 = 0.001 b6 = 0.001 b7 = 0.001 b8 = 0.001 b9 = 0.001 b10 = 0.001 b11 = 0.001 b12 = 0.001 b13 = 0.001 b14 = 0.001 b15 = 0.001 b16 = 0.001 b17 = 0.001 b18 = 0.001 b19 = 0.001 b20 = 0.001;
model co_nonsfre = b1*lo_nonsfre_lag1 + b2*lo_nonsfre_lag2 + b3*lo_nonsfre_lag3 + b4*lo_nonsfre_lag4 + b5*lo_nonsfre_lag5 + b6*lo_nonsfre_lag6 + b7*lo_nonsfre_lag7 + b8*lo_nonsfre_lag8 + b9*lo_nonsfre_lag9 + b10*lo_nonsfre_lag10 + b11*lo_nonsfre_lag11 + b12*lo_nonsfre_lag12 + b13*lo_nonsfre_lag13 + b14*lo_nonsfre_lag14 + b15*lo_nonsfre_lag15 + b16*lo_nonsfre_lag16 + b17*lo_nonsfre_lag17 + b18*lo_nonsfre_lag18 + b19*lo_nonsfre_lag19 + b20*lo_nonsfre_lag20;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_20 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_20 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 20 as model, 0.001 as param
from roll4_20 a left join residual b
on a.snlkey=b.snlkey;
quit;

ods exclude none;

*Retain model with highest adjusted r-sq;
data &roll4;
set roll4_1 roll4_2 roll4_3 roll4_4 roll4_5 roll4_6 roll4_7 roll4_8
roll4_9 roll4_10 roll4_11 roll4_12 roll4_13 roll4_14 roll4_15 roll4_16
roll4_17 roll4_18 roll4_19 roll4_20;
run;

proc sql;
create table &roll5 as select *, max(pseudo_rsq) as max_pseudo_rsq
from &roll4
group by snlkey order by snlkey, rankdate;
quit;
data &roll6 (drop=max_pseudo_rsq);
set &roll5;
if pseudo_rsq ne max_pseudo_rsq then delete;
run;

proc sort data=&roll6; by snlkey rankdate model ; run;
proc sort data=&roll6 nodupkey; by snlkey rankdate; run;

dm 'clear log';
%mend;
endrsubmit;

*Run estimation macro;
/*ROLLING REGRESSIONS FOR ECL ESTIMATION: RUN AFTER RUNNING ECL MACRO*/
rsubmit; *Macro 2016Q4;
%ecl_nonsfre_001(69, 108, inset=ecl_nonsfre2, roll1=Q42016_1 ,roll2=Q42016_2, roll3=Q42016_3, roll4=Q42016_4, roll5=Q42016_5, roll6=Q42016_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2016Q3;
%ecl_nonsfre_001(68, 107, inset=ecl_nonsfre2, roll1=Q32016_1 ,roll2=Q32016_2, roll3=Q32016_3, roll4=Q32016_4, roll5=Q32016_5, roll6=Q32016_nonsfre);
endrsubmit;dm 'clear log';
rsubmit; *Macro 2016Q2;
%ecl_nonsfre_001(67, 106, inset=ecl_nonsfre2, roll1=Q22016_1 ,roll2=Q22016_2, roll3=Q22016_3, roll4=Q22016_4, roll5=Q22016_5, roll6=Q22016_nonsfre);
endrsubmit;dm 'clear log';
rsubmit; *Macro 2016Q1;
%ecl_nonsfre_001(66, 105, inset=ecl_nonsfre2, roll1=Q12016_1 ,roll2=Q12016_2, roll3=Q12016_3, roll4=Q12016_4, roll5=Q12016_5, roll6=Q12016_nonsfre);
endrsubmit;dm 'clear log';
rsubmit; *Macro 2015Q4;
%ecl_nonsfre_001(65, 104, inset=ecl_nonsfre2, roll1=Q42015_1 ,roll2=Q42015_2, roll3=Q42015_3, roll4=Q42015_4, roll5=Q42015_5, roll6=Q42015_nonsfre);
endrsubmit;dm 'clear log';
rsubmit; *Macro 2015Q3;
%ecl_nonsfre_001(64, 103, inset=ecl_nonsfre2, roll1=Q32015_1 ,roll2=Q32015_2, roll3=Q32015_3, roll4=Q32015_4, roll5=Q32015_5, roll6=Q32015_nonsfre);
endrsubmit;dm 'clear log';
rsubmit; *Macro 2015Q2;
%ecl_nonsfre_001(63, 102, inset=ecl_nonsfre2, roll1=Q22015_1 ,roll2=Q22015_2, roll3=Q22015_3, roll4=Q22015_4, roll5=Q22015_5, roll6=Q22015_nonsfre);
endrsubmit;dm 'clear log';
rsubmit; *Macro 2015Q1;
%ecl_nonsfre_001(62, 101, inset=ecl_nonsfre2, roll1=Q12015_1 ,roll2=Q12015_2, roll3=Q12015_3, roll4=Q12015_4, roll5=Q12015_5, roll6=Q12015_nonsfre);
endrsubmit;dm 'clear log';
rsubmit; *Macro 2014Q4;
%ecl_nonsfre_001(61, 100, inset=ecl_nonsfre2, roll1=Q42014_1 ,roll2=Q42014_2, roll3=Q42014_3, roll4=Q42014_4, roll5=Q42014_5, roll6=Q42014_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q3;
%ecl_nonsfre_001(60, 99, inset=ecl_nonsfre2, roll1=Q32014_1 ,roll2=Q32014_2, roll3=Q32014_3, roll4=Q32014_4, roll5=Q32014_5, roll6=Q32014_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q2;
%ecl_nonsfre_001(59, 98, inset=ecl_nonsfre2, roll1=Q22014_1 ,roll2=Q22014_2, roll3=Q22014_3, roll4=Q22014_4, roll5=Q22014_5, roll6=Q22014_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q1;
%ecl_nonsfre_001(58, 97, inset=ecl_nonsfre2, roll1=Q12014_1 ,roll2=Q12014_2, roll3=Q12014_3, roll4=Q12014_4, roll5=Q12014_5, roll6=Q12014_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q4;
%ecl_nonsfre_001(57, 96, inset=ecl_nonsfre2, roll1=Q42013_1 ,roll2=Q42013_2, roll3=Q42013_3, roll4=Q42013_4, roll5=Q42013_5, roll6=Q42013_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q3;
%ecl_nonsfre_001(56, 95, inset=ecl_nonsfre2, roll1=Q32013_1 ,roll2=Q32013_2, roll3=Q32013_3, roll4=Q32013_4, roll5=Q32013_5, roll6=Q32013_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q2;
%ecl_nonsfre_001(55, 94, inset=ecl_nonsfre2, roll1=Q22013_1 ,roll2=Q22013_2, roll3=Q22013_3, roll4=Q22013_4, roll5=Q22013_5, roll6=Q22013_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q1;
%ecl_nonsfre_001(54, 93, inset=ecl_nonsfre2, roll1=Q12013_1 ,roll2=Q12013_2, roll3=Q12013_3, roll4=Q12013_4, roll5=Q12013_5, roll6=Q12013_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q4;
%ecl_nonsfre_001(53, 92, inset=ecl_nonsfre2, roll1=Q42012_1 ,roll2=Q42012_2, roll3=Q42012_3, roll4=Q42012_4, roll5=Q42012_5, roll6=Q42012_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q3;
%ecl_nonsfre_001(52, 91, inset=ecl_nonsfre2, roll1=Q32012_1 ,roll2=Q32012_2, roll3=Q32012_3, roll4=Q32012_4, roll5=Q32012_5, roll6=Q32012_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q2;
%ecl_nonsfre_001(51, 90, inset=ecl_nonsfre2, roll1=Q22012_1 ,roll2=Q22012_2, roll3=Q22012_3, roll4=Q22012_4, roll5=Q22012_5, roll6=Q22012_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q1;
%ecl_nonsfre_001(50, 89, inset=ecl_nonsfre2, roll1=Q12012_1 ,roll2=Q12012_2, roll3=Q12012_3, roll4=Q12012_4, roll5=Q12012_5, roll6=Q12012_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q4;
%ecl_nonsfre_001(49, 88, inset=ecl_nonsfre2, roll1=Q42011_1 ,roll2=Q42011_2, roll3=Q42011_3, roll4=Q42011_4, roll5=Q42011_5, roll6=Q42011_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q3;
%ecl_nonsfre_001(48, 87, inset=ecl_nonsfre2, roll1=Q32011_1 ,roll2=Q32011_2, roll3=Q32011_3, roll4=Q32011_4, roll5=Q32011_5, roll6=Q32011_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q2;
%ecl_nonsfre_001(47, 86, inset=ecl_nonsfre2, roll1=Q22011_1 ,roll2=Q22011_2, roll3=Q22011_3, roll4=Q22011_4, roll5=Q22011_5, roll6=Q22011_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q1;
%ecl_nonsfre_001(46, 85, inset=ecl_nonsfre2, roll1=Q12011_1 ,roll2=Q12011_2, roll3=Q12011_3, roll4=Q12011_4, roll5=Q12011_5, roll6=Q12011_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q2;
%ecl_nonsfre_001(47, 86, inset=ecl_nonsfre2, roll1=Q22011_1 ,roll2=Q22011_2, roll3=Q22011_3, roll4=Q22011_4, roll5=Q22011_5, roll6=Q22011_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q4;
%ecl_nonsfre_001(45, 84, inset=ecl_nonsfre2, roll1=Q42010_1 ,roll2=Q42010_2, roll3=Q42010_3, roll4=Q42010_4, roll5=Q42010_5, roll6=Q42010_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q3;
%ecl_nonsfre_001(44, 83, inset=ecl_nonsfre2, roll1=Q32010_1 ,roll2=Q32010_2, roll3=Q32010_3, roll4=Q32010_4, roll5=Q32010_5, roll6=Q32010_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q2;
%ecl_nonsfre_001(43, 82, inset=ecl_nonsfre2, roll1=Q22010_1 ,roll2=Q22010_2, roll3=Q22010_3, roll4=Q22010_4, roll5=Q22010_5, roll6=Q22010_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q1;
%ecl_nonsfre_001(42, 81, inset=ecl_nonsfre2, roll1=Q12010_1 ,roll2=Q12010_2, roll3=Q12010_3, roll4=Q12010_4, roll5=Q12010_5, roll6=Q12010_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q4;
%ecl_nonsfre_001(41, 80, inset=ecl_nonsfre2, roll1=Q42009_1 ,roll2=Q42009_2, roll3=Q42009_3, roll4=Q42009_4, roll5=Q42009_5, roll6=Q42009_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q3;
%ecl_nonsfre_001(40, 79, inset=ecl_nonsfre2, roll1=Q32009_1 ,roll2=Q32009_2, roll3=Q32009_3, roll4=Q32009_4, roll5=Q32009_5, roll6=Q32009_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q2;
%ecl_nonsfre_001(39, 78, inset=ecl_nonsfre2, roll1=Q22009_1 ,roll2=Q22009_2, roll3=Q22009_3, roll4=Q22009_4, roll5=Q22009_5, roll6=Q22009_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q1;
%ecl_nonsfre_001(38, 77, inset=ecl_nonsfre2, roll1=Q12009_1 ,roll2=Q12009_2, roll3=Q12009_3, roll4=Q12009_4, roll5=Q12009_5, roll6=Q12009_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q4;
%ecl_nonsfre_001(37, 76, inset=ecl_nonsfre2, roll1=Q42008_1 ,roll2=Q42008_2, roll3=Q42008_3, roll4=Q42008_4, roll5=Q42008_5, roll6=Q42008_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q3;
%ecl_nonsfre_001(36, 75, inset=ecl_nonsfre2, roll1=Q32008_1 ,roll2=Q32008_2, roll3=Q32008_3, roll4=Q32008_4, roll5=Q32008_5, roll6=Q32008_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q2;
%ecl_nonsfre_001(35, 74, inset=ecl_nonsfre2, roll1=Q22008_1 ,roll2=Q22008_2, roll3=Q22008_3, roll4=Q22008_4, roll5=Q22008_5, roll6=Q22008_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q1;
%ecl_nonsfre_001(34, 73, inset=ecl_nonsfre2, roll1=Q12008_1 ,roll2=Q12008_2, roll3=Q12008_3, roll4=Q12008_4, roll5=Q12008_5, roll6=Q12008_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q4;
%ecl_nonsfre_001(33, 72, inset=ecl_nonsfre2, roll1=Q42007_1 ,roll2=Q42007_2, roll3=Q42007_3, roll4=Q42007_4, roll5=Q42007_5, roll6=Q42007_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q3;
%ecl_nonsfre_001(32, 71, inset=ecl_nonsfre2, roll1=Q32007_1 ,roll2=Q32007_2, roll3=Q32007_3, roll4=Q32007_4, roll5=Q32007_5, roll6=Q32007_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q2;
%ecl_nonsfre_001(31, 70, inset=ecl_nonsfre2, roll1=Q22007_1 ,roll2=Q22007_2, roll3=Q22007_3, roll4=Q22007_4, roll5=Q22007_5, roll6=Q22007_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q1;
%ecl_nonsfre_001(30, 69, inset=ecl_nonsfre2, roll1=Q12007_1 ,roll2=Q12007_2, roll3=Q12007_3, roll4=Q12007_4, roll5=Q12007_5, roll6=Q12007_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q4;
%ecl_nonsfre_001(29, 68, inset=ecl_nonsfre2, roll1=Q42006_1 ,roll2=Q42006_2, roll3=Q42006_3, roll4=Q42006_4, roll5=Q42006_5, roll6=Q42006_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q3;
%ecl_nonsfre_001(28, 67, inset=ecl_nonsfre2, roll1=Q32006_1 ,roll2=Q32006_2, roll3=Q32006_3, roll4=Q32006_4, roll5=Q32006_5, roll6=Q32006_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q2;
%ecl_nonsfre_001(27, 66, inset=ecl_nonsfre2, roll1=Q22006_1 ,roll2=Q22006_2, roll3=Q22006_3, roll4=Q22006_4, roll5=Q22006_5, roll6=Q22006_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q1;
%ecl_nonsfre_001(26, 65, inset=ecl_nonsfre2, roll1=Q12006_1 ,roll2=Q12006_2, roll3=Q12006_3, roll4=Q12006_4, roll5=Q12006_5, roll6=Q12006_nonsfre);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2005Q4;
%ecl_nonsfre_001(25, 64, inset=ecl_nonsfre2, roll1=Q42005_1 ,roll2=Q42005_2, roll3=Q42005_3, roll4=Q42005_4, roll5=Q42005_5, roll6=Q42005_nonsfre);
endrsubmit; dm 'clear log';

rsubmit;
*Aggregate ECL estimates into one file;
data ecl_nonsfre3;
set 
Q42005_nonsfre
Q12006_nonsfre
Q22006_nonsfre
Q32006_nonsfre
Q42006_nonsfre
Q12007_nonsfre
Q22007_nonsfre
Q32007_nonsfre
Q42007_nonsfre
Q12008_nonsfre
Q22008_nonsfre
Q32008_nonsfre
Q42008_nonsfre
Q12009_nonsfre
Q22009_nonsfre
Q32009_nonsfre
Q42009_nonsfre
Q12010_nonsfre
Q22010_nonsfre
Q32010_nonsfre
Q42010_nonsfre
Q12011_nonsfre
Q22011_nonsfre
Q32011_nonsfre
Q42011_nonsfre
Q12012_nonsfre
Q22012_nonsfre
Q32012_nonsfre
Q42012_nonsfre
Q12013_nonsfre
Q22013_nonsfre
Q32013_nonsfre
Q42013_nonsfre
Q12014_nonsfre
Q22014_nonsfre
Q32014_nonsfre
Q42014_nonsfre
Q12015_nonsfre
Q22015_nonsfre
Q32015_nonsfre
Q42015_nonsfre
Q12016_nonsfre
Q22016_nonsfre
Q32016_nonsfre
Q42016_nonsfre;
Run;
proc sort data=ecl_nonsfre3; by snlkey rollreg_rankdate rankdate; run;
data bw2.ecl_nonsfre_res001_20;
set ecl_nonsfre3;
run;
endrsubmit;

