/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below estimates the non-linear model Eq. (5) for single-family real estate loans with 28
		lags of loan originations and an initial parameter of 0.0075 provided for each beta coefficient. 
		The residuals from these models are then collected for use in estimation of Eq. (6).

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';
libname ecl 'C:\Users\pwheeler1\Box Sync\Data Sets\ECL Estimates';

/*Connect to WRDS server*/
%let wrds=wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS compress=yes;
signon username=_prompt_;

/*Create temporary folder 4 as 'bw1' and create a remote directory in my explorer*/
libname bw1 remote '/scratch/tulane/' server=wrds;
rsubmit; libname bw1 '/scratch/tulane/'; endrsubmit;
libname bw2 remote '/home/tulane/pbwheele/' server=wrds;
rsubmit; libname bw2 '/home/tulane/pbwheele/'; endrsubmit;


*Create estimation data set;
*NOTE: HMDA data is ANNUAL not quarterly;
*Interpolate to create quarterly loan originations;
proc sql;
create table lo1a as select a.snlkey, a.name, a.rssd_id, a.rankdate, b.year, b.qtr
from lo.hmda_sf_lo_1990_2016 as a left join box.rankdates as b
on a.rankdate=b.rankdate;

create table lo1b as select a.*, b.rankdate as rankdate_new, b.qtr as qtr_new
from lo1a as a left join box.rankdates as b
on a.year=b.year order by a.rssd_id, b.rankdate;
quit;
data lo1_sfloans (drop=rankdate qtr);
set lo1b;
rename rankdate_new = rankdate qtr_new = qtr;
run;

proc sql;
create table lo2a as select a.*,
b.lo_singlefam_t/4 as lo_singlefam_t, b.lo_singlefam_t/4 as lo_singlefam_lag1, b.lo_singlefam_t/4 as lo_singlefam_lag2, b.lo_singlefam_t/4 as lo_singlefam_lag3,  
b.lo_singlefam_lag1/4 as lo_singlefam_lag4, b.lo_singlefam_lag1/4 as lo_singlefam_lag5, b.lo_singlefam_lag1/4 as lo_singlefam_lag6, b.lo_singlefam_lag1/4 as lo_singlefam_lag7,
b.lo_singlefam_lag2/4 as lo_singlefam_lag8, b.lo_singlefam_lag2/4 as lo_singlefam_lag9, b.lo_singlefam_lag2/4 as lo_singlefam_lag10, b.lo_singlefam_lag2/4 as lo_singlefam_lag11,
b.lo_singlefam_lag3/4 as lo_singlefam_lag12, b.lo_singlefam_lag3/4 as lo_singlefam_lag13, b.lo_singlefam_lag3/4 as lo_singlefam_lag14, b.lo_singlefam_lag3/4 as lo_singlefam_lag15,
b.lo_singlefam_lag4/4 as lo_singlefam_lag16, b.lo_singlefam_lag4/4 as lo_singlefam_lag17, b.lo_singlefam_lag4/4 as lo_singlefam_lag18, b.lo_singlefam_lag4/4 as lo_singlefam_lag19,
b.lo_singlefam_lag5/4 as lo_singlefam_lag20, b.lo_singlefam_lag5/4 as lo_singlefam_lag21, b.lo_singlefam_lag5/4 as lo_singlefam_lag22, b.lo_singlefam_lag5/4 as lo_singlefam_lag23,
b.lo_singlefam_lag6/4 as lo_singlefam_lag24, b.lo_singlefam_lag6/4 as lo_singlefam_lag25, b.lo_singlefam_lag6/4 as lo_singlefam_lag26, b.lo_singlefam_lag6/4 as lo_singlefam_lag27,
b.lo_singlefam_lag7/4 as lo_singlefam_lag28, b.lo_singlefam_lag7/4 as lo_singlefam_lag29, b.lo_singlefam_lag7/4 as lo_singlefam_lag30, b.lo_singlefam_lag7/4 as lo_singlefam_lag31,
b.lo_singlefam_lag8/4 as lo_singlefam_lag32, b.lo_singlefam_lag8/4 as lo_singlefam_lag33, b.lo_singlefam_lag8/4 as lo_singlefam_lag34, b.lo_singlefam_lag8/4 as lo_singlefam_lag35,
b.lo_singlefam_lag9/4 as lo_singlefam_lag36, b.lo_singlefam_lag9/4 as lo_singlefam_lag37, b.lo_singlefam_lag9/4 as lo_singlefam_lag38, b.lo_singlefam_lag9/4 as lo_singlefam_lag39

from lo1_sfloans as a left join lo.hmda_sf_lo_1990_2016 as b
on a.rssd_id=b.rssd_id and a.rankdate=b.rankdate order by a.rssd_id, a.rankdate;

create table lo2b as select a.*,
b.lo_singlefam_t/4 as lo_singlefam_t, b.lo_singlefam_t/4 as lo_singlefam_lag1, b.lo_singlefam_t/4 as lo_singlefam_lag2, b.lo_singlefam_lag1/4 as lo_singlefam_lag3, 
b.lo_singlefam_lag1/4 as lo_singlefam_lag4, b.lo_singlefam_lag1/4 as lo_singlefam_lag5, b.lo_singlefam_lag1/4 as lo_singlefam_lag6, b.lo_singlefam_lag2/4 as lo_singlefam_lag7, 
b.lo_singlefam_lag2/4 as lo_singlefam_lag8, b.lo_singlefam_lag2/4 as lo_singlefam_lag9, b.lo_singlefam_lag2/4 as lo_singlefam_lag10, b.lo_singlefam_lag3/4 as lo_singlefam_lag11, 
b.lo_singlefam_lag3/4 as lo_singlefam_lag12, b.lo_singlefam_lag3/4 as lo_singlefam_lag13, b.lo_singlefam_lag3/4 as lo_singlefam_lag14, b.lo_singlefam_lag4/4 as lo_singlefam_lag15, 
b.lo_singlefam_lag4/4 as lo_singlefam_lag16, b.lo_singlefam_lag4/4 as lo_singlefam_lag17, b.lo_singlefam_lag4/4 as lo_singlefam_lag18, b.lo_singlefam_lag5/4 as lo_singlefam_lag19, 
b.lo_singlefam_lag5/4 as lo_singlefam_lag20, b.lo_singlefam_lag5/4 as lo_singlefam_lag21, b.lo_singlefam_lag5/4 as lo_singlefam_lag22, b.lo_singlefam_lag6/4 as lo_singlefam_lag23, 
b.lo_singlefam_lag6/4 as lo_singlefam_lag24, b.lo_singlefam_lag6/4 as lo_singlefam_lag25, b.lo_singlefam_lag6/4 as lo_singlefam_lag26, b.lo_singlefam_lag7/4 as lo_singlefam_lag27, 
b.lo_singlefam_lag7/4 as lo_singlefam_lag28, b.lo_singlefam_lag7/4 as lo_singlefam_lag29, b.lo_singlefam_lag7/4 as lo_singlefam_lag30, b.lo_singlefam_lag8/4 as lo_singlefam_lag31, 
b.lo_singlefam_lag8/4 as lo_singlefam_lag32, b.lo_singlefam_lag8/4 as lo_singlefam_lag33, b.lo_singlefam_lag8/4 as lo_singlefam_lag34, b.lo_singlefam_lag9/4 as lo_singlefam_lag35, 
b.lo_singlefam_lag9/4 as lo_singlefam_lag36, b.lo_singlefam_lag9/4 as lo_singlefam_lag37, b.lo_singlefam_lag9/4 as lo_singlefam_lag38, b.lo_singlefam_lag10/4 as lo_singlefam_lag39

from lo1_sfloans as a left join lo.hmda_sf_lo_1990_2016 as b
on a.rssd_id=b.rssd_id and a.rankdate+1=b.rankdate order by a.rssd_id, a.rankdate;

create table lo2c as select a.*,
b.lo_singlefam_t/4 as lo_singlefam_t, b.lo_singlefam_t/4 as lo_singlefam_lag1, b.lo_singlefam_lag1/4 as lo_singlefam_lag2, b.lo_singlefam_lag1/4 as lo_singlefam_lag3, 
b.lo_singlefam_lag1/4 as lo_singlefam_lag4, b.lo_singlefam_lag1/4 as lo_singlefam_lag5, b.lo_singlefam_lag2/4 as lo_singlefam_lag6, b.lo_singlefam_lag2/4 as lo_singlefam_lag7, 
b.lo_singlefam_lag2/4 as lo_singlefam_lag8, b.lo_singlefam_lag2/4 as lo_singlefam_lag9, b.lo_singlefam_lag3/4 as lo_singlefam_lag10, b.lo_singlefam_lag3/4 as lo_singlefam_lag11, 
b.lo_singlefam_lag3/4 as lo_singlefam_lag12, b.lo_singlefam_lag3/4 as lo_singlefam_lag13, b.lo_singlefam_lag4/4 as lo_singlefam_lag14, b.lo_singlefam_lag4/4 as lo_singlefam_lag15, 
b.lo_singlefam_lag4/4 as lo_singlefam_lag16, b.lo_singlefam_lag4/4 as lo_singlefam_lag17, b.lo_singlefam_lag5/4 as lo_singlefam_lag18, b.lo_singlefam_lag5/4 as lo_singlefam_lag19, 
b.lo_singlefam_lag5/4 as lo_singlefam_lag20, b.lo_singlefam_lag5/4 as lo_singlefam_lag21, b.lo_singlefam_lag6/4 as lo_singlefam_lag22, b.lo_singlefam_lag6/4 as lo_singlefam_lag23, 
b.lo_singlefam_lag6/4 as lo_singlefam_lag24, b.lo_singlefam_lag6/4 as lo_singlefam_lag25, b.lo_singlefam_lag7/4 as lo_singlefam_lag26, b.lo_singlefam_lag7/4 as lo_singlefam_lag27, 
b.lo_singlefam_lag7/4 as lo_singlefam_lag28, b.lo_singlefam_lag7/4 as lo_singlefam_lag29, b.lo_singlefam_lag8/4 as lo_singlefam_lag30, b.lo_singlefam_lag8/4 as lo_singlefam_lag31, 
b.lo_singlefam_lag8/4 as lo_singlefam_lag32, b.lo_singlefam_lag8/4 as lo_singlefam_lag33, b.lo_singlefam_lag9/4 as lo_singlefam_lag34, b.lo_singlefam_lag9/4 as lo_singlefam_lag35, 
b.lo_singlefam_lag9/4 as lo_singlefam_lag36, b.lo_singlefam_lag9/4 as lo_singlefam_lag37, b.lo_singlefam_lag10/4 as lo_singlefam_lag38, b.lo_singlefam_lag10/4 as lo_singlefam_lag39

from lo1_sfloans as a left join lo.hmda_sf_lo_1990_2016 as b
on a.rssd_id=b.rssd_id and a.rankdate+2=b.rankdate order by a.rssd_id, a.rankdate;

create table lo2d as select a.*,
b.lo_singlefam_t/4 as lo_singlefam_t, b.lo_singlefam_lag1/4 as lo_singlefam_lag1, b.lo_singlefam_lag1/4 as lo_singlefam_lag2, b.lo_singlefam_lag1/4 as lo_singlefam_lag3, 
b.lo_singlefam_lag1/4 as lo_singlefam_lag4, b.lo_singlefam_lag2/4 as lo_singlefam_lag5, b.lo_singlefam_lag2/4 as lo_singlefam_lag6, b.lo_singlefam_lag2/4 as lo_singlefam_lag7, 
b.lo_singlefam_lag2/4 as lo_singlefam_lag8, b.lo_singlefam_lag3/4 as lo_singlefam_lag9, b.lo_singlefam_lag3/4 as lo_singlefam_lag10, b.lo_singlefam_lag3/4 as lo_singlefam_lag11, 
b.lo_singlefam_lag3/4 as lo_singlefam_lag12, b.lo_singlefam_lag4/4 as lo_singlefam_lag13, b.lo_singlefam_lag4/4 as lo_singlefam_lag14, b.lo_singlefam_lag4/4 as lo_singlefam_lag15, 
b.lo_singlefam_lag4/4 as lo_singlefam_lag16, b.lo_singlefam_lag5/4 as lo_singlefam_lag17, b.lo_singlefam_lag5/4 as lo_singlefam_lag18, b.lo_singlefam_lag5/4 as lo_singlefam_lag19, 
b.lo_singlefam_lag5/4 as lo_singlefam_lag20, b.lo_singlefam_lag6/4 as lo_singlefam_lag21, b.lo_singlefam_lag6/4 as lo_singlefam_lag22, b.lo_singlefam_lag6/4 as lo_singlefam_lag23, 
b.lo_singlefam_lag6/4 as lo_singlefam_lag24, b.lo_singlefam_lag7/4 as lo_singlefam_lag25, b.lo_singlefam_lag7/4 as lo_singlefam_lag26, b.lo_singlefam_lag7/4 as lo_singlefam_lag27, 
b.lo_singlefam_lag7/4 as lo_singlefam_lag28, b.lo_singlefam_lag8/4 as lo_singlefam_lag29, b.lo_singlefam_lag8/4 as lo_singlefam_lag30, b.lo_singlefam_lag8/4 as lo_singlefam_lag31, 
b.lo_singlefam_lag8/4 as lo_singlefam_lag32, b.lo_singlefam_lag9/4 as lo_singlefam_lag33, b.lo_singlefam_lag9/4 as lo_singlefam_lag34, b.lo_singlefam_lag9/4 as lo_singlefam_lag35, 
b.lo_singlefam_lag9/4 as lo_singlefam_lag36, b.lo_singlefam_lag10/4 as lo_singlefam_lag37, b.lo_singlefam_lag10/4 as lo_singlefam_lag38, b.lo_singlefam_lag10/4 as lo_singlefam_lag39

from lo1_sfloans as a left join lo.hmda_sf_lo_1990_2016 as b
on a.rssd_id=b.rssd_id and a.rankdate+3=b.rankdate order by a.rssd_id, a.rankdate;
quit;

data lo2_q4;
set lo2a;
if lo_singlefam_t=. then delete;
run;
data lo2_q3;
set lo2b;
if lo_singlefam_t=. then delete;
run;
data lo2_q2;
set lo2c;
if lo_singlefam_t=. then delete;
run;
data lo2_q1;
set lo2d;
if lo_singlefam_t=. then delete;
run;

data lo2_sfloans;
set lo2_q4 lo2_q3 lo2_q2 lo2_q1;
run;
proc sort data=lo2_sfloans;
by rssd_id rankdate;
quit;

proc sql;
create table ecl_sf1 as select a.snlkey, a.snlyear, a.snlqtr, a.name, a.reg_id, a.rankdate, a.date, a.co_sftotal, b.*
from box.all_co_bytype_1990_2018 a left join lo2_sfloans b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.snlkey, a.rankdate;
quit;

*Create dataset to estimate rolling regressions for ECL estimation;
data ecl_sf2;
set ecl_sf1;
if lo_singlefam_lag1=. then delete;
if lo_singlefam_lag2=. then delete;
if lo_singlefam_lag3=. then delete;
if lo_singlefam_lag4=. then delete;
if lo_singlefam_lag5=. then delete;
if lo_singlefam_lag6=. then delete;
if lo_singlefam_lag7=. then delete;
if lo_singlefam_lag8=. then delete;
if lo_singlefam_lag9=. then delete;
if lo_singlefam_lag10=. then delete;
if lo_singlefam_lag11=. then delete;
if lo_singlefam_lag12=. then delete;
if lo_singlefam_lag13=. then delete;
if lo_singlefam_lag14=. then delete;
if lo_singlefam_lag15=. then delete;
if lo_singlefam_lag16=. then delete;
if lo_singlefam_lag17=. then delete;
if lo_singlefam_lag18=. then delete;
if lo_singlefam_lag19=. then delete;
if lo_singlefam_lag20=. then delete;
if lo_singlefam_lag21=. then delete;
if lo_singlefam_lag22=. then delete;
if lo_singlefam_lag23=. then delete;
if lo_singlefam_lag24=. then delete;
run;

data lo.ecl_sf2_28lags; set ecl_sf2; run;

rsubmit;
data ecl_sf2; set bw2.ecl_sf2_28lags; run;
endrsubmit;

/*rsubmit;
proc upload data=ecl_sf2;
endrsubmit;
*/
rsubmit;
/*~~~~~~~~~~~~~~~~~~~~~~~~*/
/*ECL MACRO*/
/*~~~~~~~~~~~~~~~~~~~~~~~~*/

*Rolling regressions macro;
%macro ecl_sfloans_0075(first_rankdate, last_rankdate, inset=, roll1=,roll2=, roll3=, roll4=, roll5=, roll6=, roll7=, roll8=);

data &roll1;
set &inset;
if rankdate not in (&first_rankdate:&last_rankdate) then delete;
run;

proc sql;
create table &roll2 as select a.*, count(a.snlkey) as obs
from &roll1 as a
group by snlkey
order by snlkey, rankdate;
quit;

data &roll3;
set &roll2;
if obs < 40 then delete;
run;

ods graphics off;
ods exclude all;
/*1 lag*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1;
bounds b1 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_1 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_1 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 1 as model, 0.0075 as param
from roll4_1 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*2 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2;
bounds b1 >= 0, b2 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_2 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_2 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 2 as model, 0.0075 as param
from roll4_2 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*3 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3;
bounds b1 >= 0, b2 >= 0, b3 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_3 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_3 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 3 as model, 0.0075 as param
from roll4_3 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*4 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_4 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_4 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 4 as model, 0.0075 as param
from roll4_4 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*5 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_5 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_5 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 5 as model, 0.0075 as param
from roll4_5 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*6 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_6 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_6 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 6 as model, 0.0075 as param
from roll4_6 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*7 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_7 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_7 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 7 as model, 0.0075 as param
from roll4_7 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*8 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_8 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_8 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 8 as model, 0.0075 as param
from roll4_8 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*9 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_9 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_9 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 9 as model, 0.0075 as param
from roll4_9 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*10 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_10 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_10 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 10 as model, 0.0075 as param
from roll4_10 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*11 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_11 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_11 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 11 as model, 0.0075 as param
from roll4_11 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*12 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 ;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_12 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_12 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 12 as model, 0.0075 as param
from roll4_12 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*13 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_13 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_13 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 13 as model, 0.0075 as param
from roll4_13 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*14 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_14 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_14 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 14 as model, 0.0075 as param
from roll4_14 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*15 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_15 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_15 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 15 as model, 0.0075 as param
from roll4_15 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*16 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_16 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_16 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 16 as model, 0.0075 as param
from roll4_16 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*17 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_17 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_17 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 17 as model, 0.0075 as param
from roll4_17 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*18 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_18 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_18 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 18 as model, 0.0075 as param
from roll4_18 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*19 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075 b19 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18 + b19*lo_singlefam_lag19;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_19 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_19 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 19 as model, 0.0075 as param
from roll4_19 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*20 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075 b19 = 0.0075 b20 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18 + b19*lo_singlefam_lag19 + b20*lo_singlefam_lag20;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_20 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_20 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 20 as model, 0.0075 as param
from roll4_20 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*21 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075 b19 = 0.0075 b20 = 0.0075 b21 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18 + b19*lo_singlefam_lag19 + b20*lo_singlefam_lag20 + b21*lo_singlefam_lag21;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_21 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_21 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 21 as model, 0.0075 as param
from roll4_21 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*22 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075 b19 = 0.0075 b20 = 0.0075 b21 = 0.0075 b22 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18 + b19*lo_singlefam_lag19 + b20*lo_singlefam_lag20 + b21*lo_singlefam_lag21 + b22*lo_singlefam_lag22;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0;
by snlkey;  output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_22 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_22 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 22 as model, 0.0075 as param
from roll4_22 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*23 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075 b19 = 0.0075 b20 = 0.0075 b21 = 0.0075 b22 = 0.0075 b23 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18 + b19*lo_singlefam_lag19 + b20*lo_singlefam_lag20 + b21*lo_singlefam_lag21 + b22*lo_singlefam_lag22 + b23*lo_singlefam_lag23;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_23 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_23 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 23 as model, 0.0075 as param
from roll4_23 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*24 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075 b19 = 0.0075 b20 = 0.0075 b21 = 0.0075 b22 = 0.0075 b23 = 0.0075 b24 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18 + b19*lo_singlefam_lag19 + b20*lo_singlefam_lag20 + b21*lo_singlefam_lag21 + b22*lo_singlefam_lag22 + b23*lo_singlefam_lag23 + b24*lo_singlefam_lag24;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_24 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_24 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 24 as model, 0.0075 as param
from roll4_24 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*25 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075 b19 = 0.0075 b20 = 0.0075 b21 = 0.0075 b22 = 0.0075 b23 = 0.0075 b24 = 0.0075 b25 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18 + b19*lo_singlefam_lag19 + b20*lo_singlefam_lag20 + b21*lo_singlefam_lag21 + b22*lo_singlefam_lag22 + b23*lo_singlefam_lag23 + b24*lo_singlefam_lag24 + b25*lo_singlefam_lag25;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0, b25 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_25 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_25 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 25 as model, 0.0075 as param
from roll4_25 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*26 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075 b19 = 0.0075 b20 = 0.0075 b21 = 0.0075 b22 = 0.0075 b23 = 0.0075 b24 = 0.0075 b25 = 0.0075 b26 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18 + b19*lo_singlefam_lag19 + b20*lo_singlefam_lag20 + b21*lo_singlefam_lag21 + b22*lo_singlefam_lag22 + b23*lo_singlefam_lag23 + b24*lo_singlefam_lag24 + b25*lo_singlefam_lag25 + b26*lo_singlefam_lag26;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0, b25 >= 0, b26 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_26 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_26 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 26 as model, 0.0075 as param
from roll4_26 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*27 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075 b19 = 0.0075 b20 = 0.0075 b21 = 0.0075 b22 = 0.0075 b23 = 0.0075 b24 = 0.0075 b25 = 0.0075 b26 = 0.0075 b27 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18 + b19*lo_singlefam_lag19 + b20*lo_singlefam_lag20 + b21*lo_singlefam_lag21 + b22*lo_singlefam_lag22 + b23*lo_singlefam_lag23 + b24*lo_singlefam_lag24 + b25*lo_singlefam_lag25 + b26*lo_singlefam_lag26 + b27*lo_singlefam_lag27;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0, b25 >= 0, b26 >= 0, b27 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_27 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_27 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 27 as model, 0.0075 as param
from roll4_27 a left join residual b
on a.snlkey=b.snlkey;
quit;

/*28 lags*/
ods listing close; ods output anova=anova;
proc nlin data=&roll3 outest=parm totalss;
parms b1 = 0.0075 b2 = 0.0075 b3 = 0.0075 b4 = 0.0075 b5 = 0.0075 b6 = 0.0075 b7 = 0.0075 b8 = 0.0075 b9 = 0.0075 b10 = 0.0075 b11 = 0.0075 b12 = 0.0075 b13 = 0.0075 b14 = 0.0075 b15 = 0.0075 b16 = 0.0075 b17 = 0.0075 b18 = 0.0075 b19 = 0.0075 b20 = 0.0075 b21 = 0.0075 b22 = 0.0075 b23 = 0.0075 b24 = 0.0075 b25 = 0.0075 b26 = 0.0075 b27 = 0.0075 b28 = 0.0075;
model co_sftotal = b1*lo_singlefam_lag1 + b2*lo_singlefam_lag2 + b3*lo_singlefam_lag3 + b4*lo_singlefam_lag4 + b5*lo_singlefam_lag5 + b6*lo_singlefam_lag6 + b7*lo_singlefam_lag7 + b8*lo_singlefam_lag8 + b9*lo_singlefam_lag9 + b10*lo_singlefam_lag10 + b11*lo_singlefam_lag11 + b12*lo_singlefam_lag12 + b13*lo_singlefam_lag13 + b14*lo_singlefam_lag14 + b15*lo_singlefam_lag15 + b16*lo_singlefam_lag16 + b17*lo_singlefam_lag17 + b18*lo_singlefam_lag18 + b19*lo_singlefam_lag19 + b20*lo_singlefam_lag20 + b21*lo_singlefam_lag21 + b22*lo_singlefam_lag22 + b23*lo_singlefam_lag23 + b24*lo_singlefam_lag24 + b25*lo_singlefam_lag25 + b26*lo_singlefam_lag26 + b27*lo_singlefam_lag27 + b28*lo_singlefam_lag28;
bounds b1 >= 0, b2 >= 0, b3 >= 0, b4 >= 0, b5 >= 0, b6 >= 0, b7 >= 0, b8 >= 0, b9 >= 0, b10 >= 0, b11 >= 0, b12 >= 0, b13 >= 0, b14 >= 0, b15 >= 0, b16 >= 0, b17 >= 0, b18 >= 0, b19 >= 0, b20 >= 0, b21 >= 0, b22 >= 0, b23 >= 0, b24 >= 0, b25 >= 0, b26 >= 0, b27 >= 0, b28 >= 0;
by snlkey; output out=residual r=res;
run;quit;
ods listing close;
proc sql;
create table parm2 as select *, max(_ITER_) as max_iter from parm group by snlkey;
quit;
data parms; set parm2; if _ITER_ ne max_iter then delete; run;
proc sql;
create table roll4_28 as select a.*, b.SS as corrected_ss, 1-(_SSE_/corrected_ss) as pseudo_rsq
from parms as a left join anova as b on a.snlkey=b.snlkey and b.source = 'Corrected Total';
create table roll4_28 as select a.*, b.res, &last_rankdate as rollreg_rankdate, b.rankdate, 28 as model, 0.0075 as param
from roll4_28 a left join residual b
on a.snlkey=b.snlkey;
quit;

ods exclude none;

*Retain model with highest adjusted r-sq;
data &roll4;
set roll4_1 roll4_2 roll4_3 roll4_4 roll4_5 roll4_6 roll4_7 roll4_8
roll4_9 roll4_10 roll4_11 roll4_12 roll4_13 roll4_14 roll4_15 roll4_16
roll4_17 roll4_18 roll4_19 roll4_20 roll4_21 roll4_22 roll4_23 roll4_24
roll4_25 roll4_26 roll4_27 roll4_28;
run;

proc sql;
create table &roll5 as select *, max(pseudo_rsq) as max_pseudo_rsq
from &roll4
group by snlkey order by snlkey, rankdate;
quit;
data &roll6 (drop=max_pseudo_rsq);
set &roll5;
if pseudo_rsq ne max_pseudo_rsq then delete;
run;

proc sort data=&roll6; by snlkey rankdate model ; run;
proc sort data=&roll6 nodupkey; by snlkey rankdate; run;

dm 'clear log';
%mend;
endrsubmit;

*Run estimation macro;
/*ROLLING REGRESSIONS FOR ECL ESTIMATION: RUN AFTER RUNNING ECL MACRO*/
rsubmit; *Macro 2016Q4;
%ecl_sfloans_0075(69, 108, inset=ecl_sf2, roll1=Q42016_1 ,roll2=Q42016_2, roll3=Q42016_3, roll4=Q42016_4, roll5=Q42016_5, roll6=Q42016_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2016Q3;
%ecl_sfloans_0075(68, 107, inset=ecl_sf2, roll1=Q32016_1 ,roll2=Q32016_2, roll3=Q32016_3, roll4=Q32016_4, roll5=Q32016_5, roll6=Q32016_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2016Q2;
%ecl_sfloans_0075(67, 106, inset=ecl_sf2, roll1=Q22016_1 ,roll2=Q22016_2, roll3=Q22016_3, roll4=Q22016_4, roll5=Q22016_5, roll6=Q22016_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2016Q1;
%ecl_sfloans_0075(66, 105, inset=ecl_sf2, roll1=Q12016_1 ,roll2=Q12016_2, roll3=Q12016_3, roll4=Q12016_4, roll5=Q12016_5, roll6=Q12016_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q4;
%ecl_sfloans_0075(65, 104, inset=ecl_sf2, roll1=Q42015_1 ,roll2=Q42015_2, roll3=Q42015_3, roll4=Q42015_4, roll5=Q42015_5, roll6=Q42015_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q3;
%ecl_sfloans_0075(64, 103, inset=ecl_sf2, roll1=Q32015_1 ,roll2=Q32015_2, roll3=Q32015_3, roll4=Q32015_4, roll5=Q32015_5, roll6=Q32015_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q2;
%ecl_sfloans_0075(63, 102, inset=ecl_sf2, roll1=Q22015_1 ,roll2=Q22015_2, roll3=Q22015_3, roll4=Q22015_4, roll5=Q22015_5, roll6=Q22015_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2015Q1;
%ecl_sfloans_0075(62, 101, inset=ecl_sf2, roll1=Q12015_1 ,roll2=Q12015_2, roll3=Q12015_3, roll4=Q12015_4, roll5=Q12015_5, roll6=Q12015_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q4;
%ecl_sfloans_0075(61, 100, inset=ecl_sf2, roll1=Q42014_1 ,roll2=Q42014_2, roll3=Q42014_3, roll4=Q42014_4, roll5=Q42014_5, roll6=Q42014_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q3;
%ecl_sfloans_0075(60, 99, inset=ecl_sf2, roll1=Q32014_1 ,roll2=Q32014_2, roll3=Q32014_3, roll4=Q32014_4, roll5=Q32014_5, roll6=Q32014_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q2;
%ecl_sfloans_0075(59, 98, inset=ecl_sf2, roll1=Q22014_1 ,roll2=Q22014_2, roll3=Q22014_3, roll4=Q22014_4, roll5=Q22014_5, roll6=Q22014_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2014Q1;
%ecl_sfloans_0075(58, 97, inset=ecl_sf2, roll1=Q12014_1 ,roll2=Q12014_2, roll3=Q12014_3, roll4=Q12014_4, roll5=Q12014_5, roll6=Q12014_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q4;
%ecl_sfloans_0075(57, 96, inset=ecl_sf2, roll1=Q42013_1 ,roll2=Q42013_2, roll3=Q42013_3, roll4=Q42013_4, roll5=Q42013_5, roll6=Q42013_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q3;
%ecl_sfloans_0075(56, 95, inset=ecl_sf2, roll1=Q32013_1 ,roll2=Q32013_2, roll3=Q32013_3, roll4=Q32013_4, roll5=Q32013_5, roll6=Q32013_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q2;
%ecl_sfloans_0075(55, 94, inset=ecl_sf2, roll1=Q22013_1 ,roll2=Q22013_2, roll3=Q22013_3, roll4=Q22013_4, roll5=Q22013_5, roll6=Q22013_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2013Q1;
%ecl_sfloans_0075(54, 93, inset=ecl_sf2, roll1=Q12013_1 ,roll2=Q12013_2, roll3=Q12013_3, roll4=Q12013_4, roll5=Q12013_5, roll6=Q12013_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q4;
%ecl_sfloans_0075(53, 92, inset=ecl_sf2, roll1=Q42012_1 ,roll2=Q42012_2, roll3=Q42012_3, roll4=Q42012_4, roll5=Q42012_5, roll6=Q42012_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q3;
%ecl_sfloans_0075(52, 91, inset=ecl_sf2, roll1=Q32012_1 ,roll2=Q32012_2, roll3=Q32012_3, roll4=Q32012_4, roll5=Q32012_5, roll6=Q32012_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q2;
%ecl_sfloans_0075(51, 90, inset=ecl_sf2, roll1=Q22012_1 ,roll2=Q22012_2, roll3=Q22012_3, roll4=Q22012_4, roll5=Q22012_5, roll6=Q22012_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2012Q1;
%ecl_sfloans_0075(50, 89, inset=ecl_sf2, roll1=Q12012_1 ,roll2=Q12012_2, roll3=Q12012_3, roll4=Q12012_4, roll5=Q12012_5, roll6=Q12012_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q4;
%ecl_sfloans_0075(49, 88, inset=ecl_sf2, roll1=Q42011_1 ,roll2=Q42011_2, roll3=Q42011_3, roll4=Q42011_4, roll5=Q42011_5, roll6=Q42011_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q3;
%ecl_sfloans_0075(48, 87, inset=ecl_sf2, roll1=Q32011_1 ,roll2=Q32011_2, roll3=Q32011_3, roll4=Q32011_4, roll5=Q32011_5, roll6=Q32011_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q2;
%ecl_sfloans_0075(47, 86, inset=ecl_sf2, roll1=Q22011_1 ,roll2=Q22011_2, roll3=Q22011_3, roll4=Q22011_4, roll5=Q22011_5, roll6=Q22011_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q1;
%ecl_sfloans_0075(46, 85, inset=ecl_sf2, roll1=Q12011_1 ,roll2=Q12011_2, roll3=Q12011_3, roll4=Q12011_4, roll5=Q12011_5, roll6=Q12011_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2011Q2;
%ecl_sfloans_0075(47, 86, inset=ecl_sf2, roll1=Q22011_1 ,roll2=Q22011_2, roll3=Q22011_3, roll4=Q22011_4, roll5=Q22011_5, roll6=Q22011_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q4;
%ecl_sfloans_0075(45, 84, inset=ecl_sf2, roll1=Q42010_1 ,roll2=Q42010_2, roll3=Q42010_3, roll4=Q42010_4, roll5=Q42010_5, roll6=Q42010_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q3;
%ecl_sfloans_0075(44, 83, inset=ecl_sf2, roll1=Q32010_1 ,roll2=Q32010_2, roll3=Q32010_3, roll4=Q32010_4, roll5=Q32010_5, roll6=Q32010_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q2;
%ecl_sfloans_0075(43, 82, inset=ecl_sf2, roll1=Q22010_1 ,roll2=Q22010_2, roll3=Q22010_3, roll4=Q22010_4, roll5=Q22010_5, roll6=Q22010_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2010Q1;
%ecl_sfloans_0075(42, 81, inset=ecl_sf2, roll1=Q12010_1 ,roll2=Q12010_2, roll3=Q12010_3, roll4=Q12010_4, roll5=Q12010_5, roll6=Q12010_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q4;
%ecl_sfloans_0075(41, 80, inset=ecl_sf2, roll1=Q42009_1 ,roll2=Q42009_2, roll3=Q42009_3, roll4=Q42009_4, roll5=Q42009_5, roll6=Q42009_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q3;
%ecl_sfloans_0075(40, 79, inset=ecl_sf2, roll1=Q32009_1 ,roll2=Q32009_2, roll3=Q32009_3, roll4=Q32009_4, roll5=Q32009_5, roll6=Q32009_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q2;
%ecl_sfloans_0075(39, 78, inset=ecl_sf2, roll1=Q22009_1 ,roll2=Q22009_2, roll3=Q22009_3, roll4=Q22009_4, roll5=Q22009_5, roll6=Q22009_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2009Q1;
%ecl_sfloans_0075(38, 77, inset=ecl_sf2, roll1=Q12009_1 ,roll2=Q12009_2, roll3=Q12009_3, roll4=Q12009_4, roll5=Q12009_5, roll6=Q12009_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q4;
%ecl_sfloans_0075(37, 76, inset=ecl_sf2, roll1=Q42008_1 ,roll2=Q42008_2, roll3=Q42008_3, roll4=Q42008_4, roll5=Q42008_5, roll6=Q42008_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q3;
%ecl_sfloans_0075(36, 75, inset=ecl_sf2, roll1=Q32008_1 ,roll2=Q32008_2, roll3=Q32008_3, roll4=Q32008_4, roll5=Q32008_5, roll6=Q32008_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q2;
%ecl_sfloans_0075(35, 74, inset=ecl_sf2, roll1=Q22008_1 ,roll2=Q22008_2, roll3=Q22008_3, roll4=Q22008_4, roll5=Q22008_5, roll6=Q22008_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2008Q1;
%ecl_sfloans_0075(34, 73, inset=ecl_sf2, roll1=Q12008_1 ,roll2=Q12008_2, roll3=Q12008_3, roll4=Q12008_4, roll5=Q12008_5, roll6=Q12008_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q4;
%ecl_sfloans_0075(33, 72, inset=ecl_sf2, roll1=Q42007_1 ,roll2=Q42007_2, roll3=Q42007_3, roll4=Q42007_4, roll5=Q42007_5, roll6=Q42007_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q3;
%ecl_sfloans_0075(32, 71, inset=ecl_sf2, roll1=Q32007_1 ,roll2=Q32007_2, roll3=Q32007_3, roll4=Q32007_4, roll5=Q32007_5, roll6=Q32007_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q2;
%ecl_sfloans_0075(31, 70, inset=ecl_sf2, roll1=Q22007_1 ,roll2=Q22007_2, roll3=Q22007_3, roll4=Q22007_4, roll5=Q22007_5, roll6=Q22007_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2007Q1;
%ecl_sfloans_0075(30, 69, inset=ecl_sf2, roll1=Q12007_1 ,roll2=Q12007_2, roll3=Q12007_3, roll4=Q12007_4, roll5=Q12007_5, roll6=Q12007_sfloans);
endrsubmit; dm 'clear log';
rsubmit; *Macro 2006Q4;
%ecl_sfloans_0075(29, 68, inset=ecl_sf2, roll1=Q42006_1 ,roll2=Q42006_2, roll3=Q42006_3, roll4=Q42006_4, roll5=Q42006_5, roll6=Q42006_sfloans);
endrsubmit; dm 'clear log';

rsubmit;
*Aggregate ECL estimates into one file;
data ecl_sf_residuals0075;
set 
Q42006_sfloans
Q12007_sfloans
Q22007_sfloans
Q32007_sfloans
Q42007_sfloans
Q12008_sfloans
Q22008_sfloans
Q32008_sfloans
Q42008_sfloans
Q12009_sfloans
Q22009_sfloans
Q32009_sfloans
Q42009_sfloans
Q12010_sfloans
Q22010_sfloans
Q32010_sfloans
Q42010_sfloans
Q12011_sfloans
Q22011_sfloans
Q32011_sfloans
Q42011_sfloans
Q12012_sfloans
Q22012_sfloans
Q32012_sfloans
Q42012_sfloans
Q12013_sfloans
Q22013_sfloans
Q32013_sfloans
Q42013_sfloans
Q12014_sfloans
Q22014_sfloans
Q32014_sfloans
Q42014_sfloans
Q12015_sfloans
Q22015_sfloans
Q32015_sfloans
Q42015_sfloans
Q12016_sfloans
Q22016_sfloans
Q32016_sfloans
Q42016_sfloans;
Run;
proc sort data=ecl_sf_residuals0075; by snlkey rollreg_rankdate rankdate; run;
data bw2.ecl_sf_res0075_28;
set ecl_sf_residuals0075;
run;
endrsubmit;



