/*========================================================================================================
                                                                          
    ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
    AUTHOR: P. Barrett Wheeler                  
    JOURNAL OF ACCOUNTING RESEARCH 

 	The code below adjusts base expected loss estimates (see Steps 2c and 2d) eight quarters out
	for macroeconomic conditions using Eq. (6).

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';
libname ecl 'C:\Users\pwheeler1\Box Sync\Data Sets\ECL Estimates';

*~~~~~~~~ADJUST ECL ESTIMATES FOR CHANGES IN MACROECONOMIC VARIABLES~~~~~~~~~~~;

*Gather residuals from Stage 1 ECL Model;
data ecl_sf_residuals;
set 
box.ecl_sf_residuals001
box.ecl_sf_residuals005
box.ecl_sf_residuals0025
box.ecl_sf_residuals0075;
rename res=res_sf;
run;
proc sort data=ecl_sf_residuals; by snlkey rollreg_rankdate param rankdate; run;
proc sql;
create table ecl_sf_residuals as select a.*, b.param as param_max
from ecl_sf_residuals a left join box.ecl_sf_maxrsq b
on a.snlkey=b.snlkey and a.rollreg_rankdate=b.rankdate;
quit;
data ecl_sf_residuals; set ecl_sf_residuals;
if param ne param_max then delete;
run;

data ecl_nonsfre_residuals;
set 
box.ecl_nonsfre_resid001
box.ecl_nonsfre_resid005
box.ecl_nonsfre_resid0025
box.ecl_nonsfre_resid0075;
rename res=res_nonsfre;
run;
proc sql;
create table ecl_nonsfre_residuals as select a.*, b.param as param_max
from ecl_nonsfre_residuals a left join box.ecl_nonsfre_maxrsq b
on a.snlkey=b.snlkey and a.rollreg_rankdate=b.rankdate;
quit;
data ecl_nonsfre_residuals; set ecl_nonsfre_residuals;
if param ne param_max then delete;
run;

data ecl_cons_residuals;
set 
box.ecl_cons_residuals001
box.ecl_cons_residuals005
box.ecl_cons_residuals0025
box.ecl_cons_residuals0075;
rename res=res_cons;
run;
proc sql;
create table ecl_cons_residuals as select a.*, b.param as param_max
from ecl_cons_residuals a left join box.ecl_cons_maxrsq b
on a.snlkey=b.snlkey and a.rollreg_rankdate=b.rankdate;
quit;
data ecl_cons_residuals; set ecl_cons_residuals;
if param ne param_max then delete;
run;

data ecl_othnonre_residuals;
set 
box.ecl_othnonre_residuals001
box.ecl_othnonre_residuals005
box.ecl_othnonre_residuals0025
box.ecl_othnonre_residuals0075;
rename res=res_othnonre;
run;
proc sql;
create table ecl_othnonre_residuals as select a.*, b.param as param_max
from ecl_othnonre_residuals a left join box.ecl_othnonre_maxrsq b
on a.snlkey=b.snlkey and a.rollreg_rankdate=b.rankdate;
quit;
data ecl_othnonre_residuals; set ecl_othnonre_residuals;
if param ne param_max then delete;
run;

proc sql;
create table ecl_residuals as select a.snlkey, a.rollreg_rankdate, a.rankdate, a.res_sf, b.res_nonsfre, c.res_cons, d.res_othnonre
from ecl_sf_residuals a, ecl_nonsfre_residuals b, ecl_cons_residuals c, ecl_othnonre_residuals d
where a.snlkey=b.snlkey=c.snlkey=d.snlkey and a.rollreg_rankdate=b.rollreg_rankdate=c.rollreg_rankdate=d.rollreg_rankdate and a.rankdate=b.rankdate=c.rankdate=d.rankdate
order by a.snlkey, a.rollreg_rankdate, a.rankdate;
quit;

*Ensure no duplicates;
proc sort data=ecl_residuals nodupkey;
by snlkey rollreg_rankdate rankdate;
run;

*Add loan data;
proc sql;
create table stage2_1 as select a.*, b.loans
from ecl_residuals a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.loans as lag1_loans
from stage2_1 a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.loans as lag2_loans
from stage2_1 a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.loans as lag4_loans
from stage2_1 a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table stage2_1 as select a.*, b.loans as lag8_loans
from stage2_1 a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+8;

create table stage2_1 as select a.*, b.reloans
from stage2_1 a left join box.all_reloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.reloans as lag1_reloans
from stage2_1 a left join box.all_reloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.reloans as lag2_reloans
from stage2_1 a left join box.all_reloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.sfloans
from stage2_1 a left join box.all_sfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.sfloans as lag1_sfloans
from stage2_1 a left join box.all_sfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.sfloans as lag2_sfloans
from stage2_1 a left join box.all_sfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.sfcndloans
from stage2_1 a left join box.all_sfcndloans_1990_2016 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.sfcndloans as lag1_sfcndloans
from stage2_1 a left join box.all_sfcndloans_1990_2016 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.sfcndloans as lag2_sfcndloans
from stage2_1 a left join box.all_sfcndloans_1990_2016 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.loans_hfs
from stage2_1 a left join box.all_loans_hfs_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.loans_hfs as lag1_loans_hfs
from stage2_1 a left join box.all_loans_hfs_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.loans_hfs as lag2_loans_hfs
from stage2_1 a left join box.all_loans_hfs_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.mfloans
from stage2_1 a left join box.all_mfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.mfloans as lag1_mfloans
from stage2_1 a left join box.all_mfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.mfloans as lag2_mfloans
from stage2_1 a left join box.all_mfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.creloans
from stage2_1 a left join box.all_creloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.creloans as lag1_creloans
from stage2_1 a left join box.all_creloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.creloans as lag2_creloans
from stage2_1 a left join box.all_creloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.farmloans
from stage2_1 a left join box.all_farmloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.farmloans as lag1_farmloans
from stage2_1 a left join box.all_farmloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.farmloans as lag2_farmloans
from stage2_1 a left join box.all_farmloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.consloans
from stage2_1 a left join box.all_consloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.consloans as lag1_consloans
from stage2_1 a left join box.all_consloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.consloans as lag2_consloans
from stage2_1 a left join box.all_consloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.cniloans
from stage2_1 a left join box.all_cniloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.cniloans as lag1_cniloans
from stage2_1 a left join box.all_cniloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.cniloans as lag2_cniloans
from stage2_1 a left join box.all_cniloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.agloans
from stage2_1 a left join box.all_agloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.agloans as lag1_agloans
from stage2_1 a left join box.all_agloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.agloans as lag2_agloans
from stage2_1 a left join box.all_agloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.na
from stage2_1 a left join box.all_na_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.na as lag1_na
from stage2_1 a left join box.all_na_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.na as lag4_na
from stage2_1 a left join box.all_na_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table stage2_1 as select a.*, b.na as lag8_na
from stage2_1 a left join box.all_na_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+8;

create table stage2_1 as select a.*, b.pd90
from stage2_1 a left join box.all_pd90_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.pd90 as lag1_pd90
from stage2_1 a left join box.all_pd90_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.pd90 as lag4_pd90
from stage2_1 a left join box.all_pd90_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table stage2_1 as select a.*, b.pd90 as lag8_pd90
from stage2_1 a left join box.all_pd90_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+8;

create table stage2_1 as select a.*, b.pd30
from stage2_1 a left join box.all_pd30_2001_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.npl, b.npl_sf, b.npl_sfcnd, b.npl_mf, b.npl_cre, b.npl_farm, b.npl_cons, b.npl_cni, b.npl_ag
from stage2_1 as a left join box.all_npl_bytype as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.npl as lag1_npl, b.npl_sf as lag1_npl_sf, b.npl_sfcnd as lag1_npl_sfcnd, b.npl_mf as lag1_npl_mf, b.npl_cre as lag1_npl_cre, b.npl_farm as lag1_npl_farm, b.npl_cons as lag1_npl_cons, b.npl_cni as lag1_npl_cni, b.npl_ag as lag1_npl_ag
from stage2_1 as a left join box.all_npl_bytype as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.npl as lag2_npl, b.npl_sf as lag2_npl_sf, b.npl_sfcnd as lag2_npl_sfcnd, b.npl_mf as lag2_npl_mf, b.npl_cre as lag2_npl_cre, b.npl_farm as lag2_npl_farm, b.npl_cons as lag2_npl_cons, b.npl_cni as lag2_npl_cni, b.npl_ag as lag2_npl_ag
from stage2_1 as a left join box.all_npl_bytype as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2 order by a.snlkey, a.rollreg_rankdate, a.rankdate;
quit;
data stage2_2; set stage2_1;
if sfcndloans=. then sfcndloans=0;
if loans_hfs=. then loans_hfs=0;
sf_total = sfloans+sfcndloans;
sf_htm = sf_total-loans_hfs;
nonsfre = mfloans+creloans+farmloans;
othnonre = cniloans+agloans;
if lag1_sfcndloans=. then lag1_sfcndloans=0;
if lag1_loans_hfs=. then lag1_loans_hfs=0;
lag1_sf_total = lag1_sfloans+lag1_sfcndloans;
lag1_sf_htm = lag1_sf_total-lag1_loans_hfs;
lag1_nonsfre = lag1_mfloans+lag1_creloans+lag1_farmloans;
lag1_othnonre = lag1_cniloans+lag1_agloans;
if lag2_sfcndloans=. then lag2_sfcndloans=0;
if lag2_loans_hfs=. then lag2_loans_hfs=0;
lag2_sf_total = lag2_sfloans+lag2_sfcndloans;
lag2_sf_htm = lag2_sf_total-lag2_loans_hfs;
lag2_nonsfre = lag2_mfloans+lag2_creloans+lag2_farmloans;
lag2_othnonre = lag2_cniloans+lag2_agloans;
res_sf_l = res_sf / sf_htm;
res_nonsfre_l = res_nonsfre / nonsfre;
res_cons_l = res_cons / consloans;
res_othnonre_l = res_othnonre / othnonre;
if npl_sfcnd=. then npl_sfcnd=0;
npl_sf_total = npl_sf+npl_sfcnd;
npl_nonsfre = npl_mf+npl_cre+npl_farm;
npl_othnonre = npl_cni+npl_ag;
if lag1_npl_sfcnd=. then lag1_npl_sfcnd=0;
lag1_npl_sf_total = lag1_npl_sf+lag1_npl_sfcnd;
lag1_npl_nonsfre = lag1_npl_mf+lag1_npl_cre+lag1_npl_farm;
lag1_npl_othnonre = lag1_npl_cni+lag1_npl_ag;
if lag2_npl_sfcnd=. then lag2_npl_sfcnd=0;
lag2_npl_sf_total = lag2_npl_sf+lag2_npl_sfcnd;
lag2_npl_nonsfre = lag2_npl_mf+lag2_npl_cre+lag2_npl_farm;
lag2_npl_othnonre = lag2_npl_cni+lag2_npl_ag;
run;
proc sort data=stage2_2; by snlkey rollreg_rankdate rankdate; run;
*Lead residuals and lag npl;
proc expand data=stage2_2 out=stage2_3 method=none; by snlkey rollreg_rankdate; id rankdate;
convert res_sf_l = lead1_res_sf_l / transformout = (lead 1);
convert res_sf_l = lead2_res_sf_l / transformout = (lead 2);
convert res_sf_l = lead3_res_sf_l / transformout = (lead 3);
convert res_sf_l = lead4_res_sf_l / transformout = (lead 4);
convert res_sf_l = lead5_res_sf_l / transformout = (lead 5);
convert res_sf_l = lead6_res_sf_l / transformout = (lead 6);
convert res_sf_l = lead7_res_sf_l / transformout = (lead 7);
convert res_nonsfre_l = lead1_res_nonsfre_l / transformout = (lead 1);
convert res_nonsfre_l = lead2_res_nonsfre_l / transformout = (lead 2);
convert res_nonsfre_l = lead3_res_nonsfre_l / transformout = (lead 3);
convert res_nonsfre_l = lead4_res_nonsfre_l / transformout = (lead 4);
convert res_nonsfre_l = lead5_res_nonsfre_l / transformout = (lead 5);
convert res_nonsfre_l = lead6_res_nonsfre_l / transformout = (lead 6);
convert res_nonsfre_l = lead7_res_nonsfre_l / transformout = (lead 7);
convert res_cons_l = lead1_res_cons_l / transformout = (lead 1);
convert res_cons_l = lead2_res_cons_l / transformout = (lead 2);
convert res_cons_l = lead3_res_cons_l / transformout = (lead 3);
convert res_cons_l = lead4_res_cons_l / transformout = (lead 4);
convert res_cons_l = lead5_res_cons_l / transformout = (lead 5);
convert res_cons_l = lead6_res_cons_l / transformout = (lead 6);
convert res_cons_l = lead7_res_cons_l / transformout = (lead 7);
convert res_othnonre_l = lead1_res_othnonre_l / transformout = (lead 1);
convert res_othnonre_l = lead2_res_othnonre_l / transformout = (lead 2);
convert res_othnonre_l = lead3_res_othnonre_l / transformout = (lead 3);
convert res_othnonre_l = lead4_res_othnonre_l / transformout = (lead 4);
convert res_othnonre_l = lead5_res_othnonre_l / transformout = (lead 5);
convert res_othnonre_l = lead6_res_othnonre_l / transformout = (lead 6);
convert res_othnonre_l = lead7_res_othnonre_l / transformout = (lead 7);
run;

/*ADD MACROECONOMIC VARIABLES*/
proc sql;
create table macro1 as select year, quarter, ch_unemp_rate as ch_unemp
from box.unemployment_rate_2017;

create table macro2 as select a.*, b.qtch_csindex as ch_cs
from macro1 a left join box.case_shiller_2017 b
on a.year=b.year and a.quarter=b.quarter;

create table macro3 as select a.*, (b.cni_largeandmid_dom+b.cni_small_dom)/200 as tighten
from macro2 a left join box.frb_sloos_apr2017 b
on a.year=b.year and a.quarter=b.qtr;

create table gdp_1929_2018 as select a.*, b.year, b.qtr
from box.gdp_1929_2018 a left join box.rankdates b
on a.date=b.date;

create table macro4 as select a.*, b.chgdp_quarterly as ch_gdp
from macro3 a left join gdp_1929_2018 b
on a.year=b.year and a.quarter=b.qtr;

create table macro5 as select a.*, b.rankdate
from macro4 a left join box.rankdates b
on a.year=b.year and a.quarter=b.qtr;
quit;

*Lag macro variables and NPLs;
proc expand data=macro5 out=macro6 method=none; id rankdate;
convert ch_unemp = lag1_ch_unemp / transformout = (lag 1);
convert ch_unemp = lag2_ch_unemp / transformout = (lag 2);
convert ch_unemp = lag3_ch_unemp / transformout = (lag 3);
convert ch_unemp = lag4_ch_unemp / transformout = (lag 4);
convert ch_unemp = lag5_ch_unemp / transformout = (lag 5);
convert ch_unemp = lag6_ch_unemp / transformout = (lag 6);
convert ch_unemp = lag7_ch_unemp / transformout = (lag 7);
convert ch_unemp = lag8_ch_unemp / transformout = (lag 8);
convert ch_unemp = lag9_ch_unemp / transformout = (lag 9);
convert ch_unemp = lag10_ch_unemp / transformout = (lag 10);
convert ch_unemp = lag11_ch_unemp / transformout = (lag 11);
convert ch_gdp = lag1_ch_gdp / transformout = (lag 1);
convert ch_gdp = lag2_ch_gdp / transformout = (lag 2);
convert ch_gdp = lag3_ch_gdp / transformout = (lag 3);
convert ch_gdp = lag4_ch_gdp / transformout = (lag 4);
convert ch_gdp = lag5_ch_gdp / transformout = (lag 5);
convert ch_gdp = lag6_ch_gdp / transformout = (lag 6);
convert ch_gdp = lag7_ch_gdp / transformout = (lag 7);
convert ch_gdp = lag8_ch_gdp / transformout = (lag 8);
convert ch_gdp = lag9_ch_gdp / transformout = (lag 9);
convert ch_gdp = lag10_ch_gdp / transformout = (lag 10);
convert ch_gdp = lag11_ch_gdp / transformout = (lag 11);
convert ch_cs = lag1_ch_cs / transformout = (lag 1);
convert ch_cs = lag2_ch_cs / transformout = (lag 2);
convert ch_cs = lag3_ch_cs / transformout = (lag 3);
convert ch_cs = lag4_ch_cs / transformout = (lag 4);
convert ch_cs = lag5_ch_cs / transformout = (lag 5);
convert ch_cs = lag6_ch_cs / transformout = (lag 6);
convert ch_cs = lag7_ch_cs / transformout = (lag 7);
convert ch_cs = lag8_ch_cs / transformout = (lag 8);
convert ch_cs = lag9_ch_cs / transformout = (lag 9);
convert ch_cs = lag10_ch_cs / transformout = (lag 10);
convert ch_cs = lag11_ch_cs / transformout = (lag 11);
convert ch_cs = lag12_ch_cs / transformout = (lag 12);
convert ch_cs = lag13_ch_cs / transformout = (lag 13);
convert ch_cs = lag14_ch_cs / transformout = (lag 14);
convert ch_cs = lag15_ch_cs / transformout = (lag 15);
convert tighten = lag1_tighten / transformout = (lag 1);
convert tighten = lag2_tighten / transformout = (lag 2);
convert tighten = lag3_tighten / transformout = (lag 3);
convert tighten = lag4_tighten / transformout = (lag 4);
convert tighten = lag5_tighten / transformout = (lag 5);
convert tighten = lag6_tighten / transformout = (lag 6);
convert tighten = lag7_tighten / transformout = (lag 7);
convert tighten = lag8_tighten / transformout = (lag 8);
convert tighten = lag9_tighten / transformout = (lag 9);
convert tighten = lag10_tighten / transformout = (lag 10);
convert tighten = lag11_tighten / transformout = (lag 11);
convert tighten = lag12_tighten / transformout = (lag 12);
convert tighten = lag13_tighten / transformout = (lag 13);
convert tighten = lag14_tighten / transformout = (lag 14);
convert tighten = lag15_tighten / transformout = (lag 15);
run;

*Merge macro data;
proc sql;
create table stage2_4 as select a.*, b.*
from stage2_3 a left join macro6 b
on a.rankdate=b.rankdate;
quit;

*Summarize lagged macroeconomic data;
data stage2_5; set stage2_4;
ch_unemp_1y = (lag1_ch_unemp+lag2_ch_unemp+lag3_ch_unemp+lag4_ch_unemp);
ch_unemp_2y = (lag5_ch_unemp+lag6_ch_unemp+lag7_ch_unemp+lag8_ch_unemp);
ch_gdp_1y = (lag1_ch_gdp+lag2_ch_gdp+lag3_ch_gdp+lag4_ch_gdp);
ch_gdp_2y = (lag5_ch_gdp+lag6_ch_gdp+lag7_ch_gdp+lag8_ch_gdp);
ch_cs_1y = (lag1_ch_cs+lag2_ch_cs+lag3_ch_cs+lag4_ch_cs);
ch_cs_2y = (lag5_ch_cs+lag6_ch_cs+lag7_ch_cs+lag8_ch_cs);
ch_cs_3y = (lag9_ch_cs+lag10_ch_cs+lag11_ch_cs+lag12_ch_cs);
avg_tighten_1y = (lag1_tighten+lag2_tighten+lag3_tighten+lag4_tighten)/4;
avg_tighten_2y = (lag5_tighten+lag6_tighten+lag7_tighten+lag8_tighten)/4;
avg_tighten_3y = (lag9_tighten+lag10_tighten+lag11_tighten+lag12_tighten)/4;
ch_npl_sf_1q = (npl_sf_total-lag1_npl_sf_total)/lag1_sf_htm;
ch_npl_sf_2q = (lag1_npl_sf_total-lag2_npl_sf_total)/lag2_sf_htm;
ch_npl_nonsfre_1q = (npl_nonsfre-lag1_npl_nonsfre)/lag1_nonsfre;
ch_npl_nonsfre_2q = (lag1_npl_nonsfre-lag2_npl_nonsfre)/lag2_nonsfre;
ch_npl_cons_1q = (npl_cons-lag1_npl_cons)/lag1_consloans;
ch_npl_cons_2q = (lag1_npl_cons-lag2_npl_cons)/lag2_consloans;
ch_npl_othnonre_1q = (npl_othnonre-lag1_npl_othnonre)/lag1_othnonre;
ch_npl_othnonre_2q = (lag1_npl_othnonre-lag2_npl_othnonre)/lag2_othnonre;
run;
proc sort data=stage2_5; by snlkey rollreg_rankdate rankdate; run; 

/*ASSIGN TO GROUPS BASED ON SIZE AND GEOGRAPHY*/
proc sql;
create table stage2_6 as select a.*, b.ta
from stage2_5 a left join box.all_ta_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_7 as select a.*, b.state, b.fdic_region
from stage2_6 a left join box.all_geographicdata b
on a.snlkey=b.snlkey;
quit;

data states (keep=state); set box.all_geographicdata; if state='' then delete; run;
proc sort data=states nodupkey; by state; run;
data states; set states; state_no=_n_+4; run;
data stage2_8; set stage2_7;
if ta >= 200000000 then type=1;
if 200000000 > ta >= 10000000 then type=2;
if ta < 10000000 then type =3;
if fdic_region='Atlanta' then region_no=0;
if fdic_region='Chicago' then region_no=1;
if fdic_region='Dallas' then region_no=2;
if fdic_region='Kansas City' then region_no=3;
if fdic_region='New York' then region_no=4;
if fdic_region='San Francisco' then region_no=5;
run;
proc sql;
create table stage2_9 as select a.*, b.state_no
from stage2_8 a left join states b
on a.state=b.state order by snlkey, rankdate;
run;
data stage2_10; set stage2_9;
if type=1 then group=type;
if type=2 then group=type+region_no;
if type=3 then group=type+state_no;
run;

proc sort data=stage2_10; by snlkey rollreg_rankdate rankdate; run; 

/*CALCULATE MACROECONOMIC ADJUSTMENT FACTORS*/
*Single-family loans;
proc sort data=stage2_10; by group rollreg_rankdate; run;
ods graphics off; ods exclude all; ods listing close; ods output parameterestimates=ecl_parms_sf1;
proc reg data=stage2_10;
model res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf1 out=ecl_parameters_sf1 prefix=b_sf1_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_sf2;
proc reg data=stage2_10;
model lead1_res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf2 out=ecl_parameters_sf2 prefix=b_sf2_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_sf3;
proc reg data=stage2_10;
model lead2_res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf3 out=ecl_parameters_sf3 prefix=b_sf3_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_sf4;
proc reg data=stage2_10;
model lead3_res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf4 out=ecl_parameters_sf4 prefix=b_sf4_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_sf5;
proc reg data=stage2_10;
model lead4_res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf5 out=ecl_parameters_sf5 prefix=b_sf5_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_sf6;
proc reg data=stage2_10;
model lead5_res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf6 out=ecl_parameters_sf6 prefix=b_sf6_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_sf7;
proc reg data=stage2_10;
model lead6_res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf7 out=ecl_parameters_sf7 prefix=b_sf7_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_sf8;
proc reg data=stage2_10;
model lead7_res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf8 out=ecl_parameters_sf8 prefix=b_sf8_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

*Non-single-family real estate loans;
proc sort data=stage2_10; by group rollreg_rankdate; run;
ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre1;
proc reg data=stage2_10;
model res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre1 out=ecl_parameters_nonsfre1 prefix=b_nonsfre1_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre2;
proc reg data=stage2_10;
model lead1_res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre2 out=ecl_parameters_nonsfre2 prefix=b_nonsfre2_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre3;
proc reg data=stage2_10;
model lead2_res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre3 out=ecl_parameters_nonsfre3 prefix=b_nonsfre3_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre4;
proc reg data=stage2_10;
model lead3_res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre4 out=ecl_parameters_nonsfre4 prefix=b_nonsfre4_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre5;
proc reg data=stage2_10;
model lead4_res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre5 out=ecl_parameters_nonsfre5 prefix=b_nonsfre5_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre6;
proc reg data=stage2_10;
model lead5_res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre6 out=ecl_parameters_nonsfre6 prefix=b_nonsfre6_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre7;
proc reg data=stage2_10;
model lead6_res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre7 out=ecl_parameters_nonsfre7 prefix=b_nonsfre7_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre8;
proc reg data=stage2_10;
model lead7_res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre8 out=ecl_parameters_nonsfre8 prefix=b_nonsfre8_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

*Consumer loans;
proc sort data=stage2_10; by group rollreg_rankdate; run;
ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons1;
proc reg data=stage2_10;
model res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons1 out=ecl_parameters_cons1 prefix=b_cons1_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons2;
proc reg data=stage2_10;
model lead1_res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons2 out=ecl_parameters_cons2 prefix=b_cons2_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons3;
proc reg data=stage2_10;
model lead2_res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons3 out=ecl_parameters_cons3 prefix=b_cons3_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons4;
proc reg data=stage2_10;
model lead3_res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons4 out=ecl_parameters_cons4 prefix=b_cons4_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons5;
proc reg data=stage2_10;
model lead4_res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons5 out=ecl_parameters_cons5 prefix=b_cons5_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons6;
proc reg data=stage2_10;
model lead5_res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons6 out=ecl_parameters_cons6 prefix=b_cons6_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons7;
proc reg data=stage2_10;
model lead6_res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons7 out=ecl_parameters_cons7 prefix=b_cons7_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons8;
proc reg data=stage2_10;
model lead7_res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons8 out=ecl_parameters_cons8 prefix=b_cons8_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

*Other non-RE loans;
proc sort data=stage2_10; by group rollreg_rankdate; run;
ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre1;
proc reg data=stage2_10;
model res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre1 out=ecl_parameters_othnonre1 prefix=b_othnonre1_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre2;
proc reg data=stage2_10;
model lead1_res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre2 out=ecl_parameters_othnonre2 prefix=b_othnonre2_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre3;
proc reg data=stage2_10;
model lead2_res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre3 out=ecl_parameters_othnonre3 prefix=b_othnonre3_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre4;
proc reg data=stage2_10;
model lead3_res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre4 out=ecl_parameters_othnonre4 prefix=b_othnonre4_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre5;
proc reg data=stage2_10;
model lead4_res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre5 out=ecl_parameters_othnonre5 prefix=b_othnonre5_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre6;
proc reg data=stage2_10;
model lead5_res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre6 out=ecl_parameters_othnonre6 prefix=b_othnonre6_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre7;
proc reg data=stage2_10;
model lead6_res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre7 out=ecl_parameters_othnonre7 prefix=b_othnonre7_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre8;
proc reg data=stage2_10;
model lead7_res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre8 out=ecl_parameters_othnonre8 prefix=b_othnonre8_;
by group rollreg_rankdate;
id variable;
var estimate;
run;


*Merge all coefficients into one file;
proc sql;
create table ecl_parameters as select a.*, b.*
from ecl_parameters_sf1 a left join ecl_parameters_sf2 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_sf3 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_sf4 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_sf5 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_sf6 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_sf7 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_sf8 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre1 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre2 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre3 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre4 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre5 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre6 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre7 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre8 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons1 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons2 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons3 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons4 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons5 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons6 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons7 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons8 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre1 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre2 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre3 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre4 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre5 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre6 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre7 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre8 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;
quit;


/*MERGE WITH ECL ESTIMATES*/
*Create table with all ECL vintage forecasts by loan type;
proc sql;
create table ecl_all1 as select a.snlkey, a.rankdate, b.ecl_singlefam_t,ecl_singlefam_lag1,ecl_singlefam_lag2,ecl_singlefam_lag3,ecl_singlefam_lag4,
ecl_singlefam_lag5,ecl_singlefam_lag6,ecl_singlefam_lag7,ecl_singlefam_lag8,ecl_singlefam_lag9,ecl_singlefam_lag10,ecl_singlefam_lag11,ecl_singlefam_lag12,
ecl_singlefam_lag13,ecl_singlefam_lag14,ecl_singlefam_lag15,ecl_singlefam_lag16,ecl_singlefam_lag17,ecl_singlefam_lag18,ecl_singlefam_lag19,ecl_singlefam_lag20,
ecl_singlefam_lag21,ecl_singlefam_lag22,ecl_singlefam_lag23, param as param_sf, cum_loss as cum_loss_sf, wtd_lags as wtd_lags_sf, model as model_sf
from box.cecl_step2_start a left join box.ecl_sf_maxrsq b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table ecl_all2 as select a.*, b.ecl_nonsfre_t,ecl_nonsfre_lag1,ecl_nonsfre_lag2,ecl_nonsfre_lag3,ecl_nonsfre_lag4,
ecl_nonsfre_lag5,ecl_nonsfre_lag6,ecl_nonsfre_lag7,ecl_nonsfre_lag8,ecl_nonsfre_lag9,ecl_nonsfre_lag10,ecl_nonsfre_lag11,ecl_nonsfre_lag12,
ecl_nonsfre_lag13,ecl_nonsfre_lag14,ecl_nonsfre_lag15,ecl_nonsfre_lag16,ecl_nonsfre_lag17,ecl_nonsfre_lag18,ecl_nonsfre_lag19,ecl_nonsfre_lag20,
ecl_nonsfre_lag21,ecl_nonsfre_lag22,ecl_nonsfre_lag23, param as param_nonsfre, cum_loss as cum_loss_nonsfre, wtd_lags as wtd_lags_nonsfre, model as model_nonsfre
from ecl_all1 a left join box.ecl_nonsfre_maxrsq b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table ecl_all3 as select a.*, b.ecl_cons_t,ecl_cons_lag1,ecl_cons_lag2,ecl_cons_lag3,ecl_cons_lag4,
ecl_cons_lag5,ecl_cons_lag6,ecl_cons_lag7,ecl_cons_lag8,ecl_cons_lag9,ecl_cons_lag10,ecl_cons_lag11,ecl_cons_lag12,
ecl_cons_lag13,ecl_cons_lag14,ecl_cons_lag15,ecl_cons_lag16,ecl_cons_lag17,ecl_cons_lag18,ecl_cons_lag19,ecl_cons_lag20,
ecl_cons_lag21,ecl_cons_lag22,ecl_cons_lag23, param as param_cons, cum_loss as cum_loss_cons, wtd_lags as wtd_lags_cons, model as model_cons
from ecl_all2 a left join box.ecl_cons_maxrsq b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table ecl_all4 as select a.*, b.ecl_othnonre_t,ecl_othnonre_lag1,ecl_othnonre_lag2,ecl_othnonre_lag3,ecl_othnonre_lag4,
ecl_othnonre_lag5,ecl_othnonre_lag6,ecl_othnonre_lag7,ecl_othnonre_lag8,ecl_othnonre_lag9,ecl_othnonre_lag10,ecl_othnonre_lag11,ecl_othnonre_lag12,
ecl_othnonre_lag13,ecl_othnonre_lag14,ecl_othnonre_lag15,ecl_othnonre_lag16,ecl_othnonre_lag17,ecl_othnonre_lag18,ecl_othnonre_lag19,ecl_othnonre_lag20,
ecl_othnonre_lag21,ecl_othnonre_lag22,ecl_othnonre_lag23, param as param_othnonre, cum_loss as cum_loss_othnonre, wtd_lags as wtd_lags_othnonre, model as model_othnonre
from ecl_all3 a left join box.ecl_othnonre_maxrsq b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;

*Add Loans Data;
	proc sql;
	create table ecl_all5 as select a.*, b.loans
	from ecl_all4 a left join box.all_loans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.reloans
	from ecl_all5 a left join box.all_reloans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.sfloans
	from ecl_all5 a left join box.all_sfloans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.sfcndloans
	from ecl_all5 a left join box.all_sfcndloans_1990_2016 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.loans_hfs
	from ecl_all5 as a left join box.all_loans_hfs_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.mfloans
	from ecl_all5 as a left join box.all_mfloans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.creloans
	from ecl_all5 as a left join box.all_creloans_1990_2019 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.farmloans
	from ecl_all5 as a left join box.all_farmloans_1990_2019 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.consloans
	from ecl_all5 a left join box.all_consloans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.cniloans
	from ecl_all5 as a left join box.all_cniloans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.agloans
	from ecl_all5 as a left join box.all_agloans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.snlkey, a.rankdate;
	quit;

	data ecl_all6; set ecl_all5;
	if sfcndloans=. then sfcndloans=0;
	if loans_hfs=. then loans_hfs=0;
	sf_total = sfloans+sfcndloans;
	sf_htm = sf_total-loans_hfs;
	nonsfre = mfloans+creloans+farmloans;
	othnonre = cniloans+agloans;
	sf_htm_loans = sf_htm/loans;
	nonsfre_loans = nonsfre/loans;
	consloans_loans = consloans/loans;
	othnonre_loans = othnonre/loans;
	run;

*Add group # from prior file;
proc sort data=stage2_10 nodupkey out=groups; by snlkey rollreg_rankdate; run;
proc sql;
create table ecl_all7 as select a.*, b.group
from ecl_all6 a left join groups b
on a.snlkey=b.snlkey and a.rankdate=b.rollreg_rankdate;
quit;

*Scale ECL vintage estimates by loans;
data ecl_all8; set ecl_all7;
f1_ecl_sf = (ecl_singlefam_t)/sf_total;
f2_ecl_sf = (ecl_singlefam_lag1)/sf_total;
f3_ecl_sf = (ecl_singlefam_lag2)/sf_total;
f4_ecl_sf = (ecl_singlefam_lag3)/sf_total;
f5_ecl_sf = (ecl_singlefam_lag4)/sf_total;
f6_ecl_sf = (ecl_singlefam_lag5)/sf_total;
f7_ecl_sf = (ecl_singlefam_lag6)/sf_total;
f8_ecl_sf = (ecl_singlefam_lag7)/sf_total;

f1_ecl_nonsfre = (ecl_nonsfre_t)/nonsfre;
f2_ecl_nonsfre = (ecl_nonsfre_lag1)/nonsfre;
f3_ecl_nonsfre = (ecl_nonsfre_lag2)/nonsfre;
f4_ecl_nonsfre = (ecl_nonsfre_lag3)/nonsfre;
f5_ecl_nonsfre = (ecl_nonsfre_lag4)/nonsfre;
f6_ecl_nonsfre = (ecl_nonsfre_lag5)/nonsfre;
f7_ecl_nonsfre = (ecl_nonsfre_lag6)/nonsfre;
f8_ecl_nonsfre = (ecl_nonsfre_lag7)/nonsfre;

f1_ecl_cons = (ecl_cons_t)/consloans;
f2_ecl_cons = (ecl_cons_lag1)/consloans;
f3_ecl_cons = (ecl_cons_lag2)/consloans;
f4_ecl_cons = (ecl_cons_lag3)/consloans;
f5_ecl_cons = (ecl_cons_lag4)/consloans;
f6_ecl_cons = (ecl_cons_lag5)/consloans;
f7_ecl_cons = (ecl_cons_lag6)/consloans;
f8_ecl_cons = (ecl_cons_lag7)/consloans;

f1_ecl_othnonre = (ecl_othnonre_t)/othnonre;
f2_ecl_othnonre = (ecl_othnonre_lag1)/othnonre;
f3_ecl_othnonre = (ecl_othnonre_lag2)/othnonre;
f4_ecl_othnonre = (ecl_othnonre_lag3)/othnonre;
f5_ecl_othnonre = (ecl_othnonre_lag4)/othnonre;
f6_ecl_othnonre = (ecl_othnonre_lag5)/othnonre;
f7_ecl_othnonre = (ecl_othnonre_lag6)/othnonre;
f8_ecl_othnonre = (ecl_othnonre_lag7)/othnonre;
run;

*Merge macro factor coefficients;
proc sql;
create table ecl_all9 as select a.*, b.*
from ecl_all8 a left join ecl_parameters b
on a.group=b.group and a.rankdate=b.rollreg_rankdate;
quit;

*Merge macro factors;
data macro_factors (keep=rankdate ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_cs_1y ch_cs_2y avg_tighten_1y avg_tighten_2y); set stage2_10; run;
proc sort data=macro_factors nodupkey; by rankdate; run;
proc sql;
create table ecl_all10 as select a.*, b.ch_npl_sf_1q, b.ch_npl_sf_2q, b.ch_npl_nonsfre_1q, b.ch_npl_nonsfre_2q, b.ch_npl_cons_1q, b.ch_npl_cons_2q, b.ch_npl_othnonre_1q, b.ch_npl_othnonre_2q
from ecl_all9 a left join stage2_5 b
on a.snlkey=b.snlkey and a.rankdate=b.rollreg_rankdate=b.rankdate;

create table ecl_all10 as select a.*, b.ch_unemp_1y, b.ch_unemp_2y, b.ch_gdp_1y, b.ch_gdp_2y, b.ch_cs_1y, b.ch_cs_2y, b.avg_tighten_1y, b.avg_tighten_2y
from ecl_all10 a left join macro_factors b
on a.rankdate=b.rankdate order by a.rankdate, a.snlkey;
quit;

*Adjust forecasted charge-off rates for year t+1;
data ecl_all11; set ecl_all10;
sf1_adj = (ch_npl_sf_1q*b_sf1_ch_npl_sf_1q + ch_npl_sf_2q*b_sf1_ch_npl_sf_2q + ch_unemp_1y*b_sf1_ch_unemp_1y + ch_unemp_2y*b_sf1_ch_unemp_2y + ch_cs_1y*b_sf1_ch_cs_1y + ch_cs_2y*b_sf1_ch_cs_2y);
sf2_adj = (ch_npl_sf_1q*b_sf2_ch_npl_sf_1q + ch_npl_sf_2q*b_sf2_ch_npl_sf_2q + ch_unemp_1y*b_sf2_ch_unemp_1y + ch_unemp_2y*b_sf2_ch_unemp_2y + ch_cs_1y*b_sf2_ch_cs_1y + ch_cs_2y*b_sf2_ch_cs_2y);
sf3_adj = (ch_npl_sf_1q*b_sf3_ch_npl_sf_1q + ch_npl_sf_2q*b_sf3_ch_npl_sf_2q + ch_unemp_1y*b_sf3_ch_unemp_1y + ch_unemp_2y*b_sf3_ch_unemp_2y + ch_cs_1y*b_sf3_ch_cs_1y + ch_cs_2y*b_sf3_ch_cs_2y);
sf4_adj = (ch_npl_sf_1q*b_sf4_ch_npl_sf_1q + ch_npl_sf_2q*b_sf4_ch_npl_sf_2q + ch_unemp_1y*b_sf4_ch_unemp_1y + ch_unemp_2y*b_sf4_ch_unemp_2y + ch_cs_1y*b_sf4_ch_cs_1y + ch_cs_2y*b_sf4_ch_cs_2y);
sf5_adj = (ch_npl_sf_1q*b_sf5_ch_npl_sf_1q + ch_npl_sf_2q*b_sf5_ch_npl_sf_2q + ch_unemp_1y*b_sf5_ch_unemp_1y + ch_unemp_2y*b_sf5_ch_unemp_2y + ch_cs_1y*b_sf5_ch_cs_1y + ch_cs_2y*b_sf5_ch_cs_2y);
sf6_adj = (ch_npl_sf_1q*b_sf6_ch_npl_sf_1q + ch_npl_sf_2q*b_sf6_ch_npl_sf_2q + ch_unemp_1y*b_sf6_ch_unemp_1y + ch_unemp_2y*b_sf6_ch_unemp_2y + ch_cs_1y*b_sf6_ch_cs_1y + ch_cs_2y*b_sf6_ch_cs_2y);
sf7_adj = (ch_npl_sf_1q*b_sf7_ch_npl_sf_1q + ch_npl_sf_2q*b_sf7_ch_npl_sf_2q + ch_unemp_1y*b_sf7_ch_unemp_1y + ch_unemp_2y*b_sf7_ch_unemp_2y + ch_cs_1y*b_sf7_ch_cs_1y + ch_cs_2y*b_sf7_ch_cs_2y);
sf8_adj = (ch_npl_sf_1q*b_sf8_ch_npl_sf_1q + ch_npl_sf_2q*b_sf8_ch_npl_sf_2q + ch_unemp_1y*b_sf8_ch_unemp_1y + ch_unemp_2y*b_sf8_ch_unemp_2y + ch_cs_1y*b_sf8_ch_cs_1y + ch_cs_2y*b_sf8_ch_cs_2y);


nonsfre1_adj = (ch_npl_nonsfre_1q*b_nonsfre1_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre1_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre1_ch_cs_1y + ch_cs_2y*b_nonsfre1_ch_cs_2y + ch_gdp_1y*b_nonsfre1_ch_gdp_1y + ch_gdp_2y*b_nonsfre1_ch_gdp_2y);
nonsfre2_adj = (ch_npl_nonsfre_1q*b_nonsfre2_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre2_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre2_ch_cs_1y + ch_cs_2y*b_nonsfre2_ch_cs_2y + ch_gdp_1y*b_nonsfre2_ch_gdp_1y + ch_gdp_2y*b_nonsfre2_ch_gdp_2y);
nonsfre3_adj = (ch_npl_nonsfre_1q*b_nonsfre3_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre3_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre3_ch_cs_1y + ch_cs_2y*b_nonsfre3_ch_cs_2y + ch_gdp_1y*b_nonsfre3_ch_gdp_1y + ch_gdp_2y*b_nonsfre3_ch_gdp_2y);
nonsfre4_adj = (ch_npl_nonsfre_1q*b_nonsfre4_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre4_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre4_ch_cs_1y + ch_cs_2y*b_nonsfre4_ch_cs_2y + ch_gdp_1y*b_nonsfre4_ch_gdp_1y + ch_gdp_2y*b_nonsfre4_ch_gdp_2y);
nonsfre5_adj = (ch_npl_nonsfre_1q*b_nonsfre5_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre5_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre5_ch_cs_1y + ch_cs_2y*b_nonsfre5_ch_cs_2y + ch_gdp_1y*b_nonsfre5_ch_gdp_1y + ch_gdp_2y*b_nonsfre5_ch_gdp_2y);
nonsfre6_adj = (ch_npl_nonsfre_1q*b_nonsfre6_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre6_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre6_ch_cs_1y + ch_cs_2y*b_nonsfre6_ch_cs_2y + ch_gdp_1y*b_nonsfre6_ch_gdp_1y + ch_gdp_2y*b_nonsfre6_ch_gdp_2y);
nonsfre7_adj = (ch_npl_nonsfre_1q*b_nonsfre7_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre7_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre7_ch_cs_1y + ch_cs_2y*b_nonsfre7_ch_cs_2y + ch_gdp_1y*b_nonsfre7_ch_gdp_1y + ch_gdp_2y*b_nonsfre7_ch_gdp_2y);
nonsfre8_adj = (ch_npl_nonsfre_1q*b_nonsfre8_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre8_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre8_ch_cs_1y + ch_cs_2y*b_nonsfre8_ch_cs_2y + ch_gdp_1y*b_nonsfre8_ch_gdp_1y + ch_gdp_2y*b_nonsfre8_ch_gdp_2y);

cons1_adj = (ch_npl_cons_1q*b_cons1_ch_npl_cons_1q + ch_npl_cons_2q*b_cons1_ch_npl_cons_2q + ch_unemp_1y*b_cons1_ch_unemp_1y + ch_unemp_2y*b_cons1_ch_unemp_2y + ch_gdp_1y*b_cons1_ch_gdp_1y + ch_gdp_2y*b_cons1_ch_gdp_2y);
cons2_adj = (ch_npl_cons_1q*b_cons2_ch_npl_cons_1q + ch_npl_cons_2q*b_cons2_ch_npl_cons_2q + ch_unemp_1y*b_cons2_ch_unemp_1y + ch_unemp_2y*b_cons2_ch_unemp_2y + ch_gdp_1y*b_cons2_ch_gdp_1y + ch_gdp_2y*b_cons2_ch_gdp_2y);
cons3_adj = (ch_npl_cons_1q*b_cons3_ch_npl_cons_1q + ch_npl_cons_2q*b_cons3_ch_npl_cons_2q + ch_unemp_1y*b_cons3_ch_unemp_1y + ch_unemp_2y*b_cons3_ch_unemp_2y + ch_gdp_1y*b_cons3_ch_gdp_1y + ch_gdp_2y*b_cons3_ch_gdp_2y);
cons4_adj = (ch_npl_cons_1q*b_cons4_ch_npl_cons_1q + ch_npl_cons_2q*b_cons4_ch_npl_cons_2q + ch_unemp_1y*b_cons4_ch_unemp_1y + ch_unemp_2y*b_cons4_ch_unemp_2y + ch_gdp_1y*b_cons4_ch_gdp_1y + ch_gdp_2y*b_cons4_ch_gdp_2y);
cons5_adj = (ch_npl_cons_1q*b_cons5_ch_npl_cons_1q + ch_npl_cons_2q*b_cons5_ch_npl_cons_2q + ch_unemp_1y*b_cons5_ch_unemp_1y + ch_unemp_2y*b_cons5_ch_unemp_2y + ch_gdp_1y*b_cons5_ch_gdp_1y + ch_gdp_2y*b_cons5_ch_gdp_2y);
cons6_adj = (ch_npl_cons_1q*b_cons6_ch_npl_cons_1q + ch_npl_cons_2q*b_cons6_ch_npl_cons_2q + ch_unemp_1y*b_cons6_ch_unemp_1y + ch_unemp_2y*b_cons6_ch_unemp_2y + ch_gdp_1y*b_cons6_ch_gdp_1y + ch_gdp_2y*b_cons6_ch_gdp_2y);
cons7_adj = (ch_npl_cons_1q*b_cons7_ch_npl_cons_1q + ch_npl_cons_2q*b_cons7_ch_npl_cons_2q + ch_unemp_1y*b_cons7_ch_unemp_1y + ch_unemp_2y*b_cons7_ch_unemp_2y + ch_gdp_1y*b_cons7_ch_gdp_1y + ch_gdp_2y*b_cons7_ch_gdp_2y);
cons8_adj = (ch_npl_cons_1q*b_cons8_ch_npl_cons_1q + ch_npl_cons_2q*b_cons8_ch_npl_cons_2q + ch_unemp_1y*b_cons8_ch_unemp_1y + ch_unemp_2y*b_cons8_ch_unemp_2y + ch_gdp_1y*b_cons8_ch_gdp_1y + ch_gdp_2y*b_cons8_ch_gdp_2y);

othnonre1_adj = (ch_npl_othnonre_1q*b_othnonre1_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre1_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre1_ch_gdp_1y + ch_gdp_2y*b_othnonre1_ch_gdp_2y + avg_tighten_1y*b_othnonre1_avg_tighten_1y + avg_tighten_2y*b_othnonre1_avg_tighten_2y);
othnonre2_adj = (ch_npl_othnonre_1q*b_othnonre2_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre2_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre2_ch_gdp_1y + ch_gdp_2y*b_othnonre2_ch_gdp_2y + avg_tighten_1y*b_othnonre2_avg_tighten_1y + avg_tighten_2y*b_othnonre2_avg_tighten_2y);
othnonre3_adj = (ch_npl_othnonre_1q*b_othnonre3_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre3_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre3_ch_gdp_1y + ch_gdp_2y*b_othnonre3_ch_gdp_2y + avg_tighten_1y*b_othnonre3_avg_tighten_1y + avg_tighten_2y*b_othnonre3_avg_tighten_2y);
othnonre4_adj = (ch_npl_othnonre_1q*b_othnonre4_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre4_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre4_ch_gdp_1y + ch_gdp_2y*b_othnonre4_ch_gdp_2y + avg_tighten_1y*b_othnonre4_avg_tighten_1y + avg_tighten_2y*b_othnonre4_avg_tighten_2y);
othnonre5_adj = (ch_npl_othnonre_1q*b_othnonre5_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre5_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre5_ch_gdp_1y + ch_gdp_2y*b_othnonre5_ch_gdp_2y + avg_tighten_1y*b_othnonre5_avg_tighten_1y + avg_tighten_2y*b_othnonre5_avg_tighten_2y);
othnonre6_adj = (ch_npl_othnonre_1q*b_othnonre6_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre6_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre6_ch_gdp_1y + ch_gdp_2y*b_othnonre6_ch_gdp_2y + avg_tighten_1y*b_othnonre6_avg_tighten_1y + avg_tighten_2y*b_othnonre6_avg_tighten_2y);
othnonre7_adj = (ch_npl_othnonre_1q*b_othnonre7_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre7_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre7_ch_gdp_1y + ch_gdp_2y*b_othnonre7_ch_gdp_2y + avg_tighten_1y*b_othnonre7_avg_tighten_1y + avg_tighten_2y*b_othnonre7_avg_tighten_2y);
othnonre8_adj = (ch_npl_othnonre_1q*b_othnonre8_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre8_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre8_ch_gdp_1y + ch_gdp_2y*b_othnonre8_ch_gdp_2y + avg_tighten_1y*b_othnonre8_avg_tighten_1y + avg_tighten_2y*b_othnonre8_avg_tighten_2y);


if f1_ecl_sf ne 0 then adj_f1_ecl_sf = f1_ecl_sf+sf1_adj; else adj_f1_ecl_sf=0;
if f2_ecl_sf ne 0 then adj_f2_ecl_sf = f2_ecl_sf+sf2_adj; else adj_f2_ecl_sf=0;
if f3_ecl_sf ne 0 then adj_f3_ecl_sf = f3_ecl_sf+sf3_adj; else adj_f3_ecl_sf=0;
if f4_ecl_sf ne 0 then adj_f4_ecl_sf = f4_ecl_sf+sf4_adj; else adj_f4_ecl_sf=0;
if f5_ecl_sf ne 0 then adj_f5_ecl_sf = f5_ecl_sf+sf5_adj; else adj_f5_ecl_sf=0;
if f6_ecl_sf ne 0 then adj_f6_ecl_sf = f6_ecl_sf+sf6_adj; else adj_f6_ecl_sf=0;
if f7_ecl_sf ne 0 then adj_f7_ecl_sf = f7_ecl_sf+sf7_adj; else adj_f7_ecl_sf=0;
if f8_ecl_sf ne 0 then adj_f8_ecl_sf = f8_ecl_sf+sf8_adj; else adj_f8_ecl_sf=0;

if f1_ecl_nonsfre ne 0 then adj_f1_ecl_nonsfre = f1_ecl_nonsfre+nonsfre1_adj; else adj_f1_ecl_nonsfre=0;
if f2_ecl_nonsfre ne 0 then adj_f2_ecl_nonsfre = f2_ecl_nonsfre+nonsfre2_adj; else adj_f2_ecl_nonsfre=0;
if f3_ecl_nonsfre ne 0 then adj_f3_ecl_nonsfre = f3_ecl_nonsfre+nonsfre3_adj; else adj_f3_ecl_nonsfre=0;
if f4_ecl_nonsfre ne 0 then adj_f4_ecl_nonsfre = f4_ecl_nonsfre+nonsfre4_adj; else adj_f4_ecl_nonsfre=0;
if f5_ecl_nonsfre ne 0 then adj_f5_ecl_nonsfre = f5_ecl_nonsfre+nonsfre5_adj; else adj_f5_ecl_nonsfre=0;
if f6_ecl_nonsfre ne 0 then adj_f6_ecl_nonsfre = f6_ecl_nonsfre+nonsfre6_adj; else adj_f6_ecl_nonsfre=0;
if f7_ecl_nonsfre ne 0 then adj_f7_ecl_nonsfre = f7_ecl_nonsfre+nonsfre7_adj; else adj_f7_ecl_nonsfre=0;
if f8_ecl_nonsfre ne 0 then adj_f8_ecl_nonsfre = f8_ecl_nonsfre+nonsfre8_adj; else adj_f8_ecl_nonsfre=0;

if f1_ecl_cons ne 0 then adj_f1_ecl_cons = f1_ecl_cons+cons1_adj; else adj_f1_ecl_cons=0;
if f2_ecl_cons ne 0 then adj_f2_ecl_cons = f2_ecl_cons+cons2_adj; else adj_f2_ecl_cons=0;
if f3_ecl_cons ne 0 then adj_f3_ecl_cons = f3_ecl_cons+cons3_adj; else adj_f3_ecl_cons=0;
if f4_ecl_cons ne 0 then adj_f4_ecl_cons = f4_ecl_cons+cons4_adj; else adj_f4_ecl_cons=0;
if f5_ecl_cons ne 0 then adj_f5_ecl_cons = f5_ecl_cons+cons5_adj; else adj_f5_ecl_cons=0;
if f6_ecl_cons ne 0 then adj_f6_ecl_cons = f6_ecl_cons+cons6_adj; else adj_f6_ecl_cons=0;
if f7_ecl_cons ne 0 then adj_f7_ecl_cons = f7_ecl_cons+cons7_adj; else adj_f7_ecl_cons=0;
if f8_ecl_cons ne 0 then adj_f8_ecl_cons = f8_ecl_cons+cons8_adj; else adj_f8_ecl_cons=0;

if f1_ecl_othnonre ne 0 then adj_f1_ecl_othnonre = f1_ecl_othnonre+othnonre1_adj; else adj_f1_ecl_othnonre=0;
if f2_ecl_othnonre ne 0 then adj_f2_ecl_othnonre = f2_ecl_othnonre+othnonre2_adj; else adj_f2_ecl_othnonre=0;
if f3_ecl_othnonre ne 0 then adj_f3_ecl_othnonre = f3_ecl_othnonre+othnonre3_adj; else adj_f3_ecl_othnonre=0;
if f4_ecl_othnonre ne 0 then adj_f4_ecl_othnonre = f4_ecl_othnonre+othnonre4_adj; else adj_f4_ecl_othnonre=0;
if f5_ecl_othnonre ne 0 then adj_f5_ecl_othnonre = f5_ecl_othnonre+othnonre5_adj; else adj_f5_ecl_othnonre=0;
if f6_ecl_othnonre ne 0 then adj_f6_ecl_othnonre = f6_ecl_othnonre+othnonre6_adj; else adj_f6_ecl_othnonre=0;
if f7_ecl_othnonre ne 0 then adj_f7_ecl_othnonre = f7_ecl_othnonre+othnonre7_adj; else adj_f7_ecl_othnonre=0;
if f8_ecl_othnonre ne 0 then adj_f8_ecl_othnonre = f8_ecl_othnonre+othnonre8_adj; else adj_f8_ecl_othnonre=0;

*Calculate base ECL;
ecl_sf_base = ecl_singlefam_t + ecl_singlefam_lag1 + ecl_singlefam_lag2 + ecl_singlefam_lag3 + ecl_singlefam_lag4 + ecl_singlefam_lag5 + ecl_singlefam_lag6 + ecl_singlefam_lag7 + ecl_singlefam_lag8 + ecl_singlefam_lag9 + ecl_singlefam_lag10 + ecl_singlefam_lag11 + ecl_singlefam_lag12 + ecl_singlefam_lag13 + ecl_singlefam_lag14 + ecl_singlefam_lag15 + ecl_singlefam_lag16 + ecl_singlefam_lag17 + ecl_singlefam_lag18 + ecl_singlefam_lag19
+ ecl_singlefam_lag20 + ecl_singlefam_lag21 + ecl_singlefam_lag22 + ecl_singlefam_lag23;
ecl_nonsfre_base = ecl_nonsfre_t + ecl_nonsfre_lag1 + ecl_nonsfre_lag2 + ecl_nonsfre_lag3 + ecl_nonsfre_lag4 + ecl_nonsfre_lag5 + ecl_nonsfre_lag6 + ecl_nonsfre_lag7 + ecl_nonsfre_lag8 + ecl_nonsfre_lag9 + ecl_nonsfre_lag10 + ecl_nonsfre_lag11 + ecl_nonsfre_lag12 + ecl_nonsfre_lag13 + ecl_nonsfre_lag14 + ecl_nonsfre_lag15 + ecl_nonsfre_lag16 + ecl_nonsfre_lag17 + ecl_nonsfre_lag18 + ecl_nonsfre_lag19
+ ecl_nonsfre_lag20 + ecl_nonsfre_lag21 + ecl_nonsfre_lag22 + ecl_nonsfre_lag23;
ecl_cons_base = ecl_cons_t + ecl_cons_lag1 + ecl_cons_lag2 + ecl_cons_lag3 + ecl_cons_lag4 + ecl_cons_lag5 + ecl_cons_lag6 + ecl_cons_lag7 + ecl_cons_lag8 + ecl_cons_lag9 + ecl_cons_lag10 + ecl_cons_lag11 + ecl_cons_lag12 + ecl_cons_lag13 + ecl_cons_lag14 + ecl_cons_lag15 + ecl_cons_lag16 + ecl_cons_lag17 + ecl_cons_lag18 + ecl_cons_lag19
+ ecl_cons_lag20 + ecl_cons_lag21 + ecl_cons_lag22 + ecl_cons_lag23;
ecl_othnonre_base = ecl_othnonre_t + ecl_othnonre_lag1 + ecl_othnonre_lag2 + ecl_othnonre_lag3 + ecl_othnonre_lag4 + ecl_othnonre_lag5 + ecl_othnonre_lag6 + ecl_othnonre_lag7 + ecl_othnonre_lag8 + ecl_othnonre_lag9 + ecl_othnonre_lag10 + ecl_othnonre_lag11 + ecl_othnonre_lag12 + ecl_othnonre_lag13 + ecl_othnonre_lag14 + ecl_othnonre_lag15 + ecl_othnonre_lag16 + ecl_othnonre_lag17 + ecl_othnonre_lag18 + ecl_othnonre_lag19
+ ecl_othnonre_lag20 + ecl_othnonre_lag21 + ecl_othnonre_lag22 + ecl_othnonre_lag23;
ecl_base = ecl_sf_base + ecl_nonsfre_base + ecl_cons_base + ecl_othnonre_base;

*Calculate ECL adjusted for macroeconomic factors;
ecl_sf = (adj_f1_ecl_sf*sf_total)+(adj_f2_ecl_sf*sf_total)+(adj_f3_ecl_sf*sf_total)+(adj_f4_ecl_sf*sf_total)+(adj_f5_ecl_sf*sf_total)+(adj_f6_ecl_sf*sf_total)+(adj_f7_ecl_sf*sf_total)+(adj_f8_ecl_sf*sf_total)+ ecl_singlefam_lag9 + ecl_singlefam_lag10 + ecl_singlefam_lag11 + ecl_singlefam_lag12 + ecl_singlefam_lag13 + ecl_singlefam_lag14 + ecl_singlefam_lag15 + ecl_singlefam_lag16 + ecl_singlefam_lag17 + ecl_singlefam_lag18 + ecl_singlefam_lag19
+ ecl_singlefam_lag20 + ecl_singlefam_lag21 + ecl_singlefam_lag22 + ecl_singlefam_lag23;
ecl_nonsfre = (adj_f1_ecl_nonsfre*nonsfre)+(adj_f2_ecl_nonsfre*nonsfre)+(adj_f3_ecl_nonsfre*nonsfre)+(adj_f4_ecl_nonsfre*nonsfre)+(adj_f5_ecl_nonsfre*nonsfre)+(adj_f6_ecl_nonsfre*nonsfre)+(adj_f7_ecl_nonsfre*nonsfre)+(adj_f8_ecl_nonsfre*nonsfre) + ecl_nonsfre_lag9 + ecl_nonsfre_lag10 + ecl_nonsfre_lag11 + ecl_nonsfre_lag12 + ecl_nonsfre_lag13 + ecl_nonsfre_lag14 + ecl_nonsfre_lag15 + ecl_nonsfre_lag16 + ecl_nonsfre_lag17 + ecl_nonsfre_lag18 + ecl_nonsfre_lag19
+ ecl_nonsfre_lag20 + ecl_nonsfre_lag21 + ecl_nonsfre_lag22 + ecl_nonsfre_lag23;
ecl_cons = (adj_f1_ecl_cons*consloans)+(adj_f2_ecl_cons*consloans)+(adj_f3_ecl_cons*consloans)+(adj_f4_ecl_cons*consloans)+(adj_f5_ecl_cons*consloans)+(adj_f6_ecl_cons*consloans)+(adj_f7_ecl_cons*consloans)+(adj_f8_ecl_cons*consloans)+ ecl_cons_lag9 + ecl_cons_lag10 + ecl_cons_lag11 + ecl_cons_lag12 + ecl_cons_lag13 + ecl_cons_lag14 + ecl_cons_lag15 + ecl_cons_lag16 + ecl_cons_lag17 + ecl_cons_lag18 + ecl_cons_lag19
+ ecl_cons_lag20 + ecl_cons_lag21 + ecl_cons_lag22 + ecl_cons_lag23;
ecl_othnonre = (adj_f1_ecl_othnonre*othnonre)+(adj_f2_ecl_othnonre*othnonre)+(adj_f3_ecl_othnonre*othnonre)+(adj_f4_ecl_othnonre*othnonre)+(adj_f5_ecl_othnonre*othnonre)+(adj_f6_ecl_othnonre*othnonre)+(adj_f7_ecl_othnonre*othnonre)+(adj_f8_ecl_othnonre*othnonre)+ ecl_othnonre_lag9 + ecl_othnonre_lag10 + ecl_othnonre_lag11 + ecl_othnonre_lag12 + ecl_othnonre_lag13 + ecl_othnonre_lag14 + ecl_othnonre_lag15 + ecl_othnonre_lag16 + ecl_othnonre_lag17 + ecl_othnonre_lag18 + ecl_othnonre_lag19
+ ecl_othnonre_lag20 + ecl_othnonre_lag21 + ecl_othnonre_lag22 + ecl_othnonre_lag23;
ecl = ecl_sf + ecl_nonsfre + ecl_cons + ecl_othnonre;

*Calculate effect of macroeconomic adjustments;
ecl_adj_sf = ecl_sf-ecl_sf_base;
ecl_adj_nonsfre = ecl_nonsfre-ecl_nonsfre_base;
ecl_adj_cons = ecl_cons-ecl_cons_base;
ecl_adj_othnonre = ecl_othnonre-ecl_othnonre_base;
ecl_adj_total = ecl - ecl_base;

*Calculate ECL projections by year;
ecl_year1_base = ecl_singlefam_t + ecl_singlefam_lag1 + ecl_singlefam_lag2 + ecl_singlefam_lag3 + ecl_nonsfre_t + ecl_nonsfre_lag1 + ecl_nonsfre_lag2 + ecl_nonsfre_lag3 + ecl_cons_t + ecl_cons_lag1 + ecl_cons_lag2 + ecl_cons_lag3 + ecl_othnonre_t + ecl_othnonre_lag1 + ecl_othnonre_lag2 + ecl_othnonre_lag3;
ecl_year1_adj = (adj_f1_ecl_sf*sf_total)+(adj_f2_ecl_sf*sf_total)+(adj_f3_ecl_sf*sf_total)+(adj_f4_ecl_sf*sf_total) + (adj_f1_ecl_nonsfre*nonsfre)+(adj_f2_ecl_nonsfre*nonsfre)+(adj_f3_ecl_nonsfre*nonsfre)+(adj_f4_ecl_nonsfre*nonsfre) + (adj_f1_ecl_cons*consloans)+(adj_f2_ecl_cons*consloans)+(adj_f3_ecl_cons*consloans)+(adj_f4_ecl_cons*consloans) + (adj_f1_ecl_othnonre*othnonre)+(adj_f2_ecl_othnonre*othnonre)+(adj_f3_ecl_othnonre*othnonre)+(adj_f4_ecl_othnonre*othnonre);
ecl_year2_adj = (adj_f5_ecl_sf*sf_total)+(adj_f6_ecl_sf*sf_total)+(adj_f7_ecl_sf*sf_total)+(adj_f8_ecl_sf*sf_total) + (adj_f5_ecl_nonsfre*nonsfre)+(adj_f6_ecl_nonsfre*nonsfre)+(adj_f7_ecl_nonsfre*nonsfre)+(adj_f8_ecl_nonsfre*nonsfre) + (adj_f5_ecl_cons*consloans)+(adj_f6_ecl_cons*consloans)+(adj_f7_ecl_cons*consloans)+(adj_f8_ecl_cons*consloans) + (adj_f5_ecl_othnonre*othnonre)+(adj_f6_ecl_othnonre*othnonre)+(adj_f7_ecl_othnonre*othnonre)+(adj_f8_ecl_othnonre*othnonre);
ecl_year2 = ecl_singlefam_lag4 + ecl_singlefam_lag5 + ecl_singlefam_lag6 + ecl_singlefam_lag7 + ecl_nonsfre_lag4 + ecl_nonsfre_lag5 + ecl_nonsfre_lag6 + ecl_nonsfre_lag7 + ecl_cons_lag4 + ecl_cons_lag5 + ecl_cons_lag6 + ecl_cons_lag7 + ecl_othnonre_lag4 + ecl_othnonre_lag5 + ecl_othnonre_lag6 + ecl_othnonre_lag7;
ecl_year3 = ecl_singlefam_lag8 + ecl_singlefam_lag9 + ecl_singlefam_lag10 + ecl_singlefam_lag11 + ecl_nonsfre_lag8 + ecl_nonsfre_lag9 + ecl_nonsfre_lag10 + ecl_nonsfre_lag11 + ecl_cons_lag8 + ecl_cons_lag9 + ecl_cons_lag10 + ecl_cons_lag11 + ecl_othnonre_lag8 + ecl_othnonre_lag9 + ecl_othnonre_lag10 + ecl_othnonre_lag11;
ecl_year4 = ecl_singlefam_lag12 + ecl_singlefam_lag13 + ecl_singlefam_lag14 + ecl_singlefam_lag15 + ecl_nonsfre_lag12 + ecl_nonsfre_lag13 + ecl_nonsfre_lag14 + ecl_nonsfre_lag15 + ecl_cons_lag12 + ecl_cons_lag13 + ecl_cons_lag14 + ecl_cons_lag15 + ecl_othnonre_lag12 + ecl_othnonre_lag13 + ecl_othnonre_lag14 + ecl_othnonre_lag15;
ecl_year5 = ecl_singlefam_lag16 + ecl_singlefam_lag17 + ecl_singlefam_lag18 + ecl_singlefam_lag19 + ecl_nonsfre_lag16 + ecl_nonsfre_lag17 + ecl_nonsfre_lag18 + ecl_nonsfre_lag19 + ecl_cons_lag16 + ecl_cons_lag17 + ecl_cons_lag18 + ecl_cons_lag19 + ecl_othnonre_lag16 + ecl_othnonre_lag17 + ecl_othnonre_lag18 + ecl_othnonre_lag19;
ecl_year6 = ecl_singlefam_lag20 + ecl_singlefam_lag21 + ecl_singlefam_lag22 + ecl_singlefam_lag23 + ecl_nonsfre_lag20 + ecl_nonsfre_lag21 + ecl_nonsfre_lag22 + ecl_nonsfre_lag23 + ecl_cons_lag20 + ecl_cons_lag21 + ecl_cons_lag22 + ecl_cons_lag23 + ecl_othnonre_lag20 + ecl_othnonre_lag21 + ecl_othnonre_lag22 + ecl_othnonre_lag23;

ecl_year1_base_sf = ecl_singlefam_t + ecl_singlefam_lag1 + ecl_singlefam_lag2 + ecl_singlefam_lag3;
ecl_year1_base_nonsfre = ecl_nonsfre_t + ecl_nonsfre_lag1 + ecl_nonsfre_lag2 + ecl_nonsfre_lag3;
ecl_year1_base_cons = ecl_cons_t + ecl_cons_lag1 + ecl_cons_lag2 + ecl_cons_lag3;
ecl_year1_base_othnonre = ecl_othnonre_t + ecl_othnonre_lag1 + ecl_othnonre_lag2 + ecl_othnonre_lag3;
ecl_year1_adj_sf = (adj_f1_ecl_sf*sf_total)+(adj_f2_ecl_sf*sf_total)+(adj_f3_ecl_sf*sf_total)+(adj_f4_ecl_sf*sf_total);
ecl_year1_adj_nonsfre = (adj_f1_ecl_nonsfre*nonsfre)+(adj_f2_ecl_nonsfre*nonsfre)+(adj_f3_ecl_nonsfre*nonsfre)+(adj_f4_ecl_nonsfre*nonsfre);
ecl_year1_adj_cons = (adj_f1_ecl_cons*consloans)+(adj_f2_ecl_cons*consloans)+(adj_f3_ecl_cons*consloans)+(adj_f4_ecl_cons*consloans);
ecl_year1_adj_othnonre = (adj_f1_ecl_othnonre*othnonre)+(adj_f2_ecl_othnonre*othnonre)+(adj_f3_ecl_othnonre*othnonre)+(adj_f4_ecl_othnonre*othnonre);
ecl_year2_adj_sf = (adj_f5_ecl_sf*sf_total)+(adj_f6_ecl_sf*sf_total)+(adj_f7_ecl_sf*sf_total)+(adj_f8_ecl_sf*sf_total);
ecl_year2_adj_nonsfre = (adj_f5_ecl_nonsfre*nonsfre)+(adj_f6_ecl_nonsfre*nonsfre)+(adj_f7_ecl_nonsfre*nonsfre)+(adj_f8_ecl_nonsfre*nonsfre);
ecl_year2_adj_cons = (adj_f5_ecl_cons*consloans)+(adj_f6_ecl_cons*consloans)+(adj_f7_ecl_cons*consloans)+(adj_f8_ecl_cons*consloans);
ecl_year2_adj_othnonre = (adj_f5_ecl_othnonre*othnonre)+(adj_f6_ecl_othnonre*othnonre)+(adj_f7_ecl_othnonre*othnonre)+(adj_f8_ecl_othnonre*othnonre);

avg_cum_loss = (cum_loss_sf*sf_htm_loans)+(cum_loss_nonsfre*nonsfre_loans)+(cum_loss_cons*consloans_loans)+(cum_loss_othnonre*othnonre_loans);
avg_wtd_lags = (wtd_lags_sf*sf_htm_loans)+(wtd_lags_nonsfre*nonsfre_loans)+(wtd_lags_cons*consloans_loans)+(wtd_lags_othnonre*othnonre_loans);
avg_lags = (model_sf*sf_htm_loans)+(model_nonsfre*nonsfre_loans)+(model_cons*consloans_loans)+(model_othnonre*othnonre_loans);
run;


proc sql;
create table box.cecl_step2_finish_2ymac as select a.*, b.ecl, b.ecl_sf, b.ecl_nonsfre, b.ecl_cons, b.ecl_othnonre, b.ecl_base, b.ecl_sf_base, b.ecl_nonsfre_base, b.ecl_cons_base, b.ecl_othnonre_base,
b.ecl_adj_total, b.ecl_adj_sf, b.ecl_adj_nonsfre, b.ecl_adj_cons, b.ecl_adj_othnonre, b.ecl_year1_base, b.ecl_year1_adj, b.ecl_year2_adj, b.ecl_year2, b.ecl_year3, b.ecl_year4, b.ecl_year5, b.ecl_year6,
b.ecl_year1_base_sf, b.ecl_year1_base_nonsfre, b.ecl_year1_base_cons, b.ecl_year1_base_othnonre,
b.ecl_year1_adj_sf, b.ecl_year1_adj_nonsfre, b.ecl_year1_adj_cons, b.ecl_year1_adj_othnonre, b.ecl_year2_adj_sf, b.ecl_year2_adj_nonsfre, b.ecl_year2_adj_cons, b.ecl_year2_adj_othnonre, 
b.param_sf, b.param_nonsfre, b.param_cons, b.param_othnonre,
b.cum_loss_sf, b.cum_loss_nonsfre, b.cum_loss_cons, b.cum_loss_othnonre, b.wtd_lags_sf, b.wtd_lags_nonsfre, b.wtd_lags_cons, b.wtd_lags_othnonre, b.avg_cum_loss, b.avg_wtd_lags,
b.model_sf, b.model_nonsfre, b.model_cons, b.model_othnonre, b.avg_lags
from box.cecl_step2_start a left join ecl_all11 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
