/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below was used to generate the tables in the manuscript excluding Table 2.
		See separate code file for future charge-offs analysis.

 =========================================================================================================*/
 
 
bysort rankdate: egen r_cap = xtile(tier1), n(5)
gen low_cap = 0
replace low_cap = 1 if r_cap==1

bysort rankdate :egen r_nibp = xtile(nibp_ta), n(5)
gen low_nibp = 0
replace low_nibp = 1 if r_nibp==1

bysort rankdate : egen r_ecldiff = xtile(ecldiff_share), n(10)
bysort rankdate :egen r_ecldiff_base = xtile(ecldiff_base_share), n(10)
bysort rankdate :egen r_ecldiff_macro = xtile(ecldiff_macro_share), n(10)

gen ni_pos=0
replace ni_pos=nibp/shrout if nibp>0
gen ni_neg=0
replace ni_neg=nibp/shrout if nibp<0

gen under=.
replace under=1 if ecldiff_ecl>=.2
replace under=0 if ecldiff_ecl<=-.2

gen over10b=0
replace over10b=1 if ta>=10000000

*Table 1A
tabstat ecl_base_loans ecl_loans ecldiff_loans ecldiff_alll ecldiff_ta ecldiff_tier1 ecldiff_tce alll_loans npl_loans nco_loans ercl avg_cum_loss avg_wtd_lags loans_5plus_loans, stat(n mean sd min p5 p25 med p75 p95 max) save
mat T = r(StatTotal)' // the prime is for transposing the matrix

putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECL Measure.xlsx", replace // remember to specify the full path
putexcel A1 = matrix(T), names

*Table 1B: Correlations
corsp ecl_loans alll_loans npl_loans nco_loans ercl avg_cum_loss avg_wtd_lags loans_5plus_loans, sig

*Table 1C: ECL by Forecast Period
tabstat ecl_loans ecl_year1_loans ecl_year2_loans ecl_year3_loans ecl_year4_loans ecl_year5_loans ecl_year6_loans, stat(mean) save
mat T = r(StatTotal)

putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECL Estimated Emergence.xlsx", replace // remember to specify the full path
putexcel A1 = matrix(T), names

tabstat ecl_loans ecl_year1_loans ecl_year2_loans ecl_year3_loans ecl_year4_loans ecl_year5_loans ecl_year6_loans if avg_wtd_lags<=13, stat(mean) save
mat T = r(StatTotal)

putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECL Estimated Emergence - Low Wtd Lags.xlsx", replace // remember to specify the full path
putexcel A1 = matrix(T), names

tabstat ecl_loans ecl_year1_loans ecl_year2_loans ecl_year3_loans ecl_year4_loans ecl_year5_loans ecl_year6_loans if avg_wtd_lags>13, stat(mean) save
mat T = r(StatTotal)

putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECL Estimated Emergence - High Wtd Lags.xlsx", replace // remember to specify the full path
putexcel A1 = matrix(T), names

*Table 1D: Credit Loss Metrics by Year

tabstat ecl_loans ecl_base_loans ecldiff_macro_loans alll_loans npl_loans nco_loans ercl ecldiff_loans ecldiff_ta ecldiff_tier1 ecldiff_tce, by(snlyear) stat(mean)
tabstat alll_loans, by(snlyear) stat(n)

tabstat alll_loans if ecldiff_ecl >= .2, by(snlyear) stat(n)
tabstat alll_loans if ecldiff_ecl < .2 & ecldiff_ecl > -.2, by(snlyear) stat(n)
tabstat alll_loans if ecldiff_ecl <= -.2, by(snlyear) stat(n)

	*Analysis of switching
	tsset snlkey rankdate
	
	gen under=.
	replace under=1 if ecldiff_ecl>=.2
	replace under=0 if ecldiff_ecl<=-.2
	
	gen switch_to_under=0
	replace switch_to_under=1 if under==1 & l.under==0
	gen switch_to_over=0
	replace switch_to_over=1 if under==0 & l.under==1
	
	tabstat switch_to_under, by(snlyear) stat(sum)
	tabstat switch_to_over, by(snlyear) stat(sum)

	
*Table 3
ivreg2 ecldiff_base_loans ln_ta avg_cum_loss consloans_loans reloans_loans low_cap low_nibp acq i.rankdate, cluster(snlkey rankdate)
outreg2 using h1.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(4) tdec(2)
ivreg2 ecldiff_base_loans fas5_loans avg_wtd_lags ln_ta avg_cum_loss consloans_loans reloans_loans low_cap low_nibp acq i.rankdate, cluster(snlkey rankdate)
outreg2 using h1.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(4) tdec(2)
ivreg2 ecldiff_loans ln_ta avg_cum_loss consloans_loans reloans_loans low_cap low_nibp acq i.rankdate, cluster(snlkey rankdate)
outreg2 using h1.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(4) tdec(2)
ivreg2 ecldiff_loans fas5_loans avg_wtd_lags ln_ta avg_cum_loss consloans_loans reloans_loans low_cap low_nibp acq i.rankdate, cluster(snlkey rankdate)
outreg2 using h1.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(4) tdec(2)


*Table 4A
tabstat mve_share bve_share alll_share ecldiff_share ecldiff_base_share ecldiff_macro_share avgint_share reloans_share consloans_share rsa_share npl_share nco_share ni_pos ni_neg, stat(n mean sd min p5 p25 med p75 p95 max) save
mat T = r(StatTotal)' // the prime is for transposing the matrix

putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - Hypothesis Test.xlsx", replace // remember to specify the full path
putexcel A1 = matrix(T), names

*Table 4B: Correlations
corsp mve_share bve_share alll_share ecldiff_share ecldiff_base_share ecldiff_macro_share avgint_share reloans_share consloans_share rsa_share npl_share nco_share ni_pos ni_neg, sig

*Table 5
areg mve_share bve_share alll_share ecldiff_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
outreg2 using h2.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
areg mve_share bve_share alll_share ecldiff_base_share ecldiff_macro_share  avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
outreg2 using h2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
areg mve_share bve_share alll_share ecldiff_share npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
outreg2 using h2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
areg mve_share bve_share alll_share ecldiff_base_share ecldiff_macro_share npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
outreg2 using h2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)

*Table 6 - Greater or less than $10B
	
	*Deciles
	areg mve_share bve_share alll_share r_ecldiff over10b i.over10b##c.r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
	outreg2 using size.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro over10b i.over10b##c.r_ecldiff_base i.over10b##c.r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
	outreg2 using size.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff over10b i.over10b##c.r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if snlyear<=2012, absorb(rankdate) vce(cluster snlkey)
	outreg2 using size.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro over10b i.over10b##c.r_ecldiff_base i.over10b##c.r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if snlyear<=2012, absorb(rankdate) vce(cluster snlkey)
	outreg2 using size.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff over10b i.over10b##c.r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if snlyear>2012, absorb(rankdate) vce(cluster snlkey)
	outreg2 using size.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro over10b i.over10b##c.r_ecldiff_base i.over10b##c.r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if snlyear>2012, absorb(rankdate) vce(cluster snlkey)
	outreg2 using size.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)

		gen over10b_ecldiff = over10b * r_ecldiff
		gen over10b_ecldiff_base = over10b * r_ecldiff_base
		gen over10b_ecldiff_macro = over10b * r_ecldiff_macro
		
		*Difference in coefficients:
		tabulate snlyear, generate(y)
		
		quietly reg mve_share bve_share alll_share r_ecldiff over10b_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg y1 y2 y3 y4 y5 y6 y7 if snlyear<=2012
		est store reg1
		
		quietly reg mve_share bve_share alll_share r_ecldiff over10b_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg y8 y9 y10 y11 if snlyear>2012
		est store reg2
		
			quietly suest reg1 reg2, vce(cluster snlkey)
			test [reg2_mean]_b[over10b_ecldiff]+[reg2_mean]_b[r_ecldiff] = [reg1_mean]_b[over10b_ecldiff]+[reg1_mean]_b[r_ecldiff]


		quietly reg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro over10b over10b_ecldiff_base over10b_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg y1 y2 y3 y4 y5 y6 y7 if snlyear<=2012
		est store reg1
		
		quietly reg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro over10b over10b_ecldiff_base over10b_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg y8 y9 y10 y11 if snlyear>2012
		est store reg2
		
			quietly suest reg1 reg2, vce(cluster snlkey)
			test [reg2_mean]_b[over10b_ecldiff_base]+[reg2_mean]_b[r_ecldiff_base] = [reg1_mean]_b[over10b_ecldiff_base]+[reg1_mean]_b[r_ecldiff_base]
			test [reg2_mean]_b[over10b_ecldiff_macro]+[reg2_mean]_b[r_ecldiff_macro] = [reg1_mean]_b[over10b_ecldiff_macro]+[reg1_mean]_b[r_ecldiff_macro]
			

		*Combined coefficients
		areg mve_share bve_share alll_share r_ecldiff over10b over10b_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
	
		test _coef[r_ecldiff]+_coef[over10b_ecldiff]=0
		
		areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro over10b over10b_ecldiff_base over10b_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)

		test _coef[r_ecldiff_base]+_coef[over10b_ecldiff_base]=0
		test _coef[r_ecldiff_macro]+_coef[over10b_ecldiff_macro]=0
		

		areg mve_share bve_share alll_share r_ecldiff over10b over10b_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if snlyear<=2012, absorb(rankdate) vce(cluster snlkey)
	
		test _coef[r_ecldiff]+_coef[over10b_ecldiff]=0
		
		areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro over10b over10b_ecldiff_base over10b_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if snlyear<=2012, absorb(rankdate) vce(cluster snlkey)

		test _coef[r_ecldiff_base]+_coef[over10b_ecldiff_base]=0
		test _coef[r_ecldiff_macro]+_coef[over10b_ecldiff_macro]=0
		
		areg mve_share bve_share alll_share r_ecldiff over10b over10b_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if snlyear>2012, absorb(rankdate) vce(cluster snlkey)
	
		test _coef[r_ecldiff]+_coef[over10b_ecldiff]=0
		
		areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro over10b over10b_ecldiff_base over10b_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if snlyear>2012, absorb(rankdate) vce(cluster snlkey)

		test _coef[r_ecldiff_base]+_coef[over10b_ecldiff_base]=0
		test _coef[r_ecldiff_macro]+_coef[over10b_ecldiff_macro]=0

		
*Table 7
gen ecldiff_macro_20_share = ecl_adj_total_20/shrout
gen ecldiff_macro_28_share = ecl_adj_total_28/shrout
winsor2 ecldiff_macro_20_share ecldiff_macro_28_share, cuts(1 99)

areg mve_share bve_share alll_share ecldiff_share npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if ecl_28_loans!=. & ecl_20_loans!=., absorb(rankdate) vce(cluster snlkey)
outreg2 using 20lags.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
areg mve_share bve_share alll_share ecldiff_base_share ecldiff_macro_share npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if ecl_28_loans!=. & ecl_20_loans!=., absorb(rankdate) vce(cluster snlkey)
outreg2 using 20lags.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)

areg mve_share bve_share alll_share ecldiff_20_share npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if ecl_28_loans!=. & ecl_20_loans!=., absorb(rankdate) vce(cluster snlkey)
outreg2 using 20lags.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
areg mve_share bve_share alll_share ecldiff_base_share ecldiff_macro_20_share_w npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if ecl_28_loans!=. & ecl_20_loans!=., absorb(rankdate) vce(cluster snlkey)
outreg2 using 20lags.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)

areg mve_share bve_share alll_share ecldiff_28_share npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if ecl_28_loans!=. & ecl_20_loans!=., absorb(rankdate) vce(cluster snlkey)
outreg2 using 20lags.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
areg mve_share bve_share alll_share ecldiff_base_share ecldiff_macro_28_share_w npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if ecl_28_loans!=. & ecl_20_loans!=., absorb(rankdate) vce(cluster snlkey)
outreg2 using 20lags.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)


*Table 8, Panel A - Analyst Price Targets
areg medptg bve_share alll_share r_ecldiff npl_share nco_share  avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
outreg2 using pricetargets.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
areg medptg bve_share alll_share r_ecldiff_base r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
outreg2 using pricetargets.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
areg medptg bve_share alll_share r_ecldiff over10b i.over10b##c.r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
outreg2 using pricetargets.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
areg medptg bve_share alll_share r_ecldiff_base r_ecldiff_macro over10b i.over10b##c.r_ecldiff_base i.over10b##c.r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
outreg2 using pricetargets.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)

*Table 8, Panel B - Analyst Following
replace numest=0 if numest==.
bysort rankdate: egen med_numest = median(numest) if numest>0
gen hi_follow = 0
replace hi_follow = 1 if numest>med_numest

	areg mve_share bve_share alll_share r_ecldiff hi_follow i.hi_follow##c.r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if numest>0, absorb(rankdate) vce(cluster snlkey)
	outreg2 using analysts.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro hi_follow i.hi_follow##c.r_ecldiff_base i.hi_follow##c.r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if numest>0, absorb(rankdate) vce(cluster snlkey)
	outreg2 using analysts.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)

	areg mve_share bve_share alll_share r_ecldiff hi_follow i.hi_follow##c.r_ecldiff over10b i.over10b##c.r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if numest>0, absorb(rankdate) vce(cluster snlkey)
	outreg2 using analysts.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro hi_follow i.hi_follow##c.r_ecldiff_base i.hi_follow##c.r_ecldiff_macro over10b i.over10b##c.r_ecldiff_base i.over10b##c.r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if numest>0, absorb(rankdate) vce(cluster snlkey)
	outreg2 using analysts.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	
/*~~~~~~~~~~~~~~~~~~~~
ADDITIONAL ANALYSIS
~~~~~~~~~~~~~~~~~~~~*/

/*Earnings Management Incentives*/
*OA Table 1, Panel A
*Cross-sectional based on level of regulatory capital - indicator
	areg mve_share bve_share alll_share r_ecldiff low_cap i.low_cap##c.r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
	outreg2 using incentive.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro low_cap i.low_cap##c.r_ecldiff_base i.low_cap##c.r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
	outreg2 using incentive.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	
*Cross-sectional based on earnings management incentive
	areg mve_share bve_share alll_share r_ecldiff low_nibp i.low_nibp##c.r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
	outreg2 using incentive.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro low_nibp i.low_nibp##c.r_ecldiff_base i.low_nibp##c.r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg, absorb(rankdate) vce(cluster snlkey)
	outreg2 using incentive.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	
	*OA Table 1, Panel B
	areg mve_share bve_share alll_share r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if low_nibp==0, absorb(rankdate) vce(cluster snlkey)
	outreg2 using nibp.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if low_nibp==0, absorb(rankdate) vce(cluster snlkey)
	outreg2 using nibp.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if low_nibp==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using nibp.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg if low_nibp==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using nibp.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	
		tabulate snlyear, generate(y)
		quietly reg mve_share bve_share alll_share r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg y1 y2 y3 y4 y5 y6 y7 y8 y9 y10 y11 if low_nibp==0
		est store reg1
		
		quietly reg mve_share bve_share alll_share r_ecldiff npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg y1 y2 y3 y4 y5 y6 y7 y8 y9 y10 y11 if low_nibp==1
		est store reg2
		
			quietly suest reg1 reg2, vce(cluster snlkey)
			test [reg2_mean]_b[r_ecldiff] = [reg1_mean]_b[r_ecldiff]
			test [reg2_mean]_b[npl_share] = [reg1_mean]_b[npl_share]	
			test [reg2_mean]_b[nco_share] = [reg1_mean]_b[nco_share]

		quietly reg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg y1 y2 y3 y4 y5 y6 y7 y8 y9 y10 y11 if low_nibp==0
		est store reg1
		
		quietly reg mve_share bve_share alll_share r_ecldiff_base r_ecldiff_macro npl_share nco_share avgint_share reloans_share consloans_share rsa_share ni_pos ni_neg y1 y2 y3 y4 y5 y6 y7 y8 y9 y10 y11 if low_nibp==1
		est store reg2
		
			quietly suest reg1 reg2, vce(cluster snlkey)
			test [reg2_mean]_b[r_ecldiff_base] = [reg1_mean]_b[r_ecldiff_base]
			test [reg2_mean]_b[r_ecldiff_macro] = [reg1_mean]_b[r_ecldiff_macro]
			test [reg2_mean]_b[npl_share] = [reg1_mean]_b[npl_share]	
			test [reg2_mean]_b[nco_share] = [reg1_mean]_b[nco_share]
			
/*OA Table 2 - Analysis of over & under reserved banks*/
	*Panel A, Descriptive statistics by decile rank of ECLDIFF
	tabstat ecldiff_loans alll_loans ecl_loans mve_bve avg_cum_loss annual_co_rate avgint_loans avg_wtd_lags if r_ecldiff_q==1, stat(n mean) save
	mat T = r(StatTotal)' // the prime is for transposing the matrix
	putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECLDIFF Decile 1.xlsx", replace // remember to specify the full path
	putexcel A1 = matrix(T), names

	tabstat ecldiff_loans alll_loans ecl_loans mve_bve avg_cum_loss annual_co_rate avgint_loans avg_wtd_lags if r_ecldiff_q==2, stat(n mean) save
	mat T = r(StatTotal)' // the prime is for transposing the matrix
	putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECLDIFF Decile 2.xlsx", replace // remember to specify the full path
	putexcel A1 = matrix(T), names

	tabstat ecldiff_loans alll_loans ecl_loans mve_bve avg_cum_loss annual_co_rate avgint_loans avg_wtd_lags if r_ecldiff_q==3, stat(n mean) save
	mat T = r(StatTotal)' // the prime is for transposing the matrix
	putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECLDIFF Decile 3.xlsx", replace // remember to specify the full path
	putexcel A1 = matrix(T), names

	tabstat ecldiff_loans alll_loans ecl_loans mve_bve avg_cum_loss annual_co_rate avgint_loans avg_wtd_lags if r_ecldiff_q==4, stat(n mean) save
	mat T = r(StatTotal)' // the prime is for transposing the matrix
	putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECLDIFF Decile 4.xlsx", replace // remember to specify the full path
	putexcel A1 = matrix(T), names

	tabstat ecldiff_loans alll_loans ecl_loans mve_bve avg_cum_loss annual_co_rate avgint_loans avg_wtd_lags if r_ecldiff_q==5, stat(n mean) save
	mat T = r(StatTotal)' // the prime is for transposing the matrix
	putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECLDIFF Decile 5.xlsx", replace // remember to specify the full path
	putexcel A1 = matrix(T), names

	tabstat ecldiff_loans alll_loans ecl_loans mve_bve avg_cum_loss annual_co_rate avgint_loans avg_wtd_lags if r_ecldiff_q==6, stat(n mean) save
	mat T = r(StatTotal)' // the prime is for transposing the matrix
	putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECLDIFF Decile 6.xlsx", replace // remember to specify the full path
	putexcel A1 = matrix(T), names

	tabstat ecldiff_loans alll_loans ecl_loans mve_bve avg_cum_loss annual_co_rate avgint_loans avg_wtd_lags if r_ecldiff_q==7, stat(n mean) save
	mat T = r(StatTotal)' // the prime is for transposing the matrix
	putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECLDIFF Decile 7.xlsx", replace // remember to specify the full path
	putexcel A1 = matrix(T), names

	tabstat ecldiff_loans alll_loans ecl_loans mve_bve avg_cum_loss annual_co_rate avgint_loans avg_wtd_lags if r_ecldiff_q==8, stat(n mean) save
	mat T = r(StatTotal)' // the prime is for transposing the matrix
	putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECLDIFF Decile 8.xlsx", replace // remember to specify the full path
	putexcel A1 = matrix(T), names

	tabstat ecldiff_loans alll_loans ecl_loans mve_bve avg_cum_loss annual_co_rate avgint_loans avg_wtd_lags if r_ecldiff_q==9, stat(n mean) save
	mat T = r(StatTotal)' // the prime is for transposing the matrix
	putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECLDIFF Decile 9.xlsx", replace // remember to specify the full path
	putexcel A1 = matrix(T), names

	tabstat ecldiff_loans alll_loans ecl_loans mve_bve avg_cum_loss annual_co_rate avgint_loans avg_wtd_lags if r_ecldiff_q==10, stat(n mean) save
	mat T = r(StatTotal)' // the prime is for transposing the matrix
	putexcel set "C:\Users\pwheeler1\Box Sync\Data Sets\CECL\Tables\Descriptives - ECLDIFF Decile 10.xlsx", replace // remember to specify the full path
	putexcel A1 = matrix(T), names
	
	*Panel B, Test of nonlinear form;
	bysort rankdate: egen mean_alll=mean(alll_loans)
	gen dist2mean=ecl_loans-mean_alll
	gen dist2mean_sq = dist2mean^2
	gen overstatement=0
	replace overstatement=1 if ecldiff<0
	
	areg alll_loans dist2mean dist2mean_sq npl_loans nco_loans avgint_loans reloans_loans consloans_loans if overstatement==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using non_lin.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(4) tdec(2)
	areg alll_loans dist2mean dist2mean_sq npl_loans nco_loans avgint_loans reloans_loans consloans_loans if overstatement==0, absorb(rankdate) vce(cluster snlkey)
	outreg2 using non_lin.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(4) tdec(2)
	
	*OA Figure 1
	bysort rankdate: egen r_dist2mean_20 = xtile(dist2mean), n(20)
	bysort r_dist2mean_20: egen dec_mean_alll_20 = mean(alll_loans)
	tabulate r_dist2mean_20, summarize(alll_loans) mean

			
/*OA Table 3 - Future returns test*/
	bysort rankdate: egen r_ecldiff_base_l = xtile(ecldiff_base_loans), n(10)
	bysort rankdate: egen r_ecl_macro_l = xtile(ecldiff_macro_loans), n(10)
	gen ecldiff_base_rank = r_ecldiff_base_l/10
	gen eclmacro_rank = r_ecl_macro_l/10
	bysort rankdate: egen r_alll = xtile(alll_loans), n(10)
	gen alll_rank = r_alll/10

	*FF Factor Tests
	areg excret_1year ecldiff_base_rank eclmacro_rank mktrf_1year smb_1year hml_1year mkt_mom_1year, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year2 ecldiff_base_rank eclmacro_rank mktrf_year2 smb_year2 hml_year2 mkt_mom_year2, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year3 ecldiff_base_rank eclmacro_rank mktrf_year3 smb_year3 hml_year3 mkt_mom_year3, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year4 ecldiff_base_rank eclmacro_rank mktrf_year4 smb_year4 hml_year4 mkt_mom_year4, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year5 ecldiff_base_rank eclmacro_rank mktrf_year5 smb_year5 hml_year5 mkt_mom_year5, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)

	areg excret_1year ecldiff_base_rank eclmacro_rank alll_rank mktrf_1year smb_1year hml_1year mkt_mom_1year, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg2.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year2 ecldiff_base_rank eclmacro_rank alll_rank mktrf_year2 smb_year2 hml_year2 mkt_mom_year2, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year3 ecldiff_base_rank eclmacro_rank alll_rank mktrf_year3 smb_year3 hml_year3 mkt_mom_year3, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year4 ecldiff_base_rank eclmacro_rank alll_rank mktrf_year4 smb_year4 hml_year4 mkt_mom_year4, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year5 ecldiff_base_rank eclmacro_rank alll_rank mktrf_year5 smb_year5 hml_year5 mkt_mom_year5, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)

	areg excret_1year ecldiff_base_rank eclmacro_rank mktrf_1year smb_1year hml_1year mkt_mom_1year if over10b==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year2 ecldiff_base_rank eclmacro_rank mktrf_year2 smb_year2 hml_year2 mkt_mom_year2 if over10b==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year3 ecldiff_base_rank eclmacro_rank mktrf_year3 smb_year3 hml_year3 mkt_mom_year3 if over10b==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year4 ecldiff_base_rank eclmacro_rank mktrf_year4 smb_year4 hml_year4 mkt_mom_year4 if over10b==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year5 ecldiff_base_rank eclmacro_rank mktrf_year5 smb_year5 hml_year5 mkt_mom_year5 if over10b==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)

	areg excret_1year ecldiff_base_rank eclmacro_rank alll_rank mktrf_1year smb_1year hml_1year mkt_mom_1year if over10b==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg2.xls, replace excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year2 ecldiff_base_rank eclmacro_rank alll_rank mktrf_year2 smb_year2 hml_year2 mkt_mom_year2 if over10b==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year3 ecldiff_base_rank eclmacro_rank alll_rank mktrf_year3 smb_year3 hml_year3 mkt_mom_year3 if over10b==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year4 ecldiff_base_rank eclmacro_rank alll_rank mktrf_year4 smb_year4 hml_year4 mkt_mom_year4 if over10b==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)
	areg excret_year5 ecldiff_base_rank eclmacro_rank alll_rank mktrf_year5 smb_year5 hml_year5 mkt_mom_year5 if over10b==1, absorb(rankdate) vce(cluster snlkey)
	outreg2 using ret_disagg2.xls, excel stats (coef tstat) paren(tstat) asterisk(tstat) dec(3) tdec(2)


