/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below was used to generate Figure 3 for the procyclicality discussion in Section 6.3.

 =========================================================================================================*/
 
xtset snlkey rankdate

gen pcl = (ecl-l.ecl+nco)
gen pcl_loans = pcl/lag1_loans
winsor2 pcl_loans, cuts(1 99)

tabstat pcl_loans_w, by(rankdate) stat(mean)
tabstat llp_loans, by(rankdate) stat(mean)

ttest pcl_loans_w==llp_loans if rankdate>=69 & rankdate<=80
ttest pcl_loans_w==llp_loans if rankdate>=81 & rankdate<=96

ttest pcl_loans_w==llp_loans if rankdate>=69 & rankdate<=96
ttest pcl_loans_w==llp_loans if rankdate>=69 & rankdate<=107

ttest pcl_loans_w==llp_loans

gen pcl_llp_diff = pcl_loans_w-llp_loans

*Loss Emergence Horizon
gen long_emerg=0
replace long_emerg=1 if avg_wtd_lags>13.2821
replace long_emerg=. if avg_wtd_lags==.

tabstat pcl_loans_w if long_emerg==0, by(rankdate) stat(mean)
tabstat llp_loans if long_emerg==0, by(rankdate) stat(mean)
tabstat pcl_loans_w if long_emerg==1, by(rankdate) stat(mean)
tabstat llp_loans if long_emerg==1, by(rankdate) stat(mean)

tabstat pcl_loans_w llp_loans if rankdate>=69 & rankdate<=80, by(long_emerg) stat(mean)
tabstat pcl_loans_w llp_loans if rankdate>=81 & rankdate<=96, by(long_emerg) stat(mean)

ttest pcl_loans_w==llp_loans if rankdate>=69 & rankdate<=80 & long_emerg==0
ttest pcl_loans_w==llp_loans if rankdate>=81 & rankdate<=96 & long_emerg==0

ttest pcl_loans_w==llp_loans if rankdate>=69 & rankdate<=80 & long_emerg==1
ttest pcl_loans_w==llp_loans if rankdate>=81 & rankdate<=96 & long_emerg==1

ttest pcl_llp_diff if rankdate>=69 & rankdate<=80, by(long_emerg)
ttest pcl_llp_diff if rankdate>=81 & rankdate<=96, by(long_emerg) 

*Heterogeneous vs. Homogeneous Loans
gen hetero = (nonsfre + othnonre) / loans
bysort rankdate: egen median_hetero=median(hetero)
gen hi_hetero = 0
replace hi_hetero = 1 if hetero>median_hetero

tabstat pcl_loans_w if hi_hetero==0, by(rankdate) stat(mean)
tabstat llp_loans if hi_hetero==0, by(rankdate) stat(mean)
tabstat pcl_loans_w if hi_hetero==1, by(rankdate) stat(mean)
tabstat llp_loans if hi_hetero==1, by(rankdate) stat(mean)

tabstat pcl_loans_w llp_loans if rankdate>=69 & rankdate<=80, by(hi_hetero) stat(mean)
tabstat pcl_loans_w llp_loans if rankdate>=81 & rankdate<=96, by(hi_hetero) stat(mean)

ttest pcl_loans_w==llp_loans if rankdate>=69 & rankdate<=80 & hi_hetero==0
ttest pcl_loans_w==llp_loans if rankdate>=81 & rankdate<=96 & hi_hetero==0

ttest pcl_loans_w==llp_loans if rankdate>=69 & rankdate<=80 & hi_hetero==1
ttest pcl_loans_w==llp_loans if rankdate>=81 & rankdate<=96 & hi_hetero==1

ttest pcl_llp_diff if rankdate>=69 & rankdate<=80, by(hi_hetero)
ttest pcl_llp_diff if rankdate>=81 & rankdate<=96, by(hi_hetero) 

*Low vs High Capital
bysort rankdate: egen med_tier1 = median(tier1)
gen hi_tier1 = 0
replace hi_tier1 = 1 if tier1>med_tier1

tabstat pcl_loans_w if hi_tier1==0, by(rankdate) stat(mean)
tabstat llp_loans if hi_tier1==0, by(rankdate) stat(mean)
tabstat pcl_loans_w if hi_tier1==1, by(rankdate) stat(mean)
tabstat llp_loans if hi_tier1==1, by(rankdate) stat(mean)

tabstat pcl_loans_w llp_loans if rankdate>=69 & rankdate<=80, by(hi_tier1) stat(mean)
tabstat pcl_loans_w llp_loans if rankdate>=81 & rankdate<=96, by(hi_tier1) stat(mean)

ttest pcl_loans_w==llp_loans if rankdate>=69 & rankdate<=80 & hi_tier1==0
ttest pcl_loans_w==llp_loans if rankdate>=81 & rankdate<=96 & hi_tier1==0

ttest pcl_loans_w==llp_loans if rankdate>=69 & rankdate<=80 & hi_tier1==1
ttest pcl_loans_w==llp_loans if rankdate>=81 & rankdate<=96 & hi_tier1==1

ttest pcl_llp_diff if rankdate>=69 & rankdate<=80, by(hi_tier1)
ttest pcl_llp_diff if rankdate>=81 & rankdate<=96, by(hi_tier1) 
