/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below creates a dataset later merged with various expected loss estimates by loan type
		to calculate total base expected loss estimates based on Eq. (5) and adjust them based on Eq. (6).

		Loan and other data is from gathered from S&P Global Market Intelligence (SPGMI).Details on 
		SPGMI variables used are provided in a separate excel file as well as detailed in Appendix A.

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname nic 'C:\Users\pbwheele\Box Sync\Data Sets\NIC Data';
libname hmda 'C:\Users\pbwheele\Box Sync\Data Sets\HMDA';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';

/*STEP 2: See separate folder for code to estimate expected losses based on the historical relationship between loan originations and charge-offs*/

/* Aggregate variables for bank holding companies and commercial banks necessary to estimate expected losses and merge with set of publicly-traded banks.*/
proc sql;
create table all_npl_bytype1 as select a.*, b.na_re
from box.all_na_1990_2017 a left join box.all_na_re_1990_2018 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype2 as select a.*, b.na_singlefam as na_sf
from all_npl_bytype1 a left join box.all_na_sfloans_1990_2018 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype3 as select a.*, b.na_sfcnd
from all_npl_bytype2 a left join box.all_na_sfcnd_1990_2018 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype4 as select a.*, b.na_mfloans as na_mf
from all_npl_bytype3 a left join box.all_na_mfloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype5 as select a.*, b.na_creloans as na_cre
from all_npl_bytype4 a left join box.all_na_creloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype6 as select a.*, b.na_farmloans as na_farm
from all_npl_bytype5 a left join box.all_na_farmloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype7 as select a.*, b.na_cniloans as na_cni
from all_npl_bytype6 a left join box.all_na_cniloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype8 as select a.*, b.na_agloans as na_ag
from all_npl_bytype7 a left join box.all_na_agloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype9 as select a.*, b.na_consloans as na_cons
from all_npl_bytype8 a left join box.all_na_consloans_1990_2018 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype10 as select a.*, b.pd90
from all_npl_bytype9 a left join box.all_pd90_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype11 as select a.*, b.pd90_re
from all_npl_bytype10 a left join box.all_pd90_re_1990_2018 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype12 as select a.*, b.pd90_sf
from all_npl_bytype11 a left join box.all_pd90_sf_1990_2018 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype13 as select a.*, b.pd90_sfcnd
from all_npl_bytype12 a left join box.all_pd90_sfcnd_1990_2018 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype14 as select a.*, b.pd90_mfloans as pd90_mf
from all_npl_bytype13 a left join box.all_pd90_mfloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype15 as select a.*, b.pd90_creloans as pd90_cre
from all_npl_bytype14 a left join box.all_pd90_creloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype16 as select a.*, b.pd90_farmloans as pd90_farm
from all_npl_bytype15 a left join box.all_pd90_farmloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype17 as select a.*, b.pd90_cons
from all_npl_bytype16 a left join box.all_pd90_cons_1990_2018 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype18 as select a.*, b.pd90_cni
from all_npl_bytype17 a left join box.all_pd90_cniloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
proc sql;
create table all_npl_bytype19 as select a.*, b.pd90_agloans as pd90_ag
from all_npl_bytype18 a left join box.all_pd90_agloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate
order by a.snlkey, a.rankdate;
quit;

data box.all_npl_bytype; set all_npl_bytype19;
if na_sf ne . and na_sfcnd=. then na_sfcnd=0;
if pd90_sf ne . and pd90_sfcnd=. then pd90_sfcnd=0;
npl = na + pd90;
npl_re = na_re + pd90_re;
npl_sf = na_sf + pd90_sf;
npl_sfcnd = na_sfcnd + pd90_sfcnd;
npl_mf = na_mf + pd90_mf;
npl_cre = na_cre + pd90_cre;
npl_farm = na_farm + pd90_farm;
npl_cons = na_cons + pd90_cons;
npl_cni = na_cni + pd90_cni;
npl_ag = na_ag + pd90_ag;
run;

	proc sql;
	create table alll5a as select a.*, b.snlyear, b.snlqtr, b.loans
	from box.cecl_step1 as a left join box.all_loans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate and not missing (b.loans)
	order by snlkey, rankdate;

	create table alll5b as select a.*, b.loans as lag1_loans 'Loans t-1', a.loans-b.loans as ch_loans
	from alll5a as a left join box.all_loans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

	create table alll5c as select a.*, b.sfloans
	from alll5b as a left join box.all_sfloans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5c as select a.*, b.sfcndloans
	from alll5c a left join box.all_sfcndloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5c as select a.*, b.loans_hfs
	from alll5c as a left join box.all_loans_hfs_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5c as select a.*, b.reloans
	from alll5c as a left join box.all_reloans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5c as select a.*, b.mfloans
	from alll5c a left join box.all_mfloans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5c as select a.*, b.creloans
	from alll5c a left join box.all_creloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5c as select a.*, b.farmloans
	from alll5c a left join box.all_farmloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5c as select a.*, b.cniloans
	from alll5c a left join box.all_cniloans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5c as select a.*, b.agloans
	from alll5c a left join box.all_agloans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5d as select a.*, b.consloans
	from alll5c as a left join box.all_consloans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5e as select a.*, b.impaired as impaired_loans
	from alll5d as a left join box.comp_impaired_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5e_1 as select a.*, b.*
	from alll5e as a left join box.all_npl_bytype as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
	quit;

	data alll5k; set alll5e_1;
	if sfcndloans=. then sfcndloans=0;
	if loans_hfs=. then loans_hfs=0;
	sf_total = sfloans+sfcndloans;
	sf_htm = sf_total-loans_hfs;
	nonsfre = mfloans+creloans+farmloans;
	othnonre = cniloans+agloans;
	if npl_sfcnd=. then npl_sfcnd=0;
	npl_sf_total = npl_sf+npl_sfcnd;
	npl_nonsfre = npl_mf+npl_cre+npl_farm;
	npl_othnonre = npl_cni+npl_ag;
	run;


	/*Because many banks did not begin reporting impaired loans quarterly until 2009, assume that
	interim amounts in 2007 and 2008 equal those reported at the prior year end*/
	proc sql;
	create table alll5l as select a.*, CASE when a.impaired_loans=. then b.impaired_loans else a.impaired_loans END as impaired_mod
	from alll5k as a left join alll5k as b
	on a.snlkey=b.snlkey and a.snlyear=b.snlyear+1 and b.snlqtr='Q4'
	order by a.snlkey, a.rankdate;
	quit;

	/*Add total asset and credit quality data*/
	proc sql;
	create table all_co_bytype1 as select a.*, b.co_reloans as co_re
	from box.all_co_1990_2018 a left join box.all_co_reloans_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype2 as select a.*, b.co_sfloans as co_sf
	from all_co_bytype1 a left join box.all_co_sfloans_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype3 as select a.*, b.co_sfcnd
	from all_co_bytype2 a left join box.all_co_sfcnd_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype4 as select a.*, b.co_mfloans as co_mf
	from all_co_bytype3 a left join box.all_co_mfloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype5 as select a.*, b.co_creloans as co_cre
	from all_co_bytype4 a left join box.all_co_creloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype6 as select a.*, b.co_farmloans as co_farm
	from all_co_bytype5 a left join box.all_co_farmloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype7 as select a.*, b.co_consloans as co_cons
	from all_co_bytype6 a left join box.all_co_consloans_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype8 as select a.*, b.co_cniloans as co_cni
	from all_co_bytype7 a left join box.all_co_cniloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype9 as select a.*, b.co_agloans as co_ag
	from all_co_bytype8 a left join box.all_co_agloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate
	order by a.snlkey, a.rankdate;
	quit;

	data all_co_bytype10; set all_co_bytype9;
	if co_re=. then co_re=0;
	if co_sf=. then co_sf=0;
	if co_sfcnd=. then co_sfcnd=0;
	if co_mf=. then co_mf=0;
	if co_cre=. then co_cre=0;
	if co_farm=. then co_farm=0;
	if co_cons=. then co_cons=0;
	if co_cni=. then co_cni=0;
	if co_ag=. then co_ag=0;
	run;

	proc sql;
	create table all_co_bytype11 as select a.*, b.recov
	from all_co_bytype10 a left join box.all_recoveries_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype12 as select a.*, b.recov_reloans as recov_re
	from all_co_bytype11 a left join box.all_recov_reloans_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype13 as select a.*, b.recov_sfloans as recov_sf
	from all_co_bytype12 a left join box.all_recov_sf_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype14 as select a.*, b.recov_sfcnd
	from all_co_bytype13 a left join box.all_recov_sfcnd_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype15 as select a.*, b.recov_mfloans as recov_mf
	from all_co_bytype14 a left join box.all_recov_mfloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype16 as select a.*, b.recov_creloans as recov_cre
	from all_co_bytype15 a left join box.all_recov_creloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype17 as select a.*, b.recov_farmloans as recov_farm
	from all_co_bytype16 a left join box.all_recov_farmloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype18 as select a.*, b.recov_cons
	from all_co_bytype17 a left join box.all_recov_cons_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype19 as select a.*, b.recov_cniloans as recov_cni
	from all_co_bytype18 a left join box.all_recov_cniloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table all_co_bytype20 as select a.*, b.recov_agloans as recov_ag
	from all_co_bytype19 a left join box.all_recov_agloans_1990_2019 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate
	order by a.snlkey, a.rankdate;
	quit;

	data all_co_bytype21; set all_co_bytype20;
	if recov_re=. then recov_re=0;
	if recov_sf=. then recov_sf=0;
	if recov_sfcnd=. then recov_sfcnd=0;
	if recov_mf=. then recov_mf=0;
	if recov_cre=. then recov_cre=0;
	if recov_farm=. then recov_farm=0;
	if recov_cons=. then recov_cons=0;
	if recov_cni=. then recov_cni=0;
	if recov_ag=. then recov_ag=0;
	run;

	data all_co_bytype22; set all_co_bytype21;
	nco = co - recov;
	nco_re = co_re - recov_re;
	nco_sftotal = co_sf + co_sfcnd - recov_sf - recov_sfcnd;
	nco_mf = co_mf - recov_mf;
	nco_cre = co_cre - recov_cre;
	nco_farm = co_farm - recov_farm;
	nco_cons = co_cons - recov_cons;
	nco_cni = co_cni - recov_cni;
	nco_ag = co_ag - recov_ag;
	run;

	data box.all_co_bytype_1990_2018; set all_co_bytype22; run;

	proc sql;
	create table alll5m as select a.*, b.ta
	from alll5l as a left join box.all_ta_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5n as select a.*, b.co, b.recov, b.co_sf+b.co_sfcnd as co_sftotal, b.co_mf+b.co_cre+b.co_farm as co_nonsfre, b.co_cons, b.co_cni+co_ag as co_othnonre,
	b.nco, b.nco_sftotal, b.nco_mf+b.nco_cre+b.nco_farm as nco_nonsfre, b.nco_cons, b.nco_cni+nco_ag as nco_othnonre
	from alll5m a left join box.all_co_bytype_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll5o as select a.*, b.int_loans
	from alll5n as a left join box.all_int_loans_2001_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate
	order by snlkey, rankdate;
	quit;

	*Create lagged values of credit quality indicators;
	proc expand data=alll5o out=alll5p method=none; by snlkey; id rankdate;
	convert nco = nco_lag1 / transformout = (lag 1);
	convert nco = nco_lag2 / transformout = (lag 2);
	convert nco = nco_lag3 / transformout = (lag 3);

	convert nco_sftotal = nco_sftotal_lag1 / transformout = (lag 1);
	convert nco_sftotal = nco_sftotal_lag2 / transformout = (lag 2);
	convert nco_sftotal = nco_sftotal_lag3 / transformout = (lag 3);

	convert nco_nonsfre = nco_nonsfre_lag1 / transformout = (lag 1);
	convert nco_nonsfre = nco_nonsfre_lag2 / transformout = (lag 2);
	convert nco_nonsfre = nco_nonsfre_lag3 / transformout = (lag 3);

	convert nco_cons = nco_cons_lag1 / transformout = (lag 1);
	convert nco_cons = nco_cons_lag2 / transformout = (lag 2);
	convert nco_cons = nco_cons_lag3 / transformout = (lag 3);

	convert nco_othnonre = nco_othnonre_lag1 / transformout = (lag 1);
	convert nco_othnonre = nco_othnonre_lag2 / transformout = (lag 2);
	convert nco_othnonre = nco_othnonre_lag3 / transformout = (lag 3);

	convert npl = npl_lag1 / transformout = (lag 1);

	convert int_loans = int_loans_lag1 / transformout = (lag 1);
	convert int_loans = int_loans_lag2 / transformout = (lag 2);
	convert int_loans = int_loans_lag3 / transformout = (lag 3);
	convert int_loans = int_loans_lag4 / transformout = (lag 4);
	convert int_loans = int_loans_lag5 / transformout = (lag 5);
	convert int_loans = int_loans_lag6 / transformout = (lag 6);
	convert int_loans = int_loans_lag7 / transformout = (lag 7);
	convert int_loans = int_loans_lag8 / transformout = (lag 8);
	run;

	data alll5q; set alll5p;
	avg4qtr_nco = (nco+nco_lag1+nco_lag2+nco_lag3)/4;
	ch_npl = npl-npl_lag1;
	perc_ch_npl = ch_npl/lag1_loans;
	run;

	*Add macroeconomic variables [unemployment and change in real estate prices];
	proc sql;
	create table alll5r as select a.*, b.csindex, b.qtch_csindex as ch_csindex
	from alll5q as a left join box.case_shiller_2017 as b
	on a.snlyear=b.year and a.snlqtr=b.quarter;

	create table alll5s as select a.*, b.unemp_rate, b.ch_unemp_rate
	from alll5r as a left join box.unemployment_rate_2017 as b
	on a.snlyear=b.year and a.snlqtr=b.quarter
	order by snlkey, rankdate;
	quit;

	proc sort data=alll5s nodupkey;
	by snlkey rankdate descending csindex unemp_rate;
	run;
	data alll5t;
	set alll5s;
	if rankdate < 1 then delete;
	if rankdate > 112 then delete;
	avgint = (int_loans_lag1+int_loans_lag2+int_loans_lag3+int_loans_lag4+int_loans_lag5+int_loans_lag6+int_loans_lag7+int_loans_lag8)/8; 
	run;

	*Save dataset - ECL estimated using separately by loans type and aggregated in code found in file "Step2e_ECL Estimates based on Eq. (5) and Eq. (6)";
	data box.cecl_step2_start; set alll5t; run;
