/*========================================================================================================
                                                                          
    ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
    AUTHOR: P. Barrett Wheeler                  
    JOURNAL OF ACCOUNTING RESEARCH 

 	The code below retains the expected loss estimates for each loan type with the highest pseudo
	R-squared to determine the base expected loss estimate based on Eq. (5) in the manuscript. It then
	adjusts base expected loss estimates for macroeconomic conditions using Eq. (6) as discussed in the
	manuscript.

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';
libname ecl 'C:\Users\pwheeler1\Box Sync\Data Sets\ECL Estimates';

/*1-4 FAMILY*/
*Compare ECL estimates using various seed parameters and retain estimate with highest pseudo R-sq;
data ecl_sf_001 (drop = ecl);
set box.ecl_sf_parameter001;
param=.001;
run;
data ecl_sf_0025;
set box.ecl_sf_parameter0025;
param=.0025;
run;
data ecl_sf_005;
set box.ecl_sf_parameter005;
param=.005;
run;
data ecl_sf_0075;
set box.ecl_sf_parameter0075;
param=.0075;
run;
data ecl_agg;
set ecl_sf_001 ecl_sf_0025 ecl_sf_005 ecl_sf_0075;
run;
proc sort data=ecl_agg;
by snlkey rankdate param;
run;
proc sql;
create table ecl_sf1 as select *, max(pseudo_rsq) as max_pseudo_rsq
from ecl_agg
group by snlkey, rankdate;
quit;
data ecl_sf2;
set ecl_sf1;
if pseudo_rsq ne max_pseudo_rsq then delete;
cum_loss = b1+b2+b3+b4+b5+b6+b7+b8+b9+b10+b11+b12+b13+b14+b15+b16+b17+b18+b19+b20+b21+b22+b23+b24;
wtd_lags = ((b1*1)+(b2*2)+(b3*3)+(b4*4)+(b5*5)+(b6*6)+(b7*7)+(b8*8)+(b9*9)+(b10*10)+(b11*11)+(b12*12)
		  +(b13*13)+(b14*14)+(b15*15)+(b16*16)+(b17*17)+(b18*18)+(b19*19)+(b20*20)+(b21*21)+(b22*22)
		  +(b23*23)+(b24*24))/cum_loss;
f1_ecl_sf = (b1*lo_singlefam_t)+(b2*lo_singlefam_lag1)+(b3*lo_singlefam_lag2)+(b4*lo_singlefam_lag3)+(b5*lo_singlefam_lag4)+(b6*lo_singlefam_lag5)+(b7*lo_singlefam_lag6)+(b8*lo_singlefam_lag7)+(b9*lo_singlefam_lag8)+(b10*lo_singlefam_lag9)+(b11*lo_singlefam_lag10)+(b12*lo_singlefam_lag11)+(b13*lo_singlefam_lag12)+(b14*lo_singlefam_lag13)+(b15*lo_singlefam_lag14)+(b16*lo_singlefam_lag15)+(b17*lo_singlefam_lag16)+(b18*lo_singlefam_lag17)+(b19*lo_singlefam_lag18)+(b20*lo_singlefam_lag19)+(b21*lo_singlefam_lag20)+(b22*lo_singlefam_lag21)+(b23*lo_singlefam_lag22)+(b24*lo_singlefam_lag23);
f2_ecl_sf = (b2*lo_singlefam_t)+(b3*lo_singlefam_lag1)+(b4*lo_singlefam_lag2)+(b5*lo_singlefam_lag3)+(b6*lo_singlefam_lag4)+(b7*lo_singlefam_lag5)+(b8*lo_singlefam_lag6)+(b9*lo_singlefam_lag7)+(b10*lo_singlefam_lag8)+(b11*lo_singlefam_lag9)+(b12*lo_singlefam_lag10)+(b13*lo_singlefam_lag11)+(b14*lo_singlefam_lag12)+(b15*lo_singlefam_lag13)+(b16*lo_singlefam_lag14)+(b17*lo_singlefam_lag15)+(b18*lo_singlefam_lag16)+(b19*lo_singlefam_lag17)+(b20*lo_singlefam_lag18)+(b21*lo_singlefam_lag19)+(b22*lo_singlefam_lag20)+(b23*lo_singlefam_lag21)+(b24*lo_singlefam_lag22);
f3_ecl_sf = (b3*lo_singlefam_t)+(b4*lo_singlefam_lag1)+(b5*lo_singlefam_lag2)+(b6*lo_singlefam_lag3)+(b7*lo_singlefam_lag4)+(b8*lo_singlefam_lag5)+(b9*lo_singlefam_lag6)+(b10*lo_singlefam_lag7)+(b11*lo_singlefam_lag8)+(b12*lo_singlefam_lag9)+(b13*lo_singlefam_lag10)+(b14*lo_singlefam_lag11)+(b15*lo_singlefam_lag12)+(b16*lo_singlefam_lag13)+(b17*lo_singlefam_lag14)+(b18*lo_singlefam_lag15)+(b19*lo_singlefam_lag16)+(b20*lo_singlefam_lag17)+(b21*lo_singlefam_lag18)+(b22*lo_singlefam_lag19)+(b23*lo_singlefam_lag20)+(b24*lo_singlefam_lag21);
f4_ecl_sf = (b4*lo_singlefam_t)+(b5*lo_singlefam_lag1)+(b6*lo_singlefam_lag2)+(b7*lo_singlefam_lag3)+(b8*lo_singlefam_lag4)+(b9*lo_singlefam_lag5)+(b10*lo_singlefam_lag6)+(b11*lo_singlefam_lag7)+(b12*lo_singlefam_lag8)+(b13*lo_singlefam_lag9)+(b14*lo_singlefam_lag10)+(b15*lo_singlefam_lag11)+(b16*lo_singlefam_lag12)+(b17*lo_singlefam_lag13)+(b18*lo_singlefam_lag14)+(b19*lo_singlefam_lag15)+(b20*lo_singlefam_lag16)+(b21*lo_singlefam_lag17)+(b22*lo_singlefam_lag18)+(b23*lo_singlefam_lag19)+(b24*lo_singlefam_lag20);
f5_ecl_sf = (b5*lo_singlefam_t)+(b6*lo_singlefam_lag1)+(b7*lo_singlefam_lag2)+(b8*lo_singlefam_lag3)+(b9*lo_singlefam_lag4)+(b10*lo_singlefam_lag5)+(b11*lo_singlefam_lag6)+(b12*lo_singlefam_lag7)+(b13*lo_singlefam_lag8)+(b14*lo_singlefam_lag9)+(b15*lo_singlefam_lag10)+(b16*lo_singlefam_lag11)+(b17*lo_singlefam_lag12)+(b18*lo_singlefam_lag13)+(b19*lo_singlefam_lag14)+(b20*lo_singlefam_lag15)+(b21*lo_singlefam_lag16)+(b22*lo_singlefam_lag17)+(b23*lo_singlefam_lag18)+(b24*lo_singlefam_lag19);
f6_ecl_sf = (b6*lo_singlefam_t)+(b7*lo_singlefam_lag1)+(b8*lo_singlefam_lag2)+(b9*lo_singlefam_lag3)+(b10*lo_singlefam_lag4)+(b11*lo_singlefam_lag5)+(b12*lo_singlefam_lag6)+(b13*lo_singlefam_lag7)+(b14*lo_singlefam_lag8)+(b15*lo_singlefam_lag9)+(b16*lo_singlefam_lag10)+(b17*lo_singlefam_lag11)+(b18*lo_singlefam_lag12)+(b19*lo_singlefam_lag13)+(b20*lo_singlefam_lag14)+(b21*lo_singlefam_lag15)+(b22*lo_singlefam_lag16)+(b23*lo_singlefam_lag17)+(b24*lo_singlefam_lag18);
f7_ecl_sf = (b7*lo_singlefam_t)+(b8*lo_singlefam_lag1)+(b9*lo_singlefam_lag2)+(b10*lo_singlefam_lag3)+(b11*lo_singlefam_lag4)+(b12*lo_singlefam_lag5)+(b13*lo_singlefam_lag6)+(b14*lo_singlefam_lag7)+(b15*lo_singlefam_lag8)+(b16*lo_singlefam_lag9)+(b17*lo_singlefam_lag10)+(b18*lo_singlefam_lag11)+(b19*lo_singlefam_lag12)+(b20*lo_singlefam_lag13)+(b21*lo_singlefam_lag14)+(b22*lo_singlefam_lag15)+(b23*lo_singlefam_lag16)+(b24*lo_singlefam_lag17);
f8_ecl_sf = (b8*lo_singlefam_t)+(b9*lo_singlefam_lag1)+(b10*lo_singlefam_lag2)+(b11*lo_singlefam_lag3)+(b12*lo_singlefam_lag4)+(b13*lo_singlefam_lag5)+(b14*lo_singlefam_lag6)+(b15*lo_singlefam_lag7)+(b16*lo_singlefam_lag8)+(b17*lo_singlefam_lag9)+(b18*lo_singlefam_lag10)+(b19*lo_singlefam_lag11)+(b20*lo_singlefam_lag12)+(b21*lo_singlefam_lag13)+(b22*lo_singlefam_lag14)+(b23*lo_singlefam_lag15)+(b24*lo_singlefam_lag16);
f9_ecl_sf = (b9*lo_singlefam_t)+(b10*lo_singlefam_lag1)+(b11*lo_singlefam_lag2)+(b12*lo_singlefam_lag3)+(b13*lo_singlefam_lag4)+(b14*lo_singlefam_lag5)+(b15*lo_singlefam_lag6)+(b16*lo_singlefam_lag7)+(b17*lo_singlefam_lag8)+(b18*lo_singlefam_lag9)+(b19*lo_singlefam_lag10)+(b20*lo_singlefam_lag11)+(b21*lo_singlefam_lag12)+(b22*lo_singlefam_lag13)+(b23*lo_singlefam_lag14)+(b24*lo_singlefam_lag15);
f10_ecl_sf = (b10*lo_singlefam_t)+(b11*lo_singlefam_lag1)+(b12*lo_singlefam_lag2)+(b13*lo_singlefam_lag3)+(b14*lo_singlefam_lag4)+(b15*lo_singlefam_lag5)+(b16*lo_singlefam_lag6)+(b17*lo_singlefam_lag7)+(b18*lo_singlefam_lag8)+(b19*lo_singlefam_lag9)+(b20*lo_singlefam_lag10)+(b21*lo_singlefam_lag11)+(b22*lo_singlefam_lag12)+(b23*lo_singlefam_lag13)+(b24*lo_singlefam_lag14);
f11_ecl_sf = (b11*lo_singlefam_t)+(b12*lo_singlefam_lag1)+(b13*lo_singlefam_lag2)+(b14*lo_singlefam_lag3)+(b15*lo_singlefam_lag4)+(b16*lo_singlefam_lag5)+(b17*lo_singlefam_lag6)+(b18*lo_singlefam_lag7)+(b19*lo_singlefam_lag8)+(b20*lo_singlefam_lag9)+(b21*lo_singlefam_lag10)+(b22*lo_singlefam_lag11)+(b23*lo_singlefam_lag12)+(b24*lo_singlefam_lag13);
f12_ecl_sf = (b12*lo_singlefam_t)+(b13*lo_singlefam_lag1)+(b14*lo_singlefam_lag2)+(b15*lo_singlefam_lag3)+(b16*lo_singlefam_lag4)+(b17*lo_singlefam_lag5)+(b18*lo_singlefam_lag6)+(b19*lo_singlefam_lag7)+(b20*lo_singlefam_lag8)+(b21*lo_singlefam_lag9)+(b22*lo_singlefam_lag10)+(b23*lo_singlefam_lag11)+(b24*lo_singlefam_lag12);
f13_ecl_sf = (b13*lo_singlefam_t)+(b14*lo_singlefam_lag1)+(b15*lo_singlefam_lag2)+(b16*lo_singlefam_lag3)+(b17*lo_singlefam_lag4)+(b18*lo_singlefam_lag5)+(b19*lo_singlefam_lag6)+(b20*lo_singlefam_lag7)+(b21*lo_singlefam_lag8)+(b22*lo_singlefam_lag9)+(b23*lo_singlefam_lag10)+(b24*lo_singlefam_lag11);
f14_ecl_sf = (b14*lo_singlefam_t)+(b15*lo_singlefam_lag1)+(b16*lo_singlefam_lag2)+(b17*lo_singlefam_lag3)+(b18*lo_singlefam_lag4)+(b19*lo_singlefam_lag5)+(b20*lo_singlefam_lag6)+(b21*lo_singlefam_lag7)+(b22*lo_singlefam_lag8)+(b23*lo_singlefam_lag9)+(b24*lo_singlefam_lag10);
f15_ecl_sf = (b15*lo_singlefam_t)+(b16*lo_singlefam_lag1)+(b17*lo_singlefam_lag2)+(b18*lo_singlefam_lag3)+(b19*lo_singlefam_lag4)+(b20*lo_singlefam_lag5)+(b21*lo_singlefam_lag6)+(b22*lo_singlefam_lag7)+(b23*lo_singlefam_lag8)+(b24*lo_singlefam_lag9);
f16_ecl_sf = (b16*lo_singlefam_t)+(b17*lo_singlefam_lag1)+(b18*lo_singlefam_lag2)+(b19*lo_singlefam_lag3)+(b20*lo_singlefam_lag4)+(b21*lo_singlefam_lag5)+(b22*lo_singlefam_lag6)+(b23*lo_singlefam_lag7)+(b24*lo_singlefam_lag8);
f17_ecl_sf = (b17*lo_singlefam_t)+(b18*lo_singlefam_lag1)+(b19*lo_singlefam_lag2)+(b20*lo_singlefam_lag3)+(b21*lo_singlefam_lag4)+(b22*lo_singlefam_lag5)+(b23*lo_singlefam_lag6)+(b24*lo_singlefam_lag7);
f18_ecl_sf = (b18*lo_singlefam_t)+(b19*lo_singlefam_lag1)+(b20*lo_singlefam_lag2)+(b21*lo_singlefam_lag3)+(b22*lo_singlefam_lag4)+(b23*lo_singlefam_lag5)+(b24*lo_singlefam_lag6);
f19_ecl_sf = (b19*lo_singlefam_t)+(b20*lo_singlefam_lag1)+(b21*lo_singlefam_lag2)+(b22*lo_singlefam_lag3)+(b23*lo_singlefam_lag4)+(b24*lo_singlefam_lag5);
f20_ecl_sf = (b20*lo_singlefam_t)+(b21*lo_singlefam_lag1)+(b22*lo_singlefam_lag2)+(b23*lo_singlefam_lag3)+(b24*lo_singlefam_lag4);
f21_ecl_sf = (b21*lo_singlefam_t)+(b22*lo_singlefam_lag1)+(b23*lo_singlefam_lag2)+(b24*lo_singlefam_lag3);
f22_ecl_sf = (b22*lo_singlefam_t)+(b23*lo_singlefam_lag1)+(b24*lo_singlefam_lag2);
f23_ecl_sf = (b23*lo_singlefam_t)+(b24*lo_singlefam_lag1);
f24_ecl_sf = (b24*lo_singlefam_t);
run;
proc sort data=ecl_sf2 nodupkey;
by snlkey rankdate;
run;
data box.ecl_sf_maxrsq;
set ecl_sf2;
run;

/*NON 1-4 FAMILY REAL ESTATE LOANS*/
*Compare ECL estimates using various seed parameters and retain estimate with highest pseudo R-sq;
data ecl_nonsfre_001 (drop = ecl);
set box.ecl_nonsfre_param001;
param=.001;
run;
data ecl_nonsfre_0025;
set box.ecl_nonsfre_param0025;
param=.0025;
run;
data ecl_nonsfre_005;
set box.ecl_nonsfre_param005;
param=.005;
run;
data ecl_nonsfre_0075;
set box.ecl_nonsfre_param0075;
param=.0075;
run;
data ecl_agg;
set ecl_nonsfre_001 ecl_nonsfre_0025 ecl_nonsfre_005 ecl_nonsfre_0075;
run;
proc sort data=ecl_agg;
by snlkey rankdate param;
run;
proc sql;
create table ecl_nonsfre1 as select *, max(pseudo_rsq) as max_pseudo_rsq
from ecl_agg
group by snlkey, rankdate;
quit;
data ecl_nonsfre2;
set ecl_nonsfre1;
if pseudo_rsq ne max_pseudo_rsq then delete;
cum_loss = b1+b2+b3+b4+b5+b6+b7+b8+b9+b10+b11+b12+b13+b14+b15+b16+b17+b18+b19+b20+b21+b22+b23+b24;
wtd_lags = ((b1*1)+(b2*2)+(b3*3)+(b4*4)+(b5*5)+(b6*6)+(b7*7)+(b8*8)+(b9*9)+(b10*10)+(b11*11)+(b12*12)
		  +(b13*13)+(b14*14)+(b15*15)+(b16*16)+(b17*17)+(b18*18)+(b19*19)+(b20*20)+(b21*21)+(b22*22)
		  +(b23*23)+(b24*24))/cum_loss;
f1_ecl_nonsfre = (b1*lo_nonsfre_t)+(b2*lo_nonsfre_lag1)+(b3*lo_nonsfre_lag2)+(b4*lo_nonsfre_lag3)+(b5*lo_nonsfre_lag4)+(b6*lo_nonsfre_lag5)+(b7*lo_nonsfre_lag6)+(b8*lo_nonsfre_lag7)+(b9*lo_nonsfre_lag8)+(b10*lo_nonsfre_lag9)+(b11*lo_nonsfre_lag10)+(b12*lo_nonsfre_lag11)+(b13*lo_nonsfre_lag12)+(b14*lo_nonsfre_lag13)+(b15*lo_nonsfre_lag14)+(b16*lo_nonsfre_lag15)+(b17*lo_nonsfre_lag16)+(b18*lo_nonsfre_lag17)+(b19*lo_nonsfre_lag18)+(b20*lo_nonsfre_lag19)+(b21*lo_nonsfre_lag20)+(b22*lo_nonsfre_lag21)+(b23*lo_nonsfre_lag22)+(b24*lo_nonsfre_lag23);
f2_ecl_nonsfre = (b2*lo_nonsfre_t)+(b3*lo_nonsfre_lag1)+(b4*lo_nonsfre_lag2)+(b5*lo_nonsfre_lag3)+(b6*lo_nonsfre_lag4)+(b7*lo_nonsfre_lag5)+(b8*lo_nonsfre_lag6)+(b9*lo_nonsfre_lag7)+(b10*lo_nonsfre_lag8)+(b11*lo_nonsfre_lag9)+(b12*lo_nonsfre_lag10)+(b13*lo_nonsfre_lag11)+(b14*lo_nonsfre_lag12)+(b15*lo_nonsfre_lag13)+(b16*lo_nonsfre_lag14)+(b17*lo_nonsfre_lag15)+(b18*lo_nonsfre_lag16)+(b19*lo_nonsfre_lag17)+(b20*lo_nonsfre_lag18)+(b21*lo_nonsfre_lag19)+(b22*lo_nonsfre_lag20)+(b23*lo_nonsfre_lag21)+(b24*lo_nonsfre_lag22);
f3_ecl_nonsfre = (b3*lo_nonsfre_t)+(b4*lo_nonsfre_lag1)+(b5*lo_nonsfre_lag2)+(b6*lo_nonsfre_lag3)+(b7*lo_nonsfre_lag4)+(b8*lo_nonsfre_lag5)+(b9*lo_nonsfre_lag6)+(b10*lo_nonsfre_lag7)+(b11*lo_nonsfre_lag8)+(b12*lo_nonsfre_lag9)+(b13*lo_nonsfre_lag10)+(b14*lo_nonsfre_lag11)+(b15*lo_nonsfre_lag12)+(b16*lo_nonsfre_lag13)+(b17*lo_nonsfre_lag14)+(b18*lo_nonsfre_lag15)+(b19*lo_nonsfre_lag16)+(b20*lo_nonsfre_lag17)+(b21*lo_nonsfre_lag18)+(b22*lo_nonsfre_lag19)+(b23*lo_nonsfre_lag20)+(b24*lo_nonsfre_lag21);
f4_ecl_nonsfre = (b4*lo_nonsfre_t)+(b5*lo_nonsfre_lag1)+(b6*lo_nonsfre_lag2)+(b7*lo_nonsfre_lag3)+(b8*lo_nonsfre_lag4)+(b9*lo_nonsfre_lag5)+(b10*lo_nonsfre_lag6)+(b11*lo_nonsfre_lag7)+(b12*lo_nonsfre_lag8)+(b13*lo_nonsfre_lag9)+(b14*lo_nonsfre_lag10)+(b15*lo_nonsfre_lag11)+(b16*lo_nonsfre_lag12)+(b17*lo_nonsfre_lag13)+(b18*lo_nonsfre_lag14)+(b19*lo_nonsfre_lag15)+(b20*lo_nonsfre_lag16)+(b21*lo_nonsfre_lag17)+(b22*lo_nonsfre_lag18)+(b23*lo_nonsfre_lag19)+(b24*lo_nonsfre_lag20);
f5_ecl_nonsfre = (b5*lo_nonsfre_t)+(b6*lo_nonsfre_lag1)+(b7*lo_nonsfre_lag2)+(b8*lo_nonsfre_lag3)+(b9*lo_nonsfre_lag4)+(b10*lo_nonsfre_lag5)+(b11*lo_nonsfre_lag6)+(b12*lo_nonsfre_lag7)+(b13*lo_nonsfre_lag8)+(b14*lo_nonsfre_lag9)+(b15*lo_nonsfre_lag10)+(b16*lo_nonsfre_lag11)+(b17*lo_nonsfre_lag12)+(b18*lo_nonsfre_lag13)+(b19*lo_nonsfre_lag14)+(b20*lo_nonsfre_lag15)+(b21*lo_nonsfre_lag16)+(b22*lo_nonsfre_lag17)+(b23*lo_nonsfre_lag18)+(b24*lo_nonsfre_lag19);
f6_ecl_nonsfre = (b6*lo_nonsfre_t)+(b7*lo_nonsfre_lag1)+(b8*lo_nonsfre_lag2)+(b9*lo_nonsfre_lag3)+(b10*lo_nonsfre_lag4)+(b11*lo_nonsfre_lag5)+(b12*lo_nonsfre_lag6)+(b13*lo_nonsfre_lag7)+(b14*lo_nonsfre_lag8)+(b15*lo_nonsfre_lag9)+(b16*lo_nonsfre_lag10)+(b17*lo_nonsfre_lag11)+(b18*lo_nonsfre_lag12)+(b19*lo_nonsfre_lag13)+(b20*lo_nonsfre_lag14)+(b21*lo_nonsfre_lag15)+(b22*lo_nonsfre_lag16)+(b23*lo_nonsfre_lag17)+(b24*lo_nonsfre_lag18);
f7_ecl_nonsfre = (b7*lo_nonsfre_t)+(b8*lo_nonsfre_lag1)+(b9*lo_nonsfre_lag2)+(b10*lo_nonsfre_lag3)+(b11*lo_nonsfre_lag4)+(b12*lo_nonsfre_lag5)+(b13*lo_nonsfre_lag6)+(b14*lo_nonsfre_lag7)+(b15*lo_nonsfre_lag8)+(b16*lo_nonsfre_lag9)+(b17*lo_nonsfre_lag10)+(b18*lo_nonsfre_lag11)+(b19*lo_nonsfre_lag12)+(b20*lo_nonsfre_lag13)+(b21*lo_nonsfre_lag14)+(b22*lo_nonsfre_lag15)+(b23*lo_nonsfre_lag16)+(b24*lo_nonsfre_lag17);
f8_ecl_nonsfre = (b8*lo_nonsfre_t)+(b9*lo_nonsfre_lag1)+(b10*lo_nonsfre_lag2)+(b11*lo_nonsfre_lag3)+(b12*lo_nonsfre_lag4)+(b13*lo_nonsfre_lag5)+(b14*lo_nonsfre_lag6)+(b15*lo_nonsfre_lag7)+(b16*lo_nonsfre_lag8)+(b17*lo_nonsfre_lag9)+(b18*lo_nonsfre_lag10)+(b19*lo_nonsfre_lag11)+(b20*lo_nonsfre_lag12)+(b21*lo_nonsfre_lag13)+(b22*lo_nonsfre_lag14)+(b23*lo_nonsfre_lag15)+(b24*lo_nonsfre_lag16);
f9_ecl_nonsfre = (b9*lo_nonsfre_t)+(b10*lo_nonsfre_lag1)+(b11*lo_nonsfre_lag2)+(b12*lo_nonsfre_lag3)+(b13*lo_nonsfre_lag4)+(b14*lo_nonsfre_lag5)+(b15*lo_nonsfre_lag6)+(b16*lo_nonsfre_lag7)+(b17*lo_nonsfre_lag8)+(b18*lo_nonsfre_lag9)+(b19*lo_nonsfre_lag10)+(b20*lo_nonsfre_lag11)+(b21*lo_nonsfre_lag12)+(b22*lo_nonsfre_lag13)+(b23*lo_nonsfre_lag14)+(b24*lo_nonsfre_lag15);
f10_ecl_nonsfre = (b10*lo_nonsfre_t)+(b11*lo_nonsfre_lag1)+(b12*lo_nonsfre_lag2)+(b13*lo_nonsfre_lag3)+(b14*lo_nonsfre_lag4)+(b15*lo_nonsfre_lag5)+(b16*lo_nonsfre_lag6)+(b17*lo_nonsfre_lag7)+(b18*lo_nonsfre_lag8)+(b19*lo_nonsfre_lag9)+(b20*lo_nonsfre_lag10)+(b21*lo_nonsfre_lag11)+(b22*lo_nonsfre_lag12)+(b23*lo_nonsfre_lag13)+(b24*lo_nonsfre_lag14);
f11_ecl_nonsfre = (b11*lo_nonsfre_t)+(b12*lo_nonsfre_lag1)+(b13*lo_nonsfre_lag2)+(b14*lo_nonsfre_lag3)+(b15*lo_nonsfre_lag4)+(b16*lo_nonsfre_lag5)+(b17*lo_nonsfre_lag6)+(b18*lo_nonsfre_lag7)+(b19*lo_nonsfre_lag8)+(b20*lo_nonsfre_lag9)+(b21*lo_nonsfre_lag10)+(b22*lo_nonsfre_lag11)+(b23*lo_nonsfre_lag12)+(b24*lo_nonsfre_lag13);
f12_ecl_nonsfre = (b12*lo_nonsfre_t)+(b13*lo_nonsfre_lag1)+(b14*lo_nonsfre_lag2)+(b15*lo_nonsfre_lag3)+(b16*lo_nonsfre_lag4)+(b17*lo_nonsfre_lag5)+(b18*lo_nonsfre_lag6)+(b19*lo_nonsfre_lag7)+(b20*lo_nonsfre_lag8)+(b21*lo_nonsfre_lag9)+(b22*lo_nonsfre_lag10)+(b23*lo_nonsfre_lag11)+(b24*lo_nonsfre_lag12);
f13_ecl_nonsfre = (b13*lo_nonsfre_t)+(b14*lo_nonsfre_lag1)+(b15*lo_nonsfre_lag2)+(b16*lo_nonsfre_lag3)+(b17*lo_nonsfre_lag4)+(b18*lo_nonsfre_lag5)+(b19*lo_nonsfre_lag6)+(b20*lo_nonsfre_lag7)+(b21*lo_nonsfre_lag8)+(b22*lo_nonsfre_lag9)+(b23*lo_nonsfre_lag10)+(b24*lo_nonsfre_lag11);
f14_ecl_nonsfre = (b14*lo_nonsfre_t)+(b15*lo_nonsfre_lag1)+(b16*lo_nonsfre_lag2)+(b17*lo_nonsfre_lag3)+(b18*lo_nonsfre_lag4)+(b19*lo_nonsfre_lag5)+(b20*lo_nonsfre_lag6)+(b21*lo_nonsfre_lag7)+(b22*lo_nonsfre_lag8)+(b23*lo_nonsfre_lag9)+(b24*lo_nonsfre_lag10);
f15_ecl_nonsfre = (b15*lo_nonsfre_t)+(b16*lo_nonsfre_lag1)+(b17*lo_nonsfre_lag2)+(b18*lo_nonsfre_lag3)+(b19*lo_nonsfre_lag4)+(b20*lo_nonsfre_lag5)+(b21*lo_nonsfre_lag6)+(b22*lo_nonsfre_lag7)+(b23*lo_nonsfre_lag8)+(b24*lo_nonsfre_lag9);
f16_ecl_nonsfre = (b16*lo_nonsfre_t)+(b17*lo_nonsfre_lag1)+(b18*lo_nonsfre_lag2)+(b19*lo_nonsfre_lag3)+(b20*lo_nonsfre_lag4)+(b21*lo_nonsfre_lag5)+(b22*lo_nonsfre_lag6)+(b23*lo_nonsfre_lag7)+(b24*lo_nonsfre_lag8);
f17_ecl_nonsfre = (b17*lo_nonsfre_t)+(b18*lo_nonsfre_lag1)+(b19*lo_nonsfre_lag2)+(b20*lo_nonsfre_lag3)+(b21*lo_nonsfre_lag4)+(b22*lo_nonsfre_lag5)+(b23*lo_nonsfre_lag6)+(b24*lo_nonsfre_lag7);
f18_ecl_nonsfre = (b18*lo_nonsfre_t)+(b19*lo_nonsfre_lag1)+(b20*lo_nonsfre_lag2)+(b21*lo_nonsfre_lag3)+(b22*lo_nonsfre_lag4)+(b23*lo_nonsfre_lag5)+(b24*lo_nonsfre_lag6);
f19_ecl_nonsfre = (b19*lo_nonsfre_t)+(b20*lo_nonsfre_lag1)+(b21*lo_nonsfre_lag2)+(b22*lo_nonsfre_lag3)+(b23*lo_nonsfre_lag4)+(b24*lo_nonsfre_lag5);
f20_ecl_nonsfre = (b20*lo_nonsfre_t)+(b21*lo_nonsfre_lag1)+(b22*lo_nonsfre_lag2)+(b23*lo_nonsfre_lag3)+(b24*lo_nonsfre_lag4);
f21_ecl_nonsfre = (b21*lo_nonsfre_t)+(b22*lo_nonsfre_lag1)+(b23*lo_nonsfre_lag2)+(b24*lo_nonsfre_lag3);
f22_ecl_nonsfre = (b22*lo_nonsfre_t)+(b23*lo_nonsfre_lag1)+(b24*lo_nonsfre_lag2);
f23_ecl_nonsfre = (b23*lo_nonsfre_t)+(b24*lo_nonsfre_lag1);
f24_ecl_nonsfre = (b24*lo_nonsfre_t);
run;
proc sort data=ecl_nonsfre2 nodupkey;
by snlkey rankdate;
run;
data box.ecl_nonsfre_maxrsq;
set ecl_nonsfre2;
run;


/*CONSUMER LOANS*/
*Compare ECL estimates using various seed parameters and retain estimate with highest pseudo R-sq;
data ecl_cons_001 (drop = ecl);
set box.ecl_cons_param001;
param=.001;
run;
data ecl_cons_0025;
set box.ecl_cons_param0025;
param=.0025;
run;
data ecl_cons_005;
set box.ecl_cons_param005;
param=.005;
run;
data ecl_cons_0075;
set box.ecl_cons_param0075;
param=.0075;
run;
data ecl_agg;
set ecl_cons_001 ecl_cons_0025 ecl_cons_005 ecl_cons_0075;
run;
proc sort data=ecl_agg;
by snlkey rankdate param;
run;
proc sql;
create table ecl_cons1 as select *, max(pseudo_rsq) as max_pseudo_rsq
from ecl_agg
group by snlkey, rankdate;
quit;
data ecl_cons2;
set ecl_cons1;
if pseudo_rsq ne max_pseudo_rsq then delete;
cum_loss = b1+b2+b3+b4+b5+b6+b7+b8+b9+b10+b11+b12+b13+b14+b15+b16+b17+b18+b19+b20+b21+b22+b23+b24;
wtd_lags = ((b1*1)+(b2*2)+(b3*3)+(b4*4)+(b5*5)+(b6*6)+(b7*7)+(b8*8)+(b9*9)+(b10*10)+(b11*11)+(b12*12)
		  +(b13*13)+(b14*14)+(b15*15)+(b16*16)+(b17*17)+(b18*18)+(b19*19)+(b20*20)+(b21*21)+(b22*22)
		  +(b23*23)+(b24*24))/cum_loss;
f1_ecl_cons = (b1*lo_cons_t)+(b2*lo_cons_lag1)+(b3*lo_cons_lag2)+(b4*lo_cons_lag3)+(b5*lo_cons_lag4)+(b6*lo_cons_lag5)+(b7*lo_cons_lag6)+(b8*lo_cons_lag7)+(b9*lo_cons_lag8)+(b10*lo_cons_lag9)+(b11*lo_cons_lag10)+(b12*lo_cons_lag11)+(b13*lo_cons_lag12)+(b14*lo_cons_lag13)+(b15*lo_cons_lag14)+(b16*lo_cons_lag15)+(b17*lo_cons_lag16)+(b18*lo_cons_lag17)+(b19*lo_cons_lag18)+(b20*lo_cons_lag19)+(b21*lo_cons_lag20)+(b22*lo_cons_lag21)+(b23*lo_cons_lag22)+(b24*lo_cons_lag23);
f2_ecl_cons = (b2*lo_cons_t)+(b3*lo_cons_lag1)+(b4*lo_cons_lag2)+(b5*lo_cons_lag3)+(b6*lo_cons_lag4)+(b7*lo_cons_lag5)+(b8*lo_cons_lag6)+(b9*lo_cons_lag7)+(b10*lo_cons_lag8)+(b11*lo_cons_lag9)+(b12*lo_cons_lag10)+(b13*lo_cons_lag11)+(b14*lo_cons_lag12)+(b15*lo_cons_lag13)+(b16*lo_cons_lag14)+(b17*lo_cons_lag15)+(b18*lo_cons_lag16)+(b19*lo_cons_lag17)+(b20*lo_cons_lag18)+(b21*lo_cons_lag19)+(b22*lo_cons_lag20)+(b23*lo_cons_lag21)+(b24*lo_cons_lag22);
f3_ecl_cons = (b3*lo_cons_t)+(b4*lo_cons_lag1)+(b5*lo_cons_lag2)+(b6*lo_cons_lag3)+(b7*lo_cons_lag4)+(b8*lo_cons_lag5)+(b9*lo_cons_lag6)+(b10*lo_cons_lag7)+(b11*lo_cons_lag8)+(b12*lo_cons_lag9)+(b13*lo_cons_lag10)+(b14*lo_cons_lag11)+(b15*lo_cons_lag12)+(b16*lo_cons_lag13)+(b17*lo_cons_lag14)+(b18*lo_cons_lag15)+(b19*lo_cons_lag16)+(b20*lo_cons_lag17)+(b21*lo_cons_lag18)+(b22*lo_cons_lag19)+(b23*lo_cons_lag20)+(b24*lo_cons_lag21);
f4_ecl_cons = (b4*lo_cons_t)+(b5*lo_cons_lag1)+(b6*lo_cons_lag2)+(b7*lo_cons_lag3)+(b8*lo_cons_lag4)+(b9*lo_cons_lag5)+(b10*lo_cons_lag6)+(b11*lo_cons_lag7)+(b12*lo_cons_lag8)+(b13*lo_cons_lag9)+(b14*lo_cons_lag10)+(b15*lo_cons_lag11)+(b16*lo_cons_lag12)+(b17*lo_cons_lag13)+(b18*lo_cons_lag14)+(b19*lo_cons_lag15)+(b20*lo_cons_lag16)+(b21*lo_cons_lag17)+(b22*lo_cons_lag18)+(b23*lo_cons_lag19)+(b24*lo_cons_lag20);
f5_ecl_cons = (b5*lo_cons_t)+(b6*lo_cons_lag1)+(b7*lo_cons_lag2)+(b8*lo_cons_lag3)+(b9*lo_cons_lag4)+(b10*lo_cons_lag5)+(b11*lo_cons_lag6)+(b12*lo_cons_lag7)+(b13*lo_cons_lag8)+(b14*lo_cons_lag9)+(b15*lo_cons_lag10)+(b16*lo_cons_lag11)+(b17*lo_cons_lag12)+(b18*lo_cons_lag13)+(b19*lo_cons_lag14)+(b20*lo_cons_lag15)+(b21*lo_cons_lag16)+(b22*lo_cons_lag17)+(b23*lo_cons_lag18)+(b24*lo_cons_lag19);
f6_ecl_cons = (b6*lo_cons_t)+(b7*lo_cons_lag1)+(b8*lo_cons_lag2)+(b9*lo_cons_lag3)+(b10*lo_cons_lag4)+(b11*lo_cons_lag5)+(b12*lo_cons_lag6)+(b13*lo_cons_lag7)+(b14*lo_cons_lag8)+(b15*lo_cons_lag9)+(b16*lo_cons_lag10)+(b17*lo_cons_lag11)+(b18*lo_cons_lag12)+(b19*lo_cons_lag13)+(b20*lo_cons_lag14)+(b21*lo_cons_lag15)+(b22*lo_cons_lag16)+(b23*lo_cons_lag17)+(b24*lo_cons_lag18);
f7_ecl_cons = (b7*lo_cons_t)+(b8*lo_cons_lag1)+(b9*lo_cons_lag2)+(b10*lo_cons_lag3)+(b11*lo_cons_lag4)+(b12*lo_cons_lag5)+(b13*lo_cons_lag6)+(b14*lo_cons_lag7)+(b15*lo_cons_lag8)+(b16*lo_cons_lag9)+(b17*lo_cons_lag10)+(b18*lo_cons_lag11)+(b19*lo_cons_lag12)+(b20*lo_cons_lag13)+(b21*lo_cons_lag14)+(b22*lo_cons_lag15)+(b23*lo_cons_lag16)+(b24*lo_cons_lag17);
f8_ecl_cons = (b8*lo_cons_t)+(b9*lo_cons_lag1)+(b10*lo_cons_lag2)+(b11*lo_cons_lag3)+(b12*lo_cons_lag4)+(b13*lo_cons_lag5)+(b14*lo_cons_lag6)+(b15*lo_cons_lag7)+(b16*lo_cons_lag8)+(b17*lo_cons_lag9)+(b18*lo_cons_lag10)+(b19*lo_cons_lag11)+(b20*lo_cons_lag12)+(b21*lo_cons_lag13)+(b22*lo_cons_lag14)+(b23*lo_cons_lag15)+(b24*lo_cons_lag16);
f9_ecl_cons = (b9*lo_cons_t)+(b10*lo_cons_lag1)+(b11*lo_cons_lag2)+(b12*lo_cons_lag3)+(b13*lo_cons_lag4)+(b14*lo_cons_lag5)+(b15*lo_cons_lag6)+(b16*lo_cons_lag7)+(b17*lo_cons_lag8)+(b18*lo_cons_lag9)+(b19*lo_cons_lag10)+(b20*lo_cons_lag11)+(b21*lo_cons_lag12)+(b22*lo_cons_lag13)+(b23*lo_cons_lag14)+(b24*lo_cons_lag15);
f10_ecl_cons = (b10*lo_cons_t)+(b11*lo_cons_lag1)+(b12*lo_cons_lag2)+(b13*lo_cons_lag3)+(b14*lo_cons_lag4)+(b15*lo_cons_lag5)+(b16*lo_cons_lag6)+(b17*lo_cons_lag7)+(b18*lo_cons_lag8)+(b19*lo_cons_lag9)+(b20*lo_cons_lag10)+(b21*lo_cons_lag11)+(b22*lo_cons_lag12)+(b23*lo_cons_lag13)+(b24*lo_cons_lag14);
f11_ecl_cons = (b11*lo_cons_t)+(b12*lo_cons_lag1)+(b13*lo_cons_lag2)+(b14*lo_cons_lag3)+(b15*lo_cons_lag4)+(b16*lo_cons_lag5)+(b17*lo_cons_lag6)+(b18*lo_cons_lag7)+(b19*lo_cons_lag8)+(b20*lo_cons_lag9)+(b21*lo_cons_lag10)+(b22*lo_cons_lag11)+(b23*lo_cons_lag12)+(b24*lo_cons_lag13);
f12_ecl_cons = (b12*lo_cons_t)+(b13*lo_cons_lag1)+(b14*lo_cons_lag2)+(b15*lo_cons_lag3)+(b16*lo_cons_lag4)+(b17*lo_cons_lag5)+(b18*lo_cons_lag6)+(b19*lo_cons_lag7)+(b20*lo_cons_lag8)+(b21*lo_cons_lag9)+(b22*lo_cons_lag10)+(b23*lo_cons_lag11)+(b24*lo_cons_lag12);
f13_ecl_cons = (b13*lo_cons_t)+(b14*lo_cons_lag1)+(b15*lo_cons_lag2)+(b16*lo_cons_lag3)+(b17*lo_cons_lag4)+(b18*lo_cons_lag5)+(b19*lo_cons_lag6)+(b20*lo_cons_lag7)+(b21*lo_cons_lag8)+(b22*lo_cons_lag9)+(b23*lo_cons_lag10)+(b24*lo_cons_lag11);
f14_ecl_cons = (b14*lo_cons_t)+(b15*lo_cons_lag1)+(b16*lo_cons_lag2)+(b17*lo_cons_lag3)+(b18*lo_cons_lag4)+(b19*lo_cons_lag5)+(b20*lo_cons_lag6)+(b21*lo_cons_lag7)+(b22*lo_cons_lag8)+(b23*lo_cons_lag9)+(b24*lo_cons_lag10);
f15_ecl_cons = (b15*lo_cons_t)+(b16*lo_cons_lag1)+(b17*lo_cons_lag2)+(b18*lo_cons_lag3)+(b19*lo_cons_lag4)+(b20*lo_cons_lag5)+(b21*lo_cons_lag6)+(b22*lo_cons_lag7)+(b23*lo_cons_lag8)+(b24*lo_cons_lag9);
f16_ecl_cons = (b16*lo_cons_t)+(b17*lo_cons_lag1)+(b18*lo_cons_lag2)+(b19*lo_cons_lag3)+(b20*lo_cons_lag4)+(b21*lo_cons_lag5)+(b22*lo_cons_lag6)+(b23*lo_cons_lag7)+(b24*lo_cons_lag8);
f17_ecl_cons = (b17*lo_cons_t)+(b18*lo_cons_lag1)+(b19*lo_cons_lag2)+(b20*lo_cons_lag3)+(b21*lo_cons_lag4)+(b22*lo_cons_lag5)+(b23*lo_cons_lag6)+(b24*lo_cons_lag7);
f18_ecl_cons = (b18*lo_cons_t)+(b19*lo_cons_lag1)+(b20*lo_cons_lag2)+(b21*lo_cons_lag3)+(b22*lo_cons_lag4)+(b23*lo_cons_lag5)+(b24*lo_cons_lag6);
f19_ecl_cons = (b19*lo_cons_t)+(b20*lo_cons_lag1)+(b21*lo_cons_lag2)+(b22*lo_cons_lag3)+(b23*lo_cons_lag4)+(b24*lo_cons_lag5);
f20_ecl_cons = (b20*lo_cons_t)+(b21*lo_cons_lag1)+(b22*lo_cons_lag2)+(b23*lo_cons_lag3)+(b24*lo_cons_lag4);
f21_ecl_cons = (b21*lo_cons_t)+(b22*lo_cons_lag1)+(b23*lo_cons_lag2)+(b24*lo_cons_lag3);
f22_ecl_cons = (b22*lo_cons_t)+(b23*lo_cons_lag1)+(b24*lo_cons_lag2);
f23_ecl_cons = (b23*lo_cons_t)+(b24*lo_cons_lag1);
f24_ecl_cons = (b24*lo_cons_t);
run;
proc sort data=ecl_cons2 nodupkey;
by snlkey rankdate;
run;
data box.ecl_cons_maxrsq;
set ecl_cons2;
run;


/*OTHER NON-REAL ESTATE LOANS*/
*Compare ECL estimates using various seed parameters and retain estimate with highest pseudo R-sq;
data ecl_othnonre_001 (drop = ecl);
set box.ecl_othnonre_param001;
param=.001;
run;
data ecl_othnonre_0025;
set box.ecl_othnonre_param0025;
param=.0025;
run;
data ecl_othnonre_005;
set box.ecl_othnonre_param005;
param=.005;
run;
data ecl_othnonre_0075;
set box.ecl_othnonre_param0075;
param=.0075;
run;
data ecl_agg;
set ecl_othnonre_001 ecl_othnonre_0025 ecl_othnonre_005 ecl_othnonre_0075;
run;
proc sort data=ecl_agg;
by snlkey rankdate param;
run;
proc sql;
create table ecl_othnonre1 as select *, max(pseudo_rsq) as max_pseudo_rsq
from ecl_agg
group by snlkey, rankdate;
quit;
data ecl_othnonre2;
set ecl_othnonre1;
if pseudo_rsq ne max_pseudo_rsq then delete;
cum_loss = b1+b2+b3+b4+b5+b6+b7+b8+b9+b10+b11+b12+b13+b14+b15+b16+b17+b18+b19+b20+b21+b22+b23+b24;
wtd_lags = ((b1*1)+(b2*2)+(b3*3)+(b4*4)+(b5*5)+(b6*6)+(b7*7)+(b8*8)+(b9*9)+(b10*10)+(b11*11)+(b12*12)
		  +(b13*13)+(b14*14)+(b15*15)+(b16*16)+(b17*17)+(b18*18)+(b19*19)+(b20*20)+(b21*21)+(b22*22)
		  +(b23*23)+(b24*24))/cum_loss;
f1_ecl_othnonre = (b1*lo_othnonre_t)+(b2*lo_othnonre_lag1)+(b3*lo_othnonre_lag2)+(b4*lo_othnonre_lag3)+(b5*lo_othnonre_lag4)+(b6*lo_othnonre_lag5)+(b7*lo_othnonre_lag6)+(b8*lo_othnonre_lag7)+(b9*lo_othnonre_lag8)+(b10*lo_othnonre_lag9)+(b11*lo_othnonre_lag10)+(b12*lo_othnonre_lag11)+(b13*lo_othnonre_lag12)+(b14*lo_othnonre_lag13)+(b15*lo_othnonre_lag14)+(b16*lo_othnonre_lag15)+(b17*lo_othnonre_lag16)+(b18*lo_othnonre_lag17)+(b19*lo_othnonre_lag18)+(b20*lo_othnonre_lag19)+(b21*lo_othnonre_lag20)+(b22*lo_othnonre_lag21)+(b23*lo_othnonre_lag22)+(b24*lo_othnonre_lag23);
f2_ecl_othnonre = (b2*lo_othnonre_t)+(b3*lo_othnonre_lag1)+(b4*lo_othnonre_lag2)+(b5*lo_othnonre_lag3)+(b6*lo_othnonre_lag4)+(b7*lo_othnonre_lag5)+(b8*lo_othnonre_lag6)+(b9*lo_othnonre_lag7)+(b10*lo_othnonre_lag8)+(b11*lo_othnonre_lag9)+(b12*lo_othnonre_lag10)+(b13*lo_othnonre_lag11)+(b14*lo_othnonre_lag12)+(b15*lo_othnonre_lag13)+(b16*lo_othnonre_lag14)+(b17*lo_othnonre_lag15)+(b18*lo_othnonre_lag16)+(b19*lo_othnonre_lag17)+(b20*lo_othnonre_lag18)+(b21*lo_othnonre_lag19)+(b22*lo_othnonre_lag20)+(b23*lo_othnonre_lag21)+(b24*lo_othnonre_lag22);
f3_ecl_othnonre = (b3*lo_othnonre_t)+(b4*lo_othnonre_lag1)+(b5*lo_othnonre_lag2)+(b6*lo_othnonre_lag3)+(b7*lo_othnonre_lag4)+(b8*lo_othnonre_lag5)+(b9*lo_othnonre_lag6)+(b10*lo_othnonre_lag7)+(b11*lo_othnonre_lag8)+(b12*lo_othnonre_lag9)+(b13*lo_othnonre_lag10)+(b14*lo_othnonre_lag11)+(b15*lo_othnonre_lag12)+(b16*lo_othnonre_lag13)+(b17*lo_othnonre_lag14)+(b18*lo_othnonre_lag15)+(b19*lo_othnonre_lag16)+(b20*lo_othnonre_lag17)+(b21*lo_othnonre_lag18)+(b22*lo_othnonre_lag19)+(b23*lo_othnonre_lag20)+(b24*lo_othnonre_lag21);
f4_ecl_othnonre = (b4*lo_othnonre_t)+(b5*lo_othnonre_lag1)+(b6*lo_othnonre_lag2)+(b7*lo_othnonre_lag3)+(b8*lo_othnonre_lag4)+(b9*lo_othnonre_lag5)+(b10*lo_othnonre_lag6)+(b11*lo_othnonre_lag7)+(b12*lo_othnonre_lag8)+(b13*lo_othnonre_lag9)+(b14*lo_othnonre_lag10)+(b15*lo_othnonre_lag11)+(b16*lo_othnonre_lag12)+(b17*lo_othnonre_lag13)+(b18*lo_othnonre_lag14)+(b19*lo_othnonre_lag15)+(b20*lo_othnonre_lag16)+(b21*lo_othnonre_lag17)+(b22*lo_othnonre_lag18)+(b23*lo_othnonre_lag19)+(b24*lo_othnonre_lag20);
f5_ecl_othnonre = (b5*lo_othnonre_t)+(b6*lo_othnonre_lag1)+(b7*lo_othnonre_lag2)+(b8*lo_othnonre_lag3)+(b9*lo_othnonre_lag4)+(b10*lo_othnonre_lag5)+(b11*lo_othnonre_lag6)+(b12*lo_othnonre_lag7)+(b13*lo_othnonre_lag8)+(b14*lo_othnonre_lag9)+(b15*lo_othnonre_lag10)+(b16*lo_othnonre_lag11)+(b17*lo_othnonre_lag12)+(b18*lo_othnonre_lag13)+(b19*lo_othnonre_lag14)+(b20*lo_othnonre_lag15)+(b21*lo_othnonre_lag16)+(b22*lo_othnonre_lag17)+(b23*lo_othnonre_lag18)+(b24*lo_othnonre_lag19);
f6_ecl_othnonre = (b6*lo_othnonre_t)+(b7*lo_othnonre_lag1)+(b8*lo_othnonre_lag2)+(b9*lo_othnonre_lag3)+(b10*lo_othnonre_lag4)+(b11*lo_othnonre_lag5)+(b12*lo_othnonre_lag6)+(b13*lo_othnonre_lag7)+(b14*lo_othnonre_lag8)+(b15*lo_othnonre_lag9)+(b16*lo_othnonre_lag10)+(b17*lo_othnonre_lag11)+(b18*lo_othnonre_lag12)+(b19*lo_othnonre_lag13)+(b20*lo_othnonre_lag14)+(b21*lo_othnonre_lag15)+(b22*lo_othnonre_lag16)+(b23*lo_othnonre_lag17)+(b24*lo_othnonre_lag18);
f7_ecl_othnonre = (b7*lo_othnonre_t)+(b8*lo_othnonre_lag1)+(b9*lo_othnonre_lag2)+(b10*lo_othnonre_lag3)+(b11*lo_othnonre_lag4)+(b12*lo_othnonre_lag5)+(b13*lo_othnonre_lag6)+(b14*lo_othnonre_lag7)+(b15*lo_othnonre_lag8)+(b16*lo_othnonre_lag9)+(b17*lo_othnonre_lag10)+(b18*lo_othnonre_lag11)+(b19*lo_othnonre_lag12)+(b20*lo_othnonre_lag13)+(b21*lo_othnonre_lag14)+(b22*lo_othnonre_lag15)+(b23*lo_othnonre_lag16)+(b24*lo_othnonre_lag17);
f8_ecl_othnonre = (b8*lo_othnonre_t)+(b9*lo_othnonre_lag1)+(b10*lo_othnonre_lag2)+(b11*lo_othnonre_lag3)+(b12*lo_othnonre_lag4)+(b13*lo_othnonre_lag5)+(b14*lo_othnonre_lag6)+(b15*lo_othnonre_lag7)+(b16*lo_othnonre_lag8)+(b17*lo_othnonre_lag9)+(b18*lo_othnonre_lag10)+(b19*lo_othnonre_lag11)+(b20*lo_othnonre_lag12)+(b21*lo_othnonre_lag13)+(b22*lo_othnonre_lag14)+(b23*lo_othnonre_lag15)+(b24*lo_othnonre_lag16);
f9_ecl_othnonre = (b9*lo_othnonre_t)+(b10*lo_othnonre_lag1)+(b11*lo_othnonre_lag2)+(b12*lo_othnonre_lag3)+(b13*lo_othnonre_lag4)+(b14*lo_othnonre_lag5)+(b15*lo_othnonre_lag6)+(b16*lo_othnonre_lag7)+(b17*lo_othnonre_lag8)+(b18*lo_othnonre_lag9)+(b19*lo_othnonre_lag10)+(b20*lo_othnonre_lag11)+(b21*lo_othnonre_lag12)+(b22*lo_othnonre_lag13)+(b23*lo_othnonre_lag14)+(b24*lo_othnonre_lag15);
f10_ecl_othnonre = (b10*lo_othnonre_t)+(b11*lo_othnonre_lag1)+(b12*lo_othnonre_lag2)+(b13*lo_othnonre_lag3)+(b14*lo_othnonre_lag4)+(b15*lo_othnonre_lag5)+(b16*lo_othnonre_lag6)+(b17*lo_othnonre_lag7)+(b18*lo_othnonre_lag8)+(b19*lo_othnonre_lag9)+(b20*lo_othnonre_lag10)+(b21*lo_othnonre_lag11)+(b22*lo_othnonre_lag12)+(b23*lo_othnonre_lag13)+(b24*lo_othnonre_lag14);
f11_ecl_othnonre = (b11*lo_othnonre_t)+(b12*lo_othnonre_lag1)+(b13*lo_othnonre_lag2)+(b14*lo_othnonre_lag3)+(b15*lo_othnonre_lag4)+(b16*lo_othnonre_lag5)+(b17*lo_othnonre_lag6)+(b18*lo_othnonre_lag7)+(b19*lo_othnonre_lag8)+(b20*lo_othnonre_lag9)+(b21*lo_othnonre_lag10)+(b22*lo_othnonre_lag11)+(b23*lo_othnonre_lag12)+(b24*lo_othnonre_lag13);
f12_ecl_othnonre = (b12*lo_othnonre_t)+(b13*lo_othnonre_lag1)+(b14*lo_othnonre_lag2)+(b15*lo_othnonre_lag3)+(b16*lo_othnonre_lag4)+(b17*lo_othnonre_lag5)+(b18*lo_othnonre_lag6)+(b19*lo_othnonre_lag7)+(b20*lo_othnonre_lag8)+(b21*lo_othnonre_lag9)+(b22*lo_othnonre_lag10)+(b23*lo_othnonre_lag11)+(b24*lo_othnonre_lag12);
f13_ecl_othnonre = (b13*lo_othnonre_t)+(b14*lo_othnonre_lag1)+(b15*lo_othnonre_lag2)+(b16*lo_othnonre_lag3)+(b17*lo_othnonre_lag4)+(b18*lo_othnonre_lag5)+(b19*lo_othnonre_lag6)+(b20*lo_othnonre_lag7)+(b21*lo_othnonre_lag8)+(b22*lo_othnonre_lag9)+(b23*lo_othnonre_lag10)+(b24*lo_othnonre_lag11);
f14_ecl_othnonre = (b14*lo_othnonre_t)+(b15*lo_othnonre_lag1)+(b16*lo_othnonre_lag2)+(b17*lo_othnonre_lag3)+(b18*lo_othnonre_lag4)+(b19*lo_othnonre_lag5)+(b20*lo_othnonre_lag6)+(b21*lo_othnonre_lag7)+(b22*lo_othnonre_lag8)+(b23*lo_othnonre_lag9)+(b24*lo_othnonre_lag10);
f15_ecl_othnonre = (b15*lo_othnonre_t)+(b16*lo_othnonre_lag1)+(b17*lo_othnonre_lag2)+(b18*lo_othnonre_lag3)+(b19*lo_othnonre_lag4)+(b20*lo_othnonre_lag5)+(b21*lo_othnonre_lag6)+(b22*lo_othnonre_lag7)+(b23*lo_othnonre_lag8)+(b24*lo_othnonre_lag9);
f16_ecl_othnonre = (b16*lo_othnonre_t)+(b17*lo_othnonre_lag1)+(b18*lo_othnonre_lag2)+(b19*lo_othnonre_lag3)+(b20*lo_othnonre_lag4)+(b21*lo_othnonre_lag5)+(b22*lo_othnonre_lag6)+(b23*lo_othnonre_lag7)+(b24*lo_othnonre_lag8);
f17_ecl_othnonre = (b17*lo_othnonre_t)+(b18*lo_othnonre_lag1)+(b19*lo_othnonre_lag2)+(b20*lo_othnonre_lag3)+(b21*lo_othnonre_lag4)+(b22*lo_othnonre_lag5)+(b23*lo_othnonre_lag6)+(b24*lo_othnonre_lag7);
f18_ecl_othnonre = (b18*lo_othnonre_t)+(b19*lo_othnonre_lag1)+(b20*lo_othnonre_lag2)+(b21*lo_othnonre_lag3)+(b22*lo_othnonre_lag4)+(b23*lo_othnonre_lag5)+(b24*lo_othnonre_lag6);
f19_ecl_othnonre = (b19*lo_othnonre_t)+(b20*lo_othnonre_lag1)+(b21*lo_othnonre_lag2)+(b22*lo_othnonre_lag3)+(b23*lo_othnonre_lag4)+(b24*lo_othnonre_lag5);
f20_ecl_othnonre = (b20*lo_othnonre_t)+(b21*lo_othnonre_lag1)+(b22*lo_othnonre_lag2)+(b23*lo_othnonre_lag3)+(b24*lo_othnonre_lag4);
f21_ecl_othnonre = (b21*lo_othnonre_t)+(b22*lo_othnonre_lag1)+(b23*lo_othnonre_lag2)+(b24*lo_othnonre_lag3);
f22_ecl_othnonre = (b22*lo_othnonre_t)+(b23*lo_othnonre_lag1)+(b24*lo_othnonre_lag2);
f23_ecl_othnonre = (b23*lo_othnonre_t)+(b24*lo_othnonre_lag1);
f24_ecl_othnonre = (b24*lo_othnonre_t);
run;
proc sort data=ecl_othnonre2 nodupkey;
by snlkey rankdate;
run;
data box.ecl_othnonre_maxrsq;
set ecl_othnonre2;
run;


*~~~~~~~~ADJUST ECL ESTIMATES FOR CHANGES IN MACROECONOMIC VARIABLES~~~~~~~~~~~;

*Gather residuals from Stage 1 ECL Model;
data ecl_sf_residuals;
set 
box.ecl_sf_residuals001
box.ecl_sf_residuals005
box.ecl_sf_residuals0025
box.ecl_sf_residuals0075;
rename res=res_sf;
run;
proc sort data=ecl_sf_residuals; by snlkey rollreg_rankdate param rankdate; run;
proc sql;
create table ecl_sf_residuals as select a.*, b.param as param_max
from ecl_sf_residuals a left join box.ecl_sf_maxrsq b
on a.snlkey=b.snlkey and a.rollreg_rankdate=b.rankdate;
quit;
data ecl_sf_residuals; set ecl_sf_residuals;
if param ne param_max then delete;
run;

data ecl_nonsfre_residuals;
set 
box.ecl_nonsfre_resid001
box.ecl_nonsfre_resid005
box.ecl_nonsfre_resid0025
box.ecl_nonsfre_resid0075;
rename res=res_nonsfre;
run;
proc sql;
create table ecl_nonsfre_residuals as select a.*, b.param as param_max
from ecl_nonsfre_residuals a left join box.ecl_nonsfre_maxrsq b
on a.snlkey=b.snlkey and a.rollreg_rankdate=b.rankdate;
quit;
data ecl_nonsfre_residuals; set ecl_nonsfre_residuals;
if param ne param_max then delete;
run;

data ecl_cons_residuals;
set 
box.ecl_cons_residuals001
box.ecl_cons_residuals005
box.ecl_cons_residuals0025
box.ecl_cons_residuals0075;
rename res=res_cons;
run;
proc sql;
create table ecl_cons_residuals as select a.*, b.param as param_max
from ecl_cons_residuals a left join box.ecl_cons_maxrsq b
on a.snlkey=b.snlkey and a.rollreg_rankdate=b.rankdate;
quit;
data ecl_cons_residuals; set ecl_cons_residuals;
if param ne param_max then delete;
run;

data ecl_othnonre_residuals;
set 
box.ecl_othnonre_resid001
box.ecl_othnonre_resid005
box.ecl_othnonre_resid0025
box.ecl_othnonre_resid0075;
rename res=res_othnonre;
run;
proc sql;
create table ecl_othnonre_residuals as select a.*, b.param as param_max
from ecl_othnonre_residuals a left join box.ecl_othnonre_maxrsq b
on a.snlkey=b.snlkey and a.rollreg_rankdate=b.rankdate;
quit;
data ecl_othnonre_residuals; set ecl_othnonre_residuals;
if param ne param_max then delete;
run;

proc sql;
create table ecl_residuals as select a.snlkey, a.rollreg_rankdate, a.rankdate, a.res_sf, b.res_nonsfre, c.res_cons, d.res_othnonre
from ecl_sf_residuals a, ecl_nonsfre_residuals b, ecl_cons_residuals c, ecl_othnonre_residuals d
where a.snlkey=b.snlkey=c.snlkey=d.snlkey and a.rollreg_rankdate=b.rollreg_rankdate=c.rollreg_rankdate=d.rollreg_rankdate and a.rankdate=b.rankdate=c.rankdate=d.rankdate
order by a.snlkey, a.rollreg_rankdate, a.rankdate;
quit;

*Ensure no duplicates;
proc sort data=ecl_residuals nodupkey;
by snlkey rollreg_rankdate rankdate;
run;

*Add loan data;
proc sql;
create table stage2_1 as select a.*, b.loans
from ecl_residuals a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.loans as lag1_loans
from stage2_1 a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.loans as lag2_loans
from stage2_1 a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.loans as lag4_loans
from stage2_1 a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table stage2_1 as select a.*, b.loans as lag8_loans
from stage2_1 a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+8;

create table stage2_1 as select a.*, b.reloans
from stage2_1 a left join box.all_reloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.reloans as lag1_reloans
from stage2_1 a left join box.all_reloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.reloans as lag2_reloans
from stage2_1 a left join box.all_reloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.sfloans
from stage2_1 a left join box.all_sfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.sfloans as lag1_sfloans
from stage2_1 a left join box.all_sfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.sfloans as lag2_sfloans
from stage2_1 a left join box.all_sfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.sfcndloans
from stage2_1 a left join box.all_sfcndloans_1990_2016 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.sfcndloans as lag1_sfcndloans
from stage2_1 a left join box.all_sfcndloans_1990_2016 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.sfcndloans as lag2_sfcndloans
from stage2_1 a left join box.all_sfcndloans_1990_2016 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.loans_hfs
from stage2_1 a left join box.all_loans_hfs_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.loans_hfs as lag1_loans_hfs
from stage2_1 a left join box.all_loans_hfs_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.loans_hfs as lag2_loans_hfs
from stage2_1 a left join box.all_loans_hfs_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.mfloans
from stage2_1 a left join box.all_mfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.mfloans as lag1_mfloans
from stage2_1 a left join box.all_mfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.mfloans as lag2_mfloans
from stage2_1 a left join box.all_mfloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.creloans
from stage2_1 a left join box.all_creloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.creloans as lag1_creloans
from stage2_1 a left join box.all_creloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.creloans as lag2_creloans
from stage2_1 a left join box.all_creloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.farmloans
from stage2_1 a left join box.all_farmloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.farmloans as lag1_farmloans
from stage2_1 a left join box.all_farmloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.farmloans as lag2_farmloans
from stage2_1 a left join box.all_farmloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.consloans
from stage2_1 a left join box.all_consloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.consloans as lag1_consloans
from stage2_1 a left join box.all_consloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.consloans as lag2_consloans
from stage2_1 a left join box.all_consloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.cniloans
from stage2_1 a left join box.all_cniloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.cniloans as lag1_cniloans
from stage2_1 a left join box.all_cniloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.cniloans as lag2_cniloans
from stage2_1 a left join box.all_cniloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.agloans
from stage2_1 a left join box.all_agloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.agloans as lag1_agloans
from stage2_1 a left join box.all_agloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.agloans as lag2_agloans
from stage2_1 a left join box.all_agloans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

create table stage2_1 as select a.*, b.na
from stage2_1 a left join box.all_na_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.na as lag1_na
from stage2_1 a left join box.all_na_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.na as lag4_na
from stage2_1 a left join box.all_na_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table stage2_1 as select a.*, b.na as lag8_na
from stage2_1 a left join box.all_na_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+8;

create table stage2_1 as select a.*, b.pd90
from stage2_1 a left join box.all_pd90_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.pd90 as lag1_pd90
from stage2_1 a left join box.all_pd90_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.pd90 as lag4_pd90
from stage2_1 a left join box.all_pd90_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table stage2_1 as select a.*, b.pd90 as lag8_pd90
from stage2_1 a left join box.all_pd90_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+8;

create table stage2_1 as select a.*, b.pd30
from stage2_1 a left join box.all_pd30_2001_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.npl, b.npl_sf, b.npl_sfcnd, b.npl_mf, b.npl_cre, b.npl_farm, b.npl_cons, b.npl_cni, b.npl_ag
from stage2_1 as a left join box.all_npl_bytype as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_1 as select a.*, b.npl as lag1_npl, b.npl_sf as lag1_npl_sf, b.npl_sfcnd as lag1_npl_sfcnd, b.npl_mf as lag1_npl_mf, b.npl_cre as lag1_npl_cre, b.npl_farm as lag1_npl_farm, b.npl_cons as lag1_npl_cons, b.npl_cni as lag1_npl_cni, b.npl_ag as lag1_npl_ag
from stage2_1 as a left join box.all_npl_bytype as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

create table stage2_1 as select a.*, b.npl as lag2_npl, b.npl_sf as lag2_npl_sf, b.npl_sfcnd as lag2_npl_sfcnd, b.npl_mf as lag2_npl_mf, b.npl_cre as lag2_npl_cre, b.npl_farm as lag2_npl_farm, b.npl_cons as lag2_npl_cons, b.npl_cni as lag2_npl_cni, b.npl_ag as lag2_npl_ag
from stage2_1 as a left join box.all_npl_bytype as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2 order by a.snlkey, a.rollreg_rankdate, a.rankdate;
quit;
data stage2_2; set stage2_1;
if sfcndloans=. then sfcndloans=0;
if loans_hfs=. then loans_hfs=0;
sf_total = sfloans+sfcndloans;
sf_htm = sf_total-loans_hfs;
nonsfre = mfloans+creloans+farmloans;
othnonre = cniloans+agloans;
if lag1_sfcndloans=. then lag1_sfcndloans=0;
if lag1_loans_hfs=. then lag1_loans_hfs=0;
lag1_sf_total = lag1_sfloans+lag1_sfcndloans;
lag1_sf_htm = lag1_sf_total-lag1_loans_hfs;
lag1_nonsfre = lag1_mfloans+lag1_creloans+lag1_farmloans;
lag1_othnonre = lag1_cniloans+lag1_agloans;
if lag2_sfcndloans=. then lag2_sfcndloans=0;
if lag2_loans_hfs=. then lag2_loans_hfs=0;
lag2_sf_total = lag2_sfloans+lag2_sfcndloans;
lag2_sf_htm = lag2_sf_total-lag2_loans_hfs;
lag2_nonsfre = lag2_mfloans+lag2_creloans+lag2_farmloans;
lag2_othnonre = lag2_cniloans+lag2_agloans;
res_sf_l = res_sf / sf_htm;
res_nonsfre_l = res_nonsfre / nonsfre;
res_cons_l = res_cons / consloans;
res_othnonre_l = res_othnonre / othnonre;
if npl_sfcnd=. then npl_sfcnd=0;
npl_sf_total = npl_sf+npl_sfcnd;
npl_nonsfre = npl_mf+npl_cre+npl_farm;
npl_othnonre = npl_cni+npl_ag;
if lag1_npl_sfcnd=. then lag1_npl_sfcnd=0;
lag1_npl_sf_total = lag1_npl_sf+lag1_npl_sfcnd;
lag1_npl_nonsfre = lag1_npl_mf+lag1_npl_cre+lag1_npl_farm;
lag1_npl_othnonre = lag1_npl_cni+lag1_npl_ag;
if lag2_npl_sfcnd=. then lag2_npl_sfcnd=0;
lag2_npl_sf_total = lag2_npl_sf+lag2_npl_sfcnd;
lag2_npl_nonsfre = lag2_npl_mf+lag2_npl_cre+lag2_npl_farm;
lag2_npl_othnonre = lag2_npl_cni+lag2_npl_ag;
run;
proc sort data=stage2_2; by snlkey rollreg_rankdate rankdate; run;
*Lead residuals and lag npl;
proc expand data=stage2_2 out=stage2_3 method=none; by snlkey rollreg_rankdate; id rankdate;
convert res_sf_l = lead1_res_sf_l / transformout = (lead 1);
convert res_sf_l = lead2_res_sf_l / transformout = (lead 2);
convert res_sf_l = lead3_res_sf_l / transformout = (lead 3);
convert res_nonsfre_l = lead1_res_nonsfre_l / transformout = (lead 1);
convert res_nonsfre_l = lead2_res_nonsfre_l / transformout = (lead 2);
convert res_nonsfre_l = lead3_res_nonsfre_l / transformout = (lead 3);
convert res_cons_l = lead1_res_cons_l / transformout = (lead 1);
convert res_cons_l = lead2_res_cons_l / transformout = (lead 2);
convert res_cons_l = lead3_res_cons_l / transformout = (lead 3);
convert res_othnonre_l = lead1_res_othnonre_l / transformout = (lead 1);
convert res_othnonre_l = lead2_res_othnonre_l / transformout = (lead 2);
convert res_othnonre_l = lead3_res_othnonre_l / transformout = (lead 3);
run;

/*ADD MACROECONOMIC VARIABLES*/
proc sql;
create table macro1 as select year, quarter, ch_unemp_rate as ch_unemp
from box.unemployment_rate_2017;

create table macro2 as select a.*, b.qtch_csindex as ch_cs
from macro1 a left join box.case_shiller_2017 b
on a.year=b.year and a.quarter=b.quarter;

create table macro3 as select a.*, (b.cni_largeandmid_dom+b.cni_small_dom)/200 as tighten
from macro2 a left join box.frb_sloos_apr2017 b
on a.year=b.year and a.quarter=b.qtr;

create table gdp_1929_2018 as select a.*, b.year, b.qtr
from box.gdp_1929_2018 a left join box.rankdates b
on a.date=b.date;

create table macro4 as select a.*, b.chgdp_quarterly as ch_gdp
from macro3 a left join gdp_1929_2018 b
on a.year=b.year and a.quarter=b.qtr;

create table macro5 as select a.*, b.rankdate
from macro4 a left join box.rankdates b
on a.year=b.year and a.quarter=b.qtr;
quit;

*Lag macro variables and NPLs;
proc expand data=macro5 out=macro6 method=none; id rankdate;
convert ch_unemp = lag1_ch_unemp / transformout = (lag 1);
convert ch_unemp = lag2_ch_unemp / transformout = (lag 2);
convert ch_unemp = lag3_ch_unemp / transformout = (lag 3);
convert ch_unemp = lag4_ch_unemp / transformout = (lag 4);
convert ch_unemp = lag5_ch_unemp / transformout = (lag 5);
convert ch_unemp = lag6_ch_unemp / transformout = (lag 6);
convert ch_unemp = lag7_ch_unemp / transformout = (lag 7);
convert ch_unemp = lag8_ch_unemp / transformout = (lag 8);
convert ch_unemp = lag9_ch_unemp / transformout = (lag 9);
convert ch_unemp = lag10_ch_unemp / transformout = (lag 10);
convert ch_unemp = lag11_ch_unemp / transformout = (lag 11);
convert ch_gdp = lag1_ch_gdp / transformout = (lag 1);
convert ch_gdp = lag2_ch_gdp / transformout = (lag 2);
convert ch_gdp = lag3_ch_gdp / transformout = (lag 3);
convert ch_gdp = lag4_ch_gdp / transformout = (lag 4);
convert ch_gdp = lag5_ch_gdp / transformout = (lag 5);
convert ch_gdp = lag6_ch_gdp / transformout = (lag 6);
convert ch_gdp = lag7_ch_gdp / transformout = (lag 7);
convert ch_gdp = lag8_ch_gdp / transformout = (lag 8);
convert ch_gdp = lag9_ch_gdp / transformout = (lag 9);
convert ch_gdp = lag10_ch_gdp / transformout = (lag 10);
convert ch_gdp = lag11_ch_gdp / transformout = (lag 11);
convert ch_cs = lag1_ch_cs / transformout = (lag 1);
convert ch_cs = lag2_ch_cs / transformout = (lag 2);
convert ch_cs = lag3_ch_cs / transformout = (lag 3);
convert ch_cs = lag4_ch_cs / transformout = (lag 4);
convert ch_cs = lag5_ch_cs / transformout = (lag 5);
convert ch_cs = lag6_ch_cs / transformout = (lag 6);
convert ch_cs = lag7_ch_cs / transformout = (lag 7);
convert ch_cs = lag8_ch_cs / transformout = (lag 8);
convert ch_cs = lag9_ch_cs / transformout = (lag 9);
convert ch_cs = lag10_ch_cs / transformout = (lag 10);
convert ch_cs = lag11_ch_cs / transformout = (lag 11);
convert ch_cs = lag12_ch_cs / transformout = (lag 12);
convert ch_cs = lag13_ch_cs / transformout = (lag 13);
convert ch_cs = lag14_ch_cs / transformout = (lag 14);
convert ch_cs = lag15_ch_cs / transformout = (lag 15);
convert tighten = lag1_tighten / transformout = (lag 1);
convert tighten = lag2_tighten / transformout = (lag 2);
convert tighten = lag3_tighten / transformout = (lag 3);
convert tighten = lag4_tighten / transformout = (lag 4);
convert tighten = lag5_tighten / transformout = (lag 5);
convert tighten = lag6_tighten / transformout = (lag 6);
convert tighten = lag7_tighten / transformout = (lag 7);
convert tighten = lag8_tighten / transformout = (lag 8);
convert tighten = lag9_tighten / transformout = (lag 9);
convert tighten = lag10_tighten / transformout = (lag 10);
convert tighten = lag11_tighten / transformout = (lag 11);
convert tighten = lag12_tighten / transformout = (lag 12);
convert tighten = lag13_tighten / transformout = (lag 13);
convert tighten = lag14_tighten / transformout = (lag 14);
convert tighten = lag15_tighten / transformout = (lag 15);
run;

*Merge macro data;
proc sql;
create table stage2_4 as select a.*, b.*
from stage2_3 a left join macro6 b
on a.rankdate=b.rankdate;
quit;

*Summarize lagged macroeconomic data;
data stage2_5; set stage2_4;
ch_unemp_1y = (lag1_ch_unemp+lag2_ch_unemp+lag3_ch_unemp+lag4_ch_unemp);
ch_unemp_2y = (lag5_ch_unemp+lag6_ch_unemp+lag7_ch_unemp+lag8_ch_unemp);
ch_gdp_1y = (lag1_ch_gdp+lag2_ch_gdp+lag3_ch_gdp+lag4_ch_gdp);
ch_gdp_2y = (lag5_ch_gdp+lag6_ch_gdp+lag7_ch_gdp+lag8_ch_gdp);
ch_cs_1y = (lag1_ch_cs+lag2_ch_cs+lag3_ch_cs+lag4_ch_cs);
ch_cs_2y = (lag5_ch_cs+lag6_ch_cs+lag7_ch_cs+lag8_ch_cs);
ch_cs_3y = (lag9_ch_cs+lag10_ch_cs+lag11_ch_cs+lag12_ch_cs);
avg_tighten_1y = (lag1_tighten+lag2_tighten+lag3_tighten+lag4_tighten)/4;
avg_tighten_2y = (lag5_tighten+lag6_tighten+lag7_tighten+lag8_tighten)/4;
avg_tighten_3y = (lag9_tighten+lag10_tighten+lag11_tighten+lag12_tighten)/4;
ch_npl_sf_1q = (npl_sf_total-lag1_npl_sf_total)/lag1_sf_htm;
ch_npl_sf_2q = (lag1_npl_sf_total-lag2_npl_sf_total)/lag2_sf_htm;
ch_npl_nonsfre_1q = (npl_nonsfre-lag1_npl_nonsfre)/lag1_nonsfre;
ch_npl_nonsfre_2q = (lag1_npl_nonsfre-lag2_npl_nonsfre)/lag2_nonsfre;
ch_npl_cons_1q = (npl_cons-lag1_npl_cons)/lag1_consloans;
ch_npl_cons_2q = (lag1_npl_cons-lag2_npl_cons)/lag2_consloans;
ch_npl_othnonre_1q = (npl_othnonre-lag1_npl_othnonre)/lag1_othnonre;
ch_npl_othnonre_2q = (lag1_npl_othnonre-lag2_npl_othnonre)/lag2_othnonre;
run;
proc sort data=stage2_5; by snlkey rollreg_rankdate rankdate; run; 

/*ASSIGN TO GROUPS BASED ON SIZE AND GEOGRAPHY*/
proc sql;
create table stage2_6 as select a.*, b.ta
from stage2_5 a left join box.all_ta_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table stage2_7 as select a.*, b.state, b.fdic_region
from stage2_6 a left join box.all_geographicdata b
on a.snlkey=b.snlkey;
quit;

data states (keep=state); set box.all_geographicdata; if state='' then delete; run;
proc sort data=states nodupkey; by state; run;
data states; set states; state_no=_n_+4; run;
data stage2_8; set stage2_7;
if ta >= 200000000 then type=1;
if 200000000 > ta >= 10000000 then type=2;
if ta < 10000000 then type =3;
if fdic_region='Atlanta' then region_no=0;
if fdic_region='Chicago' then region_no=1;
if fdic_region='Dallas' then region_no=2;
if fdic_region='Kansas City' then region_no=3;
if fdic_region='New York' then region_no=4;
if fdic_region='San Francisco' then region_no=5;
run;
proc sql;
create table stage2_9 as select a.*, b.state_no
from stage2_8 a left join states b
on a.state=b.state order by snlkey, rankdate;
run;
data stage2_10; set stage2_9;
if type=1 then group=type;
if type=2 then group=type+region_no;
if type=3 then group=type+state_no;
run;

proc sort data=stage2_10; by snlkey rollreg_rankdate rankdate; run; 

/*CALCULATE MACROECONOMIC ADJUSTMENT FACTORS*/
*Single-family loans;
proc sort data=stage2_10; by group rollreg_rankdate; run;
ods graphics off; ods exclude all; ods listing close; ods output parameterestimates=ecl_parms_sf1;
proc reg data=stage2_10;
model res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf1 out=ecl_parameters_sf1 prefix=b_sf1_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_sf2;
proc reg data=stage2_10;
model lead1_res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf2 out=ecl_parameters_sf2 prefix=b_sf2_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_sf3;
proc reg data=stage2_10;
model lead2_res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf3 out=ecl_parameters_sf3 prefix=b_sf3_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_sf4;
proc reg data=stage2_10;
model lead3_res_sf_l = ch_unemp_1y ch_unemp_2y ch_cs_1y ch_cs_2y ch_npl_sf_1q ch_npl_sf_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_sf4 out=ecl_parameters_sf4 prefix=b_sf4_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

*Non-single-family real estate loans;
proc sort data=stage2_10; by group rollreg_rankdate; run;
ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre1;
proc reg data=stage2_10;
model res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre1 out=ecl_parameters_nonsfre1 prefix=b_nonsfre1_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre2;
proc reg data=stage2_10;
model lead1_res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre2 out=ecl_parameters_nonsfre2 prefix=b_nonsfre2_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre3;
proc reg data=stage2_10;
model lead2_res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre3 out=ecl_parameters_nonsfre3 prefix=b_nonsfre3_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_nonsfre4;
proc reg data=stage2_10;
model lead3_res_nonsfre_l = ch_cs_1y ch_cs_2y ch_gdp_1y ch_gdp_2y ch_npl_nonsfre_1q ch_npl_nonsfre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_nonsfre4 out=ecl_parameters_nonsfre4 prefix=b_nonsfre4_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

*Consumer loans;
proc sort data=stage2_10; by group rollreg_rankdate; run;
ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons1;
proc reg data=stage2_10;
model res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons1 out=ecl_parameters_cons1 prefix=b_cons1_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons2;
proc reg data=stage2_10;
model lead1_res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons2 out=ecl_parameters_cons2 prefix=b_cons2_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons3;
proc reg data=stage2_10;
model lead2_res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons3 out=ecl_parameters_cons3 prefix=b_cons3_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_cons4;
proc reg data=stage2_10;
model lead3_res_cons_l = ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_npl_cons_1q ch_npl_cons_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_cons4 out=ecl_parameters_cons4 prefix=b_cons4_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

*Other non-RE loans;
proc sort data=stage2_10; by group rollreg_rankdate; run;
ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre1;
proc reg data=stage2_10;
model res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre1 out=ecl_parameters_othnonre1 prefix=b_othnonre1_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre2;
proc reg data=stage2_10;
model lead1_res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre2 out=ecl_parameters_othnonre2 prefix=b_othnonre2_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre3;
proc reg data=stage2_10;
model lead2_res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre3 out=ecl_parameters_othnonre3 prefix=b_othnonre3_;
by group rollreg_rankdate;
id variable;
var estimate;
run;

ods graphics off;ods exclude all;ods listing close;ods output parameterestimates=ecl_parms_othnonre4;
proc reg data=stage2_10;
model lead3_res_othnonre_l = ch_gdp_1y ch_gdp_2y avg_tighten_1y avg_tighten_2y ch_npl_othnonre_1q ch_npl_othnonre_2q;
by group rollreg_rankdate;
run;
ods listing;ods exclude none;
proc transpose data=ecl_parms_othnonre4 out=ecl_parameters_othnonre4 prefix=b_othnonre4_;
by group rollreg_rankdate;
id variable;
var estimate;
run;


*Merge all coefficients into one file;
proc sql;
create table ecl_parameters as select a.*, b.*
from ecl_parameters_sf1 a left join ecl_parameters_sf2 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_sf3 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_sf4 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre1 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre2 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre3 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_nonsfre4 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons1 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons2 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons3 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_cons4 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre1 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre2 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre3 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;

create table ecl_parameters as select a.*, b.*
from ecl_parameters a left join ecl_parameters_othnonre4 b
on a.group=b.group and a.rollreg_rankdate=b.rollreg_rankdate;
quit;


/*MERGE WITH ECL ESTIMATES*/
*Create table with all ECL vintage forecasts by loan type;
proc sql;
create table ecl_all1 as select a.snlkey, a.rankdate, b.ecl_sfloans as ecl_sf_base, b.ecl_singlefam_t,ecl_singlefam_lag1,ecl_singlefam_lag2,ecl_singlefam_lag3,ecl_singlefam_lag4,
ecl_singlefam_lag5,ecl_singlefam_lag6,ecl_singlefam_lag7,ecl_singlefam_lag8,ecl_singlefam_lag9,ecl_singlefam_lag10,ecl_singlefam_lag11,ecl_singlefam_lag12,
ecl_singlefam_lag13,ecl_singlefam_lag14,ecl_singlefam_lag15,ecl_singlefam_lag16,ecl_singlefam_lag17,ecl_singlefam_lag18,ecl_singlefam_lag19,ecl_singlefam_lag20,
ecl_singlefam_lag21,ecl_singlefam_lag22,ecl_singlefam_lag23, param as param_sf, cum_loss as cum_loss_sf, wtd_lags as wtd_lags_sf, model as model_sf,
f1_ecl_sf, f2_ecl_sf, f3_ecl_sf, f4_ecl_sf, f5_ecl_sf, f6_ecl_sf, f7_ecl_sf, f8_ecl_sf, f9_ecl_sf, f10_ecl_sf, f11_ecl_sf, f12_ecl_sf, f13_ecl_sf, f14_ecl_sf, 
f15_ecl_sf, f16_ecl_sf, f17_ecl_sf, f18_ecl_sf, f19_ecl_sf, f20_ecl_sf, f21_ecl_sf, f22_ecl_sf, f23_ecl_sf, f24_ecl_sf
from box.cecl_step2_start a left join box.ecl_sf_maxrsq b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table ecl_all2 as select a.*, b.ecl_nonsfre as ecl_nonsfre_base, b.ecl_nonsfre_t,ecl_nonsfre_lag1,ecl_nonsfre_lag2,ecl_nonsfre_lag3,ecl_nonsfre_lag4,
ecl_nonsfre_lag5,ecl_nonsfre_lag6,ecl_nonsfre_lag7,ecl_nonsfre_lag8,ecl_nonsfre_lag9,ecl_nonsfre_lag10,ecl_nonsfre_lag11,ecl_nonsfre_lag12,
ecl_nonsfre_lag13,ecl_nonsfre_lag14,ecl_nonsfre_lag15,ecl_nonsfre_lag16,ecl_nonsfre_lag17,ecl_nonsfre_lag18,ecl_nonsfre_lag19,ecl_nonsfre_lag20,
ecl_nonsfre_lag21,ecl_nonsfre_lag22,ecl_nonsfre_lag23, param as param_nonsfre, cum_loss as cum_loss_nonsfre, wtd_lags as wtd_lags_nonsfre, model as model_nonsfre,
f1_ecl_nonsfre, f2_ecl_nonsfre, f3_ecl_nonsfre, f4_ecl_nonsfre, f5_ecl_nonsfre, f6_ecl_nonsfre, f7_ecl_nonsfre, f8_ecl_nonsfre, f9_ecl_nonsfre, f10_ecl_nonsfre, f11_ecl_nonsfre, f12_ecl_nonsfre, f13_ecl_nonsfre, f14_ecl_nonsfre, 
f15_ecl_nonsfre, f16_ecl_nonsfre, f17_ecl_nonsfre, f18_ecl_nonsfre, f19_ecl_nonsfre, f20_ecl_nonsfre, f21_ecl_nonsfre, f22_ecl_nonsfre, f23_ecl_nonsfre, f24_ecl_nonsfre
from ecl_all1 a left join box.ecl_nonsfre_maxrsq b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table ecl_all3 as select a.*, b.ecl_cons as ecl_cons_base, b.ecl_cons_t,ecl_cons_lag1,ecl_cons_lag2,ecl_cons_lag3,ecl_cons_lag4,
ecl_cons_lag5,ecl_cons_lag6,ecl_cons_lag7,ecl_cons_lag8,ecl_cons_lag9,ecl_cons_lag10,ecl_cons_lag11,ecl_cons_lag12,
ecl_cons_lag13,ecl_cons_lag14,ecl_cons_lag15,ecl_cons_lag16,ecl_cons_lag17,ecl_cons_lag18,ecl_cons_lag19,ecl_cons_lag20,
ecl_cons_lag21,ecl_cons_lag22,ecl_cons_lag23, param as param_cons, cum_loss as cum_loss_cons, wtd_lags as wtd_lags_cons, model as model_cons,
f1_ecl_cons, f2_ecl_cons, f3_ecl_cons, f4_ecl_cons, f5_ecl_cons, f6_ecl_cons, f7_ecl_cons, f8_ecl_cons, f9_ecl_cons, f10_ecl_cons, f11_ecl_cons, f12_ecl_cons, f13_ecl_cons, f14_ecl_cons, 
f15_ecl_cons, f16_ecl_cons, f17_ecl_cons, f18_ecl_cons, f19_ecl_cons, f20_ecl_cons, f21_ecl_cons, f22_ecl_cons, f23_ecl_cons, f24_ecl_cons
from ecl_all2 a left join box.ecl_cons_maxrsq b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

create table ecl_all4 as select a.*, b.ecl_othnonre as ecl_othnonre_base, b.ecl_othnonre_t,ecl_othnonre_lag1,ecl_othnonre_lag2,ecl_othnonre_lag3,ecl_othnonre_lag4,
ecl_othnonre_lag5,ecl_othnonre_lag6,ecl_othnonre_lag7,ecl_othnonre_lag8,ecl_othnonre_lag9,ecl_othnonre_lag10,ecl_othnonre_lag11,ecl_othnonre_lag12,
ecl_othnonre_lag13,ecl_othnonre_lag14,ecl_othnonre_lag15,ecl_othnonre_lag16,ecl_othnonre_lag17,ecl_othnonre_lag18,ecl_othnonre_lag19,ecl_othnonre_lag20,
ecl_othnonre_lag21,ecl_othnonre_lag22,ecl_othnonre_lag23, param as param_othnonre, cum_loss as cum_loss_othnonre, wtd_lags as wtd_lags_othnonre, model as model_othnonre,
f1_ecl_othnonre, f2_ecl_othnonre, f3_ecl_othnonre, f4_ecl_othnonre, f5_ecl_othnonre, f6_ecl_othnonre, f7_ecl_othnonre, f8_ecl_othnonre, f9_ecl_othnonre, f10_ecl_othnonre, f11_ecl_othnonre, f12_ecl_othnonre, f13_ecl_othnonre, f14_ecl_othnonre, 
f15_ecl_othnonre, f16_ecl_othnonre, f17_ecl_othnonre, f18_ecl_othnonre, f19_ecl_othnonre, f20_ecl_othnonre, f21_ecl_othnonre, f22_ecl_othnonre, f23_ecl_othnonre, f24_ecl_othnonre
from ecl_all3 a left join box.ecl_othnonre_maxrsq b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;

*Add Loans Data;
	proc sql;
	create table ecl_all5 as select a.*, b.loans
	from ecl_all4 a left join box.all_loans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.reloans
	from ecl_all5 a left join box.all_reloans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.sfloans
	from ecl_all5 a left join box.all_sfloans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.sfcndloans
	from ecl_all5 a left join box.all_sfcndloans_1990_2016 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.loans_hfs
	from ecl_all5 as a left join box.all_loans_hfs_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.mfloans
	from ecl_all5 as a left join box.all_mfloans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.creloans
	from ecl_all5 as a left join box.all_creloans_1990_2019 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.farmloans
	from ecl_all5 as a left join box.all_farmloans_1990_2019 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.consloans
	from ecl_all5 a left join box.all_consloans_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.cniloans
	from ecl_all5 as a left join box.all_cniloans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table ecl_all5 as select a.*, b.agloans
	from ecl_all5 as a left join box.all_agloans_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate order by a.snlkey, a.rankdate;
	quit;

	data ecl_all6; set ecl_all5;
	if sfcndloans=. then sfcndloans=0;
	if loans_hfs=. then loans_hfs=0;
	sf_total = sfloans+sfcndloans;
	sf_htm = sf_total-loans_hfs;
	nonsfre = mfloans+creloans+farmloans;
	othnonre = cniloans+agloans;
	sf_htm_loans = sf_htm/loans;
	nonsfre_loans = nonsfre/loans;
	consloans_loans = consloans/loans;
	othnonre_loans = othnonre/loans;
	run;

*Add group # from prior file;
proc sort data=stage2_10 nodupkey out=groups; by snlkey rollreg_rankdate; run;
proc sql;
create table ecl_all7 as select a.*, b.group
from ecl_all6 a left join groups b
on a.snlkey=b.snlkey and a.rankdate=b.rollreg_rankdate;
quit;


*Scale ECL vintage estimates by loans;
data ecl_all8; set ecl_all7;
f1_ecl_sf_l = (f1_ecl_sf)/sf_htm;
f2_ecl_sf_l = (f2_ecl_sf)/sf_htm;
f3_ecl_sf_l = (f3_ecl_sf)/sf_htm;
f4_ecl_sf_l = (f4_ecl_sf)/sf_htm;
f1_ecl_nonsfre_l = (f1_ecl_nonsfre)/nonsfre;
f2_ecl_nonsfre_l = (f2_ecl_nonsfre)/nonsfre;
f3_ecl_nonsfre_l = (f3_ecl_nonsfre)/nonsfre;
f4_ecl_nonsfre_l = (f4_ecl_nonsfre)/nonsfre;
f1_ecl_cons_l = (f1_ecl_cons)/consloans;
f2_ecl_cons_l = (f2_ecl_cons)/consloans;
f3_ecl_cons_l = (f3_ecl_cons)/consloans;
f4_ecl_cons_l = (f4_ecl_cons)/consloans;
f1_ecl_othnonre_l = (f1_ecl_othnonre)/othnonre;
f2_ecl_othnonre_l = (f2_ecl_othnonre)/othnonre;
f3_ecl_othnonre_l = (f3_ecl_othnonre)/othnonre;
f4_ecl_othnonre_l = (f4_ecl_othnonre)/othnonre;
run;

*Merge macro factor coefficients;
proc sql;
create table ecl_all9 as select a.*, b.*
from ecl_all8 a left join ecl_parameters b
on a.group=b.group and a.rankdate=b.rollreg_rankdate;
quit;

*Merge macro factors;
data macro_factors (keep=rankdate ch_unemp_1y ch_unemp_2y ch_gdp_1y ch_gdp_2y ch_cs_1y ch_cs_2y avg_tighten_1y avg_tighten_2y); set stage2_10; run;
proc sort data=macro_factors nodupkey; by rankdate; run;
proc sql;
create table ecl_all10 as select a.*, b.ch_npl_sf_1q, b.ch_npl_sf_2q, b.ch_npl_nonsfre_1q, b.ch_npl_nonsfre_2q, b.ch_npl_cons_1q, b.ch_npl_cons_2q, b.ch_npl_othnonre_1q, b.ch_npl_othnonre_2q
from ecl_all9 a left join stage2_5 b
on a.snlkey=b.snlkey and a.rankdate=b.rollreg_rankdate=b.rankdate;

create table ecl_all10 as select a.*, b.ch_unemp_1y, b.ch_unemp_2y, b.ch_gdp_1y, b.ch_gdp_2y, b.ch_cs_1y, b.ch_cs_2y, b.avg_tighten_1y, b.avg_tighten_2y
from ecl_all10 a left join macro_factors b
on a.rankdate=b.rankdate order by a.rankdate, a.snlkey;
quit;

*Adjust forecasted charge-off rates for year t+1;
data ecl_all11; set ecl_all10;
sf1_adj = (ch_npl_sf_1q*b_sf1_ch_npl_sf_1q + ch_npl_sf_2q*b_sf1_ch_npl_sf_2q + ch_unemp_1y*b_sf1_ch_unemp_1y + ch_unemp_2y*b_sf1_ch_unemp_2y + ch_cs_1y*b_sf1_ch_cs_1y + ch_cs_2y*b_sf1_ch_cs_2y);
sf2_adj = (ch_npl_sf_1q*b_sf2_ch_npl_sf_1q + ch_npl_sf_2q*b_sf2_ch_npl_sf_2q + ch_unemp_1y*b_sf2_ch_unemp_1y + ch_unemp_2y*b_sf2_ch_unemp_2y + ch_cs_1y*b_sf2_ch_cs_1y + ch_cs_2y*b_sf2_ch_cs_2y);
sf3_adj = (ch_npl_sf_1q*b_sf3_ch_npl_sf_1q + ch_npl_sf_2q*b_sf3_ch_npl_sf_2q + ch_unemp_1y*b_sf3_ch_unemp_1y + ch_unemp_2y*b_sf3_ch_unemp_2y + ch_cs_1y*b_sf3_ch_cs_1y + ch_cs_2y*b_sf3_ch_cs_2y);
sf4_adj = (ch_npl_sf_1q*b_sf4_ch_npl_sf_1q + ch_npl_sf_2q*b_sf4_ch_npl_sf_2q + ch_unemp_1y*b_sf4_ch_unemp_1y + ch_unemp_2y*b_sf4_ch_unemp_2y + ch_cs_1y*b_sf4_ch_cs_1y + ch_cs_2y*b_sf4_ch_cs_2y);
nonsfre1_adj = (ch_npl_nonsfre_1q*b_nonsfre1_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre1_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre1_ch_cs_1y + ch_cs_2y*b_nonsfre1_ch_cs_2y + ch_gdp_1y*b_nonsfre1_ch_gdp_1y + ch_gdp_2y*b_nonsfre1_ch_gdp_2y);
nonsfre2_adj = (ch_npl_nonsfre_1q*b_nonsfre2_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre2_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre2_ch_cs_1y + ch_cs_2y*b_nonsfre2_ch_cs_2y + ch_gdp_1y*b_nonsfre2_ch_gdp_1y + ch_gdp_2y*b_nonsfre2_ch_gdp_2y);
nonsfre3_adj = (ch_npl_nonsfre_1q*b_nonsfre3_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre3_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre3_ch_cs_1y + ch_cs_2y*b_nonsfre3_ch_cs_2y + ch_gdp_1y*b_nonsfre3_ch_gdp_1y + ch_gdp_2y*b_nonsfre3_ch_gdp_2y);
nonsfre4_adj = (ch_npl_nonsfre_1q*b_nonsfre4_ch_npl_nonsfre_1q + ch_npl_nonsfre_2q*b_nonsfre4_ch_npl_nonsfre_2q + ch_cs_1y*b_nonsfre4_ch_cs_1y + ch_cs_2y*b_nonsfre4_ch_cs_2y + ch_gdp_1y*b_nonsfre4_ch_gdp_1y + ch_gdp_2y*b_nonsfre4_ch_gdp_2y);
cons1_adj = (ch_npl_cons_1q*b_cons1_ch_npl_cons_1q + ch_npl_cons_2q*b_cons1_ch_npl_cons_2q + ch_unemp_1y*b_cons1_ch_unemp_1y + ch_unemp_2y*b_cons1_ch_unemp_2y + ch_gdp_1y*b_cons1_ch_gdp_1y + ch_gdp_2y*b_cons1_ch_gdp_2y);
cons2_adj = (ch_npl_cons_1q*b_cons2_ch_npl_cons_1q + ch_npl_cons_2q*b_cons2_ch_npl_cons_2q + ch_unemp_1y*b_cons2_ch_unemp_1y + ch_unemp_2y*b_cons2_ch_unemp_2y + ch_gdp_1y*b_cons2_ch_gdp_1y + ch_gdp_2y*b_cons2_ch_gdp_2y);
cons3_adj = (ch_npl_cons_1q*b_cons3_ch_npl_cons_1q + ch_npl_cons_2q*b_cons3_ch_npl_cons_2q + ch_unemp_1y*b_cons3_ch_unemp_1y + ch_unemp_2y*b_cons3_ch_unemp_2y + ch_gdp_1y*b_cons3_ch_gdp_1y + ch_gdp_2y*b_cons3_ch_gdp_2y);
cons4_adj = (ch_npl_cons_1q*b_cons4_ch_npl_cons_1q + ch_npl_cons_2q*b_cons4_ch_npl_cons_2q + ch_unemp_1y*b_cons4_ch_unemp_1y + ch_unemp_2y*b_cons4_ch_unemp_2y + ch_gdp_1y*b_cons4_ch_gdp_1y + ch_gdp_2y*b_cons4_ch_gdp_2y);
othnonre1_adj = (ch_npl_othnonre_1q*b_othnonre1_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre1_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre1_ch_gdp_1y + ch_gdp_2y*b_othnonre1_ch_gdp_2y + avg_tighten_1y*b_othnonre1_avg_tighten_1y + avg_tighten_2y*b_othnonre1_avg_tighten_2y);
othnonre2_adj = (ch_npl_othnonre_1q*b_othnonre2_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre2_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre2_ch_gdp_1y + ch_gdp_2y*b_othnonre2_ch_gdp_2y + avg_tighten_1y*b_othnonre2_avg_tighten_1y + avg_tighten_2y*b_othnonre2_avg_tighten_2y);
othnonre3_adj = (ch_npl_othnonre_1q*b_othnonre3_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre3_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre3_ch_gdp_1y + ch_gdp_2y*b_othnonre3_ch_gdp_2y + avg_tighten_1y*b_othnonre3_avg_tighten_1y + avg_tighten_2y*b_othnonre3_avg_tighten_2y);
othnonre4_adj = (ch_npl_othnonre_1q*b_othnonre4_ch_npl_othnonre_1q + ch_npl_othnonre_2q*b_othnonre4_ch_npl_othnonre_2q + ch_gdp_1y*b_othnonre4_ch_gdp_1y + ch_gdp_2y*b_othnonre4_ch_gdp_2y + avg_tighten_1y*b_othnonre4_avg_tighten_1y + avg_tighten_2y*b_othnonre4_avg_tighten_2y);


if f1_ecl_sf_l ne 0 then adj_f1_ecl_sf = f1_ecl_sf_l+sf1_adj; else adj_f1_ecl_sf=0;
if f2_ecl_sf_l ne 0 then adj_f2_ecl_sf = f2_ecl_sf_l+sf2_adj; else adj_f2_ecl_sf=0;
if f3_ecl_sf_l ne 0 then adj_f3_ecl_sf = f3_ecl_sf_l+sf3_adj; else adj_f3_ecl_sf=0;
if f4_ecl_sf_l ne 0 then adj_f4_ecl_sf = f4_ecl_sf_l+sf4_adj; else adj_f4_ecl_sf=0;
if f1_ecl_nonsfre_l ne 0 then adj_f1_ecl_nonsfre = f1_ecl_nonsfre_l+nonsfre1_adj; else adj_f1_ecl_nonsfre=0;
if f2_ecl_nonsfre_l ne 0 then adj_f2_ecl_nonsfre = f2_ecl_nonsfre_l+nonsfre2_adj; else adj_f2_ecl_nonsfre=0;
if f3_ecl_nonsfre_l ne 0 then adj_f3_ecl_nonsfre = f3_ecl_nonsfre_l+nonsfre3_adj; else adj_f3_ecl_nonsfre=0;
if f4_ecl_nonsfre_l ne 0 then adj_f4_ecl_nonsfre = f4_ecl_nonsfre_l+nonsfre4_adj; else adj_f4_ecl_nonsfre=0;
if f1_ecl_cons_l ne 0 then adj_f1_ecl_cons = f1_ecl_cons_l+cons1_adj; else adj_f1_ecl_cons=0;
if f2_ecl_cons_l ne 0 then adj_f2_ecl_cons = f2_ecl_cons_l+cons2_adj; else adj_f2_ecl_cons=0;
if f3_ecl_cons_l ne 0 then adj_f3_ecl_cons = f3_ecl_cons_l+cons3_adj; else adj_f3_ecl_cons=0;
if f4_ecl_cons_l ne 0 then adj_f4_ecl_cons = f4_ecl_cons_l+cons4_adj; else adj_f4_ecl_cons=0;
if f1_ecl_othnonre_l ne 0 then adj_f1_ecl_othnonre = f1_ecl_othnonre_l+othnonre1_adj; else adj_f1_ecl_othnonre=0;
if f2_ecl_othnonre_l ne 0 then adj_f2_ecl_othnonre = f2_ecl_othnonre_l+othnonre2_adj; else adj_f2_ecl_othnonre=0;
if f3_ecl_othnonre_l ne 0 then adj_f3_ecl_othnonre = f3_ecl_othnonre_l+othnonre3_adj; else adj_f3_ecl_othnonre=0;
if f4_ecl_othnonre_l ne 0 then adj_f4_ecl_othnonre = f4_ecl_othnonre_l+othnonre4_adj; else adj_f4_ecl_othnonre=0;

*Calculate ECL_Base and ECL adjusted for macroeconomic factors;
ecl_base = ecl_sf_base + ecl_nonsfre_base + ecl_cons_base + ecl_othnonre_base;
ecl_sf = ecl_sf_base - f1_ecl_sf - f2_ecl_sf - f3_ecl_sf - f4_ecl_sf + (adj_f1_ecl_sf*sf_htm)+(adj_f2_ecl_sf*sf_htm)+(adj_f3_ecl_sf*sf_htm)+(adj_f4_ecl_sf*sf_htm);
ecl_nonsfre = ecl_nonsfre_base - f1_ecl_nonsfre - f2_ecl_nonsfre - f3_ecl_nonsfre - f4_ecl_nonsfre + (adj_f1_ecl_nonsfre*nonsfre)+(adj_f2_ecl_nonsfre*nonsfre)+(adj_f3_ecl_nonsfre*nonsfre)+(adj_f4_ecl_nonsfre*nonsfre);
ecl_cons = ecl_cons_base - f1_ecl_cons - f2_ecl_cons - f3_ecl_cons - f4_ecl_cons + (adj_f1_ecl_cons*consloans)+(adj_f2_ecl_cons*consloans)+(adj_f3_ecl_cons*consloans)+(adj_f4_ecl_cons*consloans);
ecl_othnonre = ecl_othnonre_base - f1_ecl_othnonre - f2_ecl_othnonre - f3_ecl_othnonre - f4_ecl_othnonre + (adj_f1_ecl_othnonre*othnonre)+(adj_f2_ecl_othnonre*othnonre)+(adj_f3_ecl_othnonre*othnonre)+(adj_f4_ecl_othnonre*othnonre);
ecl = ecl_sf + ecl_nonsfre + ecl_cons + ecl_othnonre;

*Calculate effect of macroeconomic adjustments;
ecl_adj_sf = ecl_sf-ecl_sf_base;
ecl_adj_nonsfre = ecl_nonsfre-ecl_nonsfre_base;
ecl_adj_cons = ecl_cons-ecl_cons_base;
ecl_adj_othnonre = ecl_othnonre-ecl_othnonre_base;
ecl_adj_total = ecl - ecl_base;

*Calculate ECL projections by year;
ecl_t_base = ecl_singlefam_t + ecl_nonsfre_t + ecl_cons_t + ecl_othnonre_t;
ecl_sf_t_base = ecl_singlefam_t;
ecl_nonsfre_t_base = ecl_nonsfre_t;
ecl_cons_t_base = ecl_cons_t;
ecl_othnonre_t_base = ecl_othnonre_t;
ecl_lag1_base = ecl_singlefam_lag1 + ecl_nonsfre_lag1 + ecl_cons_lag1 + ecl_othnonre_lag1;
ecl_lag2_base = ecl_singlefam_lag2 + ecl_nonsfre_lag2 + ecl_cons_lag2 + ecl_othnonre_lag2;
ecl_lag3_base = ecl_singlefam_lag3 + ecl_nonsfre_lag3 + ecl_cons_lag3 + ecl_othnonre_lag3;
ecl_f1_base = f1_ecl_sf + f1_ecl_nonsfre + f1_ecl_cons + f1_ecl_othnonre;
ecl_year1_base = f1_ecl_sf + f2_ecl_sf + f3_ecl_sf + f4_ecl_sf + f1_ecl_nonsfre + f2_ecl_nonsfre + f3_ecl_nonsfre + f4_ecl_nonsfre + f1_ecl_cons + f2_ecl_cons + f3_ecl_cons + f4_ecl_cons + f1_ecl_othnonre + f2_ecl_othnonre + f3_ecl_othnonre + f4_ecl_othnonre;
ecl_year1_adj = ecl_year1_base + ecl_adj_total;
ecl_year2 = f5_ecl_sf + f6_ecl_sf + f7_ecl_sf + f8_ecl_sf + f5_ecl_nonsfre + f6_ecl_nonsfre + f7_ecl_nonsfre + f8_ecl_nonsfre + f5_ecl_cons + f6_ecl_cons + f7_ecl_cons + f8_ecl_cons + f5_ecl_othnonre + f6_ecl_othnonre + f7_ecl_othnonre + f8_ecl_othnonre;
ecl_year3 = f9_ecl_sf + f10_ecl_sf + f11_ecl_sf + f12_ecl_sf + f9_ecl_nonsfre + f10_ecl_nonsfre + f11_ecl_nonsfre + f12_ecl_nonsfre + f9_ecl_cons + f10_ecl_cons + f11_ecl_cons + f12_ecl_cons + f9_ecl_othnonre + f10_ecl_othnonre + f11_ecl_othnonre + f12_ecl_othnonre;
ecl_year4 = f13_ecl_sf + f14_ecl_sf + f15_ecl_sf + f16_ecl_sf + f13_ecl_nonsfre + f14_ecl_nonsfre + f15_ecl_nonsfre + f16_ecl_nonsfre + f13_ecl_cons + f14_ecl_cons + f15_ecl_cons + f16_ecl_cons + f13_ecl_othnonre + f14_ecl_othnonre + f15_ecl_othnonre + f16_ecl_othnonre;
ecl_year5 = f17_ecl_sf + f18_ecl_sf + f19_ecl_sf + f20_ecl_sf + f17_ecl_nonsfre + f18_ecl_nonsfre + f19_ecl_nonsfre + f20_ecl_nonsfre + f17_ecl_cons + f18_ecl_cons + f19_ecl_cons + f20_ecl_cons + f17_ecl_othnonre + f18_ecl_othnonre + f19_ecl_othnonre + f20_ecl_othnonre;
ecl_year6 = f21_ecl_sf + f22_ecl_sf + f23_ecl_sf + f24_ecl_sf + f21_ecl_nonsfre + f22_ecl_nonsfre + f23_ecl_nonsfre + f24_ecl_nonsfre + f21_ecl_cons + f22_ecl_cons + f23_ecl_cons + f24_ecl_cons + f21_ecl_othnonre + f22_ecl_othnonre + f23_ecl_othnonre + f24_ecl_othnonre;

avg_cum_loss = (cum_loss_sf*sf_htm_loans)+(cum_loss_nonsfre*nonsfre_loans)+(cum_loss_cons*consloans_loans)+(cum_loss_othnonre*othnonre_loans);
avg_wtd_lags = (wtd_lags_sf*sf_htm_loans)+(wtd_lags_nonsfre*nonsfre_loans)+(wtd_lags_cons*consloans_loans)+(wtd_lags_othnonre*othnonre_loans);
avg_lags = (model_sf*sf_htm_loans)+(model_nonsfre*nonsfre_loans)+(model_cons*consloans_loans)+(model_othnonre*othnonre_loans);
run;
data box.ecl_estimates; set ecl_all11; run;

proc sql;
create table box.cecl_step2_finish as select a.*, b.ecl, b.ecl_sf, b.ecl_nonsfre, b.ecl_cons, b.ecl_othnonre, b.ecl_base, b.ecl_sf_base, b.ecl_nonsfre_base, b.ecl_cons_base, b.ecl_othnonre_base,
b.ecl_adj_total, b.ecl_adj_sf, b.ecl_adj_nonsfre, b.ecl_adj_cons, b.ecl_adj_othnonre, b.ecl_year1_base, b.ecl_year1_adj, b.ecl_year2, b.ecl_year3, b.ecl_year4, b.ecl_year5, b.ecl_year6, b.ecl_f1_base,
b.param_sf, b.param_nonsfre, b.param_cons, b.param_othnonre, b.ecl_t_base, b.ecl_lag1_base, b.ecl_lag2_base, b.ecl_lag3_base, b.ecl_sf_t_base, b.ecl_nonsfre_t_base, b.ecl_cons_t_base, b.ecl_othnonre_t_base,
b.cum_loss_sf, b.cum_loss_nonsfre, b.cum_loss_cons, b.cum_loss_othnonre, b.wtd_lags_sf, b.wtd_lags_nonsfre, b.wtd_lags_cons, b.wtd_lags_othnonre, b.avg_cum_loss, b.avg_wtd_lags,
b.model_sf, b.model_nonsfre, b.model_cons, b.model_othnonre, b.avg_lags
from box.cecl_step2_start a left join ecl_all11 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
