/*========================================================================================================
                                                                          
        ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
        AUTHOR: P. Barrett Wheeler                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		The code below merges expected credit loss estimates with banks' financial, market, 
		and analyst following data.

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname nic 'C:\Users\pbwheele\Box Sync\Data Sets\NIC Data';
libname hmda 'C:\Users\pbwheele\Box Sync\Data Sets\HMDA';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';

/*Connect to WRDS server*/
%let wrds=wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS compress=yes;
signon username=_prompt_;

/*Create temporary folder 4 as 'bw1' and create a remote directory in my explorer*/
libname bw1 remote '/scratch/tulane/' server=wrds;
rsubmit; libname bw1 '/scratch/tulane/'; endrsubmit;
libname bw2 remote '/home/tulane/pbwheele/' server=wrds;
rsubmit; libname bw2 '/home/tulane/pbwheele/'; endrsubmit;

/*STEP 3: Merge ECL estimates with other financial and market data*/

	*Add CRSP data, calculate MVE and abnormal returns;
	*Create quarter end date - this will allow matching with CRSP;
	Proc Sort data=box.cecl_step2_start;
	By snlkey snlyear snlqtr;
	Run;
	Data alll6;
	Set box.cecl_step2_start;
	Format SNLYear 4.;
	Run;
	Data alll6 (Drop = QtrEnd_Old QtrDay SNLYearCharacter);
	Set alll6;
	SNLYearCharacter = PUT(SNLYear, $4.);
	Format SNLQtr $2.;
	SNLPeriod= SNLYearCharacter || SNLQtr;
	If SNLQtr='Q4' then QtrDay='1231';
	If SNLQtr='Q3' then QtrDay='0930';
	If SNLQtr='Q2' then QtrDay='0630';
	If SNLQtr='Q1' then QtrDay='0331';
	QtrEnd_Old =SNLYearCharacter||QtrDay;
	QtrEnd = Input(QtrEnd_Old,yymmdd8.);
	Format QtrEnd date9.;
	ID=_N_;
	Run;

	*Upload to WRDS to gather CRSP data;
	rsubmit;
	proc upload data=alll6;
	run;
	endrsubmit;

	*Add MVE at balance sheet date;
	*Step 1 - gather price for the balance sheet date from the monthly stock file (MSF);
	rsubmit;
	proc sql;
	create table alll7 as select a.*, b.permno, b.date as crsp_date, 
	CASE when b.prc<0 then abs(b.prc) else b.prc END as prc, b.shrout,
	CASE when b.prc<0 then (abs(b.prc)*b.shrout) else (b.prc*b.shrout) END as mv_permno
	from alll6 as a left join crsp.msf as b
	on a.permco=b.permco and (a.qtrend-5)<b.date<=a.qtrend
	order by snlkey, rankdate;
	quit;
	endrsubmit;
	*Step 2 - for firms with multiple issuances (i.e. multiple PERMNO), combine mv of each permno for total mve;
	rsubmit;
	proc sql;
	create table alll8 as select a.*, sum(a.mv_permno) as mve format 12.0
	from alll7 as a
	group by a.snlkey, a.permco, a.rankdate
	order by a.snlkey, a.rankdate;
	quit;
	endrsubmit;
	*Eliminate duplicate permco and mve observations created by firms with multiple common stock classes (i.e. multiple permno's);
	rsubmit;
	data alll9;
	set alll8;
	run;
	proc sort data=alll9 nodupkey;
	by permco rankdate;
	run;
	endrsubmit;

	*Link CRSP to Compustat;
	rsubmit;
	proc sql;
	create table alll10 as
	select a.*, b.gvkey, b.linkprim
	from alll9 as a, crsp.ccmxpf_linktable as b
	where a.permco=b.lpermco
	and substr(b.linktype,1,1)='L' and linkprim in ('P','C')
	and (intnx('month',intnx('year',a.crsp_date,0,'E'),6,'E') >= b.linkdt)
	and (b.linkenddt >= intnx('month',intnx('year',a.crsp_date,0,'E'),6,'E')
	or missing(b.linkenddt))
	order by a.crsp_date, a.permco, b.linkprim desc;
	quit;
	endrsubmit;

	*Obtain earnings announcement dates;
	rsubmit;
	proc sql;
	create table alll11a
	as select a.*, b.fyearq, b.fqtr, b.fyr, b.datadate as comp_date, b.rdq as adate 'Earnings Announcement Date'
	from alll10 as a, comp.fundq as b
	where a.gvkey=b.gvkey and a.qtrend=intnx('month',b.datadate,0,'end') 
	and (not missing(RDQ));

	create table alll11b as select a.*, b.rdq as adate_plus1
	from alll11a as a left join comp.fundq as b
	on a.gvkey=b.gvkey and intnx('month',a.qtrend,12,'end')=intnx('month',b.datadate,0,'end');

	create table alll11c as select a.*, b.rdq as adate_plus2
	from alll11b as a left join comp.fundq as b
	on a.gvkey=b.gvkey and intnx('month',a.qtrend,24,'end')=intnx('month',b.datadate,0,'end');

	create table alll11d as select a.*, b.rdq as adate_plus3
	from alll11c as a left join comp.fundq as b
	on a.gvkey=b.gvkey and intnx('month',a.qtrend,36,'end')=intnx('month',b.datadate,0,'end');

	create table alll11e as select a.*, b.rdq as adate_plus4
	from alll11d as a left join comp.fundq as b
	on a.gvkey=b.gvkey and intnx('month',a.qtrend,48,'end')=intnx('month',b.datadate,0,'end');

	create table alll11f as select a.*, b.rdq as adate_plus5
	from alll11e as a left join comp.fundq as b
	on a.gvkey=b.gvkey and intnx('month',a.qtrend,60,'end')=intnx('month',b.datadate,0,'end');

	quit;
	endrsubmit;

	*MERGE DATA FROM CRSP DSF (INDIVIDUAL STOCK RETURNS), DSI (INDEX RETURNS), AND FF DAILY FACTORS (DAILY FF FACTOR RETURNS);
	rsubmit;
	proc sql;
	create table returndata as select a.*, b.mktrf, b.smb, b.hml, b.rf, b.umd as mkt_mom
	from crsp.dsf as a left join ff.factors_daily as b
	on a.date=b.date order by a.date;
	quit;
	endrsubmit;

	*Calculate cumulative firm-specific excess returns and cumulative returns to FF factors;
	rsubmit;
	proc sql;
	create table alll12a as select distinct a.*, 
	exp(sum(log(1+b.ret)))-1 as ret_1year format 10.4, 
	exp(sum(log(1+(b.ret-b.rf))))-1 as excret_1year format 10.4,
	exp(sum(log(1+b.mktrf)))-1 as mktrf_1year format 10.4,
	exp(sum(log(1+b.smb)))-1 as smb_1year format 10.4,
	exp(sum(log(1+b.hml)))-1 as hml_1year format 10.4,
	exp(sum(log(1+b.mkt_mom)))-1 as mkt_mom_1year format 10.4

	from alll11f as a left join returndata2 as b
	on a.permno=b.permno and a.adate<=b.date<=(a.adate_plus1-3)
	group by a.snlkey, a.rankdate
	order by a.snlkey, a.rankdate;

	create table alll12b as select distinct a.*, 
	exp(sum(log(1+b.ret)))-1 as ret_2year format 10.4,

	exp(sum(log(1+(b.ret-b.rf))))-1 as excret_2year format 10.4,
	exp(sum(log(1+b.mktrf)))-1 as mktrf_2year format 10.4,
	exp(sum(log(1+b.smb)))-1 as smb_2year format 10.4,
	exp(sum(log(1+b.hml)))-1 as hml_2year format 10.4,
	exp(sum(log(1+b.mkt_mom)))-1 as mkt_mom_2year format 10.4

	from alll12a as a left join returndata2 as b
	on a.permno=b.permno and a.adate<=b.date<=(a.adate_plus2-3)
	group by a.snlkey, a.rankdate
	order by a.snlkey, a.rankdate;

	create table alll12c as select distinct a.*,
	exp(sum(log(1+b.ret)))-1 as ret_3year format 10.4,
	exp(sum(log(1+(b.ret-b.rf))))-1 as excret_3year format 10.4,
	exp(sum(log(1+b.mktrf)))-1 as mktrf_3year format 10.4,
	exp(sum(log(1+b.smb)))-1 as smb_3year format 10.4,
	exp(sum(log(1+b.hml)))-1 as hml_3year format 10.4,
	exp(sum(log(1+b.mkt_mom)))-1 as mkt_mom_3year format 10.4

	from alll12b as a left join returndata2 as b
	on a.permno=b.permno and a.adate<=b.date<=(a.adate_plus3-3)
	group by a.snlkey, a.rankdate
	order by a.snlkey, a.rankdate;

	create table alll12d as select distinct a.*,
	exp(sum(log(1+b.ret)))-1 as ret_4year format 10.4,
	exp(sum(log(1+(b.ret-b.rf))))-1 as excret_4year format 10.4,
	exp(sum(log(1+b.mktrf)))-1 as mktrf_4year format 10.4,
	exp(sum(log(1+b.smb)))-1 as smb_4year format 10.4,
	exp(sum(log(1+b.hml)))-1 as hml_4year format 10.4,
	exp(sum(log(1+b.mkt_mom)))-1 as mkt_mom_4year format 10.4

	from alll12c as a left join returndata2 as b
	on a.permno=b.permno and a.adate<=b.date<=(a.adate_plus4-3)
	group by a.snlkey, a.rankdate
	order by a.snlkey, a.rankdate;

	create table alll12e as select distinct a.*,
	exp(sum(log(1+b.ret)))-1 as ret_5year format 10.4,
	exp(sum(log(1+(b.ret-b.rf))))-1 as excret_5year format 10.4,
	exp(sum(log(1+b.mktrf)))-1 as mktrf_5year format 10.4,
	exp(sum(log(1+b.smb)))-1 as smb_5year format 10.4,
	exp(sum(log(1+b.hml)))-1 as hml_5year format 10.4,
	exp(sum(log(1+b.mkt_mom)))-1 as mkt_mom_5year format 10.4

	from alll12d as a left join returndata as b
	on a.permno=b.permno and a.adate<=b.date<=(a.adate_plus5-3)
	group by a.snlkey, a.rankdate
	order by a.snlkey, a.rankdate;

	quit;

	data alll12f;
	set alll12e;
	excret_year2 = excret_2year-excret_1year;
	excret_year3 = excret_3year-excret_2year;
	excret_year4 = excret_4year-excret_3year;
	excret_year5 = excret_5year-excret_4year;
	mktrf_year2 = mktrf_2year-mktrf_1year;
	mktrf_year3 = mktrf_3year-mktrf_2year;
	mktrf_year4 = mktrf_4year-mktrf_3year;
	mktrf_year5 = mktrf_5year-mktrf_4year;
	smb_year2 = smb_2year-smb_1year;
	smb_year3 = smb_3year-smb_2year;
	smb_year4 = smb_4year-smb_3year;
	smb_year5 = smb_5year-smb_4year;
	hml_year2 = hml_2year-hml_1year;
	hml_year3 = hml_3year-hml_2year;
	hml_year4 = hml_4year-hml_3year;
	hml_year5 = hml_5year-hml_4year;
	mkt_mom_year2 = mkt_mom_2year-mkt_mom_1year;
	mkt_mom_year3 = mkt_mom_3year-mkt_mom_2year;
	mkt_mom_year4 = mkt_mom_4year-mkt_mom_3year;
	mkt_mom_year5 = mkt_mom_5year-mkt_mom_4year;
	run;
	endrsubmit;

	/*ANALYST FORECAST DATA FROM I/B/E/S*/
	*Match unadjusted estimates to unadjusted actuals;
	rsubmit;
	proc sql;
	create table ibes1 as select a.*, log(a.numest) as ln_numest, b.pends, b.anndats, b.value as actual_eps
	from ibes.statsumu_epsus as a left join ibes.actu_epsus as b
	on a.ticker=b.ticker and a.fpedats=b.pends and a.fiscalp=b.pdicity
	order by a.ticker, a.statpers;

	create table ibes2 as select a.*, b.rankdate as fpe_rankdate
	from ibes1 a left join bw2.rankdates b
	on a.fpedats=b.date order by a.ticker, a.statpers;
	quit;
	endrsubmit;
		
		rsubmit;
		data ibes_anndats (keep=ticker fpi fpedats anndats fpe_rankdate); set ibes2;
		if fpi ne 1 then delete;
		if anndats=. then delete;
		run;
		endrsubmit;
		rsubmit;
		proc sort data=ibes_anndats nodupkey; by ticker fpe_rankdate; run;
		endrsubmit;

	rsubmit;
	proc sql;
	create table ibes3 as select distinct a.*, b.anndats as py_anndats
	from ibes2 a left join ibes_anndats b
	on a.ticker=b.ticker and b.fpe_rankdate+4>=a.fpe_rankdate>b.fpe_rankdate;
	quit;
	endrsubmit;

	*Retain first current-year forecast made after prior earnings announcement date;
	rsubmit;
	data ibes4;
	set ibes3;
	if fpi ne 1 then delete;
	days_since_py=statpers-py_anndats;
	if days_since_py < 0 then delete;
	run;
	proc sql;
	create table ibes5 as select *, min(days_since_py) as min_days_since_py
	from ibes4 group by ticker, fpedats order by ticker, fpedats;
	quit;
	data ibes6; set ibes5;
	if days_since_py ne min_days_since_py then delete;
	fcst_error=medest-actual_eps;
	fcst_error_pct=abs(fcst_error)/abs(actual_eps);
	run;
	endrsubmit;

	*Merge CRSP identifier; *separately run ICLINK macro obtained from WRDS;
	rsubmit; %ICLINK; 
	proc sql;
	create table ibes7 as select distinct a.*, b.permno, b.score
	from ibes6 as a left join iclink as b
	on a.ticker=b.ticker and (b.score<3)
	order by a.ticker, a.statpers;
	quit;
	*Delete observations with no permno;
	data ibes8; set ibes7; if permno = . then delete; run;
	endrsubmit;

	*Merge I/B/E/S data with main dataset;
	rsubmit;
	proc sql;
	create table alll12g as select a.*, b.numest, b.ln_numest, b.ticker as ticker_ibes, b.actual_eps, b.medest, b.fcst_error, b.fcst_error_pct
	from alll12f a left join ibes8 b
	on a.permno=b.permno and b.fpe_rankdate>=a.rankdate>b.fpe_rankdate-4 order by a.snlkey, a.rankdate;
	quit;
	endrsubmit;

	*Add price target data;
	*Lag EA date;
	rsubmit;
	proc sql;
	create table alll12g_1 as select a.*, b.adate as pq_adate
	from alll12g a left join alll12g b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;
	
	create table alll12g_2 as select a.*, b.statpers, b.medptg
	from alll12g_1 as a left join ibes.ptgsumu as b
	on a.ticker_ibes=b.ticker and a.pq_adate<=b.statpers<=a.adate;
	quit;
	endrsubmit;

	*Retain last price target prior to quarter end;
	rsubmit;
	data alll12g_3;
	set alll12g_2;
	days_to_ea = adate-statpers;
	run;
	proc sql;
	create table alll12g_4 as select *, max(days_to_ea) as max_days_to_ea
	from alll12g_3 group by snlkey, rankdate order by snlkey, rankdate;
	quit;
	data alll12g_5; set alll12g_4;
	if days_to_ea ne max_days_to_ea then delete;
	run;
	endrsubmit;

	*UBS and Keycorp have multiple IBES tickers.  Retain ticker with highest number of estimates;
	rsubmit;
	proc sort data=alll12g_5; by permno rankdate descending numest; run;
	endrsubmit;
	rsubmit;
	proc sort data=alll12g_5 nodupkey; by permno rankdate; run;
	endrsubmit;

	rsubmit;
	proc download cecl_step3_finish;
	set alll12g_5;
	run;
	endrsubmit;

	*STEP 2C: Merge files with ECL estimates;
	proc sql;
	create table alll6 as select a.*, b.*
	from box.cecl_step3_finish a left join box.cecl_step2_finish b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
	quit;
	data alll7 (drop=commandfarmloans recoveries co_consloans); set alll6; run;
	*ADD DATA SETS FOR SENSITIVITY ANALYSIS;
	*NOTE: IF YOU WISH TO RUN ONLY THE MAIN ANALYSIS, YOU DO NOT NEED TO RUN STEP 2F OR MERGE THE NEXT FOUR TABLES. YOU WILL, HOWEVER, NEED TO REMOVE VARIABLES, MARKED BELOW, USING THESE ESTIMATES;
	*Add estimates with 20 and 28 lags for sensitivity analysis;
	proc sql;
	create table alll7a as select a.*, b.ecl as ecl_20, b.ecl_sf as ecl_sf_20, b.ecl_nonsfre as ecl_nonsfre_20, b.ecl_cons as ecl_cons_20, b.ecl_othnonre as ecl_othnonre_20,
	b.ecl_base as ecl_base_20, b.ecl_sf_base as ecl_sf_base_20, b.ecl_nonsfre_base as ecl_nonsfre_base_20, b.ecl_cons_base as ecl_cons_base_20, b.ecl_othnonre_base as ecl_othnonre_base_20,
	b.ecl_adj_total as ecl_adj_total_20, b.ecl_adj_sf as ecl_adj_sf_20, b.ecl_adj_nonsfre as ecl_adj_nonsfre_20, b.ecl_adj_cons as ecl_adj_cons_20, b.ecl_adj_othnonre as ecl_adj_othnonre_20,
	b.ecl_year1_adj as ecl_year1_20, b.ecl_year1_base as ecl_year1_base_20, b.ecl_year2 as ecl_year2_20, b.ecl_year3 as ecl_year3_20, b.ecl_year4 as ecl_year4_20, b.ecl_year5 as ecl_year5_20,
	b.param_sf as param_sf_20, b.param_nonsfre as param_nonsfre_20, b.param_cons as param_cons_20, b.param_othnonre as param_othnonre_20, 
	b.cum_loss_sf as cum_loss_sf_20, b.cum_loss_nonsfre as cum_loss_nonsfre_20, b.cum_loss_cons as cum_loss_cons_20, b.cum_loss_othnonre as cum_loss_othnonre_20, 
	b.wtd_lags_sf as wtd_lags_sf_20, b.wtd_lags_nonsfre as wtd_lags_nonsfre_20, b.wtd_lags_cons as wtd_lags_cons_20, b.wtd_lags_othnonre as wtd_lags_othnonre_20,
	b.avg_cum_loss as avg_cum_loss_20, b.avg_wtd_lags as avg_wtd_lags_20,
	b.model_sf as model_sf_20, b.model_nonsfre as model_nonsfre_20, b.model_cons as model_cons_20, b.model_othnonre as model_othnonre_20, b.avg_lags as avg_lags_20
	from alll7 a left join box.cecl_step2_finish_20 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
	quit;
	proc sql;
	create table alll7b as select a.*, b.ecl as ecl_28, b.ecl_sf as ecl_sf_28, b.ecl_nonsfre as ecl_nonsfre_28, b.ecl_cons as ecl_cons_28, b.ecl_othnonre as ecl_othnonre_28,
	b.ecl_base as ecl_base_28, b.ecl_sf_base as ecl_sf_base_28, b.ecl_nonsfre_base as ecl_nonsfre_base_28, b.ecl_cons_base as ecl_cons_base_28, b.ecl_othnonre_base as ecl_othnonre_base_28,
	b.ecl_adj_total as ecl_adj_total_28, b.ecl_adj_sf as ecl_adj_sf_28, b.ecl_adj_nonsfre as ecl_adj_nonsfre_28, b.ecl_adj_cons as ecl_adj_cons_28, b.ecl_adj_othnonre as ecl_adj_othnonre_28,
	b.ecl_year1_adj as ecl_year1_28, b.ecl_year1_base as ecl_year1_base_28, b.ecl_year2 as ecl_year2_28, b.ecl_year3 as ecl_year3_28, b.ecl_year4 as ecl_year4_28, b.ecl_year5 as ecl_year5_28, b.ecl_year6 as ecl_year6_28, b.ecl_year7 as ecl_year7_28,
	b.param_sf as param_sf_28, b.param_nonsfre as param_nonsfre_28, b.param_cons as param_cons_28, b.param_othnonre as param_othnonre_28, 
	b.cum_loss_sf as cum_loss_sf_28, b.cum_loss_nonsfre as cum_loss_nonsfre_28, b.cum_loss_cons as cum_loss_cons_28, b.cum_loss_othnonre as cum_loss_othnonre_28, 
	b.wtd_lags_sf as wtd_lags_sf_28, b.wtd_lags_nonsfre as wtd_lags_nonsfre_28, b.wtd_lags_cons as wtd_lags_cons_28, b.wtd_lags_othnonre as wtd_lags_othnonre_28,
	b.avg_cum_loss as avg_cum_loss_28, b.avg_wtd_lags as avg_wtd_lags_28,
	b.model_sf as model_sf_28, b.model_nonsfre as model_nonsfre_28, b.model_cons as model_cons_28, b.model_othnonre as model_othnonre_28, b.avg_lags as avg_lags_28
	from alll7a a left join box.cecl_step2_finish_28 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
	quit;
	*Add estimates adjusted for macroeconomic factors two and three years out for sensitivity analysis;
	proc sql;
	create table alll7c as select a.*, b.ecl as ecl_2ymacro, b.ecl_sf as ecl_sf_2ymacro, b.ecl_nonsfre as ecl_nonsfre_2ymacro, b.ecl_cons as ecl_cons_2ymacro, b.ecl_othnonre as ecl_othnonre_2ymacro,
	b.ecl_adj_total as ecl_adj_total_2ymacro, b.ecl_adj_sf as ecl_adj_sf_2ymacro, b.ecl_adj_nonsfre as ecl_adj_nonsfre_2ymacro, b.ecl_adj_cons as ecl_adj_cons_2ymacro, b.ecl_adj_othnonre as ecl_adj_othnonre_2ymacro
	from alll7b a left join box.cecl_step2_finish_2ymac b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll7d as select a.*, b.ecl as ecl_3ymacro, b.ecl_sf as ecl_sf_3ymacro, b.ecl_nonsfre as ecl_nonsfre_3ymacro, b.ecl_cons as ecl_cons_3ymacro, b.ecl_othnonre as ecl_othnonre_3ymacro,
	b.ecl_adj_total as ecl_adj_total_3ymacro, b.ecl_adj_sf as ecl_adj_sf_3ymacro, b.ecl_adj_nonsfre as ecl_adj_nonsfre_3ymacro, b.ecl_adj_cons as ecl_adj_cons_3ymacro, b.ecl_adj_othnonre as ecl_adj_othnonre_3ymacro
	from alll7c a left join box.cecl_step2_finish_3ymac b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
	quit;

*Add SNL variables for main tests and other supplemental analysis;
	proc sql;
	create table nco_npl as select a.*, a.npl, a.npl-b.npl as ch_npl
	from box.all_npl_bytype a left join box.all_npl_bytype b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

	create table nco_npl as select a.*, b.co, b.co_sf+b.co_sfcnd as co_sftotal, b.co_mf+b.co_cre+b.co_farm as co_nonsfre, b.co_cons, b.co_cni+b.co_ag as co_othnonre,
	b.nco, b.nco_sftotal, b.nco_mf+b.nco_cre+b.nco_farm as nco_nonsfre, b.nco_cons, b.nco_cni+b.nco_ag as nco_othnonre
	from nco_npl a left join box.all_co_bytype_1990_2018 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
	quit;

	proc sql;
	create table alll8a as select a.*, b.alll
	from alll7d as a left join box.all_alll_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll8b as select a.*, b.bve
	from alll8a as a left join box.all_bve_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll8c as select a.*, b.bve as bve_lag1 'BVE t-1'
	from alll8b as a left join box.all_bve_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

	create table alll8d as select a.*, b.rsa
	from alll8c as a left join box.all_rsa_1990_2017 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll8d_1 as select a.*, b.avgint
	from alll8d as a left join alll6 as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll8e as select a.*, b.nco as nco_plus1, b.ch_npl as ch_npl_plus1, b.nco_sftotal as nco_sf_plus1, b.nco_nonsfre as nco_nonsfre_plus1, b.nco_cons as nco_cons_plus1, b.nco_othnonre as nco_othnonre_plus1
	from alll8d as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-1;

	create table alll8f as select a.*, b.nco as nco_plus2, b.ch_npl as ch_npl_plus2, b.nco_sftotal as nco_sf_plus2, b.nco_nonsfre as nco_nonsfre_plus2, b.nco_cons as nco_cons_plus2, b.nco_othnonre as nco_othnonre_plus2
	from alll8e as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-2;

	create table alll8g as select a.*, b.nco as nco_plus3, b.ch_npl as ch_npl_plus3, b.nco_sftotal as nco_sf_plus3, b.nco_nonsfre as nco_nonsfre_plus3, b.nco_cons as nco_cons_plus3, b.nco_othnonre as nco_othnonre_plus3
	from alll8f as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-3;

	create table alll8h as select a.*, b.nco as nco_plus4, b.ch_npl as ch_npl_plus4, b.nco_sftotal as nco_sf_plus4, b.nco_nonsfre as nco_nonsfre_plus4, b.nco_cons as nco_cons_plus4, b.nco_othnonre as nco_othnonre_plus4
	from alll8g as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-4;

	create table alll8i as select a.*, b.nco as nco_plus5, b.ch_npl as ch_npl_plus5, b.nco_sftotal as nco_sf_plus5, b.nco_nonsfre as nco_nonsfre_plus5, b.nco_cons as nco_cons_plus5, b.nco_othnonre as nco_othnonre_plus5
	from alll8h as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-5;

	create table alll8j as select a.*, b.nco as nco_plus6, b.ch_npl as ch_npl_plus6, b.nco_sftotal as nco_sf_plus6, b.nco_nonsfre as nco_nonsfre_plus6, b.nco_cons as nco_cons_plus6, b.nco_othnonre as nco_othnonre_plus6
	from alll8i as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-6;

	create table alll8k as select a.*, b.nco as nco_plus7, b.ch_npl as ch_npl_plus7, b.nco_sftotal as nco_sf_plus7, b.nco_nonsfre as nco_nonsfre_plus7, b.nco_cons as nco_cons_plus7, b.nco_othnonre as nco_othnonre_plus7
	from alll8j as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-7;

	create table alll8l as select a.*, b.nco as nco_plus8, b.ch_npl as ch_npl_plus8, b.nco_sftotal as nco_sf_plus8, b.nco_nonsfre as nco_nonsfre_plus8, b.nco_cons as nco_cons_plus8, b.nco_othnonre as nco_othnonre_plus8
	from alll8k as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-8;

	create table alll8m as select a.*, b.nco as nco_plus9, b.ch_npl as ch_npl_plus9, b.nco_sftotal as nco_sf_plus9, b.nco_nonsfre as nco_nonsfre_plus9, b.nco_cons as nco_cons_plus9, b.nco_othnonre as nco_othnonre_plus9
	from alll8l as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-9;

	create table alll8n as select a.*, b.nco as nco_plus10, b.ch_npl as ch_npl_plus10, b.nco_sftotal as nco_sf_plus10, b.nco_nonsfre as nco_nonsfre_plus10, b.nco_cons as nco_cons_plus10, b.nco_othnonre as nco_othnonre_plus10
	from alll8m as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-10;

	create table alll8o as select a.*, b.nco as nco_plus11, b.ch_npl as ch_npl_plus11, b.nco_sftotal as nco_sf_plus11, b.nco_nonsfre as nco_nonsfre_plus11, b.nco_cons as nco_cons_plus11, b.nco_othnonre as nco_othnonre_plus11
	from alll8n as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-11;

	create table alll8p as select a.*, b.nco as nco_plus12, b.ch_npl as ch_npl_plus12, b.nco_sftotal as nco_sf_plus12, b.nco_nonsfre as nco_nonsfre_plus12, b.nco_cons as nco_cons_plus12, b.nco_othnonre as nco_othnonre_plus12
	from alll8o as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-12;

	create table alll8q as select a.*, b.nco as nco_plus13, b.ch_npl as ch_npl_plus13, b.nco_sftotal as nco_sf_plus13, b.nco_nonsfre as nco_nonsfre_plus13, b.nco_cons as nco_cons_plus13, b.nco_othnonre as nco_othnonre_plus13
	from alll8p as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-13;

	create table alll8r as select a.*, b.nco as nco_plus14, b.ch_npl as ch_npl_plus14, b.nco_sftotal as nco_sf_plus14, b.nco_nonsfre as nco_nonsfre_plus14, b.nco_cons as nco_cons_plus14, b.nco_othnonre as nco_othnonre_plus14
	from alll8q as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-14;

	create table alll8s as select a.*, b.nco as nco_plus15, b.ch_npl as ch_npl_plus15, b.nco_sftotal as nco_sf_plus15, b.nco_nonsfre as nco_nonsfre_plus15, b.nco_cons as nco_cons_plus15, b.nco_othnonre as nco_othnonre_plus15
	from alll8r as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-15;

	create table alll8t as select a.*, b.nco as nco_plus16, b.ch_npl as ch_npl_plus16, b.nco_sftotal as nco_sf_plus16, b.nco_nonsfre as nco_nonsfre_plus16, b.nco_cons as nco_cons_plus16, b.nco_othnonre as nco_othnonre_plus16
	from alll8s as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-16;

	create table alll8u as select a.*, b.nco as nco_plus17, b.ch_npl as ch_npl_plus17, b.nco_sftotal as nco_sf_plus17, b.nco_nonsfre as nco_nonsfre_plus17, b.nco_cons as nco_cons_plus17, b.nco_othnonre as nco_othnonre_plus17
	from alll8t as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-17;

	create table alll8v as select a.*, b.nco as nco_plus18, b.ch_npl as ch_npl_plus18, b.nco_sftotal as nco_sf_plus18, b.nco_nonsfre as nco_nonsfre_plus18, b.nco_cons as nco_cons_plus18, b.nco_othnonre as nco_othnonre_plus18
	from alll8u as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-18;

	create table alll8w as select a.*, b.nco as nco_plus19, b.ch_npl as ch_npl_plus19, b.nco_sftotal as nco_sf_plus19, b.nco_nonsfre as nco_nonsfre_plus19, b.nco_cons as nco_cons_plus19, b.nco_othnonre as nco_othnonre_plus19
	from alll8v as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-19;

	create table alll8x as select a.*, b.nco as nco_plus20, b.ch_npl as ch_npl_plus20, b.nco_sftotal as nco_sf_plus20, b.nco_nonsfre as nco_nonsfre_plus20, b.nco_cons as nco_cons_plus20, b.nco_othnonre as nco_othnonre_plus20
	from alll8w as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-20
	order by snlkey, rankdate;

	create table alll8q as select a.*, b.nco as nco_plus21, b.ch_npl as ch_npl_plus21, b.nco_sftotal as nco_sf_plus21, b.nco_nonsfre as nco_nonsfre_plus21, b.nco_cons as nco_cons_plus21, b.nco_othnonre as nco_othnonre_plus21
	from alll8x as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-21;

	create table alll8r as select a.*, b.nco as nco_plus22, b.ch_npl as ch_npl_plus22, b.nco_sftotal as nco_sf_plus22, b.nco_nonsfre as nco_nonsfre_plus22, b.nco_cons as nco_cons_plus22, b.nco_othnonre as nco_othnonre_plus22
	from alll8q as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-22;

	create table alll8s as select a.*, b.nco as nco_plus23, b.ch_npl as ch_npl_plus23, b.nco_sftotal as nco_sf_plus23, b.nco_nonsfre as nco_nonsfre_plus23, b.nco_cons as nco_cons_plus23, b.nco_othnonre as nco_othnonre_plus23
	from alll8r as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-23;

	create table alll8t as select a.*, b.nco as nco_plus24, b.ch_npl as ch_npl_plus24, b.nco_sftotal as nco_sf_plus24, b.nco_nonsfre as nco_nonsfre_plus24, b.nco_cons as nco_cons_plus24, b.nco_othnonre as nco_othnonre_plus24
	from alll8s as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-24;

	create table alll8u as select a.*, b.nco as nco_plus25, b.ch_npl as ch_npl_plus25, b.nco_sftotal as nco_sf_plus25, b.nco_nonsfre as nco_nonsfre_plus25, b.nco_cons as nco_cons_plus25, b.nco_othnonre as nco_othnonre_plus25
	from alll8t as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-25;

	create table alll8v as select a.*, b.nco as nco_plus26, b.ch_npl as ch_npl_plus26, b.nco_sftotal as nco_sf_plus26, b.nco_nonsfre as nco_nonsfre_plus26, b.nco_cons as nco_cons_plus26, b.nco_othnonre as nco_othnonre_plus26
	from alll8u as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-26;

	create table alll8w as select a.*, b.nco as nco_plus27, b.ch_npl as ch_npl_plus27, b.nco_sftotal as nco_sf_plus27, b.nco_nonsfre as nco_nonsfre_plus27, b.nco_cons as nco_cons_plus27, b.nco_othnonre as nco_othnonre_plus27
	from alll8v as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-27;

	create table alll8x as select a.*, b.nco as nco_plus28, b.ch_npl as ch_npl_plus28, b.nco_sftotal as nco_sf_plus28, b.nco_nonsfre as nco_nonsfre_plus28, b.nco_cons as nco_cons_plus28, b.nco_othnonre as nco_othnonre_plus28
	from alll8w as a left join nco_npl as b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate-28 order by snlkey, rankdate;

	create table alll8y as select a.*, b.tce
	from alll8x a left join box.all_tce_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll8z as select a.*, b.llp
	from alll8y a left join box.all_llp_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

quit;
	data alll8aa;
	set alll8z;
	alll_nco = alll/avg4qtr_nco;
	nco_year1 = nco_plus1+nco_plus2+nco_plus3+nco_plus4;
	nco_year2 = nco_plus5+nco_plus6+nco_plus7+nco_plus8;
	cum_nco_2year = nco_year1+nco_year2;
	nco_year3 = nco_plus9+nco_plus10+nco_plus11+nco_plus12;
	cum_nco_3year = nco_year1+nco_year2+nco_year3;
	nco_year4 = nco_plus13+nco_plus14+nco_plus15+nco_plus16;
	cum_nco_4year = nco_year1+nco_year2+nco_year3+nco_year4;
	nco_year5 = nco_plus17+nco_plus18+nco_plus19+nco_plus20;
	cum_nco_5year = nco_year1+nco_year2+nco_year3+nco_year4+nco_year5;
	nco_year6 = nco_plus21+nco_plus22+nco_plus23+nco_plus24;
	cum_nco_6year = nco_year1+nco_year2+nco_year3+nco_year4+nco_year5+nco_year6;
	nco_year7 = nco_plus25+nco_plus26+nco_plus27+nco_plus28;
	cum_nco_7year = nco_year1+nco_year2+nco_year3+nco_year4+nco_year5+nco_year6+nco_year7;
	ch_npl_year1 = ch_npl_plus1+ch_npl_plus2+ch_npl_plus3+ch_npl_plus4;
	ch_npl_year2 = ch_npl_plus5+ch_npl_plus6+ch_npl_plus7+ch_npl_plus8;
	ch_npl_year3 = ch_npl_plus9+ch_npl_plus10+ch_npl_plus11+ch_npl_plus12;
	ch_npl_year4 = ch_npl_plus13+ch_npl_plus14+ch_npl_plus15+ch_npl_plus16;
	ch_npl_year5 = ch_npl_plus17+ch_npl_plus18+ch_npl_plus19+ch_npl_plus20;
	ch_npl_year6 = ch_npl_plus21+ch_npl_plus22+ch_npl_plus23+ch_npl_plus24;
	ch_npl_year7 = ch_npl_plus25+ch_npl_plus26+ch_npl_plus27+ch_npl_plus28;

	nco_sf_year1 = nco_sf_plus1+nco_sf_plus2+nco_sf_plus3+nco_sf_plus4;
	nco_sf_year2 = nco_sf_plus5+nco_sf_plus6+nco_sf_plus7+nco_sf_plus8;
	cum_nco_sf_2year = nco_sf_year1+nco_sf_year2;
	nco_sf_year3 = nco_sf_plus9+nco_sf_plus10+nco_sf_plus11+nco_sf_plus12;
	cum_nco_sf_3year = nco_sf_year1+nco_sf_year2+nco_sf_year3;
	nco_sf_year4 = nco_sf_plus13+nco_sf_plus14+nco_sf_plus15+nco_sf_plus16;
	cum_nco_sf_4year = nco_sf_year1+nco_sf_year2+nco_sf_year3+nco_sf_year4;
	nco_sf_year5 = nco_sf_plus17+nco_sf_plus18+nco_sf_plus19+nco_sf_plus20;
	cum_nco_sf_5year = nco_sf_year1+nco_sf_year2+nco_sf_year3+nco_sf_year4+nco_sf_year5;
	nco_sf_year6 = nco_sf_plus21+nco_sf_plus22+nco_sf_plus23+nco_sf_plus24;
	cum_nco_sf_6year = nco_sf_year1+nco_sf_year2+nco_sf_year3+nco_sf_year4+nco_sf_year5+nco_sf_year6;
	nco_sf_year7 = nco_sf_plus25+nco_sf_plus26+nco_sf_plus27+nco_sf_plus28;
	cum_nco_sf_7year = nco_sf_year1+nco_sf_year2+nco_sf_year3+nco_sf_year4+nco_sf_year5+nco_sf_year6+nco_sf_year7;

	nco_nonsfre_year1 = nco_nonsfre_plus1+nco_nonsfre_plus2+nco_nonsfre_plus3+nco_nonsfre_plus4;
	nco_nonsfre_year2 = nco_nonsfre_plus5+nco_nonsfre_plus6+nco_nonsfre_plus7+nco_nonsfre_plus8;
	cum_nco_nonsfre_2year = nco_nonsfre_year1+nco_nonsfre_year2;
	nco_nonsfre_year3 = nco_nonsfre_plus9+nco_nonsfre_plus10+nco_nonsfre_plus11+nco_nonsfre_plus12;
	cum_nco_nonsfre_3year = nco_nonsfre_year1+nco_nonsfre_year2+nco_nonsfre_year3;
	nco_nonsfre_year4 = nco_nonsfre_plus13+nco_nonsfre_plus14+nco_nonsfre_plus15+nco_nonsfre_plus16;
	cum_nco_nonsfre_4year = nco_nonsfre_year1+nco_nonsfre_year2+nco_nonsfre_year3+nco_nonsfre_year4;
	nco_nonsfre_year5 = nco_nonsfre_plus17+nco_nonsfre_plus18+nco_nonsfre_plus19+nco_nonsfre_plus20;
	cum_nco_nonsfre_5year = nco_nonsfre_year1+nco_nonsfre_year2+nco_nonsfre_year3+nco_nonsfre_year4+nco_nonsfre_year5;
	nco_nonsfre_year6 = nco_nonsfre_plus21+nco_nonsfre_plus22+nco_nonsfre_plus23+nco_nonsfre_plus24;
	cum_nco_nonsfre_6year = nco_nonsfre_year1+nco_nonsfre_year2+nco_nonsfre_year3+nco_nonsfre_year4+nco_nonsfre_year5+nco_nonsfre_year6;
	nco_nonsfre_year7 = nco_nonsfre_plus25+nco_nonsfre_plus26+nco_nonsfre_plus27+nco_nonsfre_plus28;
	cum_nco_nonsfre_7year = nco_nonsfre_year1+nco_nonsfre_year2+nco_nonsfre_year3+nco_nonsfre_year4+nco_nonsfre_year5+nco_nonsfre_year6+nco_nonsfre_year7;

	nco_cons_year1 = nco_cons_plus1+nco_cons_plus2+nco_cons_plus3+nco_cons_plus4;
	nco_cons_year2 = nco_cons_plus5+nco_cons_plus6+nco_cons_plus7+nco_cons_plus8;
	cum_nco_cons_2year = nco_cons_year1+nco_cons_year2;
	nco_cons_year3 = nco_cons_plus9+nco_cons_plus10+nco_cons_plus11+nco_cons_plus12;
	cum_nco_cons_3year = nco_cons_year1+nco_cons_year2+nco_cons_year3;
	nco_cons_year4 = nco_cons_plus13+nco_cons_plus14+nco_cons_plus15+nco_cons_plus16;
	cum_nco_cons_4year = nco_cons_year1+nco_cons_year2+nco_cons_year3+nco_cons_year4;
	nco_cons_year5 = nco_cons_plus17+nco_cons_plus18+nco_cons_plus19+nco_cons_plus20;
	cum_nco_cons_5year = nco_cons_year1+nco_cons_year2+nco_cons_year3+nco_cons_year4+nco_cons_year5;
	nco_cons_year6 = nco_cons_plus21+nco_cons_plus22+nco_cons_plus23+nco_cons_plus24;
	cum_nco_cons_6year = nco_cons_year1+nco_cons_year2+nco_cons_year3+nco_cons_year4+nco_cons_year5+nco_cons_year6;
	nco_cons_year7 = nco_cons_plus25+nco_cons_plus26+nco_cons_plus27+nco_cons_plus28;
	cum_nco_cons_7year = nco_cons_year1+nco_cons_year2+nco_cons_year3+nco_cons_year4+nco_cons_year5+nco_cons_year6+nco_cons_year7;

	nco_othnonre_year1 = nco_othnonre_plus1+nco_othnonre_plus2+nco_othnonre_plus3+nco_othnonre_plus4;
	nco_othnonre_year2 = nco_othnonre_plus5+nco_othnonre_plus6+nco_othnonre_plus7+nco_othnonre_plus8;
	cum_nco_othnonre_2year = nco_othnonre_year1+nco_othnonre_year2;
	nco_othnonre_year3 = nco_othnonre_plus9+nco_othnonre_plus10+nco_othnonre_plus11+nco_othnonre_plus12;
	cum_nco_othnonre_3year = nco_othnonre_year1+nco_othnonre_year2+nco_othnonre_year3;
	nco_othnonre_year4 = nco_othnonre_plus13+nco_othnonre_plus14+nco_othnonre_plus15+nco_othnonre_plus16;
	cum_nco_othnonre_4year = nco_othnonre_year1+nco_othnonre_year2+nco_othnonre_year3+nco_othnonre_year4;
	nco_othnonre_year5 = nco_othnonre_plus17+nco_othnonre_plus18+nco_othnonre_plus19+nco_othnonre_plus20;
	cum_nco_othnonre_5year = nco_othnonre_year1+nco_othnonre_year2+nco_othnonre_year3+nco_othnonre_year4+nco_othnonre_year5;
	nco_othnonre_year6 = nco_othnonre_plus21+nco_othnonre_plus22+nco_othnonre_plus23+nco_othnonre_plus24;
	cum_nco_othnonre_6year = nco_othnonre_year1+nco_othnonre_year2+nco_othnonre_year3+nco_othnonre_year4+nco_othnonre_year5+nco_othnonre_year6;
	nco_othnonre_year7 = nco_othnonre_plus25+nco_othnonre_plus26+nco_othnonre_plus27+nco_othnonre_plus28;
	cum_nco_othnonre_7year = nco_othnonre_year1+nco_othnonre_year2+nco_othnonre_year3+nco_othnonre_year4+nco_othnonre_year5+nco_othnonre_year6+nco_othnonre_year7;
	run;
	*Calculate "ecldiff" variable;
	*Remove observations with no expected loss estimate or expected loss estimates less than zero;
	*Clean data set of observations with no lagged loans or negative bve;
	*If impaired loans are blank, set equal to 0;
	data alll9;
	set alll8aa;
	if ecl_base=. then delete;
	if ecl=. and ecl_20=. and ecl_28=. then delete;
	if ecl<0 then delete;
	if bve<0 then delete;
	if bve_lag1<0 then delete;
	if lag1_loans=. then delete;
	if impaired_mod=. then impaired_mod=0;
	fas5=loans-impaired_mod;
	ecldiff_base = ecl_base-alll;
	ecldiff=ecl-alll;
	ecldiff_20=ecl_20-alll; /*Used for sensitivity analysis*/
	ecldiff_28=ecl_28-alll; /*Used for sensitivity analysis*/
	ecldiff_2ymacro=ecl_2ymacro-alll; /*Used for sensitivity analysis*/
	ecldiff_3ymacro=ecl_3ymacro-alll; /*Used for sensitivity analysis*/
	run;
	*Create test variables for:
	Predictive tests;
	data alll10;
	set alll9;
	ecl_loans = ecl/loans;
	ecl_20_loans = ecl_20/loans; /*Used for sensitivity analysis*/
	ecl_28_loans = ecl_28/loans; /*Used for sensitivity analysis*/
	ecl_base_loans = ecl_base/loans;

	ecl_t_base_loans = ecl_t_base/loans;
	ecl_lag1_base_loans = ecl_lag1_base/loans;
	ecl_lag2_base_loans = ecl_lag2_base/loans;
	ecl_lag3_base_loans = ecl_lag3_base/loans;
	ecl_year1_loans = ecl_year1_adj/loans;
	ecl_year1_base_loans = ecl_year1_base/loans;
	ecl_year1_20_loans = ecl_year1_20/loans; /*Used for sensitivity analysis*/
	ecl_year1_28_loans = ecl_year1_28/loans; /*Used for sensitivity analysis*/
	ecl_year2_loans = ecl_year2/loans;
	ecl_year3_loans = ecl_year3/loans;
	ecl_year4_loans = ecl_year4/loans;
	ecl_year5_loans = ecl_year5/loans;
	ecl_year6_loans = ecl_year6/loans;

	ecldiff_base_loans = ecldiff_base/loans;
	ecldiff_loans = ecldiff/loans;
	ecldiff_20_loans = ecldiff_20/loans; /*Used for sensitivity analysis*/
	ecldiff_28_loans = ecldiff_28/loans; /*Used for sensitivity analysis*/

	ecldiff_2ymacro_loans = ecldiff_2ymacro/loans; /*Used for sensitivity analysis*/
	ecldiff_3ymacro_loans = ecldiff_3ymacro/loans; /*Used for sensitivity analysis*/

	alll_loans = alll/loans;
	nco_year1_loans = nco_year1/loans;
	nco_year2_loans = nco_year2/loans;
	nco_year3_loans = nco_year3/loans;
	nco_year4_loans = nco_year4/loans;
	nco_year5_loans = nco_year5/loans;
	nco_year6_loans = nco_year6/loans;
	nco_year7_loans = nco_year7/loans;
	ch_npl_year1_loans = ch_npl_year1/loans;
	ch_npl_year2_loans = ch_npl_year2/loans;
	ch_npl_year3_loans = ch_npl_year3/loans;
	ch_npl_year4_loans = ch_npl_year4/loans;
	ch_npl_year5_loans = ch_npl_year5/loans;
	ch_npl_year6_loans = ch_npl_year6/loans;
	ch_npl_year7_loans = ch_npl_year7/loans;
	cum_nco_2year_loans = cum_nco_2year/loans;
	cum_nco_3year_loans = cum_nco_3year/loans;
	cum_nco_4year_loans = cum_nco_4year/loans;
	cum_nco_5year_loans = cum_nco_5year/loans;
	cum_nco_6year_loans = cum_nco_6year/loans;
	cum_nco_7year_loans = cum_nco_7year/loans;
	run;

	*
	1. Create scaled variables;
	data alll11;
	set alll10;
	impaired_loans = impaired_mod/loans;
	fas5_loans=fas5/loans;
	reloans_loans = reloans/loans;
	consloans_loans = consloans/loans;
	fas5xwtd_lags = fas5_loans*avg_wtd_lags;
	ln_ta = log(ta);
	win=1;

	*2. Create variables;
	alll_bve = alll/bve;
	ecl_bve = ecl/bve;
	ecl_20_bve = ecl_20/bve; /*Used for sensitivity analysis*/
	ecl_28_bve = ecl_28/bve; /*Used for sensitivity analysis*/
	ecldiff_base_bve = ecldiff_base/bve;
	ecldiff_bve = ecldiff/bve;
	ecldiff_20_bve = ecldiff_20/bve; /*Used for sensitivity analysis*/
	ecldiff_28_bve = ecldiff_28/bve; /*Used for sensitivity analysis*/
	reloans_bve = reloans/bve;
	consloans_bve = consloans/bve;
	rsa_bve = rsa/bve;
	avgint_bve = avgint/bve;

	*3. Create other scaled variables for descriptive statistics;
	npl_bve = npl/bve;
	npl_loans = npl/loans;
	ecl_loans = ecl/loans;
	alll_npl = alll/npl;
	alll_loans = alll/loans;
	ecldiff_alll = ecldiff/alll;
	ecldiff_20_alll = ecldiff_20/alll; /*Used for sensitivity analysis*/
	ecldiff_28_alll = ecldiff_28/alll; /*Used for sensitivity analysis*/
	ecldiff_tce = ecldiff/tce;
	ecldiff_20_tce = ecldiff_20/tce; /*Used for sensitivity analysis*/
	ecldiff_28_tce = ecldiff_28/tce; /*Used for sensitivity analysis*/
	annual_co_rate = (co*4)/lag1_loans;
	avgint_loans = avgint/loans;
	int_lagloans = int_loans/lag1_loans;
	llp_loans = llp/lag1_loans;
	ecldiff_ecl = ecldiff/ecl;
	nco_loans = nco/loans;
	run;

*~~Remove missing MVE and scale variables;
	data alll19;
	set alll11;
	if mve=. then delete;
	mve_bve = mve/bve;
	mve_share = mve/shrout;
	bve_share = bve/shrout;
	alll_share = alll/shrout;
	ecl_share = ecl/shrout;
	ecl_20_share = ecl_20/shrout; /*Used for sensitivity analysis*/
	ecl_28_share = ecl_28/shrout; /*Used for sensitivity analysis*/
	ecl_28_share = ecl_28/shrout; /*Used for sensitivity analysis*/
	ecldiff_share = ecldiff/shrout;
	ecldiff_base_share = ecldiff_base/shrout;
	ecldiff_20_share = ecldiff_20/shrout; /*Used for sensitivity analysis*/
	ecldiff_28_share = ecldiff_28/shrout; /*Used for sensitivity analysis*/
	ecldiff_share = ecldiff/shrout;
	ecldiff_loans = ecldiff/loans;
	ecldiff_alll = ecldiff/alll;
	ecldiff_tce = ecldiff/tce;
	ecldiff_ta = ecldiff/ta;
	ecldiff_2ymacro_share = ecldiff_2ymacro/shrout; /*Used for sensitivity analysis*/
	ecldiff_3ymacro_share = ecldiff_3ymacro/shrout; /*Used for sensitivity analysis*/
	avgint_share = avgint/shrout;
	reloans_share = reloans/shrout;
	consloans_share = consloans/shrout;
	rsa_share = rsa/shrout;
	nco_bve = nco / bve;
	npl_share = npl / shrout;
	nco_share = nco / shrout;
	ecldiff_20_ta = ecldiff_20/ta; /*Used for sensitivity analysis*/
	ecldiff_28_ta = ecldiff_28/ta; /*Used for sensitivity analysis*/
	
	ecldiff_macro_loans = ecl_adj_total / loans;
	ecldiff_macro_share = ecl_adj_total / shrout;
	ecldiff_2ymacroadj_share = ecl_adj_total_2ymacro / shrout; /*Used for sensitivity analysis*/
	ecldiff_3ymacroadj_share = ecl_adj_total_3ymacro / shrout; /*Used for sensitivity analysis*/
	ecldiff_macro_bve = ecl_adj_total / bve;
	ecldiff_macro_bve = (ecl-ecl_base) / bve;
	run;

	/*Place observations into deciles based on value of ecldiff*/
	proc sort data=alll19;
	by rankdate;
	run;
	proc rank data=alll19 out=alll20a groups=10;
	by rankdate;
	var ecldiff_loans;
	ranks ecldiff_rank;
	run;
		proc rank data=alll20a out=alll20b groups=10;
	by rankdate;
	var ecldiff_20_loans;
	ranks ecldiff_20_rank; /*Used for sensitivity analysis*/
	run;
	proc rank data=alll20b out=alll20c groups=10;
	by rankdate;
	var ecldiff_28_loans;
	ranks ecldiff_28_rank; /*Used for sensitivity analysis*/
	run;
	data alll21;
	set alll20c;
	eclrank = ecldiff_rank/9;
	eclrank_20 = ecldiff_20_rank/9; /*Used for sensitivity analysis*/
	eclrank_28 = ecldiff_28_rank/9; /*Used for sensitivity analysis*/
	run;

	/*Add data on loan maturities*/
	proc sql;
	create table alll22 as select a.*, b.loans_5plus, b.loans_5plus/a.loans as loans_5plus_loans, 
	b.loans_5to15, b.loans_5to15/a.loans as loans_5to15_loans, b.loans_15plus, b.loans_15plus/a.loans as loans_15plus_loans
	from alll21 a left join box.all_loans_5plus_1996_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
	quit;

	*Add additional control variables and data for various additional analyses;
	/*Import M&A Activity*/
	proc sql;
	create table alll23 as select a.*, b.target_regid
	from alll22 a left join box.mergers_20160802 b
	on a.rssd_id=b.buyer_regid and a.rankdate>=b.rankdate>=a.rankdate-8 order by snlkey, rankdate;
	quit;
	proc sql;
	create table alll24 as select *, count(target_regid) as acq_2year
	from alll23 group by snlkey, rankdate;
	quit;
	proc sort data=alll24 nodupkey out=alll25;
	by snlkey rankdate;
	run;
	data alll26;
	set alll25;
	if acq_2year>0 then acq=1; else acq=0;
	run;

	*Merge Harris, Khan, and Nissim measure of the expected rate of credit loss (estimated separately);
	proc sql;
	create table alll27 as select a.*, b.ercl
	from alll26 a left join box.hkn_ercl b
	on a.reg_id=b.rssdid and a.qtrend=b.reg_date;
	quit;

	*Calculate target capital ratio;
	proc sql;
	create table alll28 as select a.*, b.tier1capital as tier1_unsc
	from alll27 a left join box.all_tier1capital_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll29a as select a.*, b.tier1_riskratio as tier1
	from alll28 a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;

	create table alll29b as select a.*, b.tier1_riskratio as tier1_lag1
	from alll29a a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+1;

	create table alll29c as select a.*, b.tier1_riskratio as tier1_lag2
	from alll29b a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+2;

	create table alll29d as select a.*, b.tier1_riskratio as tier1_lag3
	from alll29c a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+3;

	create table alll29e as select a.*, b.tier1_riskratio as tier1_lag4
	from alll29d a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

	create table alll29f as select a.*, b.tier1_riskratio as tier1_lag5
	from alll29e a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+5;

	create table alll29g as select a.*, b.tier1_riskratio as tier1_lag6
	from alll29f a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+6;

	create table alll29h as select a.*, b.tier1_riskratio as tier1_lag7
	from alll29g a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+7;

	create table alll29i as select a.*, b.tier1_riskratio as tier1_lag8
	from alll29h a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+8;

	create table alll29j as select a.*, b.tier1_riskratio as tier1_lag9
	from alll29i a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+9;

	create table alll29k as select a.*, b.tier1_riskratio as tier1_lag10
	from alll29j a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+10;

	create table alll29l as select a.*, b.tier1_riskratio as tier1_lag11
	from alll29k a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+11;

	create table alll29m as select a.*, b.tier1_riskratio as tier1_lag12
	from alll29l a left join box.all_tier1riskratio_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate+12;

	create table alll29n as select a.*, b.nibp
	from alll29m a left join box.all_nibp_1990_2017 b
	on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
	quit;

	data alll30; set alll29n;
	nibp_loans = nibp/lag1_loans;
	nibp_ta = nibp/ta;
	nibp_share = nibp/shrout;
	target_tier1 = (tier1_lag1+tier1_lag2+tier1_lag3+tier1_lag4+tier1_lag5+tier1_lag6+tier1_lag7+tier1_lag8+tier1_lag9+tier1_lag10+tier1_lag11+tier1_lag12)/12;
	ecldiff_tier1 = ecldiff / tier1_unsc;
	run;

*Add lagged loans variables;
proc sql;
create table alll31a as select a.*, b.loans as lag4_loans
from alll30 a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31b as select a.*, b.loans as lag4_loans
from alll31a a left join box.all_loans_1990_2017 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31c as select a.*, b.sfloans as lag4_sfloans
from alll31b as a left join box.all_sfloans_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31d as select a.*, b.sfcndloans as lag4_sfcndloans
from alll31c a left join box.all_sfcndloans_1990_2019 b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31e as select a.*, b.loans_hfs as lag4_loans_hfs
from alll31d as a left join box.all_loans_hfs_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31f as select a.*, b.reloans as lag4_reloans
from alll31e as a left join box.all_reloans_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31f as select a.*, b.mfloans as lag4_mfloans
from alll31f as a left join box.all_mfloans_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31f as select a.*, b.creloans as lag4_creloans
from alll31f as a left join box.all_creloans_1990_2019 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31f as select a.*, b.farmloans as lag4_farmloans
from alll31f as a left join box.all_farmloans_1990_2019 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31g as select a.*, b.consloans as lag4_consloans
from alll31f as a left join box.all_consloans_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31g as select a.*, b.cniloans as lag4_cniloans
from alll31g as a left join box.all_cniloans_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;

create table alll31g as select a.*, b.agloans as lag4_agloans
from alll31g as a left join box.all_agloans_1990_2017 as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate+4;
quit;
data alll31h; set alll31g;
if lag4_sfcndloans=. then lag4_sfcndloans=0;
if lag4_loans_hfs=. then lag4_loans_hfs=0;
lag4_sf_total = lag4_sfloans+lag4_sfcndloans;
lag4_sf_htm = lag4_sf_total-lag4_loans_hfs;
lag4_nonsfre = lag4_mfloans+lag4_creloans+lag4_farmloans;
lag4_othnonre = lag4_cniloans+lag4_agloans;
run;

*Winsorize variables;
%WINSORIZE (INSET=alll31h,OUTSET=cecl_dataset,SORTVAR=win,VARS= 
mve_bve ecl_bve ecl_loans ecldiff_loans ecldiff_bve ecldiff_ta ecldiff_alll ecldiff_tce ecl_share ecldiff_share alll_loans rsa_bve npl_bve npl_loans alll_npl alll_bve avgint_bve reloans_bve consloans_bve 
mve_share bve_share alll_share avgint_share reloans_share consloans_share rsa_share loans_5plus_loans loans_5to15_loans loans_15plus_loans
ecldiff_base_loans ecldiff_base_bve ecldiff_tier1 
ecl_20_bve ecl_20_loans ecldiff_20_loans ecldiff_20_bve ecldiff_20_ta ecldiff_20_alll ecldiff_20_tce ecl_20_share ecldiff_20_share avg_cum_loss_20
ecl_28_bve ecl_28_loans ecldiff_28_loans ecldiff_28_bve ecldiff_28_ta ecldiff_28_alll ecldiff_28_tce ecl_28_share ecldiff_28_share avg_cum_loss_28
ecldiff_2ymacro_share ecldiff_3ymacro_share ecldiff_2ymacroadj_share ecldiff_3ymacroadj_share
ecl_base_loans ecl_year1_loans ecl_year1_base_loans ecl_year1_20_loans ecl_year1_28_loans ecl_year2_loans ecl_year3_loans ecl_year4_loans ecl_year5_loans ecl_year6_loans 
ecl_t_base_loans ecl_lag1_base_loans ecl_lag2_base_loans ecl_lag3_base_loans
ecldiff_macro_loans ecldiff_macro_share ecldiff_macro_bve nco_bve ecldiff_base_share npl_share nco_share 
ercl avg_cum_loss llp_loans ecldiff_ecl nco_loans nibp_loans nibp_ta nibp_share
,PERC1=1,TRIM=0);

*Clean and save final dataset;
data box.cecl_dataset;
set cecl_dataset;
if avgint_loans=. then delete;
if avg_wtd_lags>24 then delete;
if avg_wtd_lags=. then delete;
if avg_lags>24 then delete;
if loans_5plus_loans=. then delete;
if reloans_loans<1 then reloans_loans=1;
run;
