/*========================================================================================================
                                                                          
    ARTICLE: Unrecognized Expected Credit Losses and Bank Share Prices                      
    AUTHOR: P. Barrett Wheeler                  
    JOURNAL OF ACCOUNTING RESEARCH 

 	The code below aggregates and creates a time series of quarterly loan originations of consumer 
	loans by each bank's top regulatory ID for the years 1991 to 2016. These loan originations are then
	used to estimate Eq. (5) for consumer loans.

 =========================================================================================================*/

libname box 'C:\Users\pwheeler1\Box Sync\Data Sets\CECL';
libname nic 'C:\Users\pwheeler1\Box Sync\Data Sets\NIC Data';
libname lo 'C:\Users\pwheeler1\Box Sync\Data Sets\Loan Originations';

data ta;
set box.all_ta_1990_2017;
run;

/*2016*/

/*2016 Q4 Consumer Originations Plus Lags*/
data cons_lo_2016Q4 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 108 then delete;
run;
proc sql;
create table cons_lo_2016Q4_2 as select a.*, b.ta
from cons_lo_2016Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2016Q4_3;
set cons_lo_2016Q4_2;
if ta=. then delete;
run;
/*Add 2016 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2016Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2016Q4_3 as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2016Q4_4;
set cons_lo_2016Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.topid_20161231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2016Q4_4, outset=cons_lo_2016Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2016Q4_5, outset=cons_lo_2016Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2016Q4_6, outset=cons_lo_2016Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2016Q4_7, outset=cons_lo_2016Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2016Q4_8, outset=cons_lo_2016Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2016Q4_9, outset=cons_lo_2016Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2016Q4_10, outset=cons_lo_2016Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2016Q4_11, outset=cons_lo_2016Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2016Q4_12, outset=cons_lo_2016Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2016Q4_13, outset=cons_lo_2016Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2016Q4_14, outset=cons_lo_2016Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2016Q4_15, outset=cons_lo_2016Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2016Q4_16, outset=cons_lo_2016Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2016Q4_17, outset=cons_lo_2016Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2016Q4_18, outset=cons_lo_2016Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2016Q4_19, outset=cons_lo_2016Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2016Q4_20, outset=cons_lo_2016Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2016Q4_21, outset=cons_lo_2016Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2016Q4_22, outset=cons_lo_2016Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2016Q4_23, outset=cons_lo_2016Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2016Q4_24, outset=cons_lo_2016Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2016Q4_25, outset=cons_lo_2016Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2016Q4_26, outset=cons_lo_2016Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2016Q4_27, outset=cons_lo_2016Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2016Q4_28, outset=cons_lo_2016Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2016Q4_29, outset=cons_lo_2016Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2016Q4_30, outset=cons_lo_2016Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2016Q4_31, outset=cons_lo_2016Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2016Q4_32, outset=cons_lo_2016Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2016Q4_33, outset=cons_lo_2016Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2016Q4_34, outset=cons_lo_2016Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2016Q4_35, outset=cons_lo_2016Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2016Q4_36, outset=cons_lo_2016Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2016Q4_37, outset=cons_lo_2016Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2016Q4_38, outset=cons_lo_2016Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2016Q4_39, outset=cons_lo_2016Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2016Q4_40, outset=cons_lo_2016Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2016Q4_41, outset=cons_lo_2016Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2016Q4_42, outset=cons_lo_2016Q4_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2016Q4;
set cons_lo_2016Q4_43;
run;

/*2016Q3 Q4 Consumer Originations Plus Lags*/
data cons_lo_2016Q3 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 107 then delete;
run;
proc sql;
create table cons_lo_2016Q3_2 as select a.*, b.ta
from cons_lo_2016Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2016Q3_3;
set cons_lo_2016Q3_2;
if ta=. then delete;
run;
/*Add 2016Q3 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2016Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2016Q3_3 as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2016Q3_4;
set cons_lo_2016Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2016Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.topid_20160930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2016Q3_4, outset=cons_lo_2016Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2016Q3_5, outset=cons_lo_2016Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2016Q3_6, outset=cons_lo_2016Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2016Q3_7, outset=cons_lo_2016Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2016Q3_8, outset=cons_lo_2016Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2016Q3_9, outset=cons_lo_2016Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2016Q3_10, outset=cons_lo_2016Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2016Q3_11, outset=cons_lo_2016Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2016Q3_12, outset=cons_lo_2016Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2016Q3_13, outset=cons_lo_2016Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2016Q3_14, outset=cons_lo_2016Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2016Q3_15, outset=cons_lo_2016Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2016Q3_16, outset=cons_lo_2016Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2016Q3_17, outset=cons_lo_2016Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2016Q3_18, outset=cons_lo_2016Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2016Q3_19, outset=cons_lo_2016Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2016Q3_20, outset=cons_lo_2016Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2016Q3_21, outset=cons_lo_2016Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2016Q3_22, outset=cons_lo_2016Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2016Q3_23, outset=cons_lo_2016Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2016Q3_24, outset=cons_lo_2016Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2016Q3_25, outset=cons_lo_2016Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2016Q3_26, outset=cons_lo_2016Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2016Q3_27, outset=cons_lo_2016Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2016Q3_28, outset=cons_lo_2016Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2016Q3_29, outset=cons_lo_2016Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2016Q3_30, outset=cons_lo_2016Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2016Q3_31, outset=cons_lo_2016Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2016Q3_32, outset=cons_lo_2016Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2016Q3_33, outset=cons_lo_2016Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2016Q3_34, outset=cons_lo_2016Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2016Q3_35, outset=cons_lo_2016Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2016Q3_36, outset=cons_lo_2016Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2016Q3_37, outset=cons_lo_2016Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2016Q3_38, outset=cons_lo_2016Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2016Q3_39, outset=cons_lo_2016Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2016Q3_40, outset=cons_lo_2016Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2016Q3_41, outset=cons_lo_2016Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2016Q3_42, outset=cons_lo_2016Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2016Q3;
set cons_lo_2016Q3_43;
run;


/*2016Q2 Q4 Consumer Originations Plus Lags*/
data cons_lo_2016Q2 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 106 then delete;
run;
proc sql;
create table cons_lo_2016Q2_2 as select a.*, b.ta
from cons_lo_2016Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2016Q2_3;
set cons_lo_2016Q2_2;
if ta=. then delete;
run;
/*Add 2016Q2 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2016Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2016Q2_3 as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2016Q2_4;
set cons_lo_2016Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2016Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.topid_20160630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2016Q2_4, outset=cons_lo_2016Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2016Q2_5, outset=cons_lo_2016Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2016Q2_6, outset=cons_lo_2016Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2016Q2_7, outset=cons_lo_2016Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2016Q2_8, outset=cons_lo_2016Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2016Q2_9, outset=cons_lo_2016Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2016Q2_10, outset=cons_lo_2016Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2016Q2_11, outset=cons_lo_2016Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2016Q2_12, outset=cons_lo_2016Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2016Q2_13, outset=cons_lo_2016Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2016Q2_14, outset=cons_lo_2016Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2016Q2_15, outset=cons_lo_2016Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2016Q2_16, outset=cons_lo_2016Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2016Q2_17, outset=cons_lo_2016Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2016Q2_18, outset=cons_lo_2016Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2016Q2_19, outset=cons_lo_2016Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2016Q2_20, outset=cons_lo_2016Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2016Q2_21, outset=cons_lo_2016Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2016Q2_22, outset=cons_lo_2016Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2016Q2_23, outset=cons_lo_2016Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2016Q2_24, outset=cons_lo_2016Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2016Q2_25, outset=cons_lo_2016Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2016Q2_26, outset=cons_lo_2016Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2016Q2_27, outset=cons_lo_2016Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2016Q2_28, outset=cons_lo_2016Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2016Q2_29, outset=cons_lo_2016Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2016Q2_30, outset=cons_lo_2016Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2016Q2_31, outset=cons_lo_2016Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2016Q2_32, outset=cons_lo_2016Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2016Q2_33, outset=cons_lo_2016Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2016Q2_34, outset=cons_lo_2016Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2016Q2_35, outset=cons_lo_2016Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2016Q2_36, outset=cons_lo_2016Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2016Q2_37, outset=cons_lo_2016Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2016Q2_38, outset=cons_lo_2016Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2016Q2_39, outset=cons_lo_2016Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2016Q2_40, outset=cons_lo_2016Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2016Q2_41, outset=cons_lo_2016Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2016Q2_42, outset=cons_lo_2016Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2016Q2;
set cons_lo_2016Q2_43;
run;


/*2016Q1 Q1 Consumer Originations Plus Lags*/
data cons_lo_2016Q1 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 105 then delete;
run;
proc sql;
create table cons_lo_2016Q1_2 as select a.*, b.ta
from cons_lo_2016Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2016Q1_3;
set cons_lo_2016Q1_2;
if ta=. then delete;
run;
/*Add 2016Q1 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2016Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2016Q1_3 as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2016Q1_4;
set cons_lo_2016Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2016Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.topid_20160331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2016Q1_4, outset=cons_lo_2016Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2016Q1_5, outset=cons_lo_2016Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2016Q1_6, outset=cons_lo_2016Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2016Q1_7, outset=cons_lo_2016Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2016Q1_8, outset=cons_lo_2016Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2016Q1_9, outset=cons_lo_2016Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2016Q1_10, outset=cons_lo_2016Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2016Q1_11, outset=cons_lo_2016Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2016Q1_12, outset=cons_lo_2016Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2016Q1_13, outset=cons_lo_2016Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2016Q1_14, outset=cons_lo_2016Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2016Q1_15, outset=cons_lo_2016Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2016Q1_16, outset=cons_lo_2016Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2016Q1_17, outset=cons_lo_2016Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2016Q1_18, outset=cons_lo_2016Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2016Q1_19, outset=cons_lo_2016Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2016Q1_20, outset=cons_lo_2016Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2016Q1_21, outset=cons_lo_2016Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2016Q1_22, outset=cons_lo_2016Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2016Q1_23, outset=cons_lo_2016Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2016Q1_24, outset=cons_lo_2016Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2016Q1_25, outset=cons_lo_2016Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2016Q1_26, outset=cons_lo_2016Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2016Q1_27, outset=cons_lo_2016Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2016Q1_28, outset=cons_lo_2016Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2016Q1_29, outset=cons_lo_2016Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2016Q1_30, outset=cons_lo_2016Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2016Q1_31, outset=cons_lo_2016Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2016Q1_32, outset=cons_lo_2016Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2016Q1_33, outset=cons_lo_2016Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2016Q1_34, outset=cons_lo_2016Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2016Q1_35, outset=cons_lo_2016Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2016Q1_36, outset=cons_lo_2016Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2016Q1_37, outset=cons_lo_2016Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2016Q1_38, outset=cons_lo_2016Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2016Q1_39, outset=cons_lo_2016Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2016Q1_40, outset=cons_lo_2016Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2016Q1_41, outset=cons_lo_2016Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2016Q1_42, outset=cons_lo_2016Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2016Q1;
set cons_lo_2016Q1_43;
run;

/*2015*/

/*2015 Q4 Consumer Originations Plus Lags*/
data cons_lo_2015Q4 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 104 then delete;
run;
proc sql;
create table cons_lo_2015Q4_2 as select a.*, b.ta
from cons_lo_2015Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2015Q4_3;
set cons_lo_2015Q4_2;
if ta=. then delete;
run;
/*Add 2015 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2015Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2015Q4_3 as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2015Q4_4;
set cons_lo_2015Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.topid_20151231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2015Q4_4, outset=cons_lo_2015Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2015Q4_5, outset=cons_lo_2015Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2015Q4_6, outset=cons_lo_2015Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2015Q4_7, outset=cons_lo_2015Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2015Q4_8, outset=cons_lo_2015Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2015Q4_9, outset=cons_lo_2015Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2015Q4_10, outset=cons_lo_2015Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2015Q4_11, outset=cons_lo_2015Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2015Q4_12, outset=cons_lo_2015Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2015Q4_13, outset=cons_lo_2015Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2015Q4_14, outset=cons_lo_2015Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2015Q4_15, outset=cons_lo_2015Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2015Q4_16, outset=cons_lo_2015Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2015Q4_17, outset=cons_lo_2015Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2015Q4_18, outset=cons_lo_2015Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2015Q4_19, outset=cons_lo_2015Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2015Q4_20, outset=cons_lo_2015Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2015Q4_21, outset=cons_lo_2015Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2015Q4_22, outset=cons_lo_2015Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2015Q4_23, outset=cons_lo_2015Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2015Q4_24, outset=cons_lo_2015Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2015Q4_25, outset=cons_lo_2015Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2015Q4_26, outset=cons_lo_2015Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2015Q4_27, outset=cons_lo_2015Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2015Q4_28, outset=cons_lo_2015Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2015Q4_29, outset=cons_lo_2015Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2015Q4_30, outset=cons_lo_2015Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2015Q4_31, outset=cons_lo_2015Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2015Q4_32, outset=cons_lo_2015Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2015Q4_33, outset=cons_lo_2015Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2015Q4_34, outset=cons_lo_2015Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2015Q4_35, outset=cons_lo_2015Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2015Q4_36, outset=cons_lo_2015Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2015Q4_37, outset=cons_lo_2015Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2015Q4_38, outset=cons_lo_2015Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2015Q4_39, outset=cons_lo_2015Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2015Q4_40, outset=cons_lo_2015Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2015Q4_41, outset=cons_lo_2015Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2015Q4_42, outset=cons_lo_2015Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2015Q4_43, outset=cons_lo_2015Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2015Q4;
set cons_lo_2015Q4_43;
run;


/*2015Q3 Q4 Consumer Originations Plus Lags*/
data cons_lo_2015Q3 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 103 then delete;
run;
proc sql;
create table cons_lo_2015Q3_2 as select a.*, b.ta
from cons_lo_2015Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2015Q3_3;
set cons_lo_2015Q3_2;
if ta=. then delete;
run;
/*Add 2015Q3 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2015Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2015Q3_3 as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2015Q3_4;
set cons_lo_2015Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2015Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.topid_20150930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2015Q3_4, outset=cons_lo_2015Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2015Q3_5, outset=cons_lo_2015Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2015Q3_6, outset=cons_lo_2015Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2015Q3_7, outset=cons_lo_2015Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2015Q3_8, outset=cons_lo_2015Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2015Q3_9, outset=cons_lo_2015Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2015Q3_10, outset=cons_lo_2015Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2015Q3_11, outset=cons_lo_2015Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2015Q3_12, outset=cons_lo_2015Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2015Q3_13, outset=cons_lo_2015Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2015Q3_14, outset=cons_lo_2015Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2015Q3_15, outset=cons_lo_2015Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2015Q3_16, outset=cons_lo_2015Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2015Q3_17, outset=cons_lo_2015Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2015Q3_18, outset=cons_lo_2015Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2015Q3_19, outset=cons_lo_2015Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2015Q3_20, outset=cons_lo_2015Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2015Q3_21, outset=cons_lo_2015Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2015Q3_22, outset=cons_lo_2015Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2015Q3_23, outset=cons_lo_2015Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2015Q3_24, outset=cons_lo_2015Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2015Q3_25, outset=cons_lo_2015Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2015Q3_26, outset=cons_lo_2015Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2015Q3_27, outset=cons_lo_2015Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2015Q3_28, outset=cons_lo_2015Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2015Q3_29, outset=cons_lo_2015Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2015Q3_30, outset=cons_lo_2015Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2015Q3_31, outset=cons_lo_2015Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2015Q3_32, outset=cons_lo_2015Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2015Q3_33, outset=cons_lo_2015Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2015Q3_34, outset=cons_lo_2015Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2015Q3_35, outset=cons_lo_2015Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2015Q3_36, outset=cons_lo_2015Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2015Q3_37, outset=cons_lo_2015Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2015Q3_38, outset=cons_lo_2015Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2015Q3_39, outset=cons_lo_2015Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2015Q3_40, outset=cons_lo_2015Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2015Q3_41, outset=cons_lo_2015Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2015Q3_42, outset=cons_lo_2015Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2015Q3;
set cons_lo_2015Q3_43;
run;


/*2015Q2 Q4 Consumer Originations Plus Lags*/
data cons_lo_2015Q2 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 102 then delete;
run;
proc sql;
create table cons_lo_2015Q2_2 as select a.*, b.ta
from cons_lo_2015Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2015Q2_3;
set cons_lo_2015Q2_2;
if ta=. then delete;
run;
/*Add 2015Q2 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2015Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2015Q2_3 as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2015Q2_4;
set cons_lo_2015Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2015Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.topid_20150630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2015Q2_4, outset=cons_lo_2015Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2015Q2_5, outset=cons_lo_2015Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2015Q2_6, outset=cons_lo_2015Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2015Q2_7, outset=cons_lo_2015Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2015Q2_8, outset=cons_lo_2015Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2015Q2_9, outset=cons_lo_2015Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2015Q2_10, outset=cons_lo_2015Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2015Q2_11, outset=cons_lo_2015Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2015Q2_12, outset=cons_lo_2015Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2015Q2_13, outset=cons_lo_2015Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2015Q2_14, outset=cons_lo_2015Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2015Q2_15, outset=cons_lo_2015Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2015Q2_16, outset=cons_lo_2015Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2015Q2_17, outset=cons_lo_2015Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2015Q2_18, outset=cons_lo_2015Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2015Q2_19, outset=cons_lo_2015Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2015Q2_20, outset=cons_lo_2015Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2015Q2_21, outset=cons_lo_2015Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2015Q2_22, outset=cons_lo_2015Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2015Q2_23, outset=cons_lo_2015Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2015Q2_24, outset=cons_lo_2015Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2015Q2_25, outset=cons_lo_2015Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2015Q2_26, outset=cons_lo_2015Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2015Q2_27, outset=cons_lo_2015Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2015Q2_28, outset=cons_lo_2015Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2015Q2_29, outset=cons_lo_2015Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2015Q2_30, outset=cons_lo_2015Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2015Q2_31, outset=cons_lo_2015Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2015Q2_32, outset=cons_lo_2015Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2015Q2_33, outset=cons_lo_2015Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2015Q2_34, outset=cons_lo_2015Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2015Q2_35, outset=cons_lo_2015Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2015Q2_36, outset=cons_lo_2015Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2015Q2_37, outset=cons_lo_2015Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2015Q2_38, outset=cons_lo_2015Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2015Q2_39, outset=cons_lo_2015Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2015Q2_40, outset=cons_lo_2015Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2015Q2_41, outset=cons_lo_2015Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2015Q2_42, outset=cons_lo_2015Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2015Q2;
set cons_lo_2015Q2_43;
run;


/*2015Q1 Q1 Consumer Originations Plus Lags*/
data cons_lo_2015Q1 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 101 then delete;
run;
proc sql;
create table cons_lo_2015Q1_2 as select a.*, b.ta
from cons_lo_2015Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2015Q1_3;
set cons_lo_2015Q1_2;
if ta=. then delete;
run;
/*Add 2015Q1 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2015Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2015Q1_3 as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2015Q1_4;
set cons_lo_2015Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2015Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join lo.est_lo_cons_1990_2016 as b
on a.rssd_id=b.topid_20150331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2015Q1_4, outset=cons_lo_2015Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2015Q1_5, outset=cons_lo_2015Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2015Q1_6, outset=cons_lo_2015Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2015Q1_7, outset=cons_lo_2015Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2015Q1_8, outset=cons_lo_2015Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2015Q1_9, outset=cons_lo_2015Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2015Q1_10, outset=cons_lo_2015Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2015Q1_11, outset=cons_lo_2015Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2015Q1_12, outset=cons_lo_2015Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2015Q1_13, outset=cons_lo_2015Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2015Q1_14, outset=cons_lo_2015Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2015Q1_15, outset=cons_lo_2015Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2015Q1_16, outset=cons_lo_2015Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2015Q1_17, outset=cons_lo_2015Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2015Q1_18, outset=cons_lo_2015Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2015Q1_19, outset=cons_lo_2015Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2015Q1_20, outset=cons_lo_2015Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2015Q1_21, outset=cons_lo_2015Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2015Q1_22, outset=cons_lo_2015Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2015Q1_23, outset=cons_lo_2015Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2015Q1_24, outset=cons_lo_2015Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2015Q1_25, outset=cons_lo_2015Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2015Q1_26, outset=cons_lo_2015Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2015Q1_27, outset=cons_lo_2015Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2015Q1_28, outset=cons_lo_2015Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2015Q1_29, outset=cons_lo_2015Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2015Q1_30, outset=cons_lo_2015Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2015Q1_31, outset=cons_lo_2015Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2015Q1_32, outset=cons_lo_2015Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2015Q1_33, outset=cons_lo_2015Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2015Q1_34, outset=cons_lo_2015Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2015Q1_35, outset=cons_lo_2015Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2015Q1_36, outset=cons_lo_2015Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2015Q1_37, outset=cons_lo_2015Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2015Q1_38, outset=cons_lo_2015Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2015Q1_39, outset=cons_lo_2015Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2015Q1_40, outset=cons_lo_2015Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2015Q1_41, outset=cons_lo_2015Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2015Q1_42, outset=cons_lo_2015Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2015Q1;
set cons_lo_2015Q1_43;
run;

/*2014*/

/*2014 Q4 Consumer Originations Plus Lags*/
data cons_lo_2014Q4 (drop = permco link_start link_end);
set box.cecl_step1;
if rankdate ne 100 then delete;
run;
proc sql;
create table cons_lo_2014Q4_2 as select a.*, b.ta
from cons_lo_2014Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2014Q4_3;
set cons_lo_2014Q4_2;
if ta=. then delete;
run;
/*Add 2014 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2014Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2014Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2014Q4_4;
set cons_lo_2014Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20141231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2014Q4_4, outset=cons_lo_2014Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2014Q4_5, outset=cons_lo_2014Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2014Q4_6, outset=cons_lo_2014Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2014Q4_7, outset=cons_lo_2014Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2014Q4_8, outset=cons_lo_2014Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2014Q4_9, outset=cons_lo_2014Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2014Q4_10, outset=cons_lo_2014Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2014Q4_11, outset=cons_lo_2014Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2014Q4_12, outset=cons_lo_2014Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2014Q4_13, outset=cons_lo_2014Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2014Q4_14, outset=cons_lo_2014Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2014Q4_15, outset=cons_lo_2014Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2014Q4_16, outset=cons_lo_2014Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2014Q4_17, outset=cons_lo_2014Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2014Q4_18, outset=cons_lo_2014Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2014Q4_19, outset=cons_lo_2014Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2014Q4_20, outset=cons_lo_2014Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2014Q4_21, outset=cons_lo_2014Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2014Q4_22, outset=cons_lo_2014Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2014Q4_23, outset=cons_lo_2014Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2014Q4_24, outset=cons_lo_2014Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2014Q4_25, outset=cons_lo_2014Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2014Q4_26, outset=cons_lo_2014Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2014Q4_27, outset=cons_lo_2014Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2014Q4_28, outset=cons_lo_2014Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2014Q4_29, outset=cons_lo_2014Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2014Q4_30, outset=cons_lo_2014Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2014Q4_31, outset=cons_lo_2014Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2014Q4_32, outset=cons_lo_2014Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2014Q4_33, outset=cons_lo_2014Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2014Q4_34, outset=cons_lo_2014Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2014Q4_35, outset=cons_lo_2014Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2014Q4_36, outset=cons_lo_2014Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2014Q4_37, outset=cons_lo_2014Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2014Q4_38, outset=cons_lo_2014Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2014Q4_39, outset=cons_lo_2014Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2014Q4_40, outset=cons_lo_2014Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2014Q4_41, outset=cons_lo_2014Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2014Q4_42, outset=cons_lo_2014Q4_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2014Q4;
set cons_lo_2014Q4_43;
run;

/*2014Q3 Q4 Consumer Originations Plus Lags*/
data cons_lo_2014Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 99 then delete;
run;
proc sql;
create table cons_lo_2014Q3_2 as select a.*, b.ta
from cons_lo_2014Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2014Q3_3;
set cons_lo_2014Q3_2;
if ta=. then delete;
run;
/*Add 2014Q3 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2014Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2014Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2014Q3_4;
set cons_lo_2014Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2014Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20140930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2014Q3_4, outset=cons_lo_2014Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2014Q3_5, outset=cons_lo_2014Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2014Q3_6, outset=cons_lo_2014Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2014Q3_7, outset=cons_lo_2014Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2014Q3_8, outset=cons_lo_2014Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2014Q3_9, outset=cons_lo_2014Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2014Q3_10, outset=cons_lo_2014Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2014Q3_11, outset=cons_lo_2014Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2014Q3_12, outset=cons_lo_2014Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2014Q3_13, outset=cons_lo_2014Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2014Q3_14, outset=cons_lo_2014Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2014Q3_15, outset=cons_lo_2014Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2014Q3_16, outset=cons_lo_2014Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2014Q3_17, outset=cons_lo_2014Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2014Q3_18, outset=cons_lo_2014Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2014Q3_19, outset=cons_lo_2014Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2014Q3_20, outset=cons_lo_2014Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2014Q3_21, outset=cons_lo_2014Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2014Q3_22, outset=cons_lo_2014Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2014Q3_23, outset=cons_lo_2014Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2014Q3_24, outset=cons_lo_2014Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2014Q3_25, outset=cons_lo_2014Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2014Q3_26, outset=cons_lo_2014Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2014Q3_27, outset=cons_lo_2014Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2014Q3_28, outset=cons_lo_2014Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2014Q3_29, outset=cons_lo_2014Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2014Q3_30, outset=cons_lo_2014Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2014Q3_31, outset=cons_lo_2014Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2014Q3_32, outset=cons_lo_2014Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2014Q3_33, outset=cons_lo_2014Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2014Q3_34, outset=cons_lo_2014Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2014Q3_35, outset=cons_lo_2014Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2014Q3_36, outset=cons_lo_2014Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2014Q3_37, outset=cons_lo_2014Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2014Q3_38, outset=cons_lo_2014Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2014Q3_39, outset=cons_lo_2014Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2014Q3_40, outset=cons_lo_2014Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2014Q3_41, outset=cons_lo_2014Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2014Q3_42, outset=cons_lo_2014Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2014Q3;
set cons_lo_2014Q3_43;
run;


/*2014Q2 Q4 Consumer Originations Plus Lags*/
data cons_lo_2014Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 98 then delete;
run;
proc sql;
create table cons_lo_2014Q2_2 as select a.*, b.ta
from cons_lo_2014Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2014Q2_3;
set cons_lo_2014Q2_2;
if ta=. then delete;
run;
/*Add 2014Q2 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2014Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2014Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2014Q2_4;
set cons_lo_2014Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2014Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20140630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2014Q2_4, outset=cons_lo_2014Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2014Q2_5, outset=cons_lo_2014Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2014Q2_6, outset=cons_lo_2014Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2014Q2_7, outset=cons_lo_2014Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2014Q2_8, outset=cons_lo_2014Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2014Q2_9, outset=cons_lo_2014Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2014Q2_10, outset=cons_lo_2014Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2014Q2_11, outset=cons_lo_2014Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2014Q2_12, outset=cons_lo_2014Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2014Q2_13, outset=cons_lo_2014Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2014Q2_14, outset=cons_lo_2014Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2014Q2_15, outset=cons_lo_2014Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2014Q2_16, outset=cons_lo_2014Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2014Q2_17, outset=cons_lo_2014Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2014Q2_18, outset=cons_lo_2014Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2014Q2_19, outset=cons_lo_2014Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2014Q2_20, outset=cons_lo_2014Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2014Q2_21, outset=cons_lo_2014Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2014Q2_22, outset=cons_lo_2014Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2014Q2_23, outset=cons_lo_2014Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2014Q2_24, outset=cons_lo_2014Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2014Q2_25, outset=cons_lo_2014Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2014Q2_26, outset=cons_lo_2014Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2014Q2_27, outset=cons_lo_2014Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2014Q2_28, outset=cons_lo_2014Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2014Q2_29, outset=cons_lo_2014Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2014Q2_30, outset=cons_lo_2014Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2014Q2_31, outset=cons_lo_2014Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2014Q2_32, outset=cons_lo_2014Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2014Q2_33, outset=cons_lo_2014Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2014Q2_34, outset=cons_lo_2014Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2014Q2_35, outset=cons_lo_2014Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2014Q2_36, outset=cons_lo_2014Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2014Q2_37, outset=cons_lo_2014Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2014Q2_38, outset=cons_lo_2014Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2014Q2_39, outset=cons_lo_2014Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2014Q2_40, outset=cons_lo_2014Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2014Q2_41, outset=cons_lo_2014Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2014Q2_42, outset=cons_lo_2014Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2014Q2;
set cons_lo_2014Q2_43;
run;


/*2014Q1 Q1 Consumer Originations Plus Lags*/
data cons_lo_2014Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 97 then delete;
run;
proc sql;
create table cons_lo_2014Q1_2 as select a.*, b.ta
from cons_lo_2014Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2014Q1_3;
set cons_lo_2014Q1_2;
if ta=. then delete;
run;
/*Add 2014Q1 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2014Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2014Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2014Q1_4;
set cons_lo_2014Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2014Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20140331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2014Q1_4, outset=cons_lo_2014Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2014Q1_5, outset=cons_lo_2014Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2014Q1_6, outset=cons_lo_2014Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2014Q1_7, outset=cons_lo_2014Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2014Q1_8, outset=cons_lo_2014Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2014Q1_9, outset=cons_lo_2014Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2014Q1_10, outset=cons_lo_2014Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2014Q1_11, outset=cons_lo_2014Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2014Q1_12, outset=cons_lo_2014Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2014Q1_13, outset=cons_lo_2014Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2014Q1_14, outset=cons_lo_2014Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2014Q1_15, outset=cons_lo_2014Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2014Q1_16, outset=cons_lo_2014Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2014Q1_17, outset=cons_lo_2014Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2014Q1_18, outset=cons_lo_2014Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2014Q1_19, outset=cons_lo_2014Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2014Q1_20, outset=cons_lo_2014Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2014Q1_21, outset=cons_lo_2014Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2014Q1_22, outset=cons_lo_2014Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2014Q1_23, outset=cons_lo_2014Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2014Q1_24, outset=cons_lo_2014Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2014Q1_25, outset=cons_lo_2014Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2014Q1_26, outset=cons_lo_2014Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2014Q1_27, outset=cons_lo_2014Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2014Q1_28, outset=cons_lo_2014Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2014Q1_29, outset=cons_lo_2014Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2014Q1_30, outset=cons_lo_2014Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2014Q1_31, outset=cons_lo_2014Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2014Q1_32, outset=cons_lo_2014Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2014Q1_33, outset=cons_lo_2014Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2014Q1_34, outset=cons_lo_2014Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2014Q1_35, outset=cons_lo_2014Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2014Q1_36, outset=cons_lo_2014Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2014Q1_37, outset=cons_lo_2014Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2014Q1_38, outset=cons_lo_2014Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2014Q1_39, outset=cons_lo_2014Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2014Q1_40, outset=cons_lo_2014Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2014Q1_41, outset=cons_lo_2014Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2014Q1_42, outset=cons_lo_2014Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2014Q1;
set cons_lo_2014Q1_43;
run;

/*2013*/

/*2013 Q4 Consumer Originations Plus Lags*/
data cons_lo_2013Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 96 then delete;
run;
proc sql;
create table cons_lo_2013Q4_2 as select a.*, b.ta
from cons_lo_2013Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2013Q4_3;
set cons_lo_2013Q4_2;
if ta=. then delete;
run;
/*Add 2013 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2013Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2013Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2013Q4_4;
set cons_lo_2013Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20131231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2013Q4_4, outset=cons_lo_2013Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2013Q4_5, outset=cons_lo_2013Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2013Q4_6, outset=cons_lo_2013Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2013Q4_7, outset=cons_lo_2013Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2013Q4_8, outset=cons_lo_2013Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2013Q4_9, outset=cons_lo_2013Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2013Q4_10, outset=cons_lo_2013Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2013Q4_11, outset=cons_lo_2013Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2013Q4_12, outset=cons_lo_2013Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2013Q4_13, outset=cons_lo_2013Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2013Q4_14, outset=cons_lo_2013Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2013Q4_15, outset=cons_lo_2013Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2013Q4_16, outset=cons_lo_2013Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2013Q4_17, outset=cons_lo_2013Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2013Q4_18, outset=cons_lo_2013Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2013Q4_19, outset=cons_lo_2013Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2013Q4_20, outset=cons_lo_2013Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2013Q4_21, outset=cons_lo_2013Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2013Q4_22, outset=cons_lo_2013Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2013Q4_23, outset=cons_lo_2013Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2013Q4_24, outset=cons_lo_2013Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2013Q4_25, outset=cons_lo_2013Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2013Q4_26, outset=cons_lo_2013Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2013Q4_27, outset=cons_lo_2013Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2013Q4_28, outset=cons_lo_2013Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2013Q4_29, outset=cons_lo_2013Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2013Q4_30, outset=cons_lo_2013Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2013Q4_31, outset=cons_lo_2013Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2013Q4_32, outset=cons_lo_2013Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2013Q4_33, outset=cons_lo_2013Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2013Q4_34, outset=cons_lo_2013Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2013Q4_35, outset=cons_lo_2013Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2013Q4_36, outset=cons_lo_2013Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2013Q4_37, outset=cons_lo_2013Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2013Q4_38, outset=cons_lo_2013Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2013Q4_39, outset=cons_lo_2013Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2013Q4_40, outset=cons_lo_2013Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2013Q4_41, outset=cons_lo_2013Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2013Q4_42, outset=cons_lo_2013Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2013Q4_43, outset=cons_lo_2013Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2013Q4;
set cons_lo_2013Q4_43;
run;


/*2013Q3 Q4 Consumer Originations Plus Lags*/
data cons_lo_2013Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 95 then delete;
run;
proc sql;
create table cons_lo_2013Q3_2 as select a.*, b.ta
from cons_lo_2013Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2013Q3_3;
set cons_lo_2013Q3_2;
if ta=. then delete;
run;
/*Add 2013Q3 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2013Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2013Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2013Q3_4;
set cons_lo_2013Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2013Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20130930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2013Q3_4, outset=cons_lo_2013Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2013Q3_5, outset=cons_lo_2013Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2013Q3_6, outset=cons_lo_2013Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2013Q3_7, outset=cons_lo_2013Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2013Q3_8, outset=cons_lo_2013Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2013Q3_9, outset=cons_lo_2013Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2013Q3_10, outset=cons_lo_2013Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2013Q3_11, outset=cons_lo_2013Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2013Q3_12, outset=cons_lo_2013Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2013Q3_13, outset=cons_lo_2013Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2013Q3_14, outset=cons_lo_2013Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2013Q3_15, outset=cons_lo_2013Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2013Q3_16, outset=cons_lo_2013Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2013Q3_17, outset=cons_lo_2013Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2013Q3_18, outset=cons_lo_2013Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2013Q3_19, outset=cons_lo_2013Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2013Q3_20, outset=cons_lo_2013Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2013Q3_21, outset=cons_lo_2013Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2013Q3_22, outset=cons_lo_2013Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2013Q3_23, outset=cons_lo_2013Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2013Q3_24, outset=cons_lo_2013Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2013Q3_25, outset=cons_lo_2013Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2013Q3_26, outset=cons_lo_2013Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2013Q3_27, outset=cons_lo_2013Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2013Q3_28, outset=cons_lo_2013Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2013Q3_29, outset=cons_lo_2013Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2013Q3_30, outset=cons_lo_2013Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2013Q3_31, outset=cons_lo_2013Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2013Q3_32, outset=cons_lo_2013Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2013Q3_33, outset=cons_lo_2013Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2013Q3_34, outset=cons_lo_2013Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2013Q3_35, outset=cons_lo_2013Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2013Q3_36, outset=cons_lo_2013Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2013Q3_37, outset=cons_lo_2013Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2013Q3_38, outset=cons_lo_2013Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2013Q3_39, outset=cons_lo_2013Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2013Q3_40, outset=cons_lo_2013Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2013Q3_41, outset=cons_lo_2013Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2013Q3_42, outset=cons_lo_2013Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2013Q3;
set cons_lo_2013Q3_43;
run;


/*2013Q2 Q4 Consumer Originations Plus Lags*/
data cons_lo_2013Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 94 then delete;
run;
proc sql;
create table cons_lo_2013Q2_2 as select a.*, b.ta
from cons_lo_2013Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2013Q2_3;
set cons_lo_2013Q2_2;
if ta=. then delete;
run;
/*Add 2013Q2 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2013Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2013Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2013Q2_4;
set cons_lo_2013Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2013Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20130630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2013Q2_4, outset=cons_lo_2013Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2013Q2_5, outset=cons_lo_2013Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2013Q2_6, outset=cons_lo_2013Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2013Q2_7, outset=cons_lo_2013Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2013Q2_8, outset=cons_lo_2013Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2013Q2_9, outset=cons_lo_2013Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2013Q2_10, outset=cons_lo_2013Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2013Q2_11, outset=cons_lo_2013Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2013Q2_12, outset=cons_lo_2013Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2013Q2_13, outset=cons_lo_2013Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2013Q2_14, outset=cons_lo_2013Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2013Q2_15, outset=cons_lo_2013Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2013Q2_16, outset=cons_lo_2013Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2013Q2_17, outset=cons_lo_2013Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2013Q2_18, outset=cons_lo_2013Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2013Q2_19, outset=cons_lo_2013Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2013Q2_20, outset=cons_lo_2013Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2013Q2_21, outset=cons_lo_2013Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2013Q2_22, outset=cons_lo_2013Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2013Q2_23, outset=cons_lo_2013Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2013Q2_24, outset=cons_lo_2013Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2013Q2_25, outset=cons_lo_2013Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2013Q2_26, outset=cons_lo_2013Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2013Q2_27, outset=cons_lo_2013Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2013Q2_28, outset=cons_lo_2013Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2013Q2_29, outset=cons_lo_2013Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2013Q2_30, outset=cons_lo_2013Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2013Q2_31, outset=cons_lo_2013Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2013Q2_32, outset=cons_lo_2013Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2013Q2_33, outset=cons_lo_2013Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2013Q2_34, outset=cons_lo_2013Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2013Q2_35, outset=cons_lo_2013Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2013Q2_36, outset=cons_lo_2013Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2013Q2_37, outset=cons_lo_2013Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2013Q2_38, outset=cons_lo_2013Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2013Q2_39, outset=cons_lo_2013Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2013Q2_40, outset=cons_lo_2013Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2013Q2_41, outset=cons_lo_2013Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2013Q2_42, outset=cons_lo_2013Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2013Q2;
set cons_lo_2013Q2_43;
run;


/*2013Q1 Q1 Consumer Originations Plus Lags*/
data cons_lo_2013Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 93 then delete;
run;
proc sql;
create table cons_lo_2013Q1_2 as select a.*, b.ta
from cons_lo_2013Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2013Q1_3;
set cons_lo_2013Q1_2;
if ta=. then delete;
run;
/*Add 2013Q1 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2013Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2013Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2013Q1_4;
set cons_lo_2013Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2013Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20130331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2013Q1_4, outset=cons_lo_2013Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2013Q1_5, outset=cons_lo_2013Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2013Q1_6, outset=cons_lo_2013Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2013Q1_7, outset=cons_lo_2013Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2013Q1_8, outset=cons_lo_2013Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2013Q1_9, outset=cons_lo_2013Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2013Q1_10, outset=cons_lo_2013Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2013Q1_11, outset=cons_lo_2013Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2013Q1_12, outset=cons_lo_2013Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2013Q1_13, outset=cons_lo_2013Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2013Q1_14, outset=cons_lo_2013Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2013Q1_15, outset=cons_lo_2013Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2013Q1_16, outset=cons_lo_2013Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2013Q1_17, outset=cons_lo_2013Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2013Q1_18, outset=cons_lo_2013Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2013Q1_19, outset=cons_lo_2013Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2013Q1_20, outset=cons_lo_2013Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2013Q1_21, outset=cons_lo_2013Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2013Q1_22, outset=cons_lo_2013Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2013Q1_23, outset=cons_lo_2013Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2013Q1_24, outset=cons_lo_2013Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2013Q1_25, outset=cons_lo_2013Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2013Q1_26, outset=cons_lo_2013Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2013Q1_27, outset=cons_lo_2013Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2013Q1_28, outset=cons_lo_2013Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2013Q1_29, outset=cons_lo_2013Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2013Q1_30, outset=cons_lo_2013Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2013Q1_31, outset=cons_lo_2013Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2013Q1_32, outset=cons_lo_2013Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2013Q1_33, outset=cons_lo_2013Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2013Q1_34, outset=cons_lo_2013Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2013Q1_35, outset=cons_lo_2013Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2013Q1_36, outset=cons_lo_2013Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2013Q1_37, outset=cons_lo_2013Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2013Q1_38, outset=cons_lo_2013Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2013Q1_39, outset=cons_lo_2013Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2013Q1_40, outset=cons_lo_2013Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2013Q1_41, outset=cons_lo_2013Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2013Q1_42, outset=cons_lo_2013Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2013Q1;
set cons_lo_2013Q1_43;
run;


/*2012*/

/*2012 Q4 Consumer Originations Plus Lags*/
data cons_lo_2012Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 92 then delete;
run;
proc sql;
create table cons_lo_2012Q4_2 as select a.*, b.ta
from cons_lo_2012Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2012Q4_3;
set cons_lo_2012Q4_2;
if ta=. then delete;
run;
/*Add 2012 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2012Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2012Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2012Q4_4;
set cons_lo_2012Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20121231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2012Q4_4, outset=cons_lo_2012Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2012Q4_5, outset=cons_lo_2012Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2012Q4_6, outset=cons_lo_2012Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2012Q4_7, outset=cons_lo_2012Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2012Q4_8, outset=cons_lo_2012Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2012Q4_9, outset=cons_lo_2012Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2012Q4_10, outset=cons_lo_2012Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2012Q4_11, outset=cons_lo_2012Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2012Q4_12, outset=cons_lo_2012Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2012Q4_13, outset=cons_lo_2012Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2012Q4_14, outset=cons_lo_2012Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2012Q4_15, outset=cons_lo_2012Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2012Q4_16, outset=cons_lo_2012Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2012Q4_17, outset=cons_lo_2012Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2012Q4_18, outset=cons_lo_2012Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2012Q4_19, outset=cons_lo_2012Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2012Q4_20, outset=cons_lo_2012Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2012Q4_21, outset=cons_lo_2012Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2012Q4_22, outset=cons_lo_2012Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2012Q4_23, outset=cons_lo_2012Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2012Q4_24, outset=cons_lo_2012Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2012Q4_25, outset=cons_lo_2012Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2012Q4_26, outset=cons_lo_2012Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2012Q4_27, outset=cons_lo_2012Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2012Q4_28, outset=cons_lo_2012Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2012Q4_29, outset=cons_lo_2012Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2012Q4_30, outset=cons_lo_2012Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2012Q4_31, outset=cons_lo_2012Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2012Q4_32, outset=cons_lo_2012Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2012Q4_33, outset=cons_lo_2012Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2012Q4_34, outset=cons_lo_2012Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2012Q4_35, outset=cons_lo_2012Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2012Q4_36, outset=cons_lo_2012Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2012Q4_37, outset=cons_lo_2012Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2012Q4_38, outset=cons_lo_2012Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2012Q4_39, outset=cons_lo_2012Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2012Q4_40, outset=cons_lo_2012Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2012Q4_41, outset=cons_lo_2012Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2012Q4_42, outset=cons_lo_2012Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2012Q4_43, outset=cons_lo_2012Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2012Q4;
set cons_lo_2012Q4_43;
run;


/*2012Q3 Q4 Consumer Originations Plus Lags*/
data cons_lo_2012Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 91 then delete;
run;
proc sql;
create table cons_lo_2012Q3_2 as select a.*, b.ta
from cons_lo_2012Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2012Q3_3;
set cons_lo_2012Q3_2;
if ta=. then delete;
run;
/*Add 2012Q3 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2012Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2012Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2012Q3_4;
set cons_lo_2012Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2012Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20120930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2012Q3_4, outset=cons_lo_2012Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2012Q3_5, outset=cons_lo_2012Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2012Q3_6, outset=cons_lo_2012Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2012Q3_7, outset=cons_lo_2012Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2012Q3_8, outset=cons_lo_2012Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2012Q3_9, outset=cons_lo_2012Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2012Q3_10, outset=cons_lo_2012Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2012Q3_11, outset=cons_lo_2012Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2012Q3_12, outset=cons_lo_2012Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2012Q3_13, outset=cons_lo_2012Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2012Q3_14, outset=cons_lo_2012Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2012Q3_15, outset=cons_lo_2012Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2012Q3_16, outset=cons_lo_2012Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2012Q3_17, outset=cons_lo_2012Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2012Q3_18, outset=cons_lo_2012Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2012Q3_19, outset=cons_lo_2012Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2012Q3_20, outset=cons_lo_2012Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2012Q3_21, outset=cons_lo_2012Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2012Q3_22, outset=cons_lo_2012Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2012Q3_23, outset=cons_lo_2012Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2012Q3_24, outset=cons_lo_2012Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2012Q3_25, outset=cons_lo_2012Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2012Q3_26, outset=cons_lo_2012Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2012Q3_27, outset=cons_lo_2012Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2012Q3_28, outset=cons_lo_2012Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2012Q3_29, outset=cons_lo_2012Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2012Q3_30, outset=cons_lo_2012Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2012Q3_31, outset=cons_lo_2012Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2012Q3_32, outset=cons_lo_2012Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2012Q3_33, outset=cons_lo_2012Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2012Q3_34, outset=cons_lo_2012Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2012Q3_35, outset=cons_lo_2012Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2012Q3_36, outset=cons_lo_2012Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2012Q3_37, outset=cons_lo_2012Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2012Q3_38, outset=cons_lo_2012Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2012Q3_39, outset=cons_lo_2012Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2012Q3_40, outset=cons_lo_2012Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2012Q3_41, outset=cons_lo_2012Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2012Q3_42, outset=cons_lo_2012Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2012Q3;
set cons_lo_2012Q3_43;
run;


/*2012Q2 Q4 Consumer Originations Plus Lags*/
data cons_lo_2012Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 90 then delete;
run;
proc sql;
create table cons_lo_2012Q2_2 as select a.*, b.ta
from cons_lo_2012Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2012Q2_3;
set cons_lo_2012Q2_2;
if ta=. then delete;
run;
/*Add 2012Q2 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2012Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2012Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2012Q2_4;
set cons_lo_2012Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2012Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20120630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2012Q2_4, outset=cons_lo_2012Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2012Q2_5, outset=cons_lo_2012Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2012Q2_6, outset=cons_lo_2012Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2012Q2_7, outset=cons_lo_2012Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2012Q2_8, outset=cons_lo_2012Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2012Q2_9, outset=cons_lo_2012Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2012Q2_10, outset=cons_lo_2012Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2012Q2_11, outset=cons_lo_2012Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2012Q2_12, outset=cons_lo_2012Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2012Q2_13, outset=cons_lo_2012Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2012Q2_14, outset=cons_lo_2012Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2012Q2_15, outset=cons_lo_2012Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2012Q2_16, outset=cons_lo_2012Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2012Q2_17, outset=cons_lo_2012Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2012Q2_18, outset=cons_lo_2012Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2012Q2_19, outset=cons_lo_2012Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2012Q2_20, outset=cons_lo_2012Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2012Q2_21, outset=cons_lo_2012Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2012Q2_22, outset=cons_lo_2012Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2012Q2_23, outset=cons_lo_2012Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2012Q2_24, outset=cons_lo_2012Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2012Q2_25, outset=cons_lo_2012Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2012Q2_26, outset=cons_lo_2012Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2012Q2_27, outset=cons_lo_2012Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2012Q2_28, outset=cons_lo_2012Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2012Q2_29, outset=cons_lo_2012Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2012Q2_30, outset=cons_lo_2012Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2012Q2_31, outset=cons_lo_2012Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2012Q2_32, outset=cons_lo_2012Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2012Q2_33, outset=cons_lo_2012Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2012Q2_34, outset=cons_lo_2012Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2012Q2_35, outset=cons_lo_2012Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2012Q2_36, outset=cons_lo_2012Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2012Q2_37, outset=cons_lo_2012Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2012Q2_38, outset=cons_lo_2012Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2012Q2_39, outset=cons_lo_2012Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2012Q2_40, outset=cons_lo_2012Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2012Q2_41, outset=cons_lo_2012Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2012Q2_42, outset=cons_lo_2012Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2012Q2;
set cons_lo_2012Q2_43;
run;


/*2012Q1 Q1 Consumer Originations Plus Lags*/
data cons_lo_2012Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 89 then delete;
run;
proc sql;
create table cons_lo_2012Q1_2 as select a.*, b.ta
from cons_lo_2012Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2012Q1_3;
set cons_lo_2012Q1_2;
if ta=. then delete;
run;
/*Add 2012Q1 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2012Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2012Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2012Q1_4;
set cons_lo_2012Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2012Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20120331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2012Q1_4, outset=cons_lo_2012Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2012Q1_5, outset=cons_lo_2012Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2012Q1_6, outset=cons_lo_2012Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2012Q1_7, outset=cons_lo_2012Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2012Q1_8, outset=cons_lo_2012Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2012Q1_9, outset=cons_lo_2012Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2012Q1_10, outset=cons_lo_2012Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2012Q1_11, outset=cons_lo_2012Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2012Q1_12, outset=cons_lo_2012Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2012Q1_13, outset=cons_lo_2012Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2012Q1_14, outset=cons_lo_2012Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2012Q1_15, outset=cons_lo_2012Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2012Q1_16, outset=cons_lo_2012Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2012Q1_17, outset=cons_lo_2012Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2012Q1_18, outset=cons_lo_2012Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2012Q1_19, outset=cons_lo_2012Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2012Q1_20, outset=cons_lo_2012Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2012Q1_21, outset=cons_lo_2012Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2012Q1_22, outset=cons_lo_2012Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2012Q1_23, outset=cons_lo_2012Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2012Q1_24, outset=cons_lo_2012Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2012Q1_25, outset=cons_lo_2012Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2012Q1_26, outset=cons_lo_2012Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2012Q1_27, outset=cons_lo_2012Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2012Q1_28, outset=cons_lo_2012Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2012Q1_29, outset=cons_lo_2012Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2012Q1_30, outset=cons_lo_2012Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2012Q1_31, outset=cons_lo_2012Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2012Q1_32, outset=cons_lo_2012Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2012Q1_33, outset=cons_lo_2012Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2012Q1_34, outset=cons_lo_2012Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2012Q1_35, outset=cons_lo_2012Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2012Q1_36, outset=cons_lo_2012Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2012Q1_37, outset=cons_lo_2012Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2012Q1_38, outset=cons_lo_2012Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2012Q1_39, outset=cons_lo_2012Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2012Q1_40, outset=cons_lo_2012Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2012Q1_41, outset=cons_lo_2012Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2012Q1_42, outset=cons_lo_2012Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2012Q1;
set cons_lo_2012Q1_43;
run;

/*2011*/

/*2011 Q4 Consumer Originations Plus Lags*/
data cons_lo_2011Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 88 then delete;
run;
proc sql;
create table cons_lo_2011Q4_2 as select a.*, b.ta
from cons_lo_2011Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2011Q4_3;
set cons_lo_2011Q4_2;
if ta=. then delete;
run;
/*Add 2011 Consumer loan originations*/
proc sql;
create table cons_lo_2011Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2011Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2011Q4_4;
set cons_lo_2011Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20111231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2011Q4_4, outset=cons_lo_2011Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2011Q4_5, outset=cons_lo_2011Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2011Q4_6, outset=cons_lo_2011Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2011Q4_7, outset=cons_lo_2011Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2011Q4_8, outset=cons_lo_2011Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2011Q4_9, outset=cons_lo_2011Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2011Q4_10, outset=cons_lo_2011Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2011Q4_11, outset=cons_lo_2011Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2011Q4_12, outset=cons_lo_2011Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2011Q4_13, outset=cons_lo_2011Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2011Q4_14, outset=cons_lo_2011Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2011Q4_15, outset=cons_lo_2011Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2011Q4_16, outset=cons_lo_2011Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2011Q4_17, outset=cons_lo_2011Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2011Q4_18, outset=cons_lo_2011Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2011Q4_19, outset=cons_lo_2011Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2011Q4_20, outset=cons_lo_2011Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2011Q4_21, outset=cons_lo_2011Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2011Q4_22, outset=cons_lo_2011Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2011Q4_23, outset=cons_lo_2011Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2011Q4_24, outset=cons_lo_2011Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2011Q4_25, outset=cons_lo_2011Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2011Q4_26, outset=cons_lo_2011Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2011Q4_27, outset=cons_lo_2011Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2011Q4_28, outset=cons_lo_2011Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2011Q4_29, outset=cons_lo_2011Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2011Q4_30, outset=cons_lo_2011Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2011Q4_31, outset=cons_lo_2011Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2011Q4_32, outset=cons_lo_2011Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2011Q4_33, outset=cons_lo_2011Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2011Q4_34, outset=cons_lo_2011Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2011Q4_35, outset=cons_lo_2011Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2011Q4_36, outset=cons_lo_2011Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2011Q4_37, outset=cons_lo_2011Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2011Q4_38, outset=cons_lo_2011Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2011Q4_39, outset=cons_lo_2011Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2011Q4_40, outset=cons_lo_2011Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2011Q4_41, outset=cons_lo_2011Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2011Q4_42, outset=cons_lo_2011Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2011Q4_43, outset=cons_lo_2011Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2011Q4;
set cons_lo_2011Q4_43;
run;


/*2011Q3 Consumer Originations Plus Lags*/
data cons_lo_2011Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 87 then delete;
run;
proc sql;
create table cons_lo_2011Q3_2 as select a.*, b.ta
from cons_lo_2011Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2011Q3_3;
set cons_lo_2011Q3_2;
if ta=. then delete;
run;
/*Add 2011Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2011Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2011Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2011Q3_4;
set cons_lo_2011Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2011Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20110930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2011Q3_4, outset=cons_lo_2011Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2011Q3_5, outset=cons_lo_2011Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2011Q3_6, outset=cons_lo_2011Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2011Q3_7, outset=cons_lo_2011Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2011Q3_8, outset=cons_lo_2011Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2011Q3_9, outset=cons_lo_2011Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2011Q3_10, outset=cons_lo_2011Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2011Q3_11, outset=cons_lo_2011Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2011Q3_12, outset=cons_lo_2011Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2011Q3_13, outset=cons_lo_2011Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2011Q3_14, outset=cons_lo_2011Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2011Q3_15, outset=cons_lo_2011Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2011Q3_16, outset=cons_lo_2011Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2011Q3_17, outset=cons_lo_2011Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2011Q3_18, outset=cons_lo_2011Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2011Q3_19, outset=cons_lo_2011Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2011Q3_20, outset=cons_lo_2011Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2011Q3_21, outset=cons_lo_2011Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2011Q3_22, outset=cons_lo_2011Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2011Q3_23, outset=cons_lo_2011Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2011Q3_24, outset=cons_lo_2011Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2011Q3_25, outset=cons_lo_2011Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2011Q3_26, outset=cons_lo_2011Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2011Q3_27, outset=cons_lo_2011Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2011Q3_28, outset=cons_lo_2011Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2011Q3_29, outset=cons_lo_2011Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2011Q3_30, outset=cons_lo_2011Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2011Q3_31, outset=cons_lo_2011Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2011Q3_32, outset=cons_lo_2011Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2011Q3_33, outset=cons_lo_2011Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2011Q3_34, outset=cons_lo_2011Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2011Q3_35, outset=cons_lo_2011Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2011Q3_36, outset=cons_lo_2011Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2011Q3_37, outset=cons_lo_2011Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2011Q3_38, outset=cons_lo_2011Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2011Q3_39, outset=cons_lo_2011Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2011Q3_40, outset=cons_lo_2011Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2011Q3_41, outset=cons_lo_2011Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2011Q3_42, outset=cons_lo_2011Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2011Q3;
set cons_lo_2011Q3_43;
run;


/*2011Q2 Consumer Originations Plus Lags*/
data cons_lo_2011Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 86 then delete;
run;
proc sql;
create table cons_lo_2011Q2_2 as select a.*, b.ta
from cons_lo_2011Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2011Q2_3;
set cons_lo_2011Q2_2;
if ta=. then delete;
run;
/*Add 2011Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2011Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2011Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2011Q2_4;
set cons_lo_2011Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2011Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20110630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2011Q2_4, outset=cons_lo_2011Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2011Q2_5, outset=cons_lo_2011Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2011Q2_6, outset=cons_lo_2011Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2011Q2_7, outset=cons_lo_2011Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2011Q2_8, outset=cons_lo_2011Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2011Q2_9, outset=cons_lo_2011Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2011Q2_10, outset=cons_lo_2011Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2011Q2_11, outset=cons_lo_2011Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2011Q2_12, outset=cons_lo_2011Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2011Q2_13, outset=cons_lo_2011Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2011Q2_14, outset=cons_lo_2011Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2011Q2_15, outset=cons_lo_2011Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2011Q2_16, outset=cons_lo_2011Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2011Q2_17, outset=cons_lo_2011Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2011Q2_18, outset=cons_lo_2011Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2011Q2_19, outset=cons_lo_2011Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2011Q2_20, outset=cons_lo_2011Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2011Q2_21, outset=cons_lo_2011Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2011Q2_22, outset=cons_lo_2011Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2011Q2_23, outset=cons_lo_2011Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2011Q2_24, outset=cons_lo_2011Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2011Q2_25, outset=cons_lo_2011Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2011Q2_26, outset=cons_lo_2011Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2011Q2_27, outset=cons_lo_2011Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2011Q2_28, outset=cons_lo_2011Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2011Q2_29, outset=cons_lo_2011Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2011Q2_30, outset=cons_lo_2011Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2011Q2_31, outset=cons_lo_2011Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2011Q2_32, outset=cons_lo_2011Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2011Q2_33, outset=cons_lo_2011Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2011Q2_34, outset=cons_lo_2011Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2011Q2_35, outset=cons_lo_2011Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2011Q2_36, outset=cons_lo_2011Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2011Q2_37, outset=cons_lo_2011Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2011Q2_38, outset=cons_lo_2011Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2011Q2_39, outset=cons_lo_2011Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2011Q2_40, outset=cons_lo_2011Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2011Q2_41, outset=cons_lo_2011Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2011Q2_42, outset=cons_lo_2011Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2011Q2;
set cons_lo_2011Q2_43;
run;


/*2011Q1 Q1 Consumer Originations Plus Lags*/
data cons_lo_2011Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 85 then delete;
run;
proc sql;
create table cons_lo_2011Q1_2 as select a.*, b.ta
from cons_lo_2011Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2011Q1_3;
set cons_lo_2011Q1_2;
if ta=. then delete;
run;
/*Add 2011Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2011Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2011Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2011Q1_4;
set cons_lo_2011Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2011Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20110331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2011Q1_4, outset=cons_lo_2011Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2011Q1_5, outset=cons_lo_2011Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2011Q1_6, outset=cons_lo_2011Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2011Q1_7, outset=cons_lo_2011Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2011Q1_8, outset=cons_lo_2011Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2011Q1_9, outset=cons_lo_2011Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2011Q1_10, outset=cons_lo_2011Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2011Q1_11, outset=cons_lo_2011Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2011Q1_12, outset=cons_lo_2011Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2011Q1_13, outset=cons_lo_2011Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2011Q1_14, outset=cons_lo_2011Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2011Q1_15, outset=cons_lo_2011Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2011Q1_16, outset=cons_lo_2011Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2011Q1_17, outset=cons_lo_2011Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2011Q1_18, outset=cons_lo_2011Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2011Q1_19, outset=cons_lo_2011Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2011Q1_20, outset=cons_lo_2011Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2011Q1_21, outset=cons_lo_2011Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2011Q1_22, outset=cons_lo_2011Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2011Q1_23, outset=cons_lo_2011Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2011Q1_24, outset=cons_lo_2011Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2011Q1_25, outset=cons_lo_2011Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2011Q1_26, outset=cons_lo_2011Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2011Q1_27, outset=cons_lo_2011Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2011Q1_28, outset=cons_lo_2011Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2011Q1_29, outset=cons_lo_2011Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2011Q1_30, outset=cons_lo_2011Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2011Q1_31, outset=cons_lo_2011Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2011Q1_32, outset=cons_lo_2011Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2011Q1_33, outset=cons_lo_2011Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2011Q1_34, outset=cons_lo_2011Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2011Q1_35, outset=cons_lo_2011Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2011Q1_36, outset=cons_lo_2011Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2011Q1_37, outset=cons_lo_2011Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2011Q1_38, outset=cons_lo_2011Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2011Q1_39, outset=cons_lo_2011Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2011Q1_40, outset=cons_lo_2011Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2011Q1_41, outset=cons_lo_2011Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2011Q1_42, outset=cons_lo_2011Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2011Q1;
set cons_lo_2011Q1_43;
run;

/*2010*/

/*2010 Q4 Consumer Originations Plus Lags*/
data cons_lo_2010Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 84 then delete;
run;
proc sql;
create table cons_lo_2010Q4_2 as select a.*, b.ta
from cons_lo_2010Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2010Q4_3;
set cons_lo_2010Q4_2;
if ta=. then delete;
run;
/*Add 2010 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2010Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2010Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2010Q4_4;
set cons_lo_2010Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20101231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2010Q4_4, outset=cons_lo_2010Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2010Q4_5, outset=cons_lo_2010Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2010Q4_6, outset=cons_lo_2010Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2010Q4_7, outset=cons_lo_2010Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2010Q4_8, outset=cons_lo_2010Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2010Q4_9, outset=cons_lo_2010Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2010Q4_10, outset=cons_lo_2010Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2010Q4_11, outset=cons_lo_2010Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2010Q4_12, outset=cons_lo_2010Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2010Q4_13, outset=cons_lo_2010Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2010Q4_14, outset=cons_lo_2010Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2010Q4_15, outset=cons_lo_2010Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2010Q4_16, outset=cons_lo_2010Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2010Q4_17, outset=cons_lo_2010Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2010Q4_18, outset=cons_lo_2010Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2010Q4_19, outset=cons_lo_2010Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2010Q4_20, outset=cons_lo_2010Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2010Q4_21, outset=cons_lo_2010Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2010Q4_22, outset=cons_lo_2010Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2010Q4_23, outset=cons_lo_2010Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2010Q4_24, outset=cons_lo_2010Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2010Q4_25, outset=cons_lo_2010Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2010Q4_26, outset=cons_lo_2010Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2010Q4_27, outset=cons_lo_2010Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2010Q4_28, outset=cons_lo_2010Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2010Q4_29, outset=cons_lo_2010Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2010Q4_30, outset=cons_lo_2010Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2010Q4_31, outset=cons_lo_2010Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2010Q4_32, outset=cons_lo_2010Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2010Q4_33, outset=cons_lo_2010Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2010Q4_34, outset=cons_lo_2010Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2010Q4_35, outset=cons_lo_2010Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2010Q4_36, outset=cons_lo_2010Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2010Q4_37, outset=cons_lo_2010Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2010Q4_38, outset=cons_lo_2010Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2010Q4_39, outset=cons_lo_2010Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2010Q4_40, outset=cons_lo_2010Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2010Q4_41, outset=cons_lo_2010Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2010Q4_42, outset=cons_lo_2010Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2010Q4_43, outset=cons_lo_2010Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2010Q4;
set cons_lo_2010Q4_43;
run;


/*2010Q3 Consumer Originations Plus Lags*/
data cons_lo_2010Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 83 then delete;
run;
proc sql;
create table cons_lo_2010Q3_2 as select a.*, b.ta
from cons_lo_2010Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2010Q3_3;
set cons_lo_2010Q3_2;
if ta=. then delete;
run;
/*Add 2010Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2010Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2010Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2010Q3_4;
set cons_lo_2010Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2010Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20100930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2010Q3_4, outset=cons_lo_2010Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2010Q3_5, outset=cons_lo_2010Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2010Q3_6, outset=cons_lo_2010Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2010Q3_7, outset=cons_lo_2010Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2010Q3_8, outset=cons_lo_2010Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2010Q3_9, outset=cons_lo_2010Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2010Q3_10, outset=cons_lo_2010Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2010Q3_11, outset=cons_lo_2010Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2010Q3_12, outset=cons_lo_2010Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2010Q3_13, outset=cons_lo_2010Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2010Q3_14, outset=cons_lo_2010Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2010Q3_15, outset=cons_lo_2010Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2010Q3_16, outset=cons_lo_2010Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2010Q3_17, outset=cons_lo_2010Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2010Q3_18, outset=cons_lo_2010Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2010Q3_19, outset=cons_lo_2010Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2010Q3_20, outset=cons_lo_2010Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2010Q3_21, outset=cons_lo_2010Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2010Q3_22, outset=cons_lo_2010Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2010Q3_23, outset=cons_lo_2010Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2010Q3_24, outset=cons_lo_2010Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2010Q3_25, outset=cons_lo_2010Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2010Q3_26, outset=cons_lo_2010Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2010Q3_27, outset=cons_lo_2010Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2010Q3_28, outset=cons_lo_2010Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2010Q3_29, outset=cons_lo_2010Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2010Q3_30, outset=cons_lo_2010Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2010Q3_31, outset=cons_lo_2010Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2010Q3_32, outset=cons_lo_2010Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2010Q3_33, outset=cons_lo_2010Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2010Q3_34, outset=cons_lo_2010Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2010Q3_35, outset=cons_lo_2010Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2010Q3_36, outset=cons_lo_2010Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2010Q3_37, outset=cons_lo_2010Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2010Q3_38, outset=cons_lo_2010Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2010Q3_39, outset=cons_lo_2010Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2010Q3_40, outset=cons_lo_2010Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2010Q3_41, outset=cons_lo_2010Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2010Q3_42, outset=cons_lo_2010Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2010Q3;
set cons_lo_2010Q3_43;
run;


/*2010Q2 Consumer Originations Plus Lags*/
data cons_lo_2010Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 82 then delete;
run;
proc sql;
create table cons_lo_2010Q2_2 as select a.*, b.ta
from cons_lo_2010Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2010Q2_3;
set cons_lo_2010Q2_2;
if ta=. then delete;
run;
/*Add 2010Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2010Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2010Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2010Q2_4;
set cons_lo_2010Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2010Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20100630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2010Q2_4, outset=cons_lo_2010Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2010Q2_5, outset=cons_lo_2010Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2010Q2_6, outset=cons_lo_2010Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2010Q2_7, outset=cons_lo_2010Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2010Q2_8, outset=cons_lo_2010Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2010Q2_9, outset=cons_lo_2010Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2010Q2_10, outset=cons_lo_2010Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2010Q2_11, outset=cons_lo_2010Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2010Q2_12, outset=cons_lo_2010Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2010Q2_13, outset=cons_lo_2010Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2010Q2_14, outset=cons_lo_2010Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2010Q2_15, outset=cons_lo_2010Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2010Q2_16, outset=cons_lo_2010Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2010Q2_17, outset=cons_lo_2010Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2010Q2_18, outset=cons_lo_2010Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2010Q2_19, outset=cons_lo_2010Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2010Q2_20, outset=cons_lo_2010Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2010Q2_21, outset=cons_lo_2010Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2010Q2_22, outset=cons_lo_2010Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2010Q2_23, outset=cons_lo_2010Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2010Q2_24, outset=cons_lo_2010Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2010Q2_25, outset=cons_lo_2010Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2010Q2_26, outset=cons_lo_2010Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2010Q2_27, outset=cons_lo_2010Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2010Q2_28, outset=cons_lo_2010Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2010Q2_29, outset=cons_lo_2010Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2010Q2_30, outset=cons_lo_2010Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2010Q2_31, outset=cons_lo_2010Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2010Q2_32, outset=cons_lo_2010Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2010Q2_33, outset=cons_lo_2010Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2010Q2_34, outset=cons_lo_2010Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2010Q2_35, outset=cons_lo_2010Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2010Q2_36, outset=cons_lo_2010Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2010Q2_37, outset=cons_lo_2010Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2010Q2_38, outset=cons_lo_2010Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2010Q2_39, outset=cons_lo_2010Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2010Q2_40, outset=cons_lo_2010Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2010Q2_41, outset=cons_lo_2010Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2010Q2_42, outset=cons_lo_2010Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2010Q2;
set cons_lo_2010Q2_43;
run;


/*2010Q1 Consumer Originations Plus Lags*/
data cons_lo_2010Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 81 then delete;
run;
proc sql;
create table cons_lo_2010Q1_2 as select a.*, b.ta
from cons_lo_2010Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2010Q1_3;
set cons_lo_2010Q1_2;
if ta=. then delete;
run;
/*Add 2010Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2010Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2010Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2010Q1_4;
set cons_lo_2010Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2010Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20100331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2010Q1_4, outset=cons_lo_2010Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2010Q1_5, outset=cons_lo_2010Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2010Q1_6, outset=cons_lo_2010Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2010Q1_7, outset=cons_lo_2010Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2010Q1_8, outset=cons_lo_2010Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2010Q1_9, outset=cons_lo_2010Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2010Q1_10, outset=cons_lo_2010Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2010Q1_11, outset=cons_lo_2010Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2010Q1_12, outset=cons_lo_2010Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2010Q1_13, outset=cons_lo_2010Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2010Q1_14, outset=cons_lo_2010Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2010Q1_15, outset=cons_lo_2010Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2010Q1_16, outset=cons_lo_2010Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2010Q1_17, outset=cons_lo_2010Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2010Q1_18, outset=cons_lo_2010Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2010Q1_19, outset=cons_lo_2010Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2010Q1_20, outset=cons_lo_2010Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2010Q1_21, outset=cons_lo_2010Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2010Q1_22, outset=cons_lo_2010Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2010Q1_23, outset=cons_lo_2010Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2010Q1_24, outset=cons_lo_2010Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2010Q1_25, outset=cons_lo_2010Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2010Q1_26, outset=cons_lo_2010Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2010Q1_27, outset=cons_lo_2010Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2010Q1_28, outset=cons_lo_2010Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2010Q1_29, outset=cons_lo_2010Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2010Q1_30, outset=cons_lo_2010Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2010Q1_31, outset=cons_lo_2010Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2010Q1_32, outset=cons_lo_2010Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2010Q1_33, outset=cons_lo_2010Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2010Q1_34, outset=cons_lo_2010Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2010Q1_35, outset=cons_lo_2010Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2010Q1_36, outset=cons_lo_2010Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2010Q1_37, outset=cons_lo_2010Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2010Q1_38, outset=cons_lo_2010Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2010Q1_39, outset=cons_lo_2010Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2010Q1_40, outset=cons_lo_2010Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2010Q1_41, outset=cons_lo_2010Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2010Q1_42, outset=cons_lo_2010Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2010Q1;
set cons_lo_2010Q1_43;
run;

/*2009*/

/*2009 Q4 Consumer Originations Plus Lags*/
data cons_lo_2009Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 80 then delete;
run;
proc sql;
create table cons_lo_2009Q4_2 as select a.*, b.ta
from cons_lo_2009Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2009Q4_3;
set cons_lo_2009Q4_2;
if ta=. then delete;
run;
/*Add 2009 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2009Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2009Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2009Q4_4;
set cons_lo_2009Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20091231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2009Q4_4, outset=cons_lo_2009Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2009Q4_5, outset=cons_lo_2009Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2009Q4_6, outset=cons_lo_2009Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2009Q4_7, outset=cons_lo_2009Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2009Q4_8, outset=cons_lo_2009Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2009Q4_9, outset=cons_lo_2009Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2009Q4_10, outset=cons_lo_2009Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2009Q4_11, outset=cons_lo_2009Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2009Q4_12, outset=cons_lo_2009Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2009Q4_13, outset=cons_lo_2009Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2009Q4_14, outset=cons_lo_2009Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2009Q4_15, outset=cons_lo_2009Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2009Q4_16, outset=cons_lo_2009Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2009Q4_17, outset=cons_lo_2009Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2009Q4_18, outset=cons_lo_2009Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2009Q4_19, outset=cons_lo_2009Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2009Q4_20, outset=cons_lo_2009Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2009Q4_21, outset=cons_lo_2009Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2009Q4_22, outset=cons_lo_2009Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2009Q4_23, outset=cons_lo_2009Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2009Q4_24, outset=cons_lo_2009Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2009Q4_25, outset=cons_lo_2009Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2009Q4_26, outset=cons_lo_2009Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2009Q4_27, outset=cons_lo_2009Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2009Q4_28, outset=cons_lo_2009Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2009Q4_29, outset=cons_lo_2009Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2009Q4_30, outset=cons_lo_2009Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2009Q4_31, outset=cons_lo_2009Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2009Q4_32, outset=cons_lo_2009Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2009Q4_33, outset=cons_lo_2009Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2009Q4_34, outset=cons_lo_2009Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2009Q4_35, outset=cons_lo_2009Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2009Q4_36, outset=cons_lo_2009Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2009Q4_37, outset=cons_lo_2009Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2009Q4_38, outset=cons_lo_2009Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2009Q4_39, outset=cons_lo_2009Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2009Q4_40, outset=cons_lo_2009Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2009Q4_41, outset=cons_lo_2009Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2009Q4_42, outset=cons_lo_2009Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2009Q4_43, outset=cons_lo_2009Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2009Q4;
set cons_lo_2009Q4_43;
run;


/*2009Q3 Consumer Originations Plus Lags*/
data cons_lo_2009Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 79 then delete;
run;
proc sql;
create table cons_lo_2009Q3_2 as select a.*, b.ta
from cons_lo_2009Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2009Q3_3;
set cons_lo_2009Q3_2;
if ta=. then delete;
run;
/*Add 2009Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2009Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2009Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2009Q3_4;
set cons_lo_2009Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2009Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20090930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2009Q3_4, outset=cons_lo_2009Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2009Q3_5, outset=cons_lo_2009Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2009Q3_6, outset=cons_lo_2009Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2009Q3_7, outset=cons_lo_2009Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2009Q3_8, outset=cons_lo_2009Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2009Q3_9, outset=cons_lo_2009Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2009Q3_10, outset=cons_lo_2009Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2009Q3_11, outset=cons_lo_2009Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2009Q3_12, outset=cons_lo_2009Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2009Q3_13, outset=cons_lo_2009Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2009Q3_14, outset=cons_lo_2009Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2009Q3_15, outset=cons_lo_2009Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2009Q3_16, outset=cons_lo_2009Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2009Q3_17, outset=cons_lo_2009Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2009Q3_18, outset=cons_lo_2009Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2009Q3_19, outset=cons_lo_2009Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2009Q3_20, outset=cons_lo_2009Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2009Q3_21, outset=cons_lo_2009Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2009Q3_22, outset=cons_lo_2009Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2009Q3_23, outset=cons_lo_2009Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2009Q3_24, outset=cons_lo_2009Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2009Q3_25, outset=cons_lo_2009Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2009Q3_26, outset=cons_lo_2009Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2009Q3_27, outset=cons_lo_2009Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2009Q3_28, outset=cons_lo_2009Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2009Q3_29, outset=cons_lo_2009Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2009Q3_30, outset=cons_lo_2009Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2009Q3_31, outset=cons_lo_2009Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2009Q3_32, outset=cons_lo_2009Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2009Q3_33, outset=cons_lo_2009Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2009Q3_34, outset=cons_lo_2009Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2009Q3_35, outset=cons_lo_2009Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2009Q3_36, outset=cons_lo_2009Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2009Q3_37, outset=cons_lo_2009Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2009Q3_38, outset=cons_lo_2009Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2009Q3_39, outset=cons_lo_2009Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2009Q3_40, outset=cons_lo_2009Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2009Q3_41, outset=cons_lo_2009Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2009Q3_42, outset=cons_lo_2009Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2009Q3;
set cons_lo_2009Q3_43;
run;


/*2009Q2 Consumer Originations Plus Lags*/
data cons_lo_2009Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 78 then delete;
run;
proc sql;
create table cons_lo_2009Q2_2 as select a.*, b.ta
from cons_lo_2009Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2009Q2_3;
set cons_lo_2009Q2_2;
if ta=. then delete;
run;
/*Add 2009Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2009Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2009Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2009Q2_4;
set cons_lo_2009Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2009Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20090630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2009Q2_4, outset=cons_lo_2009Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2009Q2_5, outset=cons_lo_2009Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2009Q2_6, outset=cons_lo_2009Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2009Q2_7, outset=cons_lo_2009Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2009Q2_8, outset=cons_lo_2009Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2009Q2_9, outset=cons_lo_2009Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2009Q2_10, outset=cons_lo_2009Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2009Q2_11, outset=cons_lo_2009Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2009Q2_12, outset=cons_lo_2009Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2009Q2_13, outset=cons_lo_2009Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2009Q2_14, outset=cons_lo_2009Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2009Q2_15, outset=cons_lo_2009Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2009Q2_16, outset=cons_lo_2009Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2009Q2_17, outset=cons_lo_2009Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2009Q2_18, outset=cons_lo_2009Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2009Q2_19, outset=cons_lo_2009Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2009Q2_20, outset=cons_lo_2009Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2009Q2_21, outset=cons_lo_2009Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2009Q2_22, outset=cons_lo_2009Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2009Q2_23, outset=cons_lo_2009Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2009Q2_24, outset=cons_lo_2009Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2009Q2_25, outset=cons_lo_2009Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2009Q2_26, outset=cons_lo_2009Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2009Q2_27, outset=cons_lo_2009Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2009Q2_28, outset=cons_lo_2009Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2009Q2_29, outset=cons_lo_2009Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2009Q2_30, outset=cons_lo_2009Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2009Q2_31, outset=cons_lo_2009Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2009Q2_32, outset=cons_lo_2009Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2009Q2_33, outset=cons_lo_2009Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2009Q2_34, outset=cons_lo_2009Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2009Q2_35, outset=cons_lo_2009Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2009Q2_36, outset=cons_lo_2009Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2009Q2_37, outset=cons_lo_2009Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2009Q2_38, outset=cons_lo_2009Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2009Q2_39, outset=cons_lo_2009Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2009Q2_40, outset=cons_lo_2009Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2009Q2_41, outset=cons_lo_2009Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2009Q2_42, outset=cons_lo_2009Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2009Q2;
set cons_lo_2009Q2_43;
run;


/*2009Q1 Consumer Originations Plus Lags*/
data cons_lo_2009Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 77 then delete;
run;
proc sql;
create table cons_lo_2009Q1_2 as select a.*, b.ta
from cons_lo_2009Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2009Q1_3;
set cons_lo_2009Q1_2;
if ta=. then delete;
run;
/*Add 2009Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2009Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2009Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2009Q1_4;
set cons_lo_2009Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2009Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20090331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2009Q1_4, outset=cons_lo_2009Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2009Q1_5, outset=cons_lo_2009Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2009Q1_6, outset=cons_lo_2009Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2009Q1_7, outset=cons_lo_2009Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2009Q1_8, outset=cons_lo_2009Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2009Q1_9, outset=cons_lo_2009Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2009Q1_10, outset=cons_lo_2009Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2009Q1_11, outset=cons_lo_2009Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2009Q1_12, outset=cons_lo_2009Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2009Q1_13, outset=cons_lo_2009Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2009Q1_14, outset=cons_lo_2009Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2009Q1_15, outset=cons_lo_2009Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2009Q1_16, outset=cons_lo_2009Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2009Q1_17, outset=cons_lo_2009Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2009Q1_18, outset=cons_lo_2009Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2009Q1_19, outset=cons_lo_2009Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2009Q1_20, outset=cons_lo_2009Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2009Q1_21, outset=cons_lo_2009Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2009Q1_22, outset=cons_lo_2009Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2009Q1_23, outset=cons_lo_2009Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2009Q1_24, outset=cons_lo_2009Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2009Q1_25, outset=cons_lo_2009Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2009Q1_26, outset=cons_lo_2009Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2009Q1_27, outset=cons_lo_2009Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2009Q1_28, outset=cons_lo_2009Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2009Q1_29, outset=cons_lo_2009Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2009Q1_30, outset=cons_lo_2009Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2009Q1_31, outset=cons_lo_2009Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2009Q1_32, outset=cons_lo_2009Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2009Q1_33, outset=cons_lo_2009Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2009Q1_34, outset=cons_lo_2009Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2009Q1_35, outset=cons_lo_2009Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2009Q1_36, outset=cons_lo_2009Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2009Q1_37, outset=cons_lo_2009Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2009Q1_38, outset=cons_lo_2009Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2009Q1_39, outset=cons_lo_2009Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2009Q1_40, outset=cons_lo_2009Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2009Q1_41, outset=cons_lo_2009Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2009Q1_42, outset=cons_lo_2009Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2009Q1;
set cons_lo_2009Q1_43;
run;

/*2008*/

/*2008 Q4 Consumer Originations Plus Lags*/
data cons_lo_2008Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 76 then delete;
run;
proc sql;
create table cons_lo_2008Q4_2 as select a.*, b.ta
from cons_lo_2008Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2008Q4_3;
set cons_lo_2008Q4_2;
if ta=. then delete;
run;
/*Add 2008 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2008Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2008Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2008Q4_4;
set cons_lo_2008Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20081231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2008Q4_4, outset=cons_lo_2008Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2008Q4_5, outset=cons_lo_2008Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2008Q4_6, outset=cons_lo_2008Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2008Q4_7, outset=cons_lo_2008Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2008Q4_8, outset=cons_lo_2008Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2008Q4_9, outset=cons_lo_2008Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2008Q4_10, outset=cons_lo_2008Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2008Q4_11, outset=cons_lo_2008Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2008Q4_12, outset=cons_lo_2008Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2008Q4_13, outset=cons_lo_2008Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2008Q4_14, outset=cons_lo_2008Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2008Q4_15, outset=cons_lo_2008Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2008Q4_16, outset=cons_lo_2008Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2008Q4_17, outset=cons_lo_2008Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2008Q4_18, outset=cons_lo_2008Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2008Q4_19, outset=cons_lo_2008Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2008Q4_20, outset=cons_lo_2008Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2008Q4_21, outset=cons_lo_2008Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2008Q4_22, outset=cons_lo_2008Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2008Q4_23, outset=cons_lo_2008Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2008Q4_24, outset=cons_lo_2008Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2008Q4_25, outset=cons_lo_2008Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2008Q4_26, outset=cons_lo_2008Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2008Q4_27, outset=cons_lo_2008Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2008Q4_28, outset=cons_lo_2008Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2008Q4_29, outset=cons_lo_2008Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2008Q4_30, outset=cons_lo_2008Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2008Q4_31, outset=cons_lo_2008Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2008Q4_32, outset=cons_lo_2008Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2008Q4_33, outset=cons_lo_2008Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2008Q4_34, outset=cons_lo_2008Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2008Q4_35, outset=cons_lo_2008Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2008Q4_36, outset=cons_lo_2008Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2008Q4_37, outset=cons_lo_2008Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2008Q4_38, outset=cons_lo_2008Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2008Q4_39, outset=cons_lo_2008Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2008Q4_40, outset=cons_lo_2008Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2008Q4_41, outset=cons_lo_2008Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2008Q4_42, outset=cons_lo_2008Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2008Q4_43, outset=cons_lo_2008Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2008Q4;
set cons_lo_2008Q4_43;
run;


/*2008Q3 Consumer Originations Plus Lags*/
data cons_lo_2008Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 75 then delete;
run;
proc sql;
create table cons_lo_2008Q3_2 as select a.*, b.ta
from cons_lo_2008Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2008Q3_3;
set cons_lo_2008Q3_2;
if ta=. then delete;
run;
/*Add 2008Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2008Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2008Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2008Q3_4;
set cons_lo_2008Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2008Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20080930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2008Q3_4, outset=cons_lo_2008Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2008Q3_5, outset=cons_lo_2008Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2008Q3_6, outset=cons_lo_2008Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2008Q3_7, outset=cons_lo_2008Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2008Q3_8, outset=cons_lo_2008Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2008Q3_9, outset=cons_lo_2008Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2008Q3_10, outset=cons_lo_2008Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2008Q3_11, outset=cons_lo_2008Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2008Q3_12, outset=cons_lo_2008Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2008Q3_13, outset=cons_lo_2008Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2008Q3_14, outset=cons_lo_2008Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2008Q3_15, outset=cons_lo_2008Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2008Q3_16, outset=cons_lo_2008Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2008Q3_17, outset=cons_lo_2008Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2008Q3_18, outset=cons_lo_2008Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2008Q3_19, outset=cons_lo_2008Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2008Q3_20, outset=cons_lo_2008Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2008Q3_21, outset=cons_lo_2008Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2008Q3_22, outset=cons_lo_2008Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2008Q3_23, outset=cons_lo_2008Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2008Q3_24, outset=cons_lo_2008Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2008Q3_25, outset=cons_lo_2008Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2008Q3_26, outset=cons_lo_2008Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2008Q3_27, outset=cons_lo_2008Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2008Q3_28, outset=cons_lo_2008Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2008Q3_29, outset=cons_lo_2008Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2008Q3_30, outset=cons_lo_2008Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2008Q3_31, outset=cons_lo_2008Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2008Q3_32, outset=cons_lo_2008Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2008Q3_33, outset=cons_lo_2008Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2008Q3_34, outset=cons_lo_2008Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2008Q3_35, outset=cons_lo_2008Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2008Q3_36, outset=cons_lo_2008Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2008Q3_37, outset=cons_lo_2008Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2008Q3_38, outset=cons_lo_2008Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2008Q3_39, outset=cons_lo_2008Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2008Q3_40, outset=cons_lo_2008Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2008Q3_41, outset=cons_lo_2008Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2008Q3_42, outset=cons_lo_2008Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2008Q3;
set cons_lo_2008Q3_43;
run;


/*2008Q2 Consumer Originations Plus Lags*/
data cons_lo_2008Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 74 then delete;
run;
proc sql;
create table cons_lo_2008Q2_2 as select a.*, b.ta
from cons_lo_2008Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2008Q2_3;
set cons_lo_2008Q2_2;
if ta=. then delete;
run;
/*Add 2008Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2008Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2008Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2008Q2_4;
set cons_lo_2008Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2008Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20080630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2008Q2_4, outset=cons_lo_2008Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2008Q2_5, outset=cons_lo_2008Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2008Q2_6, outset=cons_lo_2008Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2008Q2_7, outset=cons_lo_2008Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2008Q2_8, outset=cons_lo_2008Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2008Q2_9, outset=cons_lo_2008Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2008Q2_10, outset=cons_lo_2008Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2008Q2_11, outset=cons_lo_2008Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2008Q2_12, outset=cons_lo_2008Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2008Q2_13, outset=cons_lo_2008Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2008Q2_14, outset=cons_lo_2008Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2008Q2_15, outset=cons_lo_2008Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2008Q2_16, outset=cons_lo_2008Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2008Q2_17, outset=cons_lo_2008Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2008Q2_18, outset=cons_lo_2008Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2008Q2_19, outset=cons_lo_2008Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2008Q2_20, outset=cons_lo_2008Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2008Q2_21, outset=cons_lo_2008Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2008Q2_22, outset=cons_lo_2008Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2008Q2_23, outset=cons_lo_2008Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2008Q2_24, outset=cons_lo_2008Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2008Q2_25, outset=cons_lo_2008Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2008Q2_26, outset=cons_lo_2008Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2008Q2_27, outset=cons_lo_2008Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2008Q2_28, outset=cons_lo_2008Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2008Q2_29, outset=cons_lo_2008Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2008Q2_30, outset=cons_lo_2008Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2008Q2_31, outset=cons_lo_2008Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2008Q2_32, outset=cons_lo_2008Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2008Q2_33, outset=cons_lo_2008Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2008Q2_34, outset=cons_lo_2008Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2008Q2_35, outset=cons_lo_2008Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2008Q2_36, outset=cons_lo_2008Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2008Q2_37, outset=cons_lo_2008Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2008Q2_38, outset=cons_lo_2008Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2008Q2_39, outset=cons_lo_2008Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2008Q2_40, outset=cons_lo_2008Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2008Q2_41, outset=cons_lo_2008Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2008Q2_42, outset=cons_lo_2008Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2008Q2;
set cons_lo_2008Q2_43;
run;


/*2008Q1 Consumer Originations Plus Lags*/
data cons_lo_2008Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 73 then delete;
run;
proc sql;
create table cons_lo_2008Q1_2 as select a.*, b.ta
from cons_lo_2008Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2008Q1_3;
set cons_lo_2008Q1_2;
if ta=. then delete;
run;
/*Add 2008Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2008Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2008Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2008Q1_4;
set cons_lo_2008Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2008Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20080331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2008Q1_4, outset=cons_lo_2008Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2008Q1_5, outset=cons_lo_2008Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2008Q1_6, outset=cons_lo_2008Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2008Q1_7, outset=cons_lo_2008Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2008Q1_8, outset=cons_lo_2008Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2008Q1_9, outset=cons_lo_2008Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2008Q1_10, outset=cons_lo_2008Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2008Q1_11, outset=cons_lo_2008Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2008Q1_12, outset=cons_lo_2008Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2008Q1_13, outset=cons_lo_2008Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2008Q1_14, outset=cons_lo_2008Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2008Q1_15, outset=cons_lo_2008Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2008Q1_16, outset=cons_lo_2008Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2008Q1_17, outset=cons_lo_2008Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2008Q1_18, outset=cons_lo_2008Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2008Q1_19, outset=cons_lo_2008Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2008Q1_20, outset=cons_lo_2008Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2008Q1_21, outset=cons_lo_2008Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2008Q1_22, outset=cons_lo_2008Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2008Q1_23, outset=cons_lo_2008Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2008Q1_24, outset=cons_lo_2008Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2008Q1_25, outset=cons_lo_2008Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2008Q1_26, outset=cons_lo_2008Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2008Q1_27, outset=cons_lo_2008Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2008Q1_28, outset=cons_lo_2008Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2008Q1_29, outset=cons_lo_2008Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2008Q1_30, outset=cons_lo_2008Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2008Q1_31, outset=cons_lo_2008Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2008Q1_32, outset=cons_lo_2008Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2008Q1_33, outset=cons_lo_2008Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2008Q1_34, outset=cons_lo_2008Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2008Q1_35, outset=cons_lo_2008Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2008Q1_36, outset=cons_lo_2008Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2008Q1_37, outset=cons_lo_2008Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2008Q1_38, outset=cons_lo_2008Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2008Q1_39, outset=cons_lo_2008Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2008Q1_40, outset=cons_lo_2008Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2008Q1_41, outset=cons_lo_2008Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2008Q1_42, outset=cons_lo_2008Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2008Q1;
set cons_lo_2008Q1_43;
run;

/*2007*/

/*2007 Q4 Consumer Originations Plus Lags*/
data cons_lo_2007Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 72 then delete;
run;
proc sql;
create table cons_lo_2007Q4_2 as select a.*, b.ta
from cons_lo_2007Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2007Q4_3;
set cons_lo_2007Q4_2;
if ta=. then delete;
run;
/*Add 2007 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2007Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2007Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2007Q4_4;
set cons_lo_2007Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20071231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2007Q4_4, outset=cons_lo_2007Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2007Q4_5, outset=cons_lo_2007Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2007Q4_6, outset=cons_lo_2007Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2007Q4_7, outset=cons_lo_2007Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2007Q4_8, outset=cons_lo_2007Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2007Q4_9, outset=cons_lo_2007Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2007Q4_10, outset=cons_lo_2007Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2007Q4_11, outset=cons_lo_2007Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2007Q4_12, outset=cons_lo_2007Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2007Q4_13, outset=cons_lo_2007Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2007Q4_14, outset=cons_lo_2007Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2007Q4_15, outset=cons_lo_2007Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2007Q4_16, outset=cons_lo_2007Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2007Q4_17, outset=cons_lo_2007Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2007Q4_18, outset=cons_lo_2007Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2007Q4_19, outset=cons_lo_2007Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2007Q4_20, outset=cons_lo_2007Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2007Q4_21, outset=cons_lo_2007Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2007Q4_22, outset=cons_lo_2007Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2007Q4_23, outset=cons_lo_2007Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2007Q4_24, outset=cons_lo_2007Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2007Q4_25, outset=cons_lo_2007Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2007Q4_26, outset=cons_lo_2007Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2007Q4_27, outset=cons_lo_2007Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2007Q4_28, outset=cons_lo_2007Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2007Q4_29, outset=cons_lo_2007Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2007Q4_30, outset=cons_lo_2007Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2007Q4_31, outset=cons_lo_2007Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2007Q4_32, outset=cons_lo_2007Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2007Q4_33, outset=cons_lo_2007Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2007Q4_34, outset=cons_lo_2007Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2007Q4_35, outset=cons_lo_2007Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2007Q4_36, outset=cons_lo_2007Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2007Q4_37, outset=cons_lo_2007Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2007Q4_38, outset=cons_lo_2007Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2007Q4_39, outset=cons_lo_2007Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2007Q4_40, outset=cons_lo_2007Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2007Q4_41, outset=cons_lo_2007Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2007Q4_42, outset=cons_lo_2007Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2007Q4_43, outset=cons_lo_2007Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2007Q4;
set cons_lo_2007Q4_43;
run;


/*2007Q3 Consumer Originations Plus Lags*/
data cons_lo_2007Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 71 then delete;
run;
proc sql;
create table cons_lo_2007Q3_2 as select a.*, b.ta
from cons_lo_2007Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2007Q3_3;
set cons_lo_2007Q3_2;
if ta=. then delete;
run;
/*Add 2007Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2007Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2007Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2007Q3_4;
set cons_lo_2007Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2007Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20070930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2007Q3_4, outset=cons_lo_2007Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2007Q3_5, outset=cons_lo_2007Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2007Q3_6, outset=cons_lo_2007Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2007Q3_7, outset=cons_lo_2007Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2007Q3_8, outset=cons_lo_2007Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2007Q3_9, outset=cons_lo_2007Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2007Q3_10, outset=cons_lo_2007Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2007Q3_11, outset=cons_lo_2007Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2007Q3_12, outset=cons_lo_2007Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2007Q3_13, outset=cons_lo_2007Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2007Q3_14, outset=cons_lo_2007Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2007Q3_15, outset=cons_lo_2007Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2007Q3_16, outset=cons_lo_2007Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2007Q3_17, outset=cons_lo_2007Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2007Q3_18, outset=cons_lo_2007Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2007Q3_19, outset=cons_lo_2007Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2007Q3_20, outset=cons_lo_2007Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2007Q3_21, outset=cons_lo_2007Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2007Q3_22, outset=cons_lo_2007Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2007Q3_23, outset=cons_lo_2007Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2007Q3_24, outset=cons_lo_2007Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2007Q3_25, outset=cons_lo_2007Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2007Q3_26, outset=cons_lo_2007Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2007Q3_27, outset=cons_lo_2007Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2007Q3_28, outset=cons_lo_2007Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2007Q3_29, outset=cons_lo_2007Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2007Q3_30, outset=cons_lo_2007Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2007Q3_31, outset=cons_lo_2007Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2007Q3_32, outset=cons_lo_2007Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2007Q3_33, outset=cons_lo_2007Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2007Q3_34, outset=cons_lo_2007Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2007Q3_35, outset=cons_lo_2007Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2007Q3_36, outset=cons_lo_2007Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2007Q3_37, outset=cons_lo_2007Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2007Q3_38, outset=cons_lo_2007Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2007Q3_39, outset=cons_lo_2007Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2007Q3_40, outset=cons_lo_2007Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2007Q3_41, outset=cons_lo_2007Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2007Q3_42, outset=cons_lo_2007Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2007Q3;
set cons_lo_2007Q3_43;
run;


/*2007Q2 Consumer Originations Plus Lags*/
data cons_lo_2007Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 70 then delete;
run;
proc sql;
create table cons_lo_2007Q2_2 as select a.*, b.ta
from cons_lo_2007Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2007Q2_3;
set cons_lo_2007Q2_2;
if ta=. then delete;
run;
/*Add 2007Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2007Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2007Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2007Q2_4;
set cons_lo_2007Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2007Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20070630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2007Q2_4, outset=cons_lo_2007Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2007Q2_5, outset=cons_lo_2007Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2007Q2_6, outset=cons_lo_2007Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2007Q2_7, outset=cons_lo_2007Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2007Q2_8, outset=cons_lo_2007Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2007Q2_9, outset=cons_lo_2007Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2007Q2_10, outset=cons_lo_2007Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2007Q2_11, outset=cons_lo_2007Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2007Q2_12, outset=cons_lo_2007Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2007Q2_13, outset=cons_lo_2007Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2007Q2_14, outset=cons_lo_2007Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2007Q2_15, outset=cons_lo_2007Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2007Q2_16, outset=cons_lo_2007Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2007Q2_17, outset=cons_lo_2007Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2007Q2_18, outset=cons_lo_2007Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2007Q2_19, outset=cons_lo_2007Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2007Q2_20, outset=cons_lo_2007Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2007Q2_21, outset=cons_lo_2007Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2007Q2_22, outset=cons_lo_2007Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2007Q2_23, outset=cons_lo_2007Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2007Q2_24, outset=cons_lo_2007Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2007Q2_25, outset=cons_lo_2007Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2007Q2_26, outset=cons_lo_2007Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2007Q2_27, outset=cons_lo_2007Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2007Q2_28, outset=cons_lo_2007Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2007Q2_29, outset=cons_lo_2007Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2007Q2_30, outset=cons_lo_2007Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2007Q2_31, outset=cons_lo_2007Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2007Q2_32, outset=cons_lo_2007Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2007Q2_33, outset=cons_lo_2007Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2007Q2_34, outset=cons_lo_2007Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2007Q2_35, outset=cons_lo_2007Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2007Q2_36, outset=cons_lo_2007Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2007Q2_37, outset=cons_lo_2007Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2007Q2_38, outset=cons_lo_2007Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2007Q2_39, outset=cons_lo_2007Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2007Q2_40, outset=cons_lo_2007Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2007Q2_41, outset=cons_lo_2007Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2007Q2_42, outset=cons_lo_2007Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2007Q2;
set cons_lo_2007Q2_43;
run;


/*2007Q1 Consumer Originations Plus Lags*/
data cons_lo_2007Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 69 then delete;
run;
proc sql;
create table cons_lo_2007Q1_2 as select a.*, b.ta
from cons_lo_2007Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2007Q1_3;
set cons_lo_2007Q1_2;
if ta=. then delete;
run;
/*Add 2007Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2007Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2007Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2007Q1_4;
set cons_lo_2007Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2007Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20070331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2007Q1_4, outset=cons_lo_2007Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2007Q1_5, outset=cons_lo_2007Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2007Q1_6, outset=cons_lo_2007Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2007Q1_7, outset=cons_lo_2007Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2007Q1_8, outset=cons_lo_2007Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2007Q1_9, outset=cons_lo_2007Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2007Q1_10, outset=cons_lo_2007Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2007Q1_11, outset=cons_lo_2007Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2007Q1_12, outset=cons_lo_2007Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2007Q1_13, outset=cons_lo_2007Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2007Q1_14, outset=cons_lo_2007Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2007Q1_15, outset=cons_lo_2007Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2007Q1_16, outset=cons_lo_2007Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2007Q1_17, outset=cons_lo_2007Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2007Q1_18, outset=cons_lo_2007Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2007Q1_19, outset=cons_lo_2007Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2007Q1_20, outset=cons_lo_2007Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2007Q1_21, outset=cons_lo_2007Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2007Q1_22, outset=cons_lo_2007Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2007Q1_23, outset=cons_lo_2007Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2007Q1_24, outset=cons_lo_2007Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2007Q1_25, outset=cons_lo_2007Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2007Q1_26, outset=cons_lo_2007Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2007Q1_27, outset=cons_lo_2007Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2007Q1_28, outset=cons_lo_2007Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2007Q1_29, outset=cons_lo_2007Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2007Q1_30, outset=cons_lo_2007Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2007Q1_31, outset=cons_lo_2007Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2007Q1_32, outset=cons_lo_2007Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2007Q1_33, outset=cons_lo_2007Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2007Q1_34, outset=cons_lo_2007Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2007Q1_35, outset=cons_lo_2007Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2007Q1_36, outset=cons_lo_2007Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2007Q1_37, outset=cons_lo_2007Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2007Q1_38, outset=cons_lo_2007Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2007Q1_39, outset=cons_lo_2007Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2007Q1_40, outset=cons_lo_2007Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2007Q1_41, outset=cons_lo_2007Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2007Q1_42, outset=cons_lo_2007Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2007Q1;
set cons_lo_2007Q1_43;
run;

/*2006*/

/*2006 Q4 Consumer Originations Plus Lags*/
data cons_lo_2006Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 68 then delete;
run;
proc sql;
create table cons_lo_2006Q4_2 as select a.*, b.ta
from cons_lo_2006Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2006Q4_3;
set cons_lo_2006Q4_2;
if ta=. then delete;
run;
/*Add 2006 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2006Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2006Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2006Q4_4;
set cons_lo_2006Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20061231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2006Q4_4, outset=cons_lo_2006Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2006Q4_5, outset=cons_lo_2006Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2006Q4_6, outset=cons_lo_2006Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2006Q4_7, outset=cons_lo_2006Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2006Q4_8, outset=cons_lo_2006Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2006Q4_9, outset=cons_lo_2006Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2006Q4_10, outset=cons_lo_2006Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2006Q4_11, outset=cons_lo_2006Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2006Q4_12, outset=cons_lo_2006Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2006Q4_13, outset=cons_lo_2006Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2006Q4_14, outset=cons_lo_2006Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2006Q4_15, outset=cons_lo_2006Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2006Q4_16, outset=cons_lo_2006Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2006Q4_17, outset=cons_lo_2006Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2006Q4_18, outset=cons_lo_2006Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2006Q4_19, outset=cons_lo_2006Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2006Q4_20, outset=cons_lo_2006Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2006Q4_21, outset=cons_lo_2006Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2006Q4_22, outset=cons_lo_2006Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2006Q4_23, outset=cons_lo_2006Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2006Q4_24, outset=cons_lo_2006Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2006Q4_25, outset=cons_lo_2006Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2006Q4_26, outset=cons_lo_2006Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2006Q4_27, outset=cons_lo_2006Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2006Q4_28, outset=cons_lo_2006Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2006Q4_29, outset=cons_lo_2006Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2006Q4_30, outset=cons_lo_2006Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2006Q4_31, outset=cons_lo_2006Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2006Q4_32, outset=cons_lo_2006Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2006Q4_33, outset=cons_lo_2006Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2006Q4_34, outset=cons_lo_2006Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2006Q4_35, outset=cons_lo_2006Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2006Q4_36, outset=cons_lo_2006Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2006Q4_37, outset=cons_lo_2006Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2006Q4_38, outset=cons_lo_2006Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2006Q4_39, outset=cons_lo_2006Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2006Q4_40, outset=cons_lo_2006Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2006Q4_41, outset=cons_lo_2006Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2006Q4_42, outset=cons_lo_2006Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2006Q4_43, outset=cons_lo_2006Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2006Q4;
set cons_lo_2006Q4_43;
run;


/*2006Q3 Consumer Originations Plus Lags*/
data cons_lo_2006Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 67 then delete;
run;
proc sql;
create table cons_lo_2006Q3_2 as select a.*, b.ta
from cons_lo_2006Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2006Q3_3;
set cons_lo_2006Q3_2;
if ta=. then delete;
run;
/*Add 2006Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2006Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2006Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2006Q3_4;
set cons_lo_2006Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2006Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20060930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2006Q3_4, outset=cons_lo_2006Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2006Q3_5, outset=cons_lo_2006Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2006Q3_6, outset=cons_lo_2006Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2006Q3_7, outset=cons_lo_2006Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2006Q3_8, outset=cons_lo_2006Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2006Q3_9, outset=cons_lo_2006Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2006Q3_10, outset=cons_lo_2006Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2006Q3_11, outset=cons_lo_2006Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2006Q3_12, outset=cons_lo_2006Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2006Q3_13, outset=cons_lo_2006Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2006Q3_14, outset=cons_lo_2006Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2006Q3_15, outset=cons_lo_2006Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2006Q3_16, outset=cons_lo_2006Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2006Q3_17, outset=cons_lo_2006Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2006Q3_18, outset=cons_lo_2006Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2006Q3_19, outset=cons_lo_2006Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2006Q3_20, outset=cons_lo_2006Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2006Q3_21, outset=cons_lo_2006Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2006Q3_22, outset=cons_lo_2006Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2006Q3_23, outset=cons_lo_2006Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2006Q3_24, outset=cons_lo_2006Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2006Q3_25, outset=cons_lo_2006Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2006Q3_26, outset=cons_lo_2006Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2006Q3_27, outset=cons_lo_2006Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2006Q3_28, outset=cons_lo_2006Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2006Q3_29, outset=cons_lo_2006Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2006Q3_30, outset=cons_lo_2006Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2006Q3_31, outset=cons_lo_2006Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2006Q3_32, outset=cons_lo_2006Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2006Q3_33, outset=cons_lo_2006Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2006Q3_34, outset=cons_lo_2006Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2006Q3_35, outset=cons_lo_2006Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2006Q3_36, outset=cons_lo_2006Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2006Q3_37, outset=cons_lo_2006Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2006Q3_38, outset=cons_lo_2006Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2006Q3_39, outset=cons_lo_2006Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2006Q3_40, outset=cons_lo_2006Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2006Q3_41, outset=cons_lo_2006Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2006Q3_42, outset=cons_lo_2006Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2006Q3;
set cons_lo_2006Q3_43;
run;


/*2006Q2 Consumer Originations Plus Lags*/
data cons_lo_2006Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 66 then delete;
run;
proc sql;
create table cons_lo_2006Q2_2 as select a.*, b.ta
from cons_lo_2006Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2006Q2_3;
set cons_lo_2006Q2_2;
if ta=. then delete;
run;
/*Add 2006Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2006Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2006Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2006Q2_4;
set cons_lo_2006Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2006Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20060630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2006Q2_4, outset=cons_lo_2006Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2006Q2_5, outset=cons_lo_2006Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2006Q2_6, outset=cons_lo_2006Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2006Q2_7, outset=cons_lo_2006Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2006Q2_8, outset=cons_lo_2006Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2006Q2_9, outset=cons_lo_2006Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2006Q2_10, outset=cons_lo_2006Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2006Q2_11, outset=cons_lo_2006Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2006Q2_12, outset=cons_lo_2006Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2006Q2_13, outset=cons_lo_2006Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2006Q2_14, outset=cons_lo_2006Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2006Q2_15, outset=cons_lo_2006Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2006Q2_16, outset=cons_lo_2006Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2006Q2_17, outset=cons_lo_2006Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2006Q2_18, outset=cons_lo_2006Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2006Q2_19, outset=cons_lo_2006Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2006Q2_20, outset=cons_lo_2006Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2006Q2_21, outset=cons_lo_2006Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2006Q2_22, outset=cons_lo_2006Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2006Q2_23, outset=cons_lo_2006Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2006Q2_24, outset=cons_lo_2006Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2006Q2_25, outset=cons_lo_2006Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2006Q2_26, outset=cons_lo_2006Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2006Q2_27, outset=cons_lo_2006Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2006Q2_28, outset=cons_lo_2006Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2006Q2_29, outset=cons_lo_2006Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2006Q2_30, outset=cons_lo_2006Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2006Q2_31, outset=cons_lo_2006Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2006Q2_32, outset=cons_lo_2006Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2006Q2_33, outset=cons_lo_2006Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2006Q2_34, outset=cons_lo_2006Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2006Q2_35, outset=cons_lo_2006Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2006Q2_36, outset=cons_lo_2006Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2006Q2_37, outset=cons_lo_2006Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2006Q2_38, outset=cons_lo_2006Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2006Q2_39, outset=cons_lo_2006Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2006Q2_40, outset=cons_lo_2006Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2006Q2_41, outset=cons_lo_2006Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2006Q2_42, outset=cons_lo_2006Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2006Q2;
set cons_lo_2006Q2_43;
run;


/*2006Q1 Consumer Originations Plus Lags*/
data cons_lo_2006Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 65 then delete;
run;
proc sql;
create table cons_lo_2006Q1_2 as select a.*, b.ta
from cons_lo_2006Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2006Q1_3;
set cons_lo_2006Q1_2;
if ta=. then delete;
run;
/*Add 2006Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2006Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2006Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2006Q1_4;
set cons_lo_2006Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2006Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20060331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2006Q1_4, outset=cons_lo_2006Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2006Q1_5, outset=cons_lo_2006Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2006Q1_6, outset=cons_lo_2006Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2006Q1_7, outset=cons_lo_2006Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2006Q1_8, outset=cons_lo_2006Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2006Q1_9, outset=cons_lo_2006Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2006Q1_10, outset=cons_lo_2006Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2006Q1_11, outset=cons_lo_2006Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2006Q1_12, outset=cons_lo_2006Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2006Q1_13, outset=cons_lo_2006Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2006Q1_14, outset=cons_lo_2006Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2006Q1_15, outset=cons_lo_2006Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2006Q1_16, outset=cons_lo_2006Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2006Q1_17, outset=cons_lo_2006Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2006Q1_18, outset=cons_lo_2006Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2006Q1_19, outset=cons_lo_2006Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2006Q1_20, outset=cons_lo_2006Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2006Q1_21, outset=cons_lo_2006Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2006Q1_22, outset=cons_lo_2006Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2006Q1_23, outset=cons_lo_2006Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2006Q1_24, outset=cons_lo_2006Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2006Q1_25, outset=cons_lo_2006Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2006Q1_26, outset=cons_lo_2006Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2006Q1_27, outset=cons_lo_2006Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2006Q1_28, outset=cons_lo_2006Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2006Q1_29, outset=cons_lo_2006Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2006Q1_30, outset=cons_lo_2006Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2006Q1_31, outset=cons_lo_2006Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2006Q1_32, outset=cons_lo_2006Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2006Q1_33, outset=cons_lo_2006Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2006Q1_34, outset=cons_lo_2006Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2006Q1_35, outset=cons_lo_2006Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2006Q1_36, outset=cons_lo_2006Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2006Q1_37, outset=cons_lo_2006Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2006Q1_38, outset=cons_lo_2006Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2006Q1_39, outset=cons_lo_2006Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2006Q1_40, outset=cons_lo_2006Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2006Q1_41, outset=cons_lo_2006Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2006Q1_42, outset=cons_lo_2006Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2006Q1;
set cons_lo_2006Q1_43;
run;

dm 'clear log';
/*2005*/

/*2005 Q4 Consumer Originations Plus Lags*/
data cons_lo_2005Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 64 then delete;
run;
proc sql;
create table cons_lo_2005Q4_2 as select a.*, b.ta
from cons_lo_2005Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2005Q4_3;
set cons_lo_2005Q4_2;
if ta=. then delete;
run;
/*Add 2005 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2005Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2005Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2005Q4_4;
set cons_lo_2005Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20051231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2005Q4_4, outset=cons_lo_2005Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2005Q4_5, outset=cons_lo_2005Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2005Q4_6, outset=cons_lo_2005Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2005Q4_7, outset=cons_lo_2005Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2005Q4_8, outset=cons_lo_2005Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2005Q4_9, outset=cons_lo_2005Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2005Q4_10, outset=cons_lo_2005Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2005Q4_11, outset=cons_lo_2005Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2005Q4_12, outset=cons_lo_2005Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2005Q4_13, outset=cons_lo_2005Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2005Q4_14, outset=cons_lo_2005Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2005Q4_15, outset=cons_lo_2005Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2005Q4_16, outset=cons_lo_2005Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2005Q4_17, outset=cons_lo_2005Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2005Q4_18, outset=cons_lo_2005Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2005Q4_19, outset=cons_lo_2005Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2005Q4_20, outset=cons_lo_2005Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2005Q4_21, outset=cons_lo_2005Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2005Q4_22, outset=cons_lo_2005Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2005Q4_23, outset=cons_lo_2005Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2005Q4_24, outset=cons_lo_2005Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2005Q4_25, outset=cons_lo_2005Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2005Q4_26, outset=cons_lo_2005Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2005Q4_27, outset=cons_lo_2005Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2005Q4_28, outset=cons_lo_2005Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2005Q4_29, outset=cons_lo_2005Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2005Q4_30, outset=cons_lo_2005Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2005Q4_31, outset=cons_lo_2005Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2005Q4_32, outset=cons_lo_2005Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2005Q4_33, outset=cons_lo_2005Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2005Q4_34, outset=cons_lo_2005Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2005Q4_35, outset=cons_lo_2005Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2005Q4_36, outset=cons_lo_2005Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2005Q4_37, outset=cons_lo_2005Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2005Q4_38, outset=cons_lo_2005Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2005Q4_39, outset=cons_lo_2005Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2005Q4_40, outset=cons_lo_2005Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2005Q4_41, outset=cons_lo_2005Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2005Q4_42, outset=cons_lo_2005Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2005Q4_43, outset=cons_lo_2005Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2005Q4;
set cons_lo_2005Q4_43;
run;


/*2005Q3 Consumer Originations Plus Lags*/
data cons_lo_2005Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 63 then delete;
run;
proc sql;
create table cons_lo_2005Q3_2 as select a.*, b.ta
from cons_lo_2005Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2005Q3_3;
set cons_lo_2005Q3_2;
if ta=. then delete;
run;
/*Add 2005Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2005Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2005Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2005Q3_4;
set cons_lo_2005Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2005Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20050930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2005Q3_4, outset=cons_lo_2005Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2005Q3_5, outset=cons_lo_2005Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2005Q3_6, outset=cons_lo_2005Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2005Q3_7, outset=cons_lo_2005Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2005Q3_8, outset=cons_lo_2005Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2005Q3_9, outset=cons_lo_2005Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2005Q3_10, outset=cons_lo_2005Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2005Q3_11, outset=cons_lo_2005Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2005Q3_12, outset=cons_lo_2005Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2005Q3_13, outset=cons_lo_2005Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2005Q3_14, outset=cons_lo_2005Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2005Q3_15, outset=cons_lo_2005Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2005Q3_16, outset=cons_lo_2005Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2005Q3_17, outset=cons_lo_2005Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2005Q3_18, outset=cons_lo_2005Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2005Q3_19, outset=cons_lo_2005Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2005Q3_20, outset=cons_lo_2005Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2005Q3_21, outset=cons_lo_2005Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2005Q3_22, outset=cons_lo_2005Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2005Q3_23, outset=cons_lo_2005Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2005Q3_24, outset=cons_lo_2005Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2005Q3_25, outset=cons_lo_2005Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2005Q3_26, outset=cons_lo_2005Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2005Q3_27, outset=cons_lo_2005Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2005Q3_28, outset=cons_lo_2005Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2005Q3_29, outset=cons_lo_2005Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2005Q3_30, outset=cons_lo_2005Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2005Q3_31, outset=cons_lo_2005Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2005Q3_32, outset=cons_lo_2005Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2005Q3_33, outset=cons_lo_2005Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2005Q3_34, outset=cons_lo_2005Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2005Q3_35, outset=cons_lo_2005Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2005Q3_36, outset=cons_lo_2005Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2005Q3_37, outset=cons_lo_2005Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2005Q3_38, outset=cons_lo_2005Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2005Q3_39, outset=cons_lo_2005Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2005Q3_40, outset=cons_lo_2005Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2005Q3_41, outset=cons_lo_2005Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2005Q3_42, outset=cons_lo_2005Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2005Q3;
set cons_lo_2005Q3_43;
run;


/*2005Q2 Consumer Originations Plus Lags*/
data cons_lo_2005Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 62 then delete;
run;
proc sql;
create table cons_lo_2005Q2_2 as select a.*, b.ta
from cons_lo_2005Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2005Q2_3;
set cons_lo_2005Q2_2;
if ta=. then delete;
run;
/*Add 2005Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2005Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2005Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2005Q2_4;
set cons_lo_2005Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2005Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20050630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2005Q2_4, outset=cons_lo_2005Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2005Q2_5, outset=cons_lo_2005Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2005Q2_6, outset=cons_lo_2005Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2005Q2_7, outset=cons_lo_2005Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2005Q2_8, outset=cons_lo_2005Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2005Q2_9, outset=cons_lo_2005Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2005Q2_10, outset=cons_lo_2005Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2005Q2_11, outset=cons_lo_2005Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2005Q2_12, outset=cons_lo_2005Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2005Q2_13, outset=cons_lo_2005Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2005Q2_14, outset=cons_lo_2005Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2005Q2_15, outset=cons_lo_2005Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2005Q2_16, outset=cons_lo_2005Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2005Q2_17, outset=cons_lo_2005Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2005Q2_18, outset=cons_lo_2005Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2005Q2_19, outset=cons_lo_2005Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2005Q2_20, outset=cons_lo_2005Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2005Q2_21, outset=cons_lo_2005Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2005Q2_22, outset=cons_lo_2005Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2005Q2_23, outset=cons_lo_2005Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2005Q2_24, outset=cons_lo_2005Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2005Q2_25, outset=cons_lo_2005Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2005Q2_26, outset=cons_lo_2005Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2005Q2_27, outset=cons_lo_2005Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2005Q2_28, outset=cons_lo_2005Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2005Q2_29, outset=cons_lo_2005Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2005Q2_30, outset=cons_lo_2005Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2005Q2_31, outset=cons_lo_2005Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2005Q2_32, outset=cons_lo_2005Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2005Q2_33, outset=cons_lo_2005Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2005Q2_34, outset=cons_lo_2005Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2005Q2_35, outset=cons_lo_2005Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2005Q2_36, outset=cons_lo_2005Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2005Q2_37, outset=cons_lo_2005Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2005Q2_38, outset=cons_lo_2005Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2005Q2_39, outset=cons_lo_2005Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2005Q2_40, outset=cons_lo_2005Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2005Q2_41, outset=cons_lo_2005Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2005Q2_42, outset=cons_lo_2005Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2005Q2;
set cons_lo_2005Q2_43;
run;


/*2005Q1 Consumer Originations Plus Lags*/
data cons_lo_2005Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 61 then delete;
run;
proc sql;
create table cons_lo_2005Q1_2 as select a.*, b.ta
from cons_lo_2005Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2005Q1_3;
set cons_lo_2005Q1_2;
if ta=. then delete;
run;
/*Add 2005Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2005Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2005Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2005Q1_4;
set cons_lo_2005Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2005Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20050331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2005Q1_4, outset=cons_lo_2005Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2005Q1_5, outset=cons_lo_2005Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2005Q1_6, outset=cons_lo_2005Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2005Q1_7, outset=cons_lo_2005Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2005Q1_8, outset=cons_lo_2005Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2005Q1_9, outset=cons_lo_2005Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2005Q1_10, outset=cons_lo_2005Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2005Q1_11, outset=cons_lo_2005Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2005Q1_12, outset=cons_lo_2005Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2005Q1_13, outset=cons_lo_2005Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2005Q1_14, outset=cons_lo_2005Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2005Q1_15, outset=cons_lo_2005Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2005Q1_16, outset=cons_lo_2005Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2005Q1_17, outset=cons_lo_2005Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2005Q1_18, outset=cons_lo_2005Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2005Q1_19, outset=cons_lo_2005Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2005Q1_20, outset=cons_lo_2005Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2005Q1_21, outset=cons_lo_2005Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2005Q1_22, outset=cons_lo_2005Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2005Q1_23, outset=cons_lo_2005Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2005Q1_24, outset=cons_lo_2005Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2005Q1_25, outset=cons_lo_2005Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2005Q1_26, outset=cons_lo_2005Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2005Q1_27, outset=cons_lo_2005Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2005Q1_28, outset=cons_lo_2005Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2005Q1_29, outset=cons_lo_2005Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2005Q1_30, outset=cons_lo_2005Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2005Q1_31, outset=cons_lo_2005Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2005Q1_32, outset=cons_lo_2005Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2005Q1_33, outset=cons_lo_2005Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2005Q1_34, outset=cons_lo_2005Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2005Q1_35, outset=cons_lo_2005Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2005Q1_36, outset=cons_lo_2005Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2005Q1_37, outset=cons_lo_2005Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2005Q1_38, outset=cons_lo_2005Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2005Q1_39, outset=cons_lo_2005Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2005Q1_40, outset=cons_lo_2005Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2005Q1_41, outset=cons_lo_2005Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2005Q1_42, outset=cons_lo_2005Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2005Q1;
set cons_lo_2005Q1_43;
run;


/*2004*/

/*2004 Q4 Consumer Originations Plus Lags*/
data cons_lo_2004Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 60 then delete;
run;
proc sql;
create table cons_lo_2004Q4_2 as select a.*, b.ta
from cons_lo_2004Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2004Q4_3;
set cons_lo_2004Q4_2;
if ta=. then delete;
run;
/*Add 2004 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2004Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2004Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2004Q4_4;
set cons_lo_2004Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20041231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2004Q4_4, outset=cons_lo_2004Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2004Q4_5, outset=cons_lo_2004Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2004Q4_6, outset=cons_lo_2004Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2004Q4_7, outset=cons_lo_2004Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2004Q4_8, outset=cons_lo_2004Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2004Q4_9, outset=cons_lo_2004Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2004Q4_10, outset=cons_lo_2004Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2004Q4_11, outset=cons_lo_2004Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2004Q4_12, outset=cons_lo_2004Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2004Q4_13, outset=cons_lo_2004Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2004Q4_14, outset=cons_lo_2004Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2004Q4_15, outset=cons_lo_2004Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2004Q4_16, outset=cons_lo_2004Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2004Q4_17, outset=cons_lo_2004Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2004Q4_18, outset=cons_lo_2004Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2004Q4_19, outset=cons_lo_2004Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2004Q4_20, outset=cons_lo_2004Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2004Q4_21, outset=cons_lo_2004Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2004Q4_22, outset=cons_lo_2004Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2004Q4_23, outset=cons_lo_2004Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2004Q4_24, outset=cons_lo_2004Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2004Q4_25, outset=cons_lo_2004Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2004Q4_26, outset=cons_lo_2004Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2004Q4_27, outset=cons_lo_2004Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2004Q4_28, outset=cons_lo_2004Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2004Q4_29, outset=cons_lo_2004Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2004Q4_30, outset=cons_lo_2004Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2004Q4_31, outset=cons_lo_2004Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2004Q4_32, outset=cons_lo_2004Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2004Q4_33, outset=cons_lo_2004Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2004Q4_34, outset=cons_lo_2004Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2004Q4_35, outset=cons_lo_2004Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2004Q4_36, outset=cons_lo_2004Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2004Q4_37, outset=cons_lo_2004Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2004Q4_38, outset=cons_lo_2004Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2004Q4_39, outset=cons_lo_2004Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2004Q4_40, outset=cons_lo_2004Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2004Q4_41, outset=cons_lo_2004Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2004Q4_42, outset=cons_lo_2004Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2004Q4_43, outset=cons_lo_2004Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2004Q4;
set cons_lo_2004Q4_43;
run;


/*2004Q3 Consumer Originations Plus Lags*/
data cons_lo_2004Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 59 then delete;
run;
proc sql;
create table cons_lo_2004Q3_2 as select a.*, b.ta
from cons_lo_2004Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2004Q3_3;
set cons_lo_2004Q3_2;
if ta=. then delete;
run;
/*Add 2004Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2004Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2004Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2004Q3_4;
set cons_lo_2004Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2004Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20040930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2004Q3_4, outset=cons_lo_2004Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2004Q3_5, outset=cons_lo_2004Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2004Q3_6, outset=cons_lo_2004Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2004Q3_7, outset=cons_lo_2004Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2004Q3_8, outset=cons_lo_2004Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2004Q3_9, outset=cons_lo_2004Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2004Q3_10, outset=cons_lo_2004Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2004Q3_11, outset=cons_lo_2004Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2004Q3_12, outset=cons_lo_2004Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2004Q3_13, outset=cons_lo_2004Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2004Q3_14, outset=cons_lo_2004Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2004Q3_15, outset=cons_lo_2004Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2004Q3_16, outset=cons_lo_2004Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2004Q3_17, outset=cons_lo_2004Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2004Q3_18, outset=cons_lo_2004Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2004Q3_19, outset=cons_lo_2004Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2004Q3_20, outset=cons_lo_2004Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2004Q3_21, outset=cons_lo_2004Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2004Q3_22, outset=cons_lo_2004Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2004Q3_23, outset=cons_lo_2004Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2004Q3_24, outset=cons_lo_2004Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2004Q3_25, outset=cons_lo_2004Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2004Q3_26, outset=cons_lo_2004Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2004Q3_27, outset=cons_lo_2004Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2004Q3_28, outset=cons_lo_2004Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2004Q3_29, outset=cons_lo_2004Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2004Q3_30, outset=cons_lo_2004Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2004Q3_31, outset=cons_lo_2004Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2004Q3_32, outset=cons_lo_2004Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2004Q3_33, outset=cons_lo_2004Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2004Q3_34, outset=cons_lo_2004Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2004Q3_35, outset=cons_lo_2004Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2004Q3_36, outset=cons_lo_2004Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2004Q3_37, outset=cons_lo_2004Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2004Q3_38, outset=cons_lo_2004Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2004Q3_39, outset=cons_lo_2004Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2004Q3_40, outset=cons_lo_2004Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2004Q3_41, outset=cons_lo_2004Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2004Q3_42, outset=cons_lo_2004Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2004Q3;
set cons_lo_2004Q3_43;
run;


/*2004Q2 Consumer Originations Plus Lags*/
data cons_lo_2004Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 58 then delete;
run;
proc sql;
create table cons_lo_2004Q2_2 as select a.*, b.ta
from cons_lo_2004Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2004Q2_3;
set cons_lo_2004Q2_2;
if ta=. then delete;
run;
/*Add 2004Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2004Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2004Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2004Q2_4;
set cons_lo_2004Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2004Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20040630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2004Q2_4, outset=cons_lo_2004Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2004Q2_5, outset=cons_lo_2004Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2004Q2_6, outset=cons_lo_2004Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2004Q2_7, outset=cons_lo_2004Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2004Q2_8, outset=cons_lo_2004Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2004Q2_9, outset=cons_lo_2004Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2004Q2_10, outset=cons_lo_2004Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2004Q2_11, outset=cons_lo_2004Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2004Q2_12, outset=cons_lo_2004Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2004Q2_13, outset=cons_lo_2004Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2004Q2_14, outset=cons_lo_2004Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2004Q2_15, outset=cons_lo_2004Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2004Q2_16, outset=cons_lo_2004Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2004Q2_17, outset=cons_lo_2004Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2004Q2_18, outset=cons_lo_2004Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2004Q2_19, outset=cons_lo_2004Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2004Q2_20, outset=cons_lo_2004Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2004Q2_21, outset=cons_lo_2004Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2004Q2_22, outset=cons_lo_2004Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2004Q2_23, outset=cons_lo_2004Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2004Q2_24, outset=cons_lo_2004Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2004Q2_25, outset=cons_lo_2004Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2004Q2_26, outset=cons_lo_2004Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2004Q2_27, outset=cons_lo_2004Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2004Q2_28, outset=cons_lo_2004Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2004Q2_29, outset=cons_lo_2004Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2004Q2_30, outset=cons_lo_2004Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2004Q2_31, outset=cons_lo_2004Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2004Q2_32, outset=cons_lo_2004Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2004Q2_33, outset=cons_lo_2004Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2004Q2_34, outset=cons_lo_2004Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2004Q2_35, outset=cons_lo_2004Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2004Q2_36, outset=cons_lo_2004Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2004Q2_37, outset=cons_lo_2004Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2004Q2_38, outset=cons_lo_2004Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2004Q2_39, outset=cons_lo_2004Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2004Q2_40, outset=cons_lo_2004Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2004Q2_41, outset=cons_lo_2004Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2004Q2_42, outset=cons_lo_2004Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2004Q2;
set cons_lo_2004Q2_43;
run;


/*2004Q1 Consumer Originations Plus Lags*/
data cons_lo_2004Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 57 then delete;
run;
proc sql;
create table cons_lo_2004Q1_2 as select a.*, b.ta
from cons_lo_2004Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2004Q1_3;
set cons_lo_2004Q1_2;
if ta=. then delete;
run;
/*Add 2004Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2004Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2004Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2004Q1_4;
set cons_lo_2004Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2004Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20040331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2004Q1_4, outset=cons_lo_2004Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2004Q1_5, outset=cons_lo_2004Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2004Q1_6, outset=cons_lo_2004Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2004Q1_7, outset=cons_lo_2004Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2004Q1_8, outset=cons_lo_2004Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2004Q1_9, outset=cons_lo_2004Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2004Q1_10, outset=cons_lo_2004Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2004Q1_11, outset=cons_lo_2004Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2004Q1_12, outset=cons_lo_2004Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2004Q1_13, outset=cons_lo_2004Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2004Q1_14, outset=cons_lo_2004Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2004Q1_15, outset=cons_lo_2004Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2004Q1_16, outset=cons_lo_2004Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2004Q1_17, outset=cons_lo_2004Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2004Q1_18, outset=cons_lo_2004Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2004Q1_19, outset=cons_lo_2004Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2004Q1_20, outset=cons_lo_2004Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2004Q1_21, outset=cons_lo_2004Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2004Q1_22, outset=cons_lo_2004Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2004Q1_23, outset=cons_lo_2004Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2004Q1_24, outset=cons_lo_2004Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2004Q1_25, outset=cons_lo_2004Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2004Q1_26, outset=cons_lo_2004Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2004Q1_27, outset=cons_lo_2004Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2004Q1_28, outset=cons_lo_2004Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2004Q1_29, outset=cons_lo_2004Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2004Q1_30, outset=cons_lo_2004Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2004Q1_31, outset=cons_lo_2004Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2004Q1_32, outset=cons_lo_2004Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2004Q1_33, outset=cons_lo_2004Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2004Q1_34, outset=cons_lo_2004Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2004Q1_35, outset=cons_lo_2004Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2004Q1_36, outset=cons_lo_2004Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2004Q1_37, outset=cons_lo_2004Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2004Q1_38, outset=cons_lo_2004Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2004Q1_39, outset=cons_lo_2004Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2004Q1_40, outset=cons_lo_2004Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2004Q1_41, outset=cons_lo_2004Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2004Q1_42, outset=cons_lo_2004Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2004Q1;
set cons_lo_2004Q1_43;
run;

/*2003*/

/*2003 Q4 Consumer Originations Plus Lags*/
data cons_lo_2003Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 56 then delete;
run;
proc sql;
create table cons_lo_2003Q4_2 as select a.*, b.ta
from cons_lo_2003Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2003Q4_3;
set cons_lo_2003Q4_2;
if ta=. then delete;
run;
/*Add 2003 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2003Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2003Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2003Q4_4;
set cons_lo_2003Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20031231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2003Q4_4, outset=cons_lo_2003Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2003Q4_5, outset=cons_lo_2003Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2003Q4_6, outset=cons_lo_2003Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2003Q4_7, outset=cons_lo_2003Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2003Q4_8, outset=cons_lo_2003Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2003Q4_9, outset=cons_lo_2003Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2003Q4_10, outset=cons_lo_2003Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2003Q4_11, outset=cons_lo_2003Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2003Q4_12, outset=cons_lo_2003Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2003Q4_13, outset=cons_lo_2003Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2003Q4_14, outset=cons_lo_2003Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2003Q4_15, outset=cons_lo_2003Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2003Q4_16, outset=cons_lo_2003Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2003Q4_17, outset=cons_lo_2003Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2003Q4_18, outset=cons_lo_2003Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2003Q4_19, outset=cons_lo_2003Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2003Q4_20, outset=cons_lo_2003Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2003Q4_21, outset=cons_lo_2003Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2003Q4_22, outset=cons_lo_2003Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2003Q4_23, outset=cons_lo_2003Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2003Q4_24, outset=cons_lo_2003Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2003Q4_25, outset=cons_lo_2003Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2003Q4_26, outset=cons_lo_2003Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2003Q4_27, outset=cons_lo_2003Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2003Q4_28, outset=cons_lo_2003Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2003Q4_29, outset=cons_lo_2003Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2003Q4_30, outset=cons_lo_2003Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2003Q4_31, outset=cons_lo_2003Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2003Q4_32, outset=cons_lo_2003Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2003Q4_33, outset=cons_lo_2003Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2003Q4_34, outset=cons_lo_2003Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2003Q4_35, outset=cons_lo_2003Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2003Q4_36, outset=cons_lo_2003Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2003Q4_37, outset=cons_lo_2003Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2003Q4_38, outset=cons_lo_2003Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2003Q4_39, outset=cons_lo_2003Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2003Q4_40, outset=cons_lo_2003Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2003Q4_41, outset=cons_lo_2003Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2003Q4_42, outset=cons_lo_2003Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2003Q4_43, outset=cons_lo_2003Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2003Q4;
set cons_lo_2003Q4_43;
run;


/*2003Q3 Consumer Originations Plus Lags*/
data cons_lo_2003Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 55 then delete;
run;
proc sql;
create table cons_lo_2003Q3_2 as select a.*, b.ta
from cons_lo_2003Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2003Q3_3;
set cons_lo_2003Q3_2;
if ta=. then delete;
run;
/*Add 2003Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2003Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2003Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2003Q3_4;
set cons_lo_2003Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2003Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20030930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2003Q3_4, outset=cons_lo_2003Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2003Q3_5, outset=cons_lo_2003Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2003Q3_6, outset=cons_lo_2003Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2003Q3_7, outset=cons_lo_2003Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2003Q3_8, outset=cons_lo_2003Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2003Q3_9, outset=cons_lo_2003Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2003Q3_10, outset=cons_lo_2003Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2003Q3_11, outset=cons_lo_2003Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2003Q3_12, outset=cons_lo_2003Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2003Q3_13, outset=cons_lo_2003Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2003Q3_14, outset=cons_lo_2003Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2003Q3_15, outset=cons_lo_2003Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2003Q3_16, outset=cons_lo_2003Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2003Q3_17, outset=cons_lo_2003Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2003Q3_18, outset=cons_lo_2003Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2003Q3_19, outset=cons_lo_2003Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2003Q3_20, outset=cons_lo_2003Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2003Q3_21, outset=cons_lo_2003Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2003Q3_22, outset=cons_lo_2003Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2003Q3_23, outset=cons_lo_2003Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2003Q3_24, outset=cons_lo_2003Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2003Q3_25, outset=cons_lo_2003Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2003Q3_26, outset=cons_lo_2003Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2003Q3_27, outset=cons_lo_2003Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2003Q3_28, outset=cons_lo_2003Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2003Q3_29, outset=cons_lo_2003Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2003Q3_30, outset=cons_lo_2003Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2003Q3_31, outset=cons_lo_2003Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2003Q3_32, outset=cons_lo_2003Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2003Q3_33, outset=cons_lo_2003Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2003Q3_34, outset=cons_lo_2003Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2003Q3_35, outset=cons_lo_2003Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2003Q3_36, outset=cons_lo_2003Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2003Q3_37, outset=cons_lo_2003Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2003Q3_38, outset=cons_lo_2003Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2003Q3_39, outset=cons_lo_2003Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2003Q3_40, outset=cons_lo_2003Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2003Q3_41, outset=cons_lo_2003Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2003Q3_42, outset=cons_lo_2003Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2003Q3;
set cons_lo_2003Q3_43;
run;


/*2003Q2 Consumer Originations Plus Lags*/
data cons_lo_2003Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 54 then delete;
run;
proc sql;
create table cons_lo_2003Q2_2 as select a.*, b.ta
from cons_lo_2003Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2003Q2_3;
set cons_lo_2003Q2_2;
if ta=. then delete;
run;
/*Add 2003Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2003Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2003Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2003Q2_4;
set cons_lo_2003Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2003Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20030630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2003Q2_4, outset=cons_lo_2003Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2003Q2_5, outset=cons_lo_2003Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2003Q2_6, outset=cons_lo_2003Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2003Q2_7, outset=cons_lo_2003Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2003Q2_8, outset=cons_lo_2003Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2003Q2_9, outset=cons_lo_2003Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2003Q2_10, outset=cons_lo_2003Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2003Q2_11, outset=cons_lo_2003Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2003Q2_12, outset=cons_lo_2003Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2003Q2_13, outset=cons_lo_2003Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2003Q2_14, outset=cons_lo_2003Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2003Q2_15, outset=cons_lo_2003Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2003Q2_16, outset=cons_lo_2003Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2003Q2_17, outset=cons_lo_2003Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2003Q2_18, outset=cons_lo_2003Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2003Q2_19, outset=cons_lo_2003Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2003Q2_20, outset=cons_lo_2003Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2003Q2_21, outset=cons_lo_2003Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2003Q2_22, outset=cons_lo_2003Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2003Q2_23, outset=cons_lo_2003Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2003Q2_24, outset=cons_lo_2003Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2003Q2_25, outset=cons_lo_2003Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2003Q2_26, outset=cons_lo_2003Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2003Q2_27, outset=cons_lo_2003Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2003Q2_28, outset=cons_lo_2003Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2003Q2_29, outset=cons_lo_2003Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2003Q2_30, outset=cons_lo_2003Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2003Q2_31, outset=cons_lo_2003Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2003Q2_32, outset=cons_lo_2003Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2003Q2_33, outset=cons_lo_2003Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2003Q2_34, outset=cons_lo_2003Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2003Q2_35, outset=cons_lo_2003Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2003Q2_36, outset=cons_lo_2003Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2003Q2_37, outset=cons_lo_2003Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2003Q2_38, outset=cons_lo_2003Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2003Q2_39, outset=cons_lo_2003Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2003Q2_40, outset=cons_lo_2003Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2003Q2_41, outset=cons_lo_2003Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2003Q2_42, outset=cons_lo_2003Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2003Q2;
set cons_lo_2003Q2_43;
run;


/*2003Q1 Consumer Originations Plus Lags*/
data cons_lo_2003Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 53 then delete;
run;
proc sql;
create table cons_lo_2003Q1_2 as select a.*, b.ta
from cons_lo_2003Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2003Q1_3;
set cons_lo_2003Q1_2;
if ta=. then delete;
run;
/*Add 2003Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2003Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2003Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2003Q1_4;
set cons_lo_2003Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2003Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20030331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2003Q1_4, outset=cons_lo_2003Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2003Q1_5, outset=cons_lo_2003Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2003Q1_6, outset=cons_lo_2003Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2003Q1_7, outset=cons_lo_2003Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2003Q1_8, outset=cons_lo_2003Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2003Q1_9, outset=cons_lo_2003Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2003Q1_10, outset=cons_lo_2003Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2003Q1_11, outset=cons_lo_2003Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2003Q1_12, outset=cons_lo_2003Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2003Q1_13, outset=cons_lo_2003Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2003Q1_14, outset=cons_lo_2003Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2003Q1_15, outset=cons_lo_2003Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2003Q1_16, outset=cons_lo_2003Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2003Q1_17, outset=cons_lo_2003Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2003Q1_18, outset=cons_lo_2003Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2003Q1_19, outset=cons_lo_2003Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2003Q1_20, outset=cons_lo_2003Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2003Q1_21, outset=cons_lo_2003Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2003Q1_22, outset=cons_lo_2003Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2003Q1_23, outset=cons_lo_2003Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2003Q1_24, outset=cons_lo_2003Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2003Q1_25, outset=cons_lo_2003Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2003Q1_26, outset=cons_lo_2003Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2003Q1_27, outset=cons_lo_2003Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2003Q1_28, outset=cons_lo_2003Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2003Q1_29, outset=cons_lo_2003Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2003Q1_30, outset=cons_lo_2003Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2003Q1_31, outset=cons_lo_2003Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2003Q1_32, outset=cons_lo_2003Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2003Q1_33, outset=cons_lo_2003Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2003Q1_34, outset=cons_lo_2003Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2003Q1_35, outset=cons_lo_2003Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2003Q1_36, outset=cons_lo_2003Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2003Q1_37, outset=cons_lo_2003Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2003Q1_38, outset=cons_lo_2003Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2003Q1_39, outset=cons_lo_2003Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2003Q1_40, outset=cons_lo_2003Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2003Q1_41, outset=cons_lo_2003Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2003Q1_42, outset=cons_lo_2003Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2003Q1;
set cons_lo_2003Q1_43;
run;

/*2002*/

/*2002 Q4 Consumer Originations Plus Lags*/
data cons_lo_2002Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 52 then delete;
run;
proc sql;
create table cons_lo_2002Q4_2 as select a.*, b.ta
from cons_lo_2002Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2002Q4_3;
set cons_lo_2002Q4_2;
if ta=. then delete;
run;
/*Add 2002 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2002Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2002Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2002Q4_4;
set cons_lo_2002Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20021231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2002Q4_4, outset=cons_lo_2002Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2002Q4_5, outset=cons_lo_2002Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2002Q4_6, outset=cons_lo_2002Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2002Q4_7, outset=cons_lo_2002Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2002Q4_8, outset=cons_lo_2002Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2002Q4_9, outset=cons_lo_2002Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2002Q4_10, outset=cons_lo_2002Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2002Q4_11, outset=cons_lo_2002Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2002Q4_12, outset=cons_lo_2002Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2002Q4_13, outset=cons_lo_2002Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2002Q4_14, outset=cons_lo_2002Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2002Q4_15, outset=cons_lo_2002Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2002Q4_16, outset=cons_lo_2002Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2002Q4_17, outset=cons_lo_2002Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2002Q4_18, outset=cons_lo_2002Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2002Q4_19, outset=cons_lo_2002Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2002Q4_20, outset=cons_lo_2002Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2002Q4_21, outset=cons_lo_2002Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2002Q4_22, outset=cons_lo_2002Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2002Q4_23, outset=cons_lo_2002Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2002Q4_24, outset=cons_lo_2002Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2002Q4_25, outset=cons_lo_2002Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2002Q4_26, outset=cons_lo_2002Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2002Q4_27, outset=cons_lo_2002Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2002Q4_28, outset=cons_lo_2002Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2002Q4_29, outset=cons_lo_2002Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2002Q4_30, outset=cons_lo_2002Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2002Q4_31, outset=cons_lo_2002Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2002Q4_32, outset=cons_lo_2002Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2002Q4_33, outset=cons_lo_2002Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2002Q4_34, outset=cons_lo_2002Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2002Q4_35, outset=cons_lo_2002Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2002Q4_36, outset=cons_lo_2002Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2002Q4_37, outset=cons_lo_2002Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2002Q4_38, outset=cons_lo_2002Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2002Q4_39, outset=cons_lo_2002Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2002Q4_40, outset=cons_lo_2002Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2002Q4_41, outset=cons_lo_2002Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2002Q4_42, outset=cons_lo_2002Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2002Q4_43, outset=cons_lo_2002Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2002Q4;
set cons_lo_2002Q4_43;
run;


/*2002Q3 Consumer Originations Plus Lags*/
data cons_lo_2002Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 51 then delete;
run;
proc sql;
create table cons_lo_2002Q3_2 as select a.*, b.ta
from cons_lo_2002Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2002Q3_3;
set cons_lo_2002Q3_2;
if ta=. then delete;
run;
/*Add 2002Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2002Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2002Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2002Q3_4;
set cons_lo_2002Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2002Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20020930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2002Q3_4, outset=cons_lo_2002Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2002Q3_5, outset=cons_lo_2002Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2002Q3_6, outset=cons_lo_2002Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2002Q3_7, outset=cons_lo_2002Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2002Q3_8, outset=cons_lo_2002Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2002Q3_9, outset=cons_lo_2002Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2002Q3_10, outset=cons_lo_2002Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2002Q3_11, outset=cons_lo_2002Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2002Q3_12, outset=cons_lo_2002Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2002Q3_13, outset=cons_lo_2002Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2002Q3_14, outset=cons_lo_2002Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2002Q3_15, outset=cons_lo_2002Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2002Q3_16, outset=cons_lo_2002Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2002Q3_17, outset=cons_lo_2002Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2002Q3_18, outset=cons_lo_2002Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2002Q3_19, outset=cons_lo_2002Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2002Q3_20, outset=cons_lo_2002Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2002Q3_21, outset=cons_lo_2002Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2002Q3_22, outset=cons_lo_2002Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2002Q3_23, outset=cons_lo_2002Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2002Q3_24, outset=cons_lo_2002Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2002Q3_25, outset=cons_lo_2002Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2002Q3_26, outset=cons_lo_2002Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2002Q3_27, outset=cons_lo_2002Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2002Q3_28, outset=cons_lo_2002Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2002Q3_29, outset=cons_lo_2002Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2002Q3_30, outset=cons_lo_2002Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2002Q3_31, outset=cons_lo_2002Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2002Q3_32, outset=cons_lo_2002Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2002Q3_33, outset=cons_lo_2002Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2002Q3_34, outset=cons_lo_2002Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2002Q3_35, outset=cons_lo_2002Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2002Q3_36, outset=cons_lo_2002Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2002Q3_37, outset=cons_lo_2002Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2002Q3_38, outset=cons_lo_2002Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2002Q3_39, outset=cons_lo_2002Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2002Q3_40, outset=cons_lo_2002Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2002Q3_41, outset=cons_lo_2002Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2002Q3_42, outset=cons_lo_2002Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2002Q3;
set cons_lo_2002Q3_43;
run;


/*2002Q2 Consumer Originations Plus Lags*/
data cons_lo_2002Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 50 then delete;
run;
proc sql;
create table cons_lo_2002Q2_2 as select a.*, b.ta
from cons_lo_2002Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2002Q2_3;
set cons_lo_2002Q2_2;
if ta=. then delete;
run;
/*Add 2002Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2002Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2002Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2002Q2_4;
set cons_lo_2002Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2002Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20020630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2002Q2_4, outset=cons_lo_2002Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2002Q2_5, outset=cons_lo_2002Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2002Q2_6, outset=cons_lo_2002Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2002Q2_7, outset=cons_lo_2002Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2002Q2_8, outset=cons_lo_2002Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2002Q2_9, outset=cons_lo_2002Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2002Q2_10, outset=cons_lo_2002Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2002Q2_11, outset=cons_lo_2002Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2002Q2_12, outset=cons_lo_2002Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2002Q2_13, outset=cons_lo_2002Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2002Q2_14, outset=cons_lo_2002Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2002Q2_15, outset=cons_lo_2002Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2002Q2_16, outset=cons_lo_2002Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2002Q2_17, outset=cons_lo_2002Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2002Q2_18, outset=cons_lo_2002Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2002Q2_19, outset=cons_lo_2002Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2002Q2_20, outset=cons_lo_2002Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2002Q2_21, outset=cons_lo_2002Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2002Q2_22, outset=cons_lo_2002Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2002Q2_23, outset=cons_lo_2002Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2002Q2_24, outset=cons_lo_2002Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2002Q2_25, outset=cons_lo_2002Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2002Q2_26, outset=cons_lo_2002Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2002Q2_27, outset=cons_lo_2002Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2002Q2_28, outset=cons_lo_2002Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2002Q2_29, outset=cons_lo_2002Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2002Q2_30, outset=cons_lo_2002Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2002Q2_31, outset=cons_lo_2002Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2002Q2_32, outset=cons_lo_2002Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2002Q2_33, outset=cons_lo_2002Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2002Q2_34, outset=cons_lo_2002Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2002Q2_35, outset=cons_lo_2002Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2002Q2_36, outset=cons_lo_2002Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2002Q2_37, outset=cons_lo_2002Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2002Q2_38, outset=cons_lo_2002Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2002Q2_39, outset=cons_lo_2002Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2002Q2_40, outset=cons_lo_2002Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2002Q2_41, outset=cons_lo_2002Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2002Q2_42, outset=cons_lo_2002Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2002Q2;
set cons_lo_2002Q2_43;
run;


/*2002Q1 Consumer Originations Plus Lags*/
data cons_lo_2002Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 49 then delete;
run;
proc sql;
create table cons_lo_2002Q1_2 as select a.*, b.ta
from cons_lo_2002Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2002Q1_3;
set cons_lo_2002Q1_2;
if ta=. then delete;
run;
/*Add 2002Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2002Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2002Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2002Q1_4;
set cons_lo_2002Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2002Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20020331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2002Q1_4, outset=cons_lo_2002Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2002Q1_5, outset=cons_lo_2002Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2002Q1_6, outset=cons_lo_2002Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2002Q1_7, outset=cons_lo_2002Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2002Q1_8, outset=cons_lo_2002Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2002Q1_9, outset=cons_lo_2002Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2002Q1_10, outset=cons_lo_2002Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2002Q1_11, outset=cons_lo_2002Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2002Q1_12, outset=cons_lo_2002Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2002Q1_13, outset=cons_lo_2002Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2002Q1_14, outset=cons_lo_2002Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2002Q1_15, outset=cons_lo_2002Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2002Q1_16, outset=cons_lo_2002Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2002Q1_17, outset=cons_lo_2002Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2002Q1_18, outset=cons_lo_2002Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2002Q1_19, outset=cons_lo_2002Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2002Q1_20, outset=cons_lo_2002Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2002Q1_21, outset=cons_lo_2002Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2002Q1_22, outset=cons_lo_2002Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2002Q1_23, outset=cons_lo_2002Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2002Q1_24, outset=cons_lo_2002Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2002Q1_25, outset=cons_lo_2002Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2002Q1_26, outset=cons_lo_2002Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2002Q1_27, outset=cons_lo_2002Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2002Q1_28, outset=cons_lo_2002Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2002Q1_29, outset=cons_lo_2002Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2002Q1_30, outset=cons_lo_2002Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2002Q1_31, outset=cons_lo_2002Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2002Q1_32, outset=cons_lo_2002Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2002Q1_33, outset=cons_lo_2002Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2002Q1_34, outset=cons_lo_2002Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2002Q1_35, outset=cons_lo_2002Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2002Q1_36, outset=cons_lo_2002Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2002Q1_37, outset=cons_lo_2002Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2002Q1_38, outset=cons_lo_2002Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2002Q1_39, outset=cons_lo_2002Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2002Q1_40, outset=cons_lo_2002Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2002Q1_41, outset=cons_lo_2002Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2002Q1_42, outset=cons_lo_2002Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2002Q1;
set cons_lo_2002Q1_43;
run;

dm 'clear log';
/*2001*/

/*2001 Q4 Consumer Originations Plus Lags*/
data cons_lo_2001Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 48 then delete;
run;
proc sql;
create table cons_lo_2001Q4_2 as select a.*, b.ta
from cons_lo_2001Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2001Q4_3;
set cons_lo_2001Q4_2;
if ta=. then delete;
run;
/*Add 2001 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2001Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2001Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2001Q4_4;
set cons_lo_2001Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20011231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2001Q4_4, outset=cons_lo_2001Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2001Q4_5, outset=cons_lo_2001Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2001Q4_6, outset=cons_lo_2001Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2001Q4_7, outset=cons_lo_2001Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2001Q4_8, outset=cons_lo_2001Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2001Q4_9, outset=cons_lo_2001Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2001Q4_10, outset=cons_lo_2001Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2001Q4_11, outset=cons_lo_2001Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2001Q4_12, outset=cons_lo_2001Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2001Q4_13, outset=cons_lo_2001Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2001Q4_14, outset=cons_lo_2001Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2001Q4_15, outset=cons_lo_2001Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2001Q4_16, outset=cons_lo_2001Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2001Q4_17, outset=cons_lo_2001Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2001Q4_18, outset=cons_lo_2001Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2001Q4_19, outset=cons_lo_2001Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2001Q4_20, outset=cons_lo_2001Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2001Q4_21, outset=cons_lo_2001Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2001Q4_22, outset=cons_lo_2001Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2001Q4_23, outset=cons_lo_2001Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2001Q4_24, outset=cons_lo_2001Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2001Q4_25, outset=cons_lo_2001Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2001Q4_26, outset=cons_lo_2001Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2001Q4_27, outset=cons_lo_2001Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2001Q4_28, outset=cons_lo_2001Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2001Q4_29, outset=cons_lo_2001Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2001Q4_30, outset=cons_lo_2001Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2001Q4_31, outset=cons_lo_2001Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2001Q4_32, outset=cons_lo_2001Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2001Q4_33, outset=cons_lo_2001Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2001Q4_34, outset=cons_lo_2001Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2001Q4_35, outset=cons_lo_2001Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2001Q4_36, outset=cons_lo_2001Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2001Q4_37, outset=cons_lo_2001Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2001Q4_38, outset=cons_lo_2001Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2001Q4_39, outset=cons_lo_2001Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2001Q4_40, outset=cons_lo_2001Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2001Q4_41, outset=cons_lo_2001Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2001Q4_42, outset=cons_lo_2001Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2001Q4_43, outset=cons_lo_2001Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2001Q4;
set cons_lo_2001Q4_43;
run;


/*2001Q3 Consumer Originations Plus Lags*/
data cons_lo_2001Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 47 then delete;
run;
proc sql;
create table cons_lo_2001Q3_2 as select a.*, b.ta
from cons_lo_2001Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2001Q3_3;
set cons_lo_2001Q3_2;
if ta=. then delete;
run;
/*Add 2001Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2001Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2001Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2001Q3_4;
set cons_lo_2001Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2001Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20010930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2001Q3_4, outset=cons_lo_2001Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2001Q3_5, outset=cons_lo_2001Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2001Q3_6, outset=cons_lo_2001Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2001Q3_7, outset=cons_lo_2001Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2001Q3_8, outset=cons_lo_2001Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2001Q3_9, outset=cons_lo_2001Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2001Q3_10, outset=cons_lo_2001Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2001Q3_11, outset=cons_lo_2001Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2001Q3_12, outset=cons_lo_2001Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2001Q3_13, outset=cons_lo_2001Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2001Q3_14, outset=cons_lo_2001Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2001Q3_15, outset=cons_lo_2001Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2001Q3_16, outset=cons_lo_2001Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2001Q3_17, outset=cons_lo_2001Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2001Q3_18, outset=cons_lo_2001Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2001Q3_19, outset=cons_lo_2001Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2001Q3_20, outset=cons_lo_2001Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2001Q3_21, outset=cons_lo_2001Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2001Q3_22, outset=cons_lo_2001Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2001Q3_23, outset=cons_lo_2001Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2001Q3_24, outset=cons_lo_2001Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2001Q3_25, outset=cons_lo_2001Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2001Q3_26, outset=cons_lo_2001Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2001Q3_27, outset=cons_lo_2001Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2001Q3_28, outset=cons_lo_2001Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2001Q3_29, outset=cons_lo_2001Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2001Q3_30, outset=cons_lo_2001Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2001Q3_31, outset=cons_lo_2001Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2001Q3_32, outset=cons_lo_2001Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2001Q3_33, outset=cons_lo_2001Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2001Q3_34, outset=cons_lo_2001Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2001Q3_35, outset=cons_lo_2001Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2001Q3_36, outset=cons_lo_2001Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2001Q3_37, outset=cons_lo_2001Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2001Q3_38, outset=cons_lo_2001Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2001Q3_39, outset=cons_lo_2001Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2001Q3_40, outset=cons_lo_2001Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2001Q3_41, outset=cons_lo_2001Q3_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2001Q3_42, outset=cons_lo_2001Q3_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2001Q3;
set cons_lo_2001Q3_43;
run;


/*2001Q2 Consumer Originations Plus Lags*/
data cons_lo_2001Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 46 then delete;
run;
proc sql;
create table cons_lo_2001Q2_2 as select a.*, b.ta
from cons_lo_2001Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2001Q2_3;
set cons_lo_2001Q2_2;
if ta=. then delete;
run;
/*Add 2001Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2001Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2001Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2001Q2_4;
set cons_lo_2001Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2001Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20010630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2001Q2_4, outset=cons_lo_2001Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2001Q2_5, outset=cons_lo_2001Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2001Q2_6, outset=cons_lo_2001Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2001Q2_7, outset=cons_lo_2001Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2001Q2_8, outset=cons_lo_2001Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2001Q2_9, outset=cons_lo_2001Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2001Q2_10, outset=cons_lo_2001Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2001Q2_11, outset=cons_lo_2001Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2001Q2_12, outset=cons_lo_2001Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2001Q2_13, outset=cons_lo_2001Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2001Q2_14, outset=cons_lo_2001Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2001Q2_15, outset=cons_lo_2001Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2001Q2_16, outset=cons_lo_2001Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2001Q2_17, outset=cons_lo_2001Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2001Q2_18, outset=cons_lo_2001Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2001Q2_19, outset=cons_lo_2001Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2001Q2_20, outset=cons_lo_2001Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2001Q2_21, outset=cons_lo_2001Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2001Q2_22, outset=cons_lo_2001Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2001Q2_23, outset=cons_lo_2001Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2001Q2_24, outset=cons_lo_2001Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2001Q2_25, outset=cons_lo_2001Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2001Q2_26, outset=cons_lo_2001Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2001Q2_27, outset=cons_lo_2001Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2001Q2_28, outset=cons_lo_2001Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2001Q2_29, outset=cons_lo_2001Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2001Q2_30, outset=cons_lo_2001Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2001Q2_31, outset=cons_lo_2001Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2001Q2_32, outset=cons_lo_2001Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2001Q2_33, outset=cons_lo_2001Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2001Q2_34, outset=cons_lo_2001Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2001Q2_35, outset=cons_lo_2001Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2001Q2_36, outset=cons_lo_2001Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2001Q2_37, outset=cons_lo_2001Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2001Q2_38, outset=cons_lo_2001Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2001Q2_39, outset=cons_lo_2001Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2001Q2_40, outset=cons_lo_2001Q2_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2001Q2_41, outset=cons_lo_2001Q2_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2001Q2_42, outset=cons_lo_2001Q2_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2001Q2;
set cons_lo_2001Q2_43;
run;


/*2001Q1 Consumer Originations Plus Lags*/
data cons_lo_2001Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 45 then delete;
run;
proc sql;
create table cons_lo_2001Q1_2 as select a.*, b.ta
from cons_lo_2001Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2001Q1_3;
set cons_lo_2001Q1_2;
if ta=. then delete;
run;
/*Add 2001Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2001Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2001Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2001Q1_4;
set cons_lo_2001Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2001Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20010331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2001Q1_4, outset=cons_lo_2001Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2001Q1_5, outset=cons_lo_2001Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2001Q1_6, outset=cons_lo_2001Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2001Q1_7, outset=cons_lo_2001Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2001Q1_8, outset=cons_lo_2001Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2001Q1_9, outset=cons_lo_2001Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2001Q1_10, outset=cons_lo_2001Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2001Q1_11, outset=cons_lo_2001Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2001Q1_12, outset=cons_lo_2001Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2001Q1_13, outset=cons_lo_2001Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2001Q1_14, outset=cons_lo_2001Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2001Q1_15, outset=cons_lo_2001Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2001Q1_16, outset=cons_lo_2001Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2001Q1_17, outset=cons_lo_2001Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2001Q1_18, outset=cons_lo_2001Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2001Q1_19, outset=cons_lo_2001Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2001Q1_20, outset=cons_lo_2001Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2001Q1_21, outset=cons_lo_2001Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2001Q1_22, outset=cons_lo_2001Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2001Q1_23, outset=cons_lo_2001Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2001Q1_24, outset=cons_lo_2001Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2001Q1_25, outset=cons_lo_2001Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2001Q1_26, outset=cons_lo_2001Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2001Q1_27, outset=cons_lo_2001Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2001Q1_28, outset=cons_lo_2001Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2001Q1_29, outset=cons_lo_2001Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2001Q1_30, outset=cons_lo_2001Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2001Q1_31, outset=cons_lo_2001Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2001Q1_32, outset=cons_lo_2001Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2001Q1_33, outset=cons_lo_2001Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2001Q1_34, outset=cons_lo_2001Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2001Q1_35, outset=cons_lo_2001Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2001Q1_36, outset=cons_lo_2001Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2001Q1_37, outset=cons_lo_2001Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2001Q1_38, outset=cons_lo_2001Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2001Q1_39, outset=cons_lo_2001Q1_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2001Q1_40, outset=cons_lo_2001Q1_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2001Q1_41, outset=cons_lo_2001Q1_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2001Q1_42, outset=cons_lo_2001Q1_43, lags=39, lagname=est_lo_lag39);

data lo.lo_cons_2001Q1;
set cons_lo_2001Q1_43;
run;


/*2000*/

/*2000 Q4 Consumer Originations Plus Lags*/
data cons_lo_2000Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 44 then delete;
run;
proc sql;
create table cons_lo_2000Q4_2 as select a.*, b.ta
from cons_lo_2000Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2000Q4_3;
set cons_lo_2000Q4_2;
if ta=. then delete;
run;
/*Add 2000 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_2000Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2000Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2000Q4_4;
set cons_lo_2000Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20001231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2000Q4_4, outset=cons_lo_2000Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2000Q4_5, outset=cons_lo_2000Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2000Q4_6, outset=cons_lo_2000Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2000Q4_7, outset=cons_lo_2000Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2000Q4_8, outset=cons_lo_2000Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2000Q4_9, outset=cons_lo_2000Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2000Q4_10, outset=cons_lo_2000Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2000Q4_11, outset=cons_lo_2000Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2000Q4_12, outset=cons_lo_2000Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2000Q4_13, outset=cons_lo_2000Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2000Q4_14, outset=cons_lo_2000Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2000Q4_15, outset=cons_lo_2000Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2000Q4_16, outset=cons_lo_2000Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2000Q4_17, outset=cons_lo_2000Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2000Q4_18, outset=cons_lo_2000Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2000Q4_19, outset=cons_lo_2000Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2000Q4_20, outset=cons_lo_2000Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2000Q4_21, outset=cons_lo_2000Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2000Q4_22, outset=cons_lo_2000Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2000Q4_23, outset=cons_lo_2000Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2000Q4_24, outset=cons_lo_2000Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2000Q4_25, outset=cons_lo_2000Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2000Q4_26, outset=cons_lo_2000Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2000Q4_27, outset=cons_lo_2000Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2000Q4_28, outset=cons_lo_2000Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2000Q4_29, outset=cons_lo_2000Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2000Q4_30, outset=cons_lo_2000Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2000Q4_31, outset=cons_lo_2000Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2000Q4_32, outset=cons_lo_2000Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2000Q4_33, outset=cons_lo_2000Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2000Q4_34, outset=cons_lo_2000Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2000Q4_35, outset=cons_lo_2000Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2000Q4_36, outset=cons_lo_2000Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2000Q4_37, outset=cons_lo_2000Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2000Q4_38, outset=cons_lo_2000Q4_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2000Q4_39, outset=cons_lo_2000Q4_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2000Q4_40, outset=cons_lo_2000Q4_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2000Q4_41, outset=cons_lo_2000Q4_42, lags=38, lagname=est_lo_lag38);
%cons_lo(inset=cons_lo_2000Q4_42, outset=cons_lo_2000Q4_43, lags=39, lagname=est_lo_lag39);
%cons_lo(inset=cons_lo_2000Q4_43, outset=cons_lo_2000Q4_44, lags=40, lagname=est_lo_lag40);

data lo.lo_cons_2000Q4;
set cons_lo_2000Q4_43;
run;


/*2000Q3 Consumer Originations Plus Lags*/
data cons_lo_2000Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 43 then delete;
run;
proc sql;
create table cons_lo_2000Q3_2 as select a.*, b.ta
from cons_lo_2000Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2000Q3_3;
set cons_lo_2000Q3_2;
if ta=. then delete;
run;
/*Add 2000Q3 Consumer loan originations*/
proc sql;
create table cons_lo_2000Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2000Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2000Q3_4;
set cons_lo_2000Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2000Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20000930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2000Q3_4, outset=cons_lo_2000Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2000Q3_5, outset=cons_lo_2000Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2000Q3_6, outset=cons_lo_2000Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2000Q3_7, outset=cons_lo_2000Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2000Q3_8, outset=cons_lo_2000Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2000Q3_9, outset=cons_lo_2000Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2000Q3_10, outset=cons_lo_2000Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2000Q3_11, outset=cons_lo_2000Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2000Q3_12, outset=cons_lo_2000Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2000Q3_13, outset=cons_lo_2000Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2000Q3_14, outset=cons_lo_2000Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2000Q3_15, outset=cons_lo_2000Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2000Q3_16, outset=cons_lo_2000Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2000Q3_17, outset=cons_lo_2000Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2000Q3_18, outset=cons_lo_2000Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2000Q3_19, outset=cons_lo_2000Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2000Q3_20, outset=cons_lo_2000Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2000Q3_21, outset=cons_lo_2000Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2000Q3_22, outset=cons_lo_2000Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2000Q3_23, outset=cons_lo_2000Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2000Q3_24, outset=cons_lo_2000Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2000Q3_25, outset=cons_lo_2000Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2000Q3_26, outset=cons_lo_2000Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2000Q3_27, outset=cons_lo_2000Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2000Q3_28, outset=cons_lo_2000Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2000Q3_29, outset=cons_lo_2000Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2000Q3_30, outset=cons_lo_2000Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2000Q3_31, outset=cons_lo_2000Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2000Q3_32, outset=cons_lo_2000Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2000Q3_33, outset=cons_lo_2000Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2000Q3_34, outset=cons_lo_2000Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2000Q3_35, outset=cons_lo_2000Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2000Q3_36, outset=cons_lo_2000Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2000Q3_37, outset=cons_lo_2000Q3_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2000Q3_38, outset=cons_lo_2000Q3_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2000Q3_39, outset=cons_lo_2000Q3_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2000Q3_40, outset=cons_lo_2000Q3_41, lags=37, lagname=est_lo_lag37);
%cons_lo(inset=cons_lo_2000Q3_41, outset=cons_lo_2000Q3, lags=38, lagname=est_lo_lag38);

data lo.lo_cons_2000Q3;
set cons_lo_2000Q3;
run;


/*2000Q2 Consumer Originations Plus Lags*/
data cons_lo_2000Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 42 then delete;
run;
proc sql;
create table cons_lo_2000Q2_2 as select a.*, b.ta
from cons_lo_2000Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2000Q2_3;
set cons_lo_2000Q2_2;
if ta=. then delete;
run;
/*Add 2000Q2 Consumer loan originations*/
proc sql;
create table cons_lo_2000Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2000Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2000Q2_4;
set cons_lo_2000Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2000Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20000630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2000Q2_4, outset=cons_lo_2000Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2000Q2_5, outset=cons_lo_2000Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2000Q2_6, outset=cons_lo_2000Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2000Q2_7, outset=cons_lo_2000Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2000Q2_8, outset=cons_lo_2000Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2000Q2_9, outset=cons_lo_2000Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2000Q2_10, outset=cons_lo_2000Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2000Q2_11, outset=cons_lo_2000Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2000Q2_12, outset=cons_lo_2000Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2000Q2_13, outset=cons_lo_2000Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2000Q2_14, outset=cons_lo_2000Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2000Q2_15, outset=cons_lo_2000Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2000Q2_16, outset=cons_lo_2000Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2000Q2_17, outset=cons_lo_2000Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2000Q2_18, outset=cons_lo_2000Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2000Q2_19, outset=cons_lo_2000Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2000Q2_20, outset=cons_lo_2000Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2000Q2_21, outset=cons_lo_2000Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2000Q2_22, outset=cons_lo_2000Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2000Q2_23, outset=cons_lo_2000Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2000Q2_24, outset=cons_lo_2000Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2000Q2_25, outset=cons_lo_2000Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2000Q2_26, outset=cons_lo_2000Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2000Q2_27, outset=cons_lo_2000Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2000Q2_28, outset=cons_lo_2000Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2000Q2_29, outset=cons_lo_2000Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2000Q2_30, outset=cons_lo_2000Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2000Q2_31, outset=cons_lo_2000Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2000Q2_32, outset=cons_lo_2000Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2000Q2_33, outset=cons_lo_2000Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2000Q2_34, outset=cons_lo_2000Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2000Q2_35, outset=cons_lo_2000Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2000Q2_36, outset=cons_lo_2000Q2_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2000Q2_37, outset=cons_lo_2000Q2_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2000Q2_38, outset=cons_lo_2000Q2_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2000Q2_39, outset=cons_lo_2000Q2_40, lags=36, lagname=est_lo_lag36);
%cons_lo(inset=cons_lo_2000Q2_40, outset=cons_lo_2000Q2, lags=37, lagname=est_lo_lag37);

data lo.lo_cons_2000Q2;
set cons_lo_2000Q2;
run;


/*2000Q1 Consumer Originations Plus Lags*/
data cons_lo_2000Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 41 then delete;
run;
proc sql;
create table cons_lo_2000Q1_2 as select a.*, b.ta
from cons_lo_2000Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_2000Q1_3;
set cons_lo_2000Q1_2;
if ta=. then delete;
run;
/*Add 2000Q1 Consumer loan originations*/
proc sql;
create table cons_lo_2000Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_2000Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_2000Q1_4;
set cons_lo_2000Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 2000Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_20000331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_2000Q1_4, outset=cons_lo_2000Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_2000Q1_5, outset=cons_lo_2000Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_2000Q1_6, outset=cons_lo_2000Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_2000Q1_7, outset=cons_lo_2000Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_2000Q1_8, outset=cons_lo_2000Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_2000Q1_9, outset=cons_lo_2000Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_2000Q1_10, outset=cons_lo_2000Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_2000Q1_11, outset=cons_lo_2000Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_2000Q1_12, outset=cons_lo_2000Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_2000Q1_13, outset=cons_lo_2000Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_2000Q1_14, outset=cons_lo_2000Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_2000Q1_15, outset=cons_lo_2000Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_2000Q1_16, outset=cons_lo_2000Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_2000Q1_17, outset=cons_lo_2000Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_2000Q1_18, outset=cons_lo_2000Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_2000Q1_19, outset=cons_lo_2000Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_2000Q1_20, outset=cons_lo_2000Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_2000Q1_21, outset=cons_lo_2000Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_2000Q1_22, outset=cons_lo_2000Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_2000Q1_23, outset=cons_lo_2000Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_2000Q1_24, outset=cons_lo_2000Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_2000Q1_25, outset=cons_lo_2000Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_2000Q1_26, outset=cons_lo_2000Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_2000Q1_27, outset=cons_lo_2000Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_2000Q1_28, outset=cons_lo_2000Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_2000Q1_29, outset=cons_lo_2000Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_2000Q1_30, outset=cons_lo_2000Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_2000Q1_31, outset=cons_lo_2000Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_2000Q1_32, outset=cons_lo_2000Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_2000Q1_33, outset=cons_lo_2000Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_2000Q1_34, outset=cons_lo_2000Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_2000Q1_35, outset=cons_lo_2000Q1_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_2000Q1_36, outset=cons_lo_2000Q1_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_2000Q1_37, outset=cons_lo_2000Q1_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_2000Q1_38, outset=cons_lo_2000Q1_39, lags=35, lagname=est_lo_lag35);
%cons_lo(inset=cons_lo_2000Q1_39, outset=cons_lo_2000Q1, lags=36, lagname=est_lo_lag36);

data lo.lo_cons_2000Q1;
set cons_lo_2000Q1;
run;


/*1999*/

/*1999 Q4 Consumer Originations Plus Lags*/
data cons_lo_1999Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 40 then delete;
run;
proc sql;
create table cons_lo_1999Q4_2 as select a.*, b.ta
from cons_lo_1999Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1999Q4_3;
set cons_lo_1999Q4_2;
if ta=. then delete;
run;
/*Add 1999 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_1999Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1999Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1999Q4_4;
set cons_lo_1999Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19991231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1999Q4_4, outset=cons_lo_1999Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1999Q4_5, outset=cons_lo_1999Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1999Q4_6, outset=cons_lo_1999Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1999Q4_7, outset=cons_lo_1999Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1999Q4_8, outset=cons_lo_1999Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1999Q4_9, outset=cons_lo_1999Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1999Q4_10, outset=cons_lo_1999Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1999Q4_11, outset=cons_lo_1999Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1999Q4_12, outset=cons_lo_1999Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1999Q4_13, outset=cons_lo_1999Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1999Q4_14, outset=cons_lo_1999Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1999Q4_15, outset=cons_lo_1999Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1999Q4_16, outset=cons_lo_1999Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1999Q4_17, outset=cons_lo_1999Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1999Q4_18, outset=cons_lo_1999Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1999Q4_19, outset=cons_lo_1999Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1999Q4_20, outset=cons_lo_1999Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1999Q4_21, outset=cons_lo_1999Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1999Q4_22, outset=cons_lo_1999Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1999Q4_23, outset=cons_lo_1999Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1999Q4_24, outset=cons_lo_1999Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1999Q4_25, outset=cons_lo_1999Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1999Q4_26, outset=cons_lo_1999Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1999Q4_27, outset=cons_lo_1999Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1999Q4_28, outset=cons_lo_1999Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_1999Q4_29, outset=cons_lo_1999Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_1999Q4_30, outset=cons_lo_1999Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_1999Q4_31, outset=cons_lo_1999Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_1999Q4_32, outset=cons_lo_1999Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_1999Q4_33, outset=cons_lo_1999Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_1999Q4_34, outset=cons_lo_1999Q4_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_1999Q4_35, outset=cons_lo_1999Q4_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_1999Q4_36, outset=cons_lo_1999Q4_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_1999Q4_37, outset=cons_lo_1999Q4_38, lags=34, lagname=est_lo_lag34);
%cons_lo(inset=cons_lo_1999Q4_38, outset=cons_lo_1999Q4, lags=35, lagname=est_lo_lag35);

data lo.lo_cons_1999Q4;
set cons_lo_1999Q4;
run;


/*1999Q3 Consumer Originations Plus Lags*/
data cons_lo_1999Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 39 then delete;
run;
proc sql;
create table cons_lo_1999Q3_2 as select a.*, b.ta
from cons_lo_1999Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1999Q3_3;
set cons_lo_1999Q3_2;
if ta=. then delete;
run;
/*Add 1999Q3 Consumer loan originations*/
proc sql;
create table cons_lo_1999Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1999Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1999Q3_4;
set cons_lo_1999Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1999Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19990930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1999Q3_4, outset=cons_lo_1999Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1999Q3_5, outset=cons_lo_1999Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1999Q3_6, outset=cons_lo_1999Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1999Q3_7, outset=cons_lo_1999Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1999Q3_8, outset=cons_lo_1999Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1999Q3_9, outset=cons_lo_1999Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1999Q3_10, outset=cons_lo_1999Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1999Q3_11, outset=cons_lo_1999Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1999Q3_12, outset=cons_lo_1999Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1999Q3_13, outset=cons_lo_1999Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1999Q3_14, outset=cons_lo_1999Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1999Q3_15, outset=cons_lo_1999Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1999Q3_16, outset=cons_lo_1999Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1999Q3_17, outset=cons_lo_1999Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1999Q3_18, outset=cons_lo_1999Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1999Q3_19, outset=cons_lo_1999Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1999Q3_20, outset=cons_lo_1999Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1999Q3_21, outset=cons_lo_1999Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1999Q3_22, outset=cons_lo_1999Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1999Q3_23, outset=cons_lo_1999Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1999Q3_24, outset=cons_lo_1999Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1999Q3_25, outset=cons_lo_1999Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1999Q3_26, outset=cons_lo_1999Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1999Q3_27, outset=cons_lo_1999Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1999Q3_28, outset=cons_lo_1999Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_1999Q3_29, outset=cons_lo_1999Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_1999Q3_30, outset=cons_lo_1999Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_1999Q3_31, outset=cons_lo_1999Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_1999Q3_32, outset=cons_lo_1999Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_1999Q3_33, outset=cons_lo_1999Q3_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_1999Q3_34, outset=cons_lo_1999Q3_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_1999Q3_35, outset=cons_lo_1999Q3_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_1999Q3_36, outset=cons_lo_1999Q3_37, lags=33, lagname=est_lo_lag33);
%cons_lo(inset=cons_lo_1999Q3_37, outset=cons_lo_1999Q3, lags=34, lagname=est_lo_lag34);

data lo.lo_cons_1999Q3;
set cons_lo_1999Q3;
run;


/*1999Q2 Consumer Originations Plus Lags*/
data cons_lo_1999Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 38 then delete;
run;
proc sql;
create table cons_lo_1999Q2_2 as select a.*, b.ta
from cons_lo_1999Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1999Q2_3;
set cons_lo_1999Q2_2;
if ta=. then delete;
run;
/*Add 1999Q2 Consumer loan originations*/
proc sql;
create table cons_lo_1999Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1999Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1999Q2_4;
set cons_lo_1999Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1999Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19990630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1999Q2_4, outset=cons_lo_1999Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1999Q2_5, outset=cons_lo_1999Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1999Q2_6, outset=cons_lo_1999Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1999Q2_7, outset=cons_lo_1999Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1999Q2_8, outset=cons_lo_1999Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1999Q2_9, outset=cons_lo_1999Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1999Q2_10, outset=cons_lo_1999Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1999Q2_11, outset=cons_lo_1999Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1999Q2_12, outset=cons_lo_1999Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1999Q2_13, outset=cons_lo_1999Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1999Q2_14, outset=cons_lo_1999Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1999Q2_15, outset=cons_lo_1999Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1999Q2_16, outset=cons_lo_1999Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1999Q2_17, outset=cons_lo_1999Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1999Q2_18, outset=cons_lo_1999Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1999Q2_19, outset=cons_lo_1999Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1999Q2_20, outset=cons_lo_1999Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1999Q2_21, outset=cons_lo_1999Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1999Q2_22, outset=cons_lo_1999Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1999Q2_23, outset=cons_lo_1999Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1999Q2_24, outset=cons_lo_1999Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1999Q2_25, outset=cons_lo_1999Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1999Q2_26, outset=cons_lo_1999Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1999Q2_27, outset=cons_lo_1999Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1999Q2_28, outset=cons_lo_1999Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_1999Q2_29, outset=cons_lo_1999Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_1999Q2_30, outset=cons_lo_1999Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_1999Q2_31, outset=cons_lo_1999Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_1999Q2_32, outset=cons_lo_1999Q2_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_1999Q2_33, outset=cons_lo_1999Q2_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_1999Q2_34, outset=cons_lo_1999Q2_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_1999Q2_35, outset=cons_lo_1999Q2_36, lags=32, lagname=est_lo_lag32);
%cons_lo(inset=cons_lo_1999Q2_36, outset=cons_lo_1999Q2, lags=33, lagname=est_lo_lag33);

data lo.lo_cons_1999Q2;
set cons_lo_1999Q2;
run;


/*1999Q1 Consumer Originations Plus Lags*/
data cons_lo_1999Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 37 then delete;
run;
proc sql;
create table cons_lo_1999Q1_2 as select a.*, b.ta
from cons_lo_1999Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1999Q1_3;
set cons_lo_1999Q1_2;
if ta=. then delete;
run;
/*Add 1999Q1 Consumer loan originations*/
proc sql;
create table cons_lo_1999Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1999Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1999Q1_4;
set cons_lo_1999Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1999Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19990331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1999Q1_4, outset=cons_lo_1999Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1999Q1_5, outset=cons_lo_1999Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1999Q1_6, outset=cons_lo_1999Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1999Q1_7, outset=cons_lo_1999Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1999Q1_8, outset=cons_lo_1999Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1999Q1_9, outset=cons_lo_1999Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1999Q1_10, outset=cons_lo_1999Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1999Q1_11, outset=cons_lo_1999Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1999Q1_12, outset=cons_lo_1999Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1999Q1_13, outset=cons_lo_1999Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1999Q1_14, outset=cons_lo_1999Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1999Q1_15, outset=cons_lo_1999Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1999Q1_16, outset=cons_lo_1999Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1999Q1_17, outset=cons_lo_1999Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1999Q1_18, outset=cons_lo_1999Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1999Q1_19, outset=cons_lo_1999Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1999Q1_20, outset=cons_lo_1999Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1999Q1_21, outset=cons_lo_1999Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1999Q1_22, outset=cons_lo_1999Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1999Q1_23, outset=cons_lo_1999Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1999Q1_24, outset=cons_lo_1999Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1999Q1_25, outset=cons_lo_1999Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1999Q1_26, outset=cons_lo_1999Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1999Q1_27, outset=cons_lo_1999Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1999Q1_28, outset=cons_lo_1999Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_1999Q1_29, outset=cons_lo_1999Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_1999Q1_30, outset=cons_lo_1999Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_1999Q1_31, outset=cons_lo_1999Q1_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_1999Q1_32, outset=cons_lo_1999Q1_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_1999Q1_33, outset=cons_lo_1999Q1_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_1999Q1_34, outset=cons_lo_1999Q1_35, lags=31, lagname=est_lo_lag31);
%cons_lo(inset=cons_lo_1999Q1_35, outset=cons_lo_1999Q1, lags=32, lagname=est_lo_lag32);

data lo.lo_cons_1999Q1;
set cons_lo_1999Q1;
run;


/*1998*/

/*1998 Q4 Consumer Originations Plus Lags*/
data cons_lo_1998Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 36 then delete;
run;
proc sql;
create table cons_lo_1998Q4_2 as select a.*, b.ta
from cons_lo_1998Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1998Q4_3;
set cons_lo_1998Q4_2;
if ta=. then delete;
run;
/*Add 1998 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_1998Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1998Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1998Q4_4;
set cons_lo_1998Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19981231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1998Q4_4, outset=cons_lo_1998Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1998Q4_5, outset=cons_lo_1998Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1998Q4_6, outset=cons_lo_1998Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1998Q4_7, outset=cons_lo_1998Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1998Q4_8, outset=cons_lo_1998Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1998Q4_9, outset=cons_lo_1998Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1998Q4_10, outset=cons_lo_1998Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1998Q4_11, outset=cons_lo_1998Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1998Q4_12, outset=cons_lo_1998Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1998Q4_13, outset=cons_lo_1998Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1998Q4_14, outset=cons_lo_1998Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1998Q4_15, outset=cons_lo_1998Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1998Q4_16, outset=cons_lo_1998Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1998Q4_17, outset=cons_lo_1998Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1998Q4_18, outset=cons_lo_1998Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1998Q4_19, outset=cons_lo_1998Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1998Q4_20, outset=cons_lo_1998Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1998Q4_21, outset=cons_lo_1998Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1998Q4_22, outset=cons_lo_1998Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1998Q4_23, outset=cons_lo_1998Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1998Q4_24, outset=cons_lo_1998Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1998Q4_25, outset=cons_lo_1998Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1998Q4_26, outset=cons_lo_1998Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1998Q4_27, outset=cons_lo_1998Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1998Q4_28, outset=cons_lo_1998Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_1998Q4_29, outset=cons_lo_1998Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_1998Q4_30, outset=cons_lo_1998Q4_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_1998Q4_31, outset=cons_lo_1998Q4_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_1998Q4_32, outset=cons_lo_1998Q4_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_1998Q4_33, outset=cons_lo_1998Q4_34, lags=30, lagname=est_lo_lag30);
%cons_lo(inset=cons_lo_1998Q4_34, outset=cons_lo_1998Q4, lags=31, lagname=est_lo_lag31);

data lo.lo_cons_1998Q4;
set cons_lo_1998Q4;
run;


/*1998Q3 Consumer Originations Plus Lags*/
data cons_lo_1998Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 35 then delete;
run;
proc sql;
create table cons_lo_1998Q3_2 as select a.*, b.ta
from cons_lo_1998Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1998Q3_3;
set cons_lo_1998Q3_2;
if ta=. then delete;
run;
/*Add 1998Q3 Consumer loan originations*/
proc sql;
create table cons_lo_1998Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1998Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1998Q3_4;
set cons_lo_1998Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1998Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19980930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1998Q3_4, outset=cons_lo_1998Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1998Q3_5, outset=cons_lo_1998Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1998Q3_6, outset=cons_lo_1998Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1998Q3_7, outset=cons_lo_1998Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1998Q3_8, outset=cons_lo_1998Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1998Q3_9, outset=cons_lo_1998Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1998Q3_10, outset=cons_lo_1998Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1998Q3_11, outset=cons_lo_1998Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1998Q3_12, outset=cons_lo_1998Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1998Q3_13, outset=cons_lo_1998Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1998Q3_14, outset=cons_lo_1998Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1998Q3_15, outset=cons_lo_1998Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1998Q3_16, outset=cons_lo_1998Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1998Q3_17, outset=cons_lo_1998Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1998Q3_18, outset=cons_lo_1998Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1998Q3_19, outset=cons_lo_1998Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1998Q3_20, outset=cons_lo_1998Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1998Q3_21, outset=cons_lo_1998Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1998Q3_22, outset=cons_lo_1998Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1998Q3_23, outset=cons_lo_1998Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1998Q3_24, outset=cons_lo_1998Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1998Q3_25, outset=cons_lo_1998Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1998Q3_26, outset=cons_lo_1998Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1998Q3_27, outset=cons_lo_1998Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1998Q3_28, outset=cons_lo_1998Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_1998Q3_29, outset=cons_lo_1998Q3_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_1998Q3_30, outset=cons_lo_1998Q3_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_1998Q3_31, outset=cons_lo_1998Q3_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_1998Q3_32, outset=cons_lo_1998Q3_33, lags=29, lagname=est_lo_lag29);
%cons_lo(inset=cons_lo_1998Q3_33, outset=cons_lo_1998Q3, lags=30, lagname=est_lo_lag30);

data lo.lo_cons_1998Q3;
set cons_lo_1998Q3;
run;


/*1998Q2 Consumer Originations Plus Lags*/
data cons_lo_1998Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 34 then delete;
run;
proc sql;
create table cons_lo_1998Q2_2 as select a.*, b.ta
from cons_lo_1998Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1998Q2_3;
set cons_lo_1998Q2_2;
if ta=. then delete;
run;
/*Add 1998Q2 Consumer loan originations*/
proc sql;
create table cons_lo_1998Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1998Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1998Q2_4;
set cons_lo_1998Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1998Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19980630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1998Q2_4, outset=cons_lo_1998Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1998Q2_5, outset=cons_lo_1998Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1998Q2_6, outset=cons_lo_1998Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1998Q2_7, outset=cons_lo_1998Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1998Q2_8, outset=cons_lo_1998Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1998Q2_9, outset=cons_lo_1998Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1998Q2_10, outset=cons_lo_1998Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1998Q2_11, outset=cons_lo_1998Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1998Q2_12, outset=cons_lo_1998Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1998Q2_13, outset=cons_lo_1998Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1998Q2_14, outset=cons_lo_1998Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1998Q2_15, outset=cons_lo_1998Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1998Q2_16, outset=cons_lo_1998Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1998Q2_17, outset=cons_lo_1998Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1998Q2_18, outset=cons_lo_1998Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1998Q2_19, outset=cons_lo_1998Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1998Q2_20, outset=cons_lo_1998Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1998Q2_21, outset=cons_lo_1998Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1998Q2_22, outset=cons_lo_1998Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1998Q2_23, outset=cons_lo_1998Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1998Q2_24, outset=cons_lo_1998Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1998Q2_25, outset=cons_lo_1998Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1998Q2_26, outset=cons_lo_1998Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1998Q2_27, outset=cons_lo_1998Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1998Q2_28, outset=cons_lo_1998Q2_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_1998Q2_29, outset=cons_lo_1998Q2_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_1998Q2_30, outset=cons_lo_1998Q2_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_1998Q2_31, outset=cons_lo_1998Q2_32, lags=28, lagname=est_lo_lag28);
%cons_lo(inset=cons_lo_1998Q2_32, outset=cons_lo_1998Q2, lags=29, lagname=est_lo_lag29);

data lo.lo_cons_1998Q2;
set cons_lo_1998Q2;
run;


/*1998Q1 Consumer Originations Plus Lags*/
data cons_lo_1998Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 33 then delete;
run;
proc sql;
create table cons_lo_1998Q1_2 as select a.*, b.ta
from cons_lo_1998Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1998Q1_3;
set cons_lo_1998Q1_2;
if ta=. then delete;
run;
/*Add 1998Q1 Consumer loan originations*/
proc sql;
create table cons_lo_1998Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1998Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1998Q1_4;
set cons_lo_1998Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1998Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19980331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1998Q1_4, outset=cons_lo_1998Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1998Q1_5, outset=cons_lo_1998Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1998Q1_6, outset=cons_lo_1998Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1998Q1_7, outset=cons_lo_1998Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1998Q1_8, outset=cons_lo_1998Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1998Q1_9, outset=cons_lo_1998Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1998Q1_10, outset=cons_lo_1998Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1998Q1_11, outset=cons_lo_1998Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1998Q1_12, outset=cons_lo_1998Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1998Q1_13, outset=cons_lo_1998Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1998Q1_14, outset=cons_lo_1998Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1998Q1_15, outset=cons_lo_1998Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1998Q1_16, outset=cons_lo_1998Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1998Q1_17, outset=cons_lo_1998Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1998Q1_18, outset=cons_lo_1998Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1998Q1_19, outset=cons_lo_1998Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1998Q1_20, outset=cons_lo_1998Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1998Q1_21, outset=cons_lo_1998Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1998Q1_22, outset=cons_lo_1998Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1998Q1_23, outset=cons_lo_1998Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1998Q1_24, outset=cons_lo_1998Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1998Q1_25, outset=cons_lo_1998Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1998Q1_26, outset=cons_lo_1998Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1998Q1_27, outset=cons_lo_1998Q1_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1998Q1_28, outset=cons_lo_1998Q1_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_1998Q1_29, outset=cons_lo_1998Q1_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_1998Q1_30, outset=cons_lo_1998Q1_31, lags=27, lagname=est_lo_lag27);
%cons_lo(inset=cons_lo_1998Q1_31, outset=cons_lo_1998Q1, lags=28, lagname=est_lo_lag28);

data lo.lo_cons_1998Q1;
set cons_lo_1998Q1;
run;

/*1997*/

/*1997 Q4 Consumer Originations Plus Lags*/
data cons_lo_1997Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 32 then delete;
run;
proc sql;
create table cons_lo_1997Q4_2 as select a.*, b.ta
from cons_lo_1997Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1997Q4_3;
set cons_lo_1997Q4_2;
if ta=. then delete;
run;
/*Add 1997 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_1997Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1997Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1997Q4_4;
set cons_lo_1997Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19971231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1997Q4_4, outset=cons_lo_1997Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1997Q4_5, outset=cons_lo_1997Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1997Q4_6, outset=cons_lo_1997Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1997Q4_7, outset=cons_lo_1997Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1997Q4_8, outset=cons_lo_1997Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1997Q4_9, outset=cons_lo_1997Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1997Q4_10, outset=cons_lo_1997Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1997Q4_11, outset=cons_lo_1997Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1997Q4_12, outset=cons_lo_1997Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1997Q4_13, outset=cons_lo_1997Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1997Q4_14, outset=cons_lo_1997Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1997Q4_15, outset=cons_lo_1997Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1997Q4_16, outset=cons_lo_1997Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1997Q4_17, outset=cons_lo_1997Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1997Q4_18, outset=cons_lo_1997Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1997Q4_19, outset=cons_lo_1997Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1997Q4_20, outset=cons_lo_1997Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1997Q4_21, outset=cons_lo_1997Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1997Q4_22, outset=cons_lo_1997Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1997Q4_23, outset=cons_lo_1997Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1997Q4_24, outset=cons_lo_1997Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1997Q4_25, outset=cons_lo_1997Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1997Q4_26, outset=cons_lo_1997Q4_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1997Q4_27, outset=cons_lo_1997Q4_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1997Q4_28, outset=cons_lo_1997Q4_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_1997Q4_29, outset=cons_lo_1997Q4_30, lags=26, lagname=est_lo_lag26);
%cons_lo(inset=cons_lo_1997Q4_30, outset=cons_lo_1997Q4, lags=27, lagname=est_lo_lag27);

data lo.lo_cons_1997Q4;
set cons_lo_1997Q4;
run;


/*1997Q3 Consumer Originations Plus Lags*/
data cons_lo_1997Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 31 then delete;
run;
proc sql;
create table cons_lo_1997Q3_2 as select a.*, b.ta
from cons_lo_1997Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1997Q3_3;
set cons_lo_1997Q3_2;
if ta=. then delete;
run;
/*Add 1997Q3 Consumer loan originations*/
proc sql;
create table cons_lo_1997Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1997Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1997Q3_4;
set cons_lo_1997Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1997Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19970930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1997Q3_4, outset=cons_lo_1997Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1997Q3_5, outset=cons_lo_1997Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1997Q3_6, outset=cons_lo_1997Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1997Q3_7, outset=cons_lo_1997Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1997Q3_8, outset=cons_lo_1997Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1997Q3_9, outset=cons_lo_1997Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1997Q3_10, outset=cons_lo_1997Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1997Q3_11, outset=cons_lo_1997Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1997Q3_12, outset=cons_lo_1997Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1997Q3_13, outset=cons_lo_1997Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1997Q3_14, outset=cons_lo_1997Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1997Q3_15, outset=cons_lo_1997Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1997Q3_16, outset=cons_lo_1997Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1997Q3_17, outset=cons_lo_1997Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1997Q3_18, outset=cons_lo_1997Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1997Q3_19, outset=cons_lo_1997Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1997Q3_20, outset=cons_lo_1997Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1997Q3_21, outset=cons_lo_1997Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1997Q3_22, outset=cons_lo_1997Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1997Q3_23, outset=cons_lo_1997Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1997Q3_24, outset=cons_lo_1997Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1997Q3_25, outset=cons_lo_1997Q3_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1997Q3_26, outset=cons_lo_1997Q3_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1997Q3_27, outset=cons_lo_1997Q3_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1997Q3_28, outset=cons_lo_1997Q3_29, lags=25, lagname=est_lo_lag25);
%cons_lo(inset=cons_lo_1997Q3_29, outset=cons_lo_1997Q3, lags=26, lagname=est_lo_lag26);

data lo.lo_cons_1997Q3;
set cons_lo_1997Q3;
run;


/*1997Q2 Consumer Originations Plus Lags*/
data cons_lo_1997Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 30 then delete;
run;
proc sql;
create table cons_lo_1997Q2_2 as select a.*, b.ta
from cons_lo_1997Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1997Q2_3;
set cons_lo_1997Q2_2;
if ta=. then delete;
run;
/*Add 1997Q2 Consumer loan originations*/
proc sql;
create table cons_lo_1997Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1997Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1997Q2_4;
set cons_lo_1997Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1997Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19970630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1997Q2_4, outset=cons_lo_1997Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1997Q2_5, outset=cons_lo_1997Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1997Q2_6, outset=cons_lo_1997Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1997Q2_7, outset=cons_lo_1997Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1997Q2_8, outset=cons_lo_1997Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1997Q2_9, outset=cons_lo_1997Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1997Q2_10, outset=cons_lo_1997Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1997Q2_11, outset=cons_lo_1997Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1997Q2_12, outset=cons_lo_1997Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1997Q2_13, outset=cons_lo_1997Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1997Q2_14, outset=cons_lo_1997Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1997Q2_15, outset=cons_lo_1997Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1997Q2_16, outset=cons_lo_1997Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1997Q2_17, outset=cons_lo_1997Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1997Q2_18, outset=cons_lo_1997Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1997Q2_19, outset=cons_lo_1997Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1997Q2_20, outset=cons_lo_1997Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1997Q2_21, outset=cons_lo_1997Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1997Q2_22, outset=cons_lo_1997Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1997Q2_23, outset=cons_lo_1997Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1997Q2_24, outset=cons_lo_1997Q2_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1997Q2_25, outset=cons_lo_1997Q2_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1997Q2_26, outset=cons_lo_1997Q2_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1997Q2_27, outset=cons_lo_1997Q2_28, lags=24, lagname=est_lo_lag24);
%cons_lo(inset=cons_lo_1997Q2_28, outset=cons_lo_1997Q2, lags=25, lagname=est_lo_lag25);

data lo.lo_cons_1997Q2;
set cons_lo_1997Q2;
run;


/*1997Q1 Consumer Originations Plus Lags*/
data cons_lo_1997Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 29 then delete;
run;
proc sql;
create table cons_lo_1997Q1_2 as select a.*, b.ta
from cons_lo_1997Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1997Q1_3;
set cons_lo_1997Q1_2;
if ta=. then delete;
run;
/*Add 1997Q1 Consumer loan originations*/
proc sql;
create table cons_lo_1997Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1997Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1997Q1_4;
set cons_lo_1997Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1997Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19970331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1997Q1_4, outset=cons_lo_1997Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1997Q1_5, outset=cons_lo_1997Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1997Q1_6, outset=cons_lo_1997Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1997Q1_7, outset=cons_lo_1997Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1997Q1_8, outset=cons_lo_1997Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1997Q1_9, outset=cons_lo_1997Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1997Q1_10, outset=cons_lo_1997Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1997Q1_11, outset=cons_lo_1997Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1997Q1_12, outset=cons_lo_1997Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1997Q1_13, outset=cons_lo_1997Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1997Q1_14, outset=cons_lo_1997Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1997Q1_15, outset=cons_lo_1997Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1997Q1_16, outset=cons_lo_1997Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1997Q1_17, outset=cons_lo_1997Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1997Q1_18, outset=cons_lo_1997Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1997Q1_19, outset=cons_lo_1997Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1997Q1_20, outset=cons_lo_1997Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1997Q1_21, outset=cons_lo_1997Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1997Q1_22, outset=cons_lo_1997Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1997Q1_23, outset=cons_lo_1997Q1_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1997Q1_24, outset=cons_lo_1997Q1_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1997Q1_25, outset=cons_lo_1997Q1_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1997Q1_26, outset=cons_lo_1997Q1_27, lags=23, lagname=est_lo_lag23);
%cons_lo(inset=cons_lo_1997Q1_27, outset=cons_lo_1997Q1, lags=24, lagname=est_lo_lag24);

data lo.lo_cons_1997Q1;
set cons_lo_1997Q1;
run;


/*1996*/

/*1996 Q4 Consumer Originations Plus Lags*/
data cons_lo_1996Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 28 then delete;
run;
proc sql;
create table cons_lo_1996Q4_2 as select a.*, b.ta
from cons_lo_1996Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1996Q4_3;
set cons_lo_1996Q4_2;
if ta=. then delete;
run;
/*Add 1996 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_1996Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1996Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1996Q4_4;
set cons_lo_1996Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19961231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1996Q4_4, outset=cons_lo_1996Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1996Q4_5, outset=cons_lo_1996Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1996Q4_6, outset=cons_lo_1996Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1996Q4_7, outset=cons_lo_1996Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1996Q4_8, outset=cons_lo_1996Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1996Q4_9, outset=cons_lo_1996Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1996Q4_10, outset=cons_lo_1996Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1996Q4_11, outset=cons_lo_1996Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1996Q4_12, outset=cons_lo_1996Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1996Q4_13, outset=cons_lo_1996Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1996Q4_14, outset=cons_lo_1996Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1996Q4_15, outset=cons_lo_1996Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1996Q4_16, outset=cons_lo_1996Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1996Q4_17, outset=cons_lo_1996Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1996Q4_18, outset=cons_lo_1996Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1996Q4_19, outset=cons_lo_1996Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1996Q4_20, outset=cons_lo_1996Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1996Q4_21, outset=cons_lo_1996Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1996Q4_22, outset=cons_lo_1996Q4_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1996Q4_23, outset=cons_lo_1996Q4_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1996Q4_24, outset=cons_lo_1996Q4_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1996Q4_25, outset=cons_lo_1996Q4_26, lags=22, lagname=est_lo_lag22);
%cons_lo(inset=cons_lo_1996Q4_26, outset=cons_lo_1996Q4, lags=23, lagname=est_lo_lag23);

data lo.lo_cons_1996Q4;
set cons_lo_1996Q4;
run;


/*1996Q3 Consumer Originations Plus Lags*/
data cons_lo_1996Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 27 then delete;
run;
proc sql;
create table cons_lo_1996Q3_2 as select a.*, b.ta
from cons_lo_1996Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1996Q3_3;
set cons_lo_1996Q3_2;
if ta=. then delete;
run;
/*Add 1996Q3 Consumer loan originations*/
proc sql;
create table cons_lo_1996Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1996Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1996Q3_4;
set cons_lo_1996Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1996Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19960930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1996Q3_4, outset=cons_lo_1996Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1996Q3_5, outset=cons_lo_1996Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1996Q3_6, outset=cons_lo_1996Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1996Q3_7, outset=cons_lo_1996Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1996Q3_8, outset=cons_lo_1996Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1996Q3_9, outset=cons_lo_1996Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1996Q3_10, outset=cons_lo_1996Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1996Q3_11, outset=cons_lo_1996Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1996Q3_12, outset=cons_lo_1996Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1996Q3_13, outset=cons_lo_1996Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1996Q3_14, outset=cons_lo_1996Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1996Q3_15, outset=cons_lo_1996Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1996Q3_16, outset=cons_lo_1996Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1996Q3_17, outset=cons_lo_1996Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1996Q3_18, outset=cons_lo_1996Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1996Q3_19, outset=cons_lo_1996Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1996Q3_20, outset=cons_lo_1996Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1996Q3_21, outset=cons_lo_1996Q3_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1996Q3_22, outset=cons_lo_1996Q3_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1996Q3_23, outset=cons_lo_1996Q3_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1996Q3_24, outset=cons_lo_1996Q3_25, lags=21, lagname=est_lo_lag21);
%cons_lo(inset=cons_lo_1996Q3_25, outset=cons_lo_1996Q3, lags=22, lagname=est_lo_lag22);

data lo.lo_cons_1996Q3;
set cons_lo_1996Q3;
run;


/*1996Q2 Consumer Originations Plus Lags*/
data cons_lo_1996Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 26 then delete;
run;
proc sql;
create table cons_lo_1996Q2_2 as select a.*, b.ta
from cons_lo_1996Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1996Q2_3;
set cons_lo_1996Q2_2;
if ta=. then delete;
run;
/*Add 1996Q2 Consumer loan originations*/
proc sql;
create table cons_lo_1996Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1996Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1996Q2_4;
set cons_lo_1996Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1996Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19960630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1996Q2_4, outset=cons_lo_1996Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1996Q2_5, outset=cons_lo_1996Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1996Q2_6, outset=cons_lo_1996Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1996Q2_7, outset=cons_lo_1996Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1996Q2_8, outset=cons_lo_1996Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1996Q2_9, outset=cons_lo_1996Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1996Q2_10, outset=cons_lo_1996Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1996Q2_11, outset=cons_lo_1996Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1996Q2_12, outset=cons_lo_1996Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1996Q2_13, outset=cons_lo_1996Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1996Q2_14, outset=cons_lo_1996Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1996Q2_15, outset=cons_lo_1996Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1996Q2_16, outset=cons_lo_1996Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1996Q2_17, outset=cons_lo_1996Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1996Q2_18, outset=cons_lo_1996Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1996Q2_19, outset=cons_lo_1996Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1996Q2_20, outset=cons_lo_1996Q2_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1996Q2_21, outset=cons_lo_1996Q2_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1996Q2_22, outset=cons_lo_1996Q2_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1996Q2_23, outset=cons_lo_1996Q2_24, lags=20, lagname=est_lo_lag20);
%cons_lo(inset=cons_lo_1996Q2_24, outset=cons_lo_1996Q2, lags=21, lagname=est_lo_lag21);

data lo.lo_cons_1996Q2;
set cons_lo_1996Q2;
run;


/*1996Q1 Consumer Originations Plus Lags*/
data cons_lo_1996Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 25 then delete;
run;
proc sql;
create table cons_lo_1996Q1_2 as select a.*, b.ta
from cons_lo_1996Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1996Q1_3;
set cons_lo_1996Q1_2;
if ta=. then delete;
run;
/*Add 1996Q1 Consumer loan originations*/
proc sql;
create table cons_lo_1996Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1996Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1996Q1_4;
set cons_lo_1996Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1996Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19960331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1996Q1_4, outset=cons_lo_1996Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1996Q1_5, outset=cons_lo_1996Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1996Q1_6, outset=cons_lo_1996Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1996Q1_7, outset=cons_lo_1996Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1996Q1_8, outset=cons_lo_1996Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1996Q1_9, outset=cons_lo_1996Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1996Q1_10, outset=cons_lo_1996Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1996Q1_11, outset=cons_lo_1996Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1996Q1_12, outset=cons_lo_1996Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1996Q1_13, outset=cons_lo_1996Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1996Q1_14, outset=cons_lo_1996Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1996Q1_15, outset=cons_lo_1996Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1996Q1_16, outset=cons_lo_1996Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1996Q1_17, outset=cons_lo_1996Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1996Q1_18, outset=cons_lo_1996Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1996Q1_19, outset=cons_lo_1996Q1_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1996Q1_20, outset=cons_lo_1996Q1_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1996Q1_21, outset=cons_lo_1996Q1_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1996Q1_22, outset=cons_lo_1996Q1_23, lags=19, lagname=est_lo_lag19);
%cons_lo(inset=cons_lo_1996Q1_23, outset=cons_lo_1996Q1, lags=20, lagname=est_lo_lag20);

data lo.lo_cons_1996Q1;
set cons_lo_1996Q1;
run;

dm 'clear log';
/*1995*/

/*1995 Q4 Consumer Originations Plus Lags*/
data cons_lo_1995Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 24 then delete;
run;
proc sql;
create table cons_lo_1995Q4_2 as select a.*, b.ta
from cons_lo_1995Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1995Q4_3;
set cons_lo_1995Q4_2;
if ta=. then delete;
run;
/*Add 1995 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_1995Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1995Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1995Q4_4;
set cons_lo_1995Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19951231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1995Q4_4, outset=cons_lo_1995Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1995Q4_5, outset=cons_lo_1995Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1995Q4_6, outset=cons_lo_1995Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1995Q4_7, outset=cons_lo_1995Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1995Q4_8, outset=cons_lo_1995Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1995Q4_9, outset=cons_lo_1995Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1995Q4_10, outset=cons_lo_1995Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1995Q4_11, outset=cons_lo_1995Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1995Q4_12, outset=cons_lo_1995Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1995Q4_13, outset=cons_lo_1995Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1995Q4_14, outset=cons_lo_1995Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1995Q4_15, outset=cons_lo_1995Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1995Q4_16, outset=cons_lo_1995Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1995Q4_17, outset=cons_lo_1995Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1995Q4_18, outset=cons_lo_1995Q4_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1995Q4_19, outset=cons_lo_1995Q4_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1995Q4_20, outset=cons_lo_1995Q4_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1995Q4_21, outset=cons_lo_1995Q4_22, lags=18, lagname=est_lo_lag18);
%cons_lo(inset=cons_lo_1995Q4_22, outset=cons_lo_1995Q4, lags=19, lagname=est_lo_lag19);

data lo.lo_cons_1995Q4;
set cons_lo_1995Q4;
run;


/*1995Q3 Consumer Originations Plus Lags*/
data cons_lo_1995Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 23 then delete;
run;
proc sql;
create table cons_lo_1995Q3_2 as select a.*, b.ta
from cons_lo_1995Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1995Q3_3;
set cons_lo_1995Q3_2;
if ta=. then delete;
run;
/*Add 1995Q3 Consumer loan originations*/
proc sql;
create table cons_lo_1995Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1995Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1995Q3_4;
set cons_lo_1995Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1995Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19950930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1995Q3_4, outset=cons_lo_1995Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1995Q3_5, outset=cons_lo_1995Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1995Q3_6, outset=cons_lo_1995Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1995Q3_7, outset=cons_lo_1995Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1995Q3_8, outset=cons_lo_1995Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1995Q3_9, outset=cons_lo_1995Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1995Q3_10, outset=cons_lo_1995Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1995Q3_11, outset=cons_lo_1995Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1995Q3_12, outset=cons_lo_1995Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1995Q3_13, outset=cons_lo_1995Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1995Q3_14, outset=cons_lo_1995Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1995Q3_15, outset=cons_lo_1995Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1995Q3_16, outset=cons_lo_1995Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1995Q3_17, outset=cons_lo_1995Q3_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1995Q3_18, outset=cons_lo_1995Q3_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1995Q3_19, outset=cons_lo_1995Q3_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1995Q3_20, outset=cons_lo_1995Q3_21, lags=17, lagname=est_lo_lag17);
%cons_lo(inset=cons_lo_1995Q3_21, outset=cons_lo_1995Q3, lags=18, lagname=est_lo_lag18);

data lo.lo_cons_1995Q3;
set cons_lo_1995Q3;
run;


/*1995Q2 Consumer Originations Plus Lags*/
data cons_lo_1995Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 22 then delete;
run;
proc sql;
create table cons_lo_1995Q2_2 as select a.*, b.ta
from cons_lo_1995Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1995Q2_3;
set cons_lo_1995Q2_2;
if ta=. then delete;
run;
/*Add 1995Q2 Consumer loan originations*/
proc sql;
create table cons_lo_1995Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1995Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1995Q2_4;
set cons_lo_1995Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1995Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19950630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1995Q2_4, outset=cons_lo_1995Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1995Q2_5, outset=cons_lo_1995Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1995Q2_6, outset=cons_lo_1995Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1995Q2_7, outset=cons_lo_1995Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1995Q2_8, outset=cons_lo_1995Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1995Q2_9, outset=cons_lo_1995Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1995Q2_10, outset=cons_lo_1995Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1995Q2_11, outset=cons_lo_1995Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1995Q2_12, outset=cons_lo_1995Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1995Q2_13, outset=cons_lo_1995Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1995Q2_14, outset=cons_lo_1995Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1995Q2_15, outset=cons_lo_1995Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1995Q2_16, outset=cons_lo_1995Q2_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1995Q2_17, outset=cons_lo_1995Q2_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1995Q2_18, outset=cons_lo_1995Q2_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1995Q2_19, outset=cons_lo_1995Q2_20, lags=16, lagname=est_lo_lag16);
%cons_lo(inset=cons_lo_1995Q2_20, outset=cons_lo_1995Q2, lags=17, lagname=est_lo_lag17);

data lo.lo_cons_1995Q2;
set cons_lo_1995Q2;
run;


/*1995Q1 Consumer Originations Plus Lags*/
data cons_lo_1995Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 21 then delete;
run;
proc sql;
create table cons_lo_1995Q1_2 as select a.*, b.ta
from cons_lo_1995Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1995Q1_3;
set cons_lo_1995Q1_2;
if ta=. then delete;
run;
/*Add 1995Q1 Consumer loan originations*/
proc sql;
create table cons_lo_1995Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1995Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1995Q1_4;
set cons_lo_1995Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1995Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19950331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1995Q1_4, outset=cons_lo_1995Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1995Q1_5, outset=cons_lo_1995Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1995Q1_6, outset=cons_lo_1995Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1995Q1_7, outset=cons_lo_1995Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1995Q1_8, outset=cons_lo_1995Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1995Q1_9, outset=cons_lo_1995Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1995Q1_10, outset=cons_lo_1995Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1995Q1_11, outset=cons_lo_1995Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1995Q1_12, outset=cons_lo_1995Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1995Q1_13, outset=cons_lo_1995Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1995Q1_14, outset=cons_lo_1995Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1995Q1_15, outset=cons_lo_1995Q1_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1995Q1_16, outset=cons_lo_1995Q1_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1995Q1_17, outset=cons_lo_1995Q1_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1995Q1_18, outset=cons_lo_1995Q1_19, lags=15, lagname=est_lo_lag15);
%cons_lo(inset=cons_lo_1995Q1_19, outset=cons_lo_1995Q1, lags=16, lagname=est_lo_lag16);

data lo.lo_cons_1995Q1;
set cons_lo_1995Q1;
run;


/*1994*/

/*1994 Q4 Consumer Originations Plus Lags*/
data cons_lo_1994Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 20 then delete;
run;
proc sql;
create table cons_lo_1994Q4_2 as select a.*, b.ta
from cons_lo_1994Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1994Q4_3;
set cons_lo_1994Q4_2;
if ta=. then delete;
run;
/*Add 1994 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_1994Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1994Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1994Q4_4;
set cons_lo_1994Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19941231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1994Q4_4, outset=cons_lo_1994Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1994Q4_5, outset=cons_lo_1994Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1994Q4_6, outset=cons_lo_1994Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1994Q4_7, outset=cons_lo_1994Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1994Q4_8, outset=cons_lo_1994Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1994Q4_9, outset=cons_lo_1994Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1994Q4_10, outset=cons_lo_1994Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1994Q4_11, outset=cons_lo_1994Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1994Q4_12, outset=cons_lo_1994Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1994Q4_13, outset=cons_lo_1994Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1994Q4_14, outset=cons_lo_1994Q4_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1994Q4_15, outset=cons_lo_1994Q4_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1994Q4_16, outset=cons_lo_1994Q4_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1994Q4_17, outset=cons_lo_1994Q4_18, lags=14, lagname=est_lo_lag14);
%cons_lo(inset=cons_lo_1994Q4_18, outset=cons_lo_1994Q4, lags=15, lagname=est_lo_lag15);

data lo.lo_cons_1994Q4;
set cons_lo_1994Q4;
run;


/*1994Q3 Consumer Originations Plus Lags*/
data cons_lo_1994Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 19 then delete;
run;
proc sql;
create table cons_lo_1994Q3_2 as select a.*, b.ta
from cons_lo_1994Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1994Q3_3;
set cons_lo_1994Q3_2;
if ta=. then delete;
run;
/*Add 1994Q3 Consumer loan originations*/
proc sql;
create table cons_lo_1994Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1994Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1994Q3_4;
set cons_lo_1994Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1994Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19940930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1994Q3_4, outset=cons_lo_1994Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1994Q3_5, outset=cons_lo_1994Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1994Q3_6, outset=cons_lo_1994Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1994Q3_7, outset=cons_lo_1994Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1994Q3_8, outset=cons_lo_1994Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1994Q3_9, outset=cons_lo_1994Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1994Q3_10, outset=cons_lo_1994Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1994Q3_11, outset=cons_lo_1994Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1994Q3_12, outset=cons_lo_1994Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1994Q3_13, outset=cons_lo_1994Q3_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1994Q3_14, outset=cons_lo_1994Q3_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1994Q3_15, outset=cons_lo_1994Q3_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1994Q3_16, outset=cons_lo_1994Q3_17, lags=13, lagname=est_lo_lag13);
%cons_lo(inset=cons_lo_1994Q3_17, outset=cons_lo_1994Q3, lags=14, lagname=est_lo_lag14);

data lo.lo_cons_1994Q3;
set cons_lo_1994Q3;
run;


/*1994Q2 Consumer Originations Plus Lags*/
data cons_lo_1994Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 18 then delete;
run;
proc sql;
create table cons_lo_1994Q2_2 as select a.*, b.ta
from cons_lo_1994Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1994Q2_3;
set cons_lo_1994Q2_2;
if ta=. then delete;
run;
/*Add 1994Q2 Consumer loan originations*/
proc sql;
create table cons_lo_1994Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1994Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1994Q2_4;
set cons_lo_1994Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1994Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19940630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1994Q2_4, outset=cons_lo_1994Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1994Q2_5, outset=cons_lo_1994Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1994Q2_6, outset=cons_lo_1994Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1994Q2_7, outset=cons_lo_1994Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1994Q2_8, outset=cons_lo_1994Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1994Q2_9, outset=cons_lo_1994Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1994Q2_10, outset=cons_lo_1994Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1994Q2_11, outset=cons_lo_1994Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1994Q2_12, outset=cons_lo_1994Q2_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1994Q2_13, outset=cons_lo_1994Q2_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1994Q2_14, outset=cons_lo_1994Q2_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1994Q2_15, outset=cons_lo_1994Q2_16, lags=12, lagname=est_lo_lag12);
%cons_lo(inset=cons_lo_1994Q2_16, outset=cons_lo_1994Q2, lags=13, lagname=est_lo_lag13);

data lo.lo_cons_1994Q2;
set cons_lo_1994Q2;
run;


/*1994Q1 Consumer Originations Plus Lags*/
data cons_lo_1994Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 17 then delete;
run;
proc sql;
create table cons_lo_1994Q1_2 as select a.*, b.ta
from cons_lo_1994Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1994Q1_3;
set cons_lo_1994Q1_2;
if ta=. then delete;
run;
/*Add 1994Q1 Consumer loan originations*/
proc sql;
create table cons_lo_1994Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1994Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1994Q1_4;
set cons_lo_1994Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1994Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19940331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1994Q1_4, outset=cons_lo_1994Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1994Q1_5, outset=cons_lo_1994Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1994Q1_6, outset=cons_lo_1994Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1994Q1_7, outset=cons_lo_1994Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1994Q1_8, outset=cons_lo_1994Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1994Q1_9, outset=cons_lo_1994Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1994Q1_10, outset=cons_lo_1994Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1994Q1_11, outset=cons_lo_1994Q1_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1994Q1_12, outset=cons_lo_1994Q1_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1994Q1_13, outset=cons_lo_1994Q1_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1994Q1_14, outset=cons_lo_1994Q1_15, lags=11, lagname=est_lo_lag11);
%cons_lo(inset=cons_lo_1994Q1_15, outset=cons_lo_1994Q1, lags=12, lagname=est_lo_lag12);

data lo.lo_cons_1994Q1;
set cons_lo_1994Q1;
run;


/*1993*/

/*1993 Q4 Consumer Originations Plus Lags*/
data cons_lo_1993Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 16 then delete;
run;
proc sql;
create table cons_lo_1993Q4_2 as select a.*, b.ta
from cons_lo_1993Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1993Q4_3;
set cons_lo_1993Q4_2;
if ta=. then delete;
run;
/*Add 1993 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_1993Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1993Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1993Q4_4;
set cons_lo_1993Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19931231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1993Q4_4, outset=cons_lo_1993Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1993Q4_5, outset=cons_lo_1993Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1993Q4_6, outset=cons_lo_1993Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1993Q4_7, outset=cons_lo_1993Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1993Q4_8, outset=cons_lo_1993Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1993Q4_9, outset=cons_lo_1993Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1993Q4_10, outset=cons_lo_1993Q4_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1993Q4_11, outset=cons_lo_1993Q4_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1993Q4_12, outset=cons_lo_1993Q4_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1993Q4_13, outset=cons_lo_1993Q4_14, lags=10, lagname=est_lo_lag10);
%cons_lo(inset=cons_lo_1993Q4_14, outset=cons_lo_1993Q4, lags=11, lagname=est_lo_lag11);

data lo.lo_cons_1993Q4;
set cons_lo_1993Q4;
run;


/*1993Q3 Consumer Originations Plus Lags*/
data cons_lo_1993Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 15 then delete;
run;
proc sql;
create table cons_lo_1993Q3_2 as select a.*, b.ta
from cons_lo_1993Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1993Q3_3;
set cons_lo_1993Q3_2;
if ta=. then delete;
run;
/*Add 1993Q3 Consumer loan originations*/
proc sql;
create table cons_lo_1993Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1993Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1993Q3_4;
set cons_lo_1993Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1993Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19930930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1993Q3_4, outset=cons_lo_1993Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1993Q3_5, outset=cons_lo_1993Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1993Q3_6, outset=cons_lo_1993Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1993Q3_7, outset=cons_lo_1993Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1993Q3_8, outset=cons_lo_1993Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1993Q3_9, outset=cons_lo_1993Q3_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1993Q3_10, outset=cons_lo_1993Q3_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1993Q3_11, outset=cons_lo_1993Q3_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1993Q3_12, outset=cons_lo_1993Q3_13, lags=9, lagname=est_lo_lag9);
%cons_lo(inset=cons_lo_1993Q3_13, outset=cons_lo_1993Q3, lags=10, lagname=est_lo_lag10);

data lo.lo_cons_1993Q3;
set cons_lo_1993Q3;
run;


/*1993Q2 Consumer Originations Plus Lags*/
data cons_lo_1993Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 14 then delete;
run;
proc sql;
create table cons_lo_1993Q2_2 as select a.*, b.ta
from cons_lo_1993Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1993Q2_3;
set cons_lo_1993Q2_2;
if ta=. then delete;
run;
/*Add 1993Q2 Consumer loan originations*/
proc sql;
create table cons_lo_1993Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1993Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1993Q2_4;
set cons_lo_1993Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1993Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19930630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1993Q2_4, outset=cons_lo_1993Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1993Q2_5, outset=cons_lo_1993Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1993Q2_6, outset=cons_lo_1993Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1993Q2_7, outset=cons_lo_1993Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1993Q2_8, outset=cons_lo_1993Q2_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1993Q2_9, outset=cons_lo_1993Q2_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1993Q2_10, outset=cons_lo_1993Q2_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1993Q2_11, outset=cons_lo_1993Q2_12, lags=8, lagname=est_lo_lag8);
%cons_lo(inset=cons_lo_1993Q2_12, outset=cons_lo_1993Q2, lags=9, lagname=est_lo_lag9);

data lo.lo_cons_1993Q2;
set cons_lo_1993Q2;
run;


/*1993Q1 Consumer Originations Plus Lags*/
data cons_lo_1993Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 13 then delete;
run;
proc sql;
create table cons_lo_1993Q1_2 as select a.*, b.ta
from cons_lo_1993Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1993Q1_3;
set cons_lo_1993Q1_2;
if ta=. then delete;
run;
/*Add 1993Q1 Consumer loan originations*/
proc sql;
create table cons_lo_1993Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1993Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1993Q1_4;
set cons_lo_1993Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1993Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19930331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1993Q1_4, outset=cons_lo_1993Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1993Q1_5, outset=cons_lo_1993Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1993Q1_6, outset=cons_lo_1993Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1993Q1_7, outset=cons_lo_1993Q1_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1993Q1_8, outset=cons_lo_1993Q1_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1993Q1_9, outset=cons_lo_1993Q1_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1993Q1_10, outset=cons_lo_1993Q1_11, lags=7, lagname=est_lo_lag7);
%cons_lo(inset=cons_lo_1993Q1_11, outset=cons_lo_1993Q1, lags=8, lagname=est_lo_lag8);

data lo.lo_cons_1993Q1;
set cons_lo_1993Q1;
run;


/*1992*/

/*1992 Q4 Consumer Originations Plus Lags*/
data cons_lo_1992Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 12 then delete;
run;
proc sql;
create table cons_lo_1992Q4_2 as select a.*, b.ta
from cons_lo_1992Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1992Q4_3;
set cons_lo_1992Q4_2;
if ta=. then delete;
run;
/*Add 1992 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_1992Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1992Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1992Q4_4;
set cons_lo_1992Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19921231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1992Q4_4, outset=cons_lo_1992Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1992Q4_5, outset=cons_lo_1992Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1992Q4_6, outset=cons_lo_1992Q4_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1992Q4_7, outset=cons_lo_1992Q4_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1992Q4_8, outset=cons_lo_1992Q4_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1992Q4_9, outset=cons_lo_1992Q4_10, lags=6, lagname=est_lo_lag6);
%cons_lo(inset=cons_lo_1992Q4_10, outset=cons_lo_1992Q4, lags=7, lagname=est_lo_lag7);

data lo.lo_cons_1992Q4;
set cons_lo_1992Q4;
run;


/*1992Q3 Consumer Originations Plus Lags*/
data cons_lo_1992Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 11 then delete;
run;
proc sql;
create table cons_lo_1992Q3_2 as select a.*, b.ta
from cons_lo_1992Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1992Q3_3;
set cons_lo_1992Q3_2;
if ta=. then delete;
run;
/*Add 1992Q3 Consumer loan originations*/
proc sql;
create table cons_lo_1992Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1992Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1992Q3_4;
set cons_lo_1992Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1992Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19920930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1992Q3_4, outset=cons_lo_1992Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1992Q3_5, outset=cons_lo_1992Q3_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1992Q3_6, outset=cons_lo_1992Q3_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1992Q3_7, outset=cons_lo_1992Q3_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1992Q3_8, outset=cons_lo_1992Q3_9, lags=5, lagname=est_lo_lag5);
%cons_lo(inset=cons_lo_1992Q3_9, outset=cons_lo_1992Q3, lags=6, lagname=est_lo_lag6);

data lo.lo_cons_1992Q3;
set cons_lo_1992Q3;
run;


/*1992Q2 Consumer Originations Plus Lags*/
data cons_lo_1992Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 10 then delete;
run;
proc sql;
create table cons_lo_1992Q2_2 as select a.*, b.ta
from cons_lo_1992Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1992Q2_3;
set cons_lo_1992Q2_2;
if ta=. then delete;
run;
/*Add 1992Q2 Consumer loan originations*/
proc sql;
create table cons_lo_1992Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1992Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1992Q2_4;
set cons_lo_1992Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1992Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19920630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1992Q2_4, outset=cons_lo_1992Q2_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1992Q2_5, outset=cons_lo_1992Q2_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1992Q2_6, outset=cons_lo_1992Q2_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1992Q2_7, outset=cons_lo_1992Q2_8, lags=4, lagname=est_lo_lag4);
%cons_lo(inset=cons_lo_1992Q2_8, outset=cons_lo_1992Q2, lags=5, lagname=est_lo_lag5);


data lo.lo_cons_1992Q2;
set cons_lo_1992Q2;
run;


/*1992Q1 Consumer Originations Plus Lags*/
data cons_lo_1992Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 9 then delete;
run;
proc sql;
create table cons_lo_1992Q1_2 as select a.*, b.ta
from cons_lo_1992Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1992Q1_3;
set cons_lo_1992Q1_2;
if ta=. then delete;
run;
/*Add 1992Q1 Consumer loan originations*/
proc sql;
create table cons_lo_1992Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1992Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1992Q1_4;
set cons_lo_1992Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1992Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19920331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1992Q1_4, outset=cons_lo_1992Q1_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1992Q1_5, outset=cons_lo_1992Q1_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1992Q1_6, outset=cons_lo_1992Q1_7, lags=3, lagname=est_lo_lag3);
%cons_lo(inset=cons_lo_1992Q1_7, outset=cons_lo_1992Q1, lags=4, lagname=est_lo_lag4);

data lo.lo_cons_1992Q1;
set cons_lo_1992Q1;
run;


/*1991*/

/*1991 Q4 Consumer Originations Plus Lags*/
data cons_lo_1991Q4 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 8 then delete;
run;
proc sql;
create table cons_lo_1991Q4_2 as select a.*, b.ta
from cons_lo_1991Q4 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1991Q4_3;
set cons_lo_1991Q4_2;
if ta=. then delete;
run;
/*Add 1991 Q4 Consumer loan originations*/
proc sql;
create table cons_lo_1991Q4_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1991Q4_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1991Q4_4;
set cons_lo_1991Q4_4a;
if est_lo_t = . then est_lo_t = 0;
run;

*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19911231 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1991Q4_4, outset=cons_lo_1991Q4_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1991Q4_5, outset=cons_lo_1991Q4_6, lags=2, lagname=est_lo_lag2);
%cons_lo(inset=cons_lo_1991Q4_6, outset=cons_lo_1991Q4, lags=3, lagname=est_lo_lag3);

data lo.lo_cons_1991Q4;
set cons_lo_1991Q4;
run;


/*1991Q3 Consumer Originations Plus Lags*/
data cons_lo_1991Q3 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 7 then delete;
run;
proc sql;
create table cons_lo_1991Q3_2 as select a.*, b.ta
from cons_lo_1991Q3 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1991Q3_3;
set cons_lo_1991Q3_2;
if ta=. then delete;
run;
/*Add 1991Q3 Consumer loan originations*/
proc sql;
create table cons_lo_1991Q3_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1991Q3_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1991Q3_4;
set cons_lo_1991Q3_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1991Q3*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19910930 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1991Q3_4, outset=cons_lo_1991Q3_5, lags=1, lagname=est_lo_lag1);
%cons_lo(inset=cons_lo_1991Q3_5, outset=cons_lo_1991Q3, lags=2, lagname=est_lo_lag2);

data lo.lo_cons_1991Q3;
set cons_lo_1991Q3;
run;


/*1991Q2 Consumer Originations Plus Lags*/
data cons_lo_1991Q2 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 6 then delete;
run;
proc sql;
create table cons_lo_1991Q2_2 as select a.*, b.ta
from cons_lo_1991Q2 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1991Q2_3;
set cons_lo_1991Q2_2;
if ta=. then delete;
run;
/*Add 1991Q2 Consumer loan originations*/
proc sql;
create table cons_lo_1991Q2_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1991Q2_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1991Q2_4;
set cons_lo_1991Q2_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1991Q2*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19910630 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

%cons_lo(inset=cons_lo_1991Q2_4, outset=cons_lo_1991Q2, lags=1, lagname=est_lo_lag1);

data lo.lo_cons_1991Q2;
set cons_lo_1991Q2;
run;


/*1991Q1 Consumer Originations Plus Lags*/
data cons_lo_1991Q1 (drop = permco link_start link_end);
set cecl_step1;
if rankdate ne 5 then delete;
run;
proc sql;
create table cons_lo_1991Q1_2 as select a.*, b.ta
from cons_lo_1991Q1 as a left join ta as b
on a.snlkey=b.snlkey and a.rankdate=b.rankdate;
quit;
data cons_lo_1991Q1_3;
set cons_lo_1991Q1_2;
if ta=. then delete;
run;
/*Add 1991Q1 Consumer loan originations*/
proc sql;
create table cons_lo_1991Q1_4a as select a.*, b.est_lo as est_lo_t format 12.0
from cons_lo_1991Q1_3 as a left join box.est_lo_cons as b
on a.rssd_id=b.reg_id and a.rankdate=b.rankdate order by a.name;
quit;
data cons_lo_1991Q1_4;
set cons_lo_1991Q1_4a;
if est_lo_t = . then est_lo_t = 0;
run;

/*CREATE LAGGED ORIGINATIONS FOR 1991Q1*/
*~~~~~~~~~*
MACRO
*~~~~~~~~~;
%macro cons_lo (inset=, outset=, lags=, lagname=);

proc sql;
create table step1 as select a.*, b.est_lo
from &inset as a left join box.est_lo_cons as b
on a.rssd_id=b.topid_19910331 and a.rankdate=b.rankdate+&lags order by a.name;

create table step2 as select *, sum(est_lo) as &lagname format 12.0
from step1 group by rssd_id order by name;
quit;
proc sort data=step2 nodupkey out=step3;
by rssd_id;
run;
data &outset (drop = est_lo);
set step3;
if &lagname = . then &lagname = 0;
run;
%mend;

data lo.lo_cons_1991Q1;
set cons_lo_1991Q1_4;
run;

data lo.lo_cons_1990_2016;
set 
lo.lo_cons_2016q4
lo.lo_cons_2016q3
lo.lo_cons_2016q2
lo.lo_cons_2016q1
lo.lo_cons_2015q4
lo.lo_cons_2015q3
lo.lo_cons_2015q2
lo.lo_cons_2015q1
lo.lo_cons_2014q4
lo.lo_cons_2014q3
lo.lo_cons_2014q2
lo.lo_cons_2014q1
lo.lo_cons_2013q4
lo.lo_cons_2013q3
lo.lo_cons_2013q2
lo.lo_cons_2013q1
lo.lo_cons_2012q4
lo.lo_cons_2012q3
lo.lo_cons_2012q2
lo.lo_cons_2012q1
lo.lo_cons_2011q4
lo.lo_cons_2011q3
lo.lo_cons_2011q2
lo.lo_cons_2011q1
lo.lo_cons_2010q4
lo.lo_cons_2010q3
lo.lo_cons_2010q2
lo.lo_cons_2010q1
lo.lo_cons_2009q4
lo.lo_cons_2009q3
lo.lo_cons_2009q2
lo.lo_cons_2009q1
lo.lo_cons_2008q4
lo.lo_cons_2008q3
lo.lo_cons_2008q2
lo.lo_cons_2008q1
lo.lo_cons_2007q4
lo.lo_cons_2007q3
lo.lo_cons_2007q2
lo.lo_cons_2007q1
lo.lo_cons_2006q4
lo.lo_cons_2006q3
lo.lo_cons_2006q2
lo.lo_cons_2006q1
lo.lo_cons_2005q4
lo.lo_cons_2005q3
lo.lo_cons_2005q2
lo.lo_cons_2005q1
lo.lo_cons_2004q4
lo.lo_cons_2004q3
lo.lo_cons_2004q2
lo.lo_cons_2004q1
lo.lo_cons_2003q4
lo.lo_cons_2003q3
lo.lo_cons_2003q2
lo.lo_cons_2003q1
lo.lo_cons_2002q4
lo.lo_cons_2002q3
lo.lo_cons_2002q2
lo.lo_cons_2002q1
lo.lo_cons_2001q4
lo.lo_cons_2001q3
lo.lo_cons_2001q2
lo.lo_cons_2001q1
lo.lo_cons_2000q4
lo.lo_cons_2000q3
lo.lo_cons_2000q2
lo.lo_cons_2000q1
lo.lo_cons_1999q4
lo.lo_cons_1999q3
lo.lo_cons_1999q2
lo.lo_cons_1999q1
lo.lo_cons_1998q4
lo.lo_cons_1998q3
lo.lo_cons_1998q2
lo.lo_cons_1998q1
lo.lo_cons_1997q4
lo.lo_cons_1997q3
lo.lo_cons_1997q2
lo.lo_cons_1997q1
lo.lo_cons_1996q4
lo.lo_cons_1996q3
lo.lo_cons_1996q2
lo.lo_cons_1996q1
lo.lo_cons_1995q4
lo.lo_cons_1995q3
lo.lo_cons_1995q2
lo.lo_cons_1995q1
lo.lo_cons_1994q4
lo.lo_cons_1994q3
lo.lo_cons_1994q2
lo.lo_cons_1994q1
lo.lo_cons_1993q4
lo.lo_cons_1993q3
lo.lo_cons_1993q2
lo.lo_cons_1993q1
lo.lo_cons_1992q4
lo.lo_cons_1992q3
lo.lo_cons_1992q2
lo.lo_cons_1992q1
lo.lo_cons_1991q4
lo.lo_cons_1991q3
lo.lo_cons_1991q2
lo.lo_cons_1991q1;
run;
